@@ -4,6 +4,12 @@
  */
 #ifdef WIN32
 
+#ifndef WIN32_LEAN_AND_MEAN
+# define WIN32_LEAN_AND_MEAN
+#endif
+#ifndef NOMINMAX
+# define NOMINMAX
+#endif
 #include <windows.h>
 
 // windows.h which defines a HUGE number of macros...
