@@ -3,7 +3,7 @@
  *  @file  ApproximationAlgorithmImplementation.cxx
  *  @brief Regression from a data sample upon a particular basis
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -45,50 +45,54 @@ ApproximationAlgorithmImplementation::ApproximationAlgorithmImplementation()
 /* Default constructor */
 ApproximationAlgorithmImplementation::ApproximationAlgorithmImplementation(const NumericalSample & x,
     const NumericalSample & y,
-    const Basis & psi)
+    const Basis & psi,
+    const Indices & indices)
   : PersistentObject()
   , x_(x)
   , y_(y)
   , weight_(NumericalPoint( x.getSize(), 1.0 ))
   , psi_(psi)
+  , I_p_(indices)
   , isAlreadyComputedCoefficients_(false)
   , residual_(0.0)
   , relativeError_(0.0)
   , verbose_(false)
 {
-  const UnsignedLong dataSize(x.getSize());
+  const UnsignedInteger dataSize(x.getSize());
   if (dataSize == 0) throw InvalidArgumentException(HERE) << "Error: cannot perform approximation based on an empty sample.";
   if (dataSize != y.getSize()) throw InvalidArgumentException(HERE) << "Error: cannot perform approximation based on samples of different size.";
   if (y.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: cannot perform approximation based on output sample of dimension different from 1.";
-  const UnsignedLong basisSize(psi.getSize());
-  for (UnsignedLong i = 0; i < basisSize; ++i)
-    if (psi[i].getOutputDimension() != 1) throw InvalidArgumentException(HERE) << "Error: can only use basis functions with 1D values.";
+//   const UnsignedInteger basisSize = indices.getSize();
+//   for (UnsignedInteger i = 0; i < basisSize; ++i)
+//     if (psi[i].getOutputDimension() != 1) throw InvalidArgumentException(HERE) << "Error: can only use basis functions with 1D values.";
 }
 
 /* Default constructor */
 ApproximationAlgorithmImplementation::ApproximationAlgorithmImplementation(const NumericalSample & x,
     const NumericalSample & y,
     const NumericalPoint & weight,
-    const Basis & psi)
+    const Basis & psi,
+    const Indices & indices)
   : PersistentObject()
   , x_(x)
   , y_(y)
   , weight_(weight)
   , psi_(psi)
+  , I_p_(indices)
   , isAlreadyComputedCoefficients_(false)
   , residual_(0.0)
   , relativeError_(0.0)
   , verbose_(false)
 {
-  UnsignedLong dataSize( x.getSize() );
+  UnsignedInteger dataSize( x.getSize() );
   if (dataSize == 0) throw InvalidArgumentException(HERE) << "Error: cannot perform approximation based on an empty sample.";
   if (dataSize != y.getSize()) throw InvalidArgumentException(HERE) << "Error: cannot perform approximation based on samples of different size.";
   if (y.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: cannot perform approximation based on output sample of dimension different from 1.";
-  const UnsignedLong basisSize(psi.getSize());
-  for (UnsignedLong i = 0; i < basisSize; ++i)
-    if (psi[i].getOutputDimension() != 1) throw InvalidArgumentException(HERE) << "Error: can only use basis functions with 1D values.";
+  //const UnsignedInteger basisSize = indices.getSize();
+//   for (UnsignedInteger i = 0; i < basisSize; ++i)
+//     if (psi[i].getOutputDimension() != 1) throw InvalidArgumentException(HERE) << "Error: can only use basis functions with 1D values.";
   if ( dataSize != weight.getDimension() ) throw InvalidArgumentException(HERE) << "Error: cannot perform approximation with weight of improper dimension.";
-  for ( UnsignedLong i = 0; i < dataSize; ++ i )
+  for ( UnsignedInteger i = 0; i < dataSize; ++ i )
     if ( weight[i] < 0.0 ) throw InvalidArgumentException(HERE) << "Error: can only use positive weight.";
 }
 
@@ -122,7 +126,13 @@ Basis ApproximationAlgorithmImplementation::getPsi() const
 /* Perform the selection */
 void ApproximationAlgorithmImplementation::run()
 {
-  throw NotYetImplementedException(HERE);
+  const DesignProxy proxy(x_, psi_);
+  run(proxy);
+}
+
+void ApproximationAlgorithmImplementation::run(const DesignProxy & proxy)
+{
+  throw NotYetImplementedException(HERE) << "In ApproximationAlgorithmImplementation::run(const DesignProxy & proxy)";
 }
 
 /* String converter */
@@ -197,6 +207,7 @@ void ApproximationAlgorithmImplementation::save(Advocate & adv) const
   adv.saveAttribute( "y_", y_ );
   adv.saveAttribute( "weight_", weight_ );
   adv.saveAttribute( "psi_", psi_ );
+  adv.saveAttribute( "I_p_", I_p_ );
   adv.saveAttribute( "verbose_", verbose_ );
 }
 
@@ -209,6 +220,7 @@ void ApproximationAlgorithmImplementation::load(Advocate & adv)
   adv.loadAttribute( "y_", y_ );
   adv.loadAttribute( "weight_", weight_ );
   adv.loadAttribute( "psi_", psi_ );
+  adv.loadAttribute( "I_p_", I_p_ );
   adv.loadAttribute( "verbose_", verbose_ );
   isAlreadyComputedCoefficients_ = false;
   residual_ = 0.0;
