@@ -3,7 +3,7 @@
  *  @file  ClassifierImplementation.cxx
  *  @brief Classification algorithm base type
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -57,18 +57,17 @@ ClassifierImplementation * ClassifierImplementation::clone() const
 
 
 /* Classify a sample */
-UnsignedLong ClassifierImplementation::classify(const NumericalPoint & inP) const
+UnsignedInteger ClassifierImplementation::classify(const NumericalPoint & inP) const
 {
-  throw NotYetImplementedException(HERE) << "ClassifierImplementation::classify";
-  return 0;
+  throw NotYetImplementedException(HERE) << "In ClassifierImplementation::classify(const NumericalPoint & inP) const";
 }
 
 /* Classify a sample */
 Indices ClassifierImplementation::classify(const NumericalSample & inS) const
 {
-  const UnsignedLong size(inS.getSize());
+  const UnsignedInteger size(inS.getSize());
   Indices prediction(size);
-  for ( UnsignedLong i = 0; i < size; ++ i )
+  for ( UnsignedInteger i = 0; i < size; ++ i )
   {
     prediction[i] = classify(inS[i]);
   }
@@ -76,20 +75,19 @@ Indices ClassifierImplementation::classify(const NumericalSample & inS) const
 }
 
 /* Grade a point */
-NumericalScalar ClassifierImplementation::grade(const NumericalPoint & inP, UnsignedLong hClass) const
+NumericalScalar ClassifierImplementation::grade(const NumericalPoint & inP, const UnsignedInteger hClass) const
 {
-  throw NotYetImplementedException(HERE) << "ClassifierImplementation::grade";
-  return 0.0;
+  throw NotYetImplementedException(HERE) << "In ClassifierImplementation::grade(const NumericalPoint & inP, const UnsignedInteger hClass) const";
 }
 
 /* Grade a sample */
 NumericalPoint ClassifierImplementation::grade(const NumericalSample & inS, const Indices & hClass) const
 {
-  const UnsignedLong size(inS.getSize());
+  const UnsignedInteger size(inS.getSize());
   if ( size != hClass.getSize() )
     throw InvalidDimensionException(HERE) << "Input sample dimension (=" << size << ") and classes dimension (=" << hClass.getSize() << ") do not match.";
   NumericalPoint grades(size);
-  for ( UnsignedLong i = 0; i < size; ++ i )
+  for ( UnsignedInteger i = 0; i < size; ++ i )
   {
     grades[i] = grade(inS[i], hClass[i]);
   }
@@ -123,7 +121,7 @@ Bool ClassifierImplementation::getVerbose() const
 }
 
 /* Input space dimension accessor */
-UnsignedLong ClassifierImplementation::getDimension() const
+UnsignedInteger ClassifierImplementation::getDimension() const
 {
   return inputSample_.getDimension();
 }
