@@ -3,7 +3,7 @@
  *  @file  FittingAlgorithm.cxx
  *  @brief Cross-validation algorithm interface
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -63,12 +63,17 @@ String FittingAlgorithm::__str__(const String & offset) const
   return getImplementation()->__str__( offset );
 }
 
-/* Perform cross-validation */
 NumericalScalar FittingAlgorithm::run(const NumericalSample & x,
                                       const NumericalSample & y,
-                                      const Basis & basis) const
+                                      const Basis & basis,
+                                      const Indices & indices) const
 {
-  return getImplementation()->run( x, y, basis );
+  return getImplementation()->run(x, y, basis, indices);
+}
+
+NumericalScalar FittingAlgorithm::run(const NumericalSample & y, const Indices & indices, const DesignProxy & proxy) const
+{
+  return getImplementation()->run(y, indices, proxy);
 }
 
 
