@@ -3,7 +3,7 @@
  *  @file  LeastSquaresMetaModelSelectionFactory.cxx
  *  @brief A factory for building LeastSquaresMetaModelSelectionFactory objects
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -78,9 +78,10 @@ String LeastSquaresMetaModelSelectionFactory::__repr__() const
 LeastSquaresMetaModelSelection * LeastSquaresMetaModelSelectionFactory::build(const NumericalSample & x,
     const NumericalSample & y,
     const NumericalPoint & weight,
-    const Basis & psi) const
+    const Basis & psi,
+    const Indices & indices) const
 {
-  return new LeastSquaresMetaModelSelection( x, y, weight, psi, basisSequenceFactory_, fittingAlgorithm_ );
+  return new LeastSquaresMetaModelSelection( x, y, weight, psi, indices, basisSequenceFactory_, fittingAlgorithm_ );
 }
 
 /* Method save() stores the object through the StorageManager */
