@@ -3,7 +3,7 @@
  *  @file  PenalizedLeastSquaresAlgorithm.cxx
  *  @brief This Penalized Least Squares Algorithm as a functor class
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -30,16 +30,15 @@
 
 BEGIN_NAMESPACE_OPENTURNS
 
-
-
 CLASSNAMEINIT(PenalizedLeastSquaresAlgorithm);
 
 static Factory<PenalizedLeastSquaresAlgorithm> RegisteredFactory("PenalizedLeastSquaresAlgorithm");
 
 
 /* Default constructor */
-PenalizedLeastSquaresAlgorithm::PenalizedLeastSquaresAlgorithm()
+PenalizedLeastSquaresAlgorithm::PenalizedLeastSquaresAlgorithm(const Bool useNormal)
   : ApproximationAlgorithmImplementation()
+  , useNormal_(useNormal)
 {
   // Nothing to do
 }
@@ -47,61 +46,77 @@ PenalizedLeastSquaresAlgorithm::PenalizedLeastSquaresAlgorithm()
 /* Parameters constructor */
 PenalizedLeastSquaresAlgorithm::PenalizedLeastSquaresAlgorithm(const NumericalSample & x,
     const NumericalSample & y,
-    const NumericalMathFunctionCollection & psi,
-    const NumericalScalar penalizationFactor)
-  : ApproximationAlgorithmImplementation( x, y, psi ),
-    penalizationFactor_(penalizationFactor),
-    penalizationMatrix_(0)
-{
-  // If the penalization factor is strictly positive, use the identity matrix as a penalization term
-  if (penalizationFactor > 0.0)
-  {
-    const UnsignedLong basisSize(psi.getSize());
-    penalizationMatrix_ = IdentityMatrix(basisSize);
-  }
-}
-
-
-/* Parameters constructor */
-PenalizedLeastSquaresAlgorithm::PenalizedLeastSquaresAlgorithm(const NumericalSample & x,
-    const NumericalSample & y,
-    const NumericalPoint & weight,
-    const NumericalMathFunctionCollection & psi,
-    const NumericalScalar penalizationFactor)
-  : ApproximationAlgorithmImplementation( x, y, weight, psi ),
-    penalizationFactor_(penalizationFactor),
-    penalizationMatrix_(0)
-{
-  // If the penalization factor is strictly positive, use the identity matrix as a penalization term
-  if (penalizationFactor > 0.0)
-  {
-    const UnsignedLong basisSize(psi.getSize());
-    penalizationMatrix_ = IdentityMatrix(basisSize);
-  }
-}
-
-/* Parameters constructor */
-PenalizedLeastSquaresAlgorithm::PenalizedLeastSquaresAlgorithm(const NumericalSample & x,
-    const NumericalSample & y,
-    const NumericalPoint & weight,
-    const NumericalMathFunctionCollection & psi,
+    const Basis & psi,
+    const Indices & indices,
     const NumericalScalar penalizationFactor,
-    const CovarianceMatrix & penalizationMatrix)
-  : ApproximationAlgorithmImplementation( x, y, weight, psi ),
-    penalizationFactor_(penalizationFactor),
-    penalizationMatrix_(penalizationMatrix)
+    const Bool useNormal)
+  : ApproximationAlgorithmImplementation( x, y, psi, indices )
+  , penalizationFactor_(penalizationFactor)
+  , penalizationMatrix_(0)
+  , useNormal_(useNormal)
 {
-  const UnsignedLong basisSize(psi.getSize());
+  // If the penalization factor is strictly positive, use the identity matrix as a penalization term
+  if (penalizationFactor > 0.0)
+  {
+    const UnsignedInteger basisSize(indices.getSize());
+    penalizationMatrix_ = IdentityMatrix(basisSize);
+  }
+}
+
+
+/* Parameters constructor */
+PenalizedLeastSquaresAlgorithm::PenalizedLeastSquaresAlgorithm(const NumericalSample & x,
+    const NumericalSample & y,
+    const NumericalPoint & weight,
+    const Basis & psi,
+    const Indices & indices,
+    const NumericalScalar penalizationFactor,
+    const Bool useNormal)
+  : ApproximationAlgorithmImplementation( x, y, weight, psi, indices )
+  , penalizationFactor_(penalizationFactor)
+  , penalizationMatrix_(0)
+  , useNormal_(useNormal)
+{
+  // If the penalization factor is strictly positive, use the identity matrix as a penalization term
+  if (penalizationFactor > 0.0)
+  {
+    const UnsignedInteger basisSize(indices.getSize());
+    penalizationMatrix_ = IdentityMatrix(basisSize);
+  }
+}
+
+/* Parameters constructor */
+PenalizedLeastSquaresAlgorithm::PenalizedLeastSquaresAlgorithm(const NumericalSample & x,
+    const NumericalSample & y,
+    const NumericalPoint & weight,
+    const Basis & psi,
+    const Indices & indices,
+    const NumericalScalar penalizationFactor,
+    const CovarianceMatrix & penalizationMatrix,
+    const Bool useNormal)
+  : ApproximationAlgorithmImplementation( x, y, weight, psi, indices )
+  , penalizationFactor_(penalizationFactor)
+  , penalizationMatrix_(penalizationMatrix)
+  , useNormal_(useNormal)
+{
+  const UnsignedInteger basisSize(indices.getSize());
   // Check if the penalization matrix has the proper dimension
   if (penalizationMatrix_.getDimension() != basisSize) throw InvalidArgumentException(HERE) << "Error: the given penalization matrix has an improper dimension.";
+  // Must const_cast here because the isPositiveDefinite() method is not const in
+  // the general case, but no modification will occur here.
   if (!const_cast<CovarianceMatrix*>(&penalizationMatrix)->isPositiveDefinite()) throw NotSymmetricDefinitePositiveException(HERE) << "Error: the given penalization matrix is not strictly definite positive.";
 }
 
-/* Perform the optimization */
 void PenalizedLeastSquaresAlgorithm::run()
 {
-  const UnsignedLong basisDimension(psi_.getSize());
-  const UnsignedLong sampleSize(x_.getSize());
+  ApproximationAlgorithmImplementation::run();
+}
+
+/* Perform the optimization */
+void PenalizedLeastSquaresAlgorithm::run(const DesignProxy & proxy)
+{
+  const UnsignedInteger basisDimension = I_p_.getSize();
+  const UnsignedInteger sampleSize(x_.getSize());
   Matrix basisMatrix;
   NumericalPoint rightHandSide;
   // If there is a penalization term, augment the dimension of the matrix and the right hand side
@@ -117,35 +132,56 @@ void PenalizedLeastSquaresAlgorithm::run()
   }
   NumericalPoint weightSquareRoot(sampleSize);
   // Build the right-hand side
-  for (UnsignedLong rowIndex = 0; rowIndex < sampleSize; ++rowIndex)
+  for (UnsignedInteger rowIndex = 0; rowIndex < sampleSize; ++rowIndex)
   {
     weightSquareRoot[rowIndex] = sqrt(weight_[rowIndex]);
     rightHandSide[rowIndex] = weightSquareRoot[rowIndex] * y_[rowIndex][0];
   }
   // Build the matrix column-wise
-  for (UnsignedLong functionIndex = 0; functionIndex < basisDimension; ++functionIndex)
+  for (UnsignedInteger functionIndex = 0; functionIndex < basisDimension; ++functionIndex)
   {
-    NumericalSample functionSample(psi_[functionIndex](x_));
     // Fill-in the matrix column
-    for (UnsignedLong rowIndex = 0; rowIndex < sampleSize; ++rowIndex)
+    for (UnsignedInteger rowIndex = 0; rowIndex < sampleSize; ++rowIndex)
     {
-      basisMatrix(rowIndex, functionIndex) = functionSample[rowIndex][0] * weightSquareRoot[rowIndex];
+      basisMatrix(rowIndex, functionIndex) = proxy.operator()(rowIndex, I_p_[functionIndex]) * weightSquareRoot[rowIndex];
     }
   }
   // If there is a penalization term, add the penalization matrix to the basis matrix
   if (penalizationFactor_ > 0.0)
   {
-    const Matrix transposedSquareRootPenalizationMatrix(sqrt(penalizationFactor_) * penalizationMatrix_.computeCholesky());
-    for (UnsignedLong i = 0; i < basisDimension; ++i)
+    const TriangularMatrix transposedSquareRootPenalizationMatrix(sqrt(penalizationFactor_) * penalizationMatrix_.computeCholesky());
+    for (UnsignedInteger i = 0; i < basisDimension; ++i)
     {
       // The cholesky factor has to be transposed, thus we fill only the upper triangular part of the trailing block
-      for (UnsignedLong j = i; j < basisDimension; ++j)
+      for (UnsignedInteger j = i; j < basisDimension; ++j)
         basisMatrix(sampleSize + i, j) = transposedSquareRootPenalizationMatrix(j, i);
     }
   }
   // Solve the linear system (least squares solution)
-  setCoefficients( basisMatrix.solveLinearSystem( rightHandSide ) );
-
+  // If we can use the normal equation (fastest method, not very stable)
+  Bool isSolved(false);
+  // The normal matrix will be singular if not enough rows
+  if (useNormal_ && (basisMatrix.getNbRows() >= basisMatrix.getNbColumns()))
+  {
+    try
+    {
+      LOGINFO("In PenalizedLeastSquaresAlgorithm::run(), use normal equation");
+      CovarianceMatrix normalMatrix(basisMatrix.computeGram());
+      setCoefficients( normalMatrix.solveLinearSystem(basisMatrix.transpose() * rightHandSide, false) );
+      isSolved = true;
+    }
+    catch (NotDefinedException & ex)
+    {
+      LOGINFO(OSS() << ex);
+      isSolved = false;
+    }
+  }
+  // Use the QR decomposition, slowest but more stable and able to deal with singular cases
+  if (!(useNormal_ && isSolved))
+  {
+    LOGINFO("In PenalizedLeastSquaresAlgorithm::run(), use QR decomposition");
+    setCoefficients( basisMatrix.solveLinearSystem( rightHandSide ) );
+  }
   const NumericalScalar quadraticResidual( (basisMatrix * getCoefficients() - rightHandSide).normSquare() );
 
   // The residual is the mean L2 norm of the fitting
@@ -154,7 +190,7 @@ void PenalizedLeastSquaresAlgorithm::run()
   const NumericalScalar empiricalError( quadraticResidual / sampleSize );
 
   // The relative error
-  setRelativeError( empiricalError / y_.computeVariancePerComponent()[0] );
+  setRelativeError( empiricalError / y_.computeVariance()[0] );
 }
 
 
@@ -192,6 +228,4 @@ void PenalizedLeastSquaresAlgorithm::load(Advocate & adv)
   adv.loadAttribute( "penalizationMatrix_", penalizationMatrix_ );
 }
 
-
-
 END_NAMESPACE_OPENTURNS
