@@ -3,7 +3,7 @@
  *  @file  ComparisonOperatorImplementation.cxx
  *  @brief Abstract top-level class for all ComparisonOperatorImplementation
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -47,7 +47,7 @@ ComparisonOperatorImplementation * ComparisonOperatorImplementation::clone() con
 Bool ComparisonOperatorImplementation::operator() (const NumericalScalar a,
     const NumericalScalar b) const
 {
-  throw NotYetImplementedException(HERE);
+  throw NotYetImplementedException(HERE) << "In ComparisonOperatorImplementation::operator() (const NumericalScalar a, const NumericalScalar b) const";
 }
 
 /* String converter */
