@@ -3,7 +3,7 @@
  *  @file  Path.cxx
  *  @brief This class provides all the treatments for wrapper file manipulation
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -29,8 +29,13 @@
 #ifdef WIN32
 #include <fstream>                // for ofstream
 #include "OTwindows.h"            // for GetTempFileName, GetModuleFileName
+#ifdef _MSC_VER
+# include <direct.h>
+#define mkdir(p)  _mkdir(p)
+#else  /* _MSC_VER */
 #include <libgen.h>               // for dirname
-#endif
+#endif /* _MSC_VER */
+#endif /* WIN32 */
 #include <sys/types.h>            // for stat
 #include <sys/stat.h>             // for stat
 #include <unistd.h>               // for stat
@@ -91,10 +96,6 @@ const char * Path::PrefixWrapperSubdirectory_ = "/lib/openturns/wrappers";
 /* The 'openturns' configuration subdirectory path */
 const char * Path::PrefixConfigSubdirectory_ = "/openturns";
 
-/* The 'openturns' module subdirectory path */
-const char * Path::PrefixModuleSubdirectory_ = "/lib/openturns/module";
-
-
 /*
  * Default constructor
  */
@@ -136,44 +137,28 @@ FileName Path::GetWinDirectory()
   // get python.exe absolute path
   TCHAR szPath[MAX_PATH];
   GetModuleFileName(NULL, szPath, MAX_PATH);
-  // add path to openturns module
+#ifdef _MSC_VER
+  // remove executable name
+  String otModulePath(szPath);
+  if (otModulePath.empty()) return otModulePath;
+  for(UnsignedInteger i = otModulePath.size() - 1; i >= 0; --i)
+  {
+    /* We do not care about escaped backslashes */
+    if(otModulePath.at(i) == '\\')
+    {
+      otModulePath.resize(i);
+      break;
+    }
+  }
+#else
   String otModulePath(dirname(szPath));
+#endif
+  // add path to openturns module
   otModulePath += "\\Lib\\site-packages\\openturns";
   return otModulePath;
 }
 #endif
 
-/**
- * Return the path of the module standard directory
- *
- * The search rule is: check the following paths, in that order:
- *    + if the env var OPENTURNS_HOME exists, return ${OPENTURNS_HOME}/lib/openturns/module if it
- *      exists and is a directory,
- *    + otherwise return the installation path ${prefix}/lib/openturns/module, where 'prefix' is
- *      the installation path of the platform as provided at configuration time.
- */
-FileName Path::GetModuleDirectory()
-{
-  FileName directory;
-  bool dirExists = false;
-  const char * otHome = getenv(OPENTURNS_HOME_ENV_VAR);
-  if (otHome)
-  {
-    directory = String(otHome);
-#ifndef WIN32
-    directory += PrefixModuleSubdirectory_;
-#endif
-    struct stat status;
-    dirExists = (stat( directory.c_str(), &status ) == 0 && ( status.st_mode & S_IFDIR ));
-  }
-  if (!dirExists)
-  {
-    directory = String(INSTALL_PATH) + PrefixModuleSubdirectory_;
-  }
-  return directory;
-}
-
-
 /**
  * Analyse the process environment and return the directory where
  * installed wrappers and DTD are.
@@ -228,8 +213,8 @@ Path::DirectoryList Path::GetWrapperDirectoryList()
   if (openturnsWrapperDirectory)
   {
     std::string  pathToSplit = openturnsWrapperDirectory;
-    UnsignedLong lastColonPosition = 0;
-    UnsignedLong currentColonPosition = 0;
+    String::size_type lastColonPosition = 0;
+    String::size_type currentColonPosition = 0;
     while ( ((currentColonPosition = pathToSplit.find(Os::GetDirectoryListSeparator(), lastColonPosition)) != String::npos) &&
             ( currentColonPosition < pathToSplit.size() ) )
     {
@@ -286,8 +271,8 @@ Path::DirectoryList Path::GetConfigDirectoryList()
   if (openturnsConfigDirectory)
   {
     std::string  pathToSplit = openturnsConfigDirectory;
-    UnsignedLong lastColonPosition = 0;
-    UnsignedLong currentColonPosition = 0;
+    String::size_type lastColonPosition = 0;
+    String::size_type currentColonPosition = 0;
     while ( ((currentColonPosition = pathToSplit.find(Os::GetDirectoryListSeparator(), lastColonPosition)) != String::npos) &&
             ( currentColonPosition < pathToSplit.size() ) )
     {
@@ -399,7 +384,7 @@ FileName Path::FindFileByNameInDirectoryList(const FileName & name,
  */
 void Path::AntislashFileName(FileName & filename)
 {
-  UnsignedLong i;
+  UnsignedInteger i;
   for(i = 0; i < filename.size(); i++)
     if(filename.at(i) == '/')
       filename.at(i) = '\\';
@@ -411,8 +396,7 @@ void Path::AntislashFileName(FileName & filename)
  */
 void Path::DoubleslashFileName(FileName & filename)
 {
-  SignedInteger loc = 0;
-  loc = filename.find(Os::GetDirectorySeparator());
+  String::size_type loc = filename.find(Os::GetDirectorySeparator());
   while(loc != String::npos)
   {
     // "\" at the last pos
@@ -462,7 +446,7 @@ FileName Path::BuildTemporaryFileName(const FileName & pattern)
 {
 #ifndef WIN32
   String fullPattern(GetTemporaryDirectory() + String(Os::GetDirectorySeparator()) + pattern);
-  UnsignedLong size(fullPattern.size());
+  UnsignedInteger size(fullPattern.size());
   char temporaryFileName[size + 1];
   strcpy(temporaryFileName, fullPattern.c_str());
   temporaryFileName[size] = 0;
@@ -541,11 +525,8 @@ String Path::CreateTemporaryDirectory (const FileName & directoryPrefix)
  */
 void Path::DeleteTemporaryDirectory (const FileName & directoryName)
 {
-  struct WrapperError wrapperError;
-  if (deleteDirectory( directoryName.c_str(), &wrapperError ))
-    LOGWARN( OSS() << "Can't remove temporary directory  " << directoryName
-             << ". Reason: " << getWrapperError(&wrapperError) );
-
+  if (Os::DeleteDirectory( directoryName))
+    LOGWARN( OSS() << "Can't remove temporary directory  " << directoryName );
 }
 
 
