@@ -3,7 +3,7 @@
  *  @file  PersistentObject.cxx
  *  @brief Class PersistentObject saves and reloads the object's internal state
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -27,18 +27,6 @@
 
 BEGIN_NAMESPACE_OPENTURNS
 
-/*
- * The default name of any object
- */
-const String DefaultName = String(
-#ifdef OBJECT_DEFAULT_NAME
-                             OBJECT_DEFAULT_NAME
-#else
-                             "Unnamed"
-#endif
-                           );
-
-
 
 CLASSNAMEINIT(PersistentObject);
 
@@ -72,7 +60,7 @@ void PersistentObject::save(Advocate & adv) const
 {
   adv.saveAttribute( "class", getClassName() );
   adv.saveAttribute( "id", id_ );
-  if ( hasName() )
+  if ( hasVisibleName() )
   {
     adv.saveAttribute( "name", getName() );
   }
