@@ -3,7 +3,7 @@
  *  @file  PlatformInfo.cxx
  *  @brief The class PlatformInfo gives information about the library
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -31,7 +31,7 @@ BEGIN_NAMESPACE_OPENTURNS
 
 
 
-UnsignedLong PlatformInfo::Precision_ = 6;
+UnsignedInteger PlatformInfo::Precision_ = 6;
 
 PlatformInfo::PlatformInfo()
 {
@@ -63,17 +63,12 @@ String PlatformInfo::GetInstallationDirectory()
   return InstallationDirectory;
 }
 
-String PlatformInfo::GetModuleDirectory()
-{
-  return ModuleDirectory;
-}
-
 String PlatformInfo::GetConfigureCommandLine()
 {
   return ConfigureArgs;
 }
 
-UnsignedLong PlatformInfo::GetNumericalPrecision()
+UnsignedInteger PlatformInfo::GetNumericalPrecision()
 {
   return PlatformInfo::Precision_;
 }
