@@ -3,7 +3,7 @@
  *  @file  Study.cxx
  *  @brief Study keeps all PersistentObjects in a file
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -92,7 +92,7 @@ String Study::__str__(const String & offset) const
   for(Map::const_iterator it = map_.begin(); it != map_.end(); ++it, separator = "\n  ")
   {
     oss << separator << (*it).first << " => " << ((*it).second)->getClassName() << "\n"
-        << ((*it).second)->__str__( String( 7 + int( ((*it).first != 0 ? log10((*it).first) : 1) ), ' ') );
+        << ((*it).second)->__str__( String( 7 + int( ((*it).first != 0 ? log10(static_cast<double>((*it).first)) : 1) ), ' ') );
   }
   oss << "\n";
   separator = "  ";
@@ -386,11 +386,13 @@ void Study::add(const String & label, const PersistentObject * po, Bool force)
   defineLabel( po->getShadowedId(), label );
 }
 
-
-
-
-
-
-
+/* Print all the labels in the study */
+String Study::printLabels() const
+{
+  OSS oss;
+  String separator("");
+  for(Map::const_iterator it = map_.begin(); it != map_.end(); ++it, separator = ";") oss << separator << (*it).first;
+  return oss;
+}
 
 END_NAMESPACE_OPENTURNS
