@@ -3,7 +3,7 @@
  * @file  WrapperCommon.cxx
  * @brief This file provides objects and functions commonly used by wrappers
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -31,7 +31,16 @@
 #define _DARWIN_C_SOURCE
 #endif
 
+#ifdef _MSC_VER
+# include <direct.h>
+# define mkdir(p)  _mkdir(p)
+#include <BaseTsd.h>
+typedef SSIZE_T ssize_t;
+#endif
+
+#ifndef _MSC_VER
 #include <sys/time.h>  // for select(2)
+#endif
 #include <sys/types.h> // for select(2)
 #include <sys/stat.h>
 #include <ctype.h>
@@ -39,7 +48,9 @@
 #include <malloc.h>
 #endif
 #include <unistd.h>    // for select(2)
+#ifndef _MSC_VER
 #include <libgen.h>    // for dirname(3)
+#endif
 #include <cstring>
 #include <fcntl.h>
 #include <cerrno>
@@ -916,12 +927,13 @@ extern char * wrapper_createTemporaryDirectory(const char * tempDirPrefix,
     void * p_error)
 {
   char * tempDirName = NULL;
-  char * name = NULL;
   const char sfx[] = "_XXXXXX";
-  ssize_t len = 0;
   int myerrno UNUSED;
 #ifdef WIN32
   int ret = 0;
+#else
+  char * name = NULL;
+  ssize_t len = 0;
 #endif
 
   if ( (tempDirPrefix == 0) || (strlen(tempDirPrefix) == 0) )
@@ -1079,6 +1091,21 @@ extern void wrapper_deleteTemporaryDirectory(char * tempDir,
  */
 extern char * wrapper_getCurrentWorkingDirectory(void * p_error)
 {
+#ifdef _MSC_VER
+  DWORD dwSize = MAX_PATH;
+  char * path = (char*) calloc(dwSize, sizeof(char));
+  if (path == NULL)
+  {
+    wrapper_setError( p_error, "(wrapper_getCurrentWorkingDirectory) Can't build directory name" );
+    return NULL;
+  }
+  if ( GetCurrentDirectory(dwSize, path) > 0 )
+    return path;
+
+  delete path;
+  wrapper_setError( p_error, "(getCurrentWorkingDirectory) Can NOT get current working directory" );
+  return NULL;
+#else
   long size = BUFFER_LENGTH;
   char * path = NULL;
   char * buf = NULL;
@@ -1108,6 +1135,7 @@ extern char * wrapper_getCurrentWorkingDirectory(void * p_error)
   }
 
   return path;
+#endif
 }
 
 
@@ -1800,7 +1828,7 @@ extern long wrapper_runInsulatedCommand(const char * temporaryDir,
   {
     struct timeval tv;
     tv.tv_sec  = 0;
-    tv.tv_usec = ResourceMap::GetAsUnsignedLong("slow-filesystem-wait-time");
+    tv.tv_usec = ResourceMap::GetAsUnsignedInteger("slow-filesystem-wait-time");
     FSLOCK( rc = access( cmd2, R_OK ); myerrno = errno; );
     while ( (retries-- > 0) && (rc == -1) )
     {
@@ -1842,19 +1870,14 @@ extern long wrapper_runInsulatedCommand(const char * temporaryDir,
   rc = 0;
   retries = wrapper_getRunCommandRetries( p_exchangedData );
   {
+    long waitfor = ResourceMap::GetAsUnsignedInteger("slow-filesystem-error-recovery");
+#ifndef WIN32
     const long MICROSECONDS = 1000 * 1000;
-    long waitfor = ResourceMap::GetAsUnsignedLong("slow-filesystem-error-recovery");
     struct timeval tv;
     tv.tv_sec  = waitfor / MICROSECONDS;
     tv.tv_usec = waitfor % MICROSECONDS;
-#ifndef WIN32
     while ( (retries-- > 0) && ((rc = runCommand( cmd2, temporaryDir, p_exchangedData, p_point, p_error)) == 33) )
     {
-#else /* WIN32 */
-    while ( (retries-- > 0) && ((rc = system( cmd2 )) != 0) )
-    {
-      rc = rc & 0xff; // WEXITSTATUS(rc)
-#endif /* WIN32 */
       if (Log::HasWrapper())
       {
         char * msg = newFormattedString( "Command %s failed to execute (execve failure). Try #%d out of %d",
@@ -1870,6 +1893,24 @@ extern long wrapper_runInsulatedCommand(const char * temporaryDir,
       tv.tv_sec  = waitfor / MICROSECONDS;
       tv.tv_usec = waitfor % MICROSECONDS;
     }
+#else /* WIN32 */
+    while ( (retries-- > 0) && ((rc = system( cmd2 )) != 0) )
+    {
+      rc = rc & 0xff; // WEXITSTATUS(rc)
+      if (Log::HasWrapper())
+      {
+        char * msg = newFormattedString( "Command %s failed to execute (execve failure). Try #%d out of %d",
+                                         cmd2,
+                                         wrapper_getRunCommandRetries( p_exchangedData ) - retries,
+                                         wrapper_getRunCommandRetries( p_exchangedData ) );
+        printToLogWrapper( "(runInsulatedCommand) %s", msg );
+        free( msg );
+      }
+      // Wait for 1s to ensure that the filesystem has been updated.
+      Sleep(waitfor * 1000);
+      waitfor *= 2;
+    }
+#endif /* WIN32 */
   }
 
   if (rc != 0)
