@@ -3,7 +3,7 @@
  * @file  WrapperCommonFunctions.cxx
  * @brief This file provides function tools for the wrapper library
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -35,8 +35,10 @@
 #ifndef WIN32
 #include <sys/wait.h>  // for waitpid(2)
 #endif
+#ifndef _MSC_VER
 #include <libgen.h>    // for dirname(3)
 #include <dirent.h>    // for scandir(3)
+#endif
 #include <sys/stat.h>  // for stat(2)
 #ifndef WIN32
 #include <ftw.h>       // for stat(2)
@@ -48,6 +50,50 @@
 #include "Exception.hxx"
 #include "TTY.hxx"
 
+
+#ifdef _MSC_VER
+#include <BaseTsd.h>
+#include <io.h>
+
+
+typedef SSIZE_T ssize_t;
+# define open  _open
+# define close _close
+# define creat _creat
+# define read  _read
+# define write _write
+# define S_ISDIR(mode)	(((mode) & S_IFDIR) != 0)
+
+# define va_copy(d,s) ((d) = (s))
+# define snprintf c99_snprintf
+
+static inline int c99_vsnprintf(char* str, size_t size, const char* format, va_list ap)
+{
+  int count = -1;
+
+  if (size != 0)
+    count = _vsnprintf_s(str, size, _TRUNCATE, format, ap);
+  if (count == -1)
+    count = _vscprintf(format, ap);
+
+  return count;
+}
+
+static inline int c99_snprintf(char* str, size_t size, const char* format, ...)
+{
+  int count;
+  va_list ap;
+
+  va_start(ap, format);
+  count = c99_vsnprintf(str, size, format, ap);
+  va_end(ap);
+
+  return count;
+}
+
+#endif /* _MSC_VER */
+
+
 #define SHELL_NAME "sh"
 #define SHELL_PATH "/bin/sh"
 
@@ -82,10 +128,12 @@ extern char ** environ; // Standard environment definition
 #endif
 
 pthread_mutex_t FileSystemMutex;
+
+
+
+#ifdef SLOW_FILESYSTEM
 static pthread_once_t FileSystemMutex_once = PTHREAD_ONCE_INIT;
 
-
-
 FileSystemMutex_init::FileSystemMutex_init()
 {
   int rc = pthread_once( &FileSystemMutex_once, FileSystemMutex_init::Initialization );
@@ -100,6 +148,7 @@ FileSystemMutex_init::FileSystemMutex_init()
 
 void FileSystemMutex_init::Initialization()
 {
+#ifndef OT_MUTEXINIT_NOCHECK
   pthread_mutexattr_t attr;
   pthread_mutexattr_init( &attr );
   //pthread_mutexattr_settype( &attr, PTHREAD_MUTEX_NORMAL );
@@ -111,8 +160,11 @@ void FileSystemMutex_init::Initialization()
     perror("FileSystemMutex_init::Initialization mutex initialization failed");
     exit(1);
   }
+#else
+  pthread_mutex_init( &FileSystemMutex, NULL );
+#endif
 }
-
+#endif // SLOW_FILESYSTEM
 
 
 using OT::ResourceMap;
@@ -190,13 +242,7 @@ static void printToLog(void (*func)(const OT::String & msg),
                        va_list args)
 {
   OT::OSS newfmt;
-  newfmt << "[tid=" <<
-#ifdef PTW32_VERSION          // pthreads-win32
-         pthread_self().p
-#else                         // winpthreads
-         pthread_self()
-#endif
-         << "] " << format;
+  newfmt << "[tid=" << pthread_self() << "] " << format;
   char * msg = vnewFormattedString( newfmt.str().c_str(), args );
   (*func)( msg );
   free( msg );
@@ -429,12 +475,16 @@ void initMutex(const struct WrapperExchangedData * p_exchangedData)
   ptr->p_lock_ = new pthread_mutex_t;
   assert(ptr->p_lock_);
 
+#ifndef OT_MUTEXINIT_NOCHECK
   pthread_mutexattr_t attr;
   pthread_mutexattr_init( &attr );
   //pthread_mutexattr_settype( &attr, PTHREAD_MUTEX_NORMAL );
   pthread_mutexattr_settype( &attr, PTHREAD_MUTEX_RECURSIVE );
   pthread_mutex_init( const_cast<pthread_mutex_t *>(ptr->p_lock_), &attr );
   pthread_mutexattr_destroy( &attr );
+#else
+  pthread_mutex_init( const_cast<pthread_mutex_t *>(ptr->p_lock_), NULL );
+#endif
 }
 
 
@@ -461,7 +511,7 @@ size_t _getNumberOfVariables(const struct WrapperExchangedData * p_exchangedData
   const struct WrapperVariableList * currentVariableElement = p_exchangedData->variableList_;
   while (currentVariableElement)
   {
-    if (static_cast<UnsignedLong>(currentVariableElement->variable_->type_) == type) ++number;
+    if (static_cast<UnsignedInteger>(currentVariableElement->variable_->type_) == type) ++number;
     currentVariableElement = currentVariableElement->next_;
   }
 
@@ -481,7 +531,7 @@ size_t _getNumberOfFiles(const struct WrapperExchangedData * p_exchangedData,
   const struct WrapperFileList * currentFileElement = p_exchangedData->fileList_;
   while (currentFileElement)
   {
-    if (static_cast<UnsignedLong>(currentFileElement->file_->type_) == type) ++number;
+    if (static_cast<UnsignedInteger>(currentFileElement->file_->type_) == type) ++number;
     currentFileElement = currentFileElement->next_;
   }
 
@@ -543,105 +593,17 @@ int createDirectory(const char * directory,
     return 1;
   }
 
-  // Root directory (/) and current directory (.) are supposed to exists
-  if (!strcmp( directory, "/" )) return 0;
-  if (!strcmp( directory, "." )) return 0;
-#ifdef WIN32
-  // Root directory (e.g. C:\) are supposed to exists
-  if ((strlen( directory ) == 3) &&
-      (directory[1] == ':') &&
-      (directory[2] == '\\' || directory[2] == '/'))
-    return 0;
-#endif
-
-
-  char * parent = strdup( directory );
-  parent = dirname( parent );
-  int rc = createDirectory( parent, p_error );
-  free( parent );
-  if (rc) return 1;
-
-  //IDM
-  // LOGTRACE( OT::String("IDM - ??? dir  : ") + directory );
-
-  struct stat file_stat;
-  FSLOCK( rc = stat( directory, &file_stat ) );
-  if (rc == 0)
+  const String path(directory);
+  if (Os::MakeDirectory(path))
   {
-    if (! S_ISDIR(file_stat.st_mode))
-    {
-      char msg[BUFFER_LENGTH];
-      snprintf( msg, BUFFER_LENGTH, "(createDirectory) %s exists and is NOT a directory", directory );
-      setWrapperError( p_error, msg );
-      return 1;
-    }
-
+    setWrapperError( p_error, "(createDirectory) Unable to create directory" );
+    return 1;
   }
-  else
-  {
-#ifndef WIN32
-    FSLOCK( rc = mkdir( directory, 0777 ) );
-#else
-    FSLOCK( rc = mkdir( directory ) );
-#endif
-    if (rc < 0)
-    {
-      char msg[BUFFER_LENGTH];
-      snprintf( msg, BUFFER_LENGTH, "(createDirectory) Can't create directory %s", directory );
-      setWrapperError( p_error, msg );
-      return 1;
-    } // else LOGTRACE( OT::String("IDM - Add dir  : ") + directory );
-
-  }
-
   return 0;
 }
 
 
 
-#ifndef WIN32
-static int deleteRegularFileOrDirectory(const char * path,
-                                        const struct stat * p_sb,
-                                        int typeflag,
-                                        struct FTW * ftwbuf)
-{
-  int rc;
-
-  switch (typeflag)
-  {
-    case FTW_DP:
-      FSLOCK( rc = rmdir( path ); );
-      if ( rc < 0 )
-      {
-        char * msg = newFormattedString( "(deleteRegularFileOrDirectory) Can NOT remove directory %s", path );
-        LOGWRAPPER( msg );
-        free( msg );
-        return 1;
-      }
-      break;
-
-    case FTW_SL:
-    case FTW_SLN:
-    case FTW_F:
-      FSLOCK( rc = unlink( path ); );
-      if ( rc < 0 )
-      {
-        char * msg = newFormattedString( "(deleteRegularFileOrDirectory) Can NOT remove file %s", path );
-        LOGWRAPPER( msg );
-        free( msg );
-        return 1;
-      }
-      break;
-
-  } /* end switch */
-
-  return 0;
-}
-#endif /* WIN32 */
-
-
-
-
 /* Delete a directory and all its content. Return non-null value on error */
 int deleteDirectory(const char * directory,
                     void * p_error)
@@ -652,104 +614,12 @@ int deleteDirectory(const char * directory,
     return 1;
   }
 
-  // Root directory (/) and current directory (.) are supposed to exists
-  if (!strcmp( directory, "/" ))
+  const String path(directory);
+  if (Os::DeleteDirectory(path))
   {
-    setWrapperError( p_error, "(deleteDirectory) Can't delete / directory" );
+    setWrapperError( p_error, "(deleteDirectory) Unable to delete directory" );
     return 1;
   }
-  if (!strcmp( directory, "." ))
-  {
-    setWrapperError( p_error, "(deleteDirectory) Can't delete . directory" );
-    return 1;
-  }
-#ifdef WIN32
-  if ( ((strlen( directory ) == 3) && (directory[1] == ':') && (directory[2] == '\\' || directory[2] == '/')) ||
-       ((strlen( directory ) == 2) && (directory[1] == ':')) )
-  {
-    setWrapperError( p_error, OT::String("(deleteDirectory) Can't delete ") + directory + " drive directory" );
-    return 1;
-  }
-#endif
-
-  struct stat file_stat;
-  int rc = 0;
-  FSLOCK( rc = stat( directory, &file_stat ) );
-  if (rc == 0)
-  {
-    if (! S_ISDIR(file_stat.st_mode))
-    {
-      char msg[BUFFER_LENGTH];
-      snprintf( msg, BUFFER_LENGTH, "(deleteDirectory) %s exists and is NOT a directory", directory );
-      setWrapperError( p_error, msg );
-      return 1;
-    }
-  }
-
-#ifndef WIN32
-
-  rc = nftw( directory, deleteRegularFileOrDirectory, 20, FTW_DEPTH );
-  if ( rc != 0 )
-  {
-    char msg[BUFFER_LENGTH];
-    snprintf( msg, BUFFER_LENGTH, "(deleteDirectory) Can't delete directory %s",
-              directory );
-    setWrapperError( p_error, msg );
-    return 1;
-  }
-
-#else /* WIN32 */
-
-  size_t timeout = ResourceMap::GetAsUnsignedLong("output-files-timeout");
-  size_t countdown = timeout;
-  OT::String rmdirCmd = OT::String("rmdir /Q /S \"") + directory + "\"";
-  int directoryExists;
-
-  do
-  {
-    // only show the output of the last try
-    if ( countdown <= 0 )
-      rc = system( rmdirCmd.c_str() );
-    else
-      rc = system( (rmdirCmd + " > NUL 2>&1").c_str() );
-    if ( rc != 0 )
-    {
-      char msg[BUFFER_LENGTH];
-      snprintf( msg, BUFFER_LENGTH, "(deleteDirectory) Can't delete directory %s. Command rmdir failed to execute. "
-                "Retry still %d times.", directory, countdown );
-      if ( countdown <= 0 )
-        printToLogWarn( msg );
-      else
-        printToLogDebug( msg );
-    }
-
-    // check if directory still there (rmdir dos command always return 0)
-    struct stat dir_stat;
-    directoryExists = stat( directory, &dir_stat );
-    if( directoryExists == 0 )
-    {
-      if  ( countdown <= 0 )
-      {
-        char msg[BUFFER_LENGTH];
-        snprintf( msg, BUFFER_LENGTH, "(deleteDirectory) Can't delete directory %s (after %i retry)",
-                  directory, timeout );
-        printToLogWarn( msg );
-        setWrapperError( p_error, msg );
-        return 1;
-      }
-      else
-      {
-        printToLogDebug( "(deleteDirectory) Can't delete directory %s. Wait the directory still %d times.",
-                         directory, countdown );
-        --countdown;
-      }
-    }
-    Sleep( 1000 );
-  }
-  while( directoryExists == 0 );
-
-#endif /* WIN32 */
-
   return 0;
 }
 
@@ -945,8 +815,17 @@ int writeFile(const char * path,
 
   /* Create all upper directories */
   char * copypath = strdup( path );
+#ifdef _MSC_VER
+  char * parent = strdup( copypath );
+  char * cp = parent + strlen(parent);
+  while (*cp != '\\' && *cp != '/' && cp != parent) --cp;
+  if (cp != parent) *cp = '\0';
+  rc = createDirectory( parent, p_error );
+  free( parent );
+#else
   char * parent = dirname( copypath );
   rc = createDirectory( parent, p_error );
+#endif
   free( copypath );
   if (rc)
   {
@@ -1084,7 +963,7 @@ void printRegexpMatchArray(const struct regexp_match regmatch)
 
 
 /* Return the number of parenthesis that corresponds to subexpressions in pattern matching */
-size_t getNumberOfParenthesis(const std::string & s)
+inline size_t getNumberOfParenthesis(const std::string & s)
 {
   size_t number = 0;
   const char * ptr = 0;
@@ -1307,7 +1186,7 @@ char * substitute(const char * mystring,
                   const struct regexp_match regmatch,
                   void * p_error)
 {
-#ifdef HAVE_REGEX
+#ifdef OPENTURNS_HAVE_REGEX
   if (newRegexp.size())   /* Only substitute non null regex */
   {
     regex_t * compiled;
@@ -1426,7 +1305,7 @@ char * substitute(const char * mystring,
           if ( isdigit(newReplace[j]) )
           {
             /* Get the number of the shortcut (\nnn) */
-            size_t width = ResourceMap::GetAsUnsignedLong( "regexp-shortcut-width" );
+            size_t width = ResourceMap::GetAsUnsignedInteger( "regexp-shortcut-width" );
             char NNN[width + 1];
             strncpy( NNN, newReplace.c_str() + j, width );
             NNN[width] = 0;
@@ -1516,9 +1395,9 @@ char * substitute(const char * mystring,
   } /* endif (newRegexp.size()) */
 
 
-#else /* HAVE_REGEX */
+#else /* OPENTURNS_HAVE_REGEX */
   throw NotYetImplementedException(HERE) << "WrapperCommonFunctions need regex";
-#endif /* HAVE_REGEX */
+#endif /* OPENTURNS_HAVE_REGEX */
 }
 
 
@@ -1558,7 +1437,7 @@ void substituteShortcuts(const ShortcutMap & shMap,
                          struct regexp_match regmatch,
                          void * p_error)
 {
-#ifdef HAVE_REGEX
+#ifdef OPENTURNS_HAVE_REGEX
   newRegexp.erase();
   newReplace.erase();
 
@@ -1650,7 +1529,7 @@ void substituteShortcuts(const ShortcutMap & shMap,
       int cflags = REG_EXTENDED | REG_NEWLINE;
       int rc = 0;
       //char re[] = "\\\\[0-9]+";
-      size_t width = ResourceMap::GetAsUnsignedLong( "regexp-shortcut-width" );
+      size_t width = ResourceMap::GetAsUnsignedInteger( "regexp-shortcut-width" );
       char * re = newFormattedString( "^\\\\[0-9]{%u}$", width );
       if (( rc = regcomp(compiled, re, cflags) )) /* We look for the \nnn back references */
       {
@@ -1713,7 +1592,7 @@ void substituteShortcuts(const ShortcutMap & shMap,
           } /* end for */
 
           /* We do the substitutions */
-          size_t width = ResourceMap::GetAsUnsignedLong( "regexp-shortcut-width" );
+          width = ResourceMap::GetAsUnsignedInteger( "regexp-shortcut-width" );
           char NNN[width + 2];
           snprintf( NNN, width + 2, "%0*u", static_cast<int>(width), static_cast<unsigned int>(new_nnn) );
           newReplace.append( replaceBeforeSubstitution, pos1, pos2 - pos1 ); /* We copy the part between two substituted substrings */
@@ -1752,9 +1631,9 @@ void substituteShortcuts(const ShortcutMap & shMap,
 
   if (Log::HasDebug()) printToLogDebug( "(substituteShortcuts) build new regexp '%s' and replace string '%s'", newRegexp.c_str(), newReplace.c_str() );
 
-#else /* HAVE_REGEX */
+#else /* OPENTURNS_HAVE_REGEX */
   throw NotYetImplementedException(HERE) << "WrapperCommonFunctions need regex";
-#endif /* HAVE_REGEX */
+#endif /* OPENTURNS_HAVE_REGEX */
 }
 
 
@@ -1926,7 +1805,7 @@ int retrieve(const std::string & mystring,
              double & value,
              void * p_error)
 {
-#ifdef HAVE_REGEX
+#ifdef OPENTURNS_HAVE_REGEX
   regex_t * compiled;
   int cflags;
   size_t nmatch;
@@ -1963,7 +1842,7 @@ int retrieve(const std::string & mystring,
   /* We expect a format like '\nnn' where nnn is the number of the parenthesis we have to extract */
   /* The size of nnn is determined by the value of "regexp-shortcut-width" */
   regex_t * expr = (regex_t *) malloc(sizeof(regex_t));
-  size_t width = ResourceMap::GetAsUnsignedLong( "regexp-shortcut-width" );
+  size_t width = ResourceMap::GetAsUnsignedInteger( "regexp-shortcut-width" );
   char * re = newFormattedString( "^\\\\[0-9]{%u}$", width );
   char NNN[width + 1];
   memset( NNN, 'n', width );
@@ -2072,9 +1951,9 @@ int retrieve(const std::string & mystring,
 
   return 0;
 
-#else /* HAVE_REGEX */
+#else /* OPENTURNS_HAVE_REGEX */
   throw NotYetImplementedException(HERE) << "WrapperCommonFunctions need regex";
-#endif /* HAVE_REGEX */
+#endif /* OPENTURNS_HAVE_REGEX */
 }
 
 
@@ -2151,10 +2030,11 @@ int retrieveVariables(char * buf,
 
         if ( origFormat.size() == 0 )
         {
-          size_t width = ResourceMap::GetAsUnsignedLong( "regexp-shortcut-width" );
-          char NNN[width + 2];
+          size_t width = ResourceMap::GetAsUnsignedInteger( "regexp-shortcut-width" );
+          char * NNN = new char[width + 2];
           snprintf( NNN, width + 2, "\\%0*u", static_cast<int>(width), 1 );
           origFormat = NNN;
+          delete [] NNN;
           //LOGTRACE(OSS() << "origFormat='" << origFormat << "'");
         }
 
@@ -2399,9 +2279,11 @@ int runCommand(const char * command,
     stdout = freopen( newStdout.c_str(), "w", stdout );
     stderr = freopen( newStderr.c_str(), "w", stderr );
 
+#ifdef SLOW_FILESYSTEM
     // Filesystem lock destroyed to avoid future deadlocks in case fork() happened during critical section and
     // mutex remains locked
     pthread_mutex_destroy( &FileSystemMutex );
+#endif
 
     // Wait for 1ms to ensure that the filesystem has been updated.
     //     struct timeval tv;
