@@ -3,7 +3,7 @@
  * @file  WrapperCommon_static.h
  * @brief This file provides definitions for exported wrapper functions
  *
- * Copyright (C) 2005-2013 EDF
+ * Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  * Permission to copy, use, modify, sell and distribute this software
  * is granted provided this copyright notice appears in all copies.
@@ -20,9 +20,18 @@
 
 #include <WrapperInterface.h>
 #include <WrapperCommon_macros.h>
+#include <OTdebug.h>
+
+#ifdef __cplusplus
+extern "C" {
+#endif
 
 #undef BIND_ACTION
-#define BIND_ACTION(rtype, name, args) extern rtype (* name) args;
+#define BIND_ACTION(rtype, name, args) OT_API rtype (* name) args;
 BIND_METHODS;
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif /* OPENTURNS_WRAPPERCOMMON_STATIC_H */
