@@ -40,10 +40,10 @@ public:
   BasicExpression();
 
   // create a constant leaf
-  BasicExpression(const double t);
+  explicit BasicExpression(const double t);
 
   // create a constant (integer-valued) leaf
-  BasicExpression(const Int t);
+  explicit BasicExpression(const Int t);
 
   // create an (empty) operator or a variable leaf
   BasicExpression(const Int t,
@@ -65,20 +65,20 @@ public:
   ~BasicExpression();
 
   // BasicExpression class methods:
-  void Debug (void) const;
+  void Debug () const;
 
   // prints to a string
-  std::string ToString(void) const;
+  std::string ToString() const;
 
   // output is a tree
   std::string PrintTree(const int blanks,
                         const int tabs) const;
 
   // sets an expression to zero (deleting all existing subnodes)
-  void Zero(void);
+  void Zero();
 
   // sets an expression to one (deleting all existing subnodes)
-  void One(void);
+  void One();
 
   // is expression this == expression t?
   // (note that this half-replicates Tree::operator==,
@@ -102,7 +102,7 @@ public:
   bool IsEqualByOperator(const int theoplabel) const;
 
   // this returns the number of variables in the expression
-  int NumberOfVariables(void) const;
+  int NumberOfVariables() const;
   int NumberOfVariables(int & maxvi) const;
 
   // whether expression depends on variable
@@ -117,16 +117,16 @@ public:
   // resulting global coeff is zero, delete all nodes and set
   // this to zero constant.
   // don't do anything on other operators
-  void ConsolidateProductCoeffs(void);
+  void ConsolidateProductCoeffs();
 
   // in a sum or product, if coeff of sum operand is not 1, distribute it
   // to the operands and set whole coeff to 1
-  void DistributeCoeffOverSum(void);
-  void DistributeCoeffOverProduct(void);
+  void DistributeCoeffOverSum();
+  void DistributeCoeffOverProduct();
 
   // enforce constant dependencies (added for MORON - see ../PROGNOTES)
   // this only acts on the proper leaf nodes
-  void EnforceDependency(void);
+  void EnforceDependency();
 
   // substitute a variable with a constant
   void VariableToConstant(const int varindex,
@@ -176,7 +176,7 @@ public:
 
   // distribute products over sums - returns true if changed
   // (re-call until false)
-  bool DistributeProductsOverSums(void);
+  bool DistributeProductsOverSums();
 
   // find variable indices in an expression
   void GetVarIndices(std::vector<int> & vidx);
@@ -190,12 +190,12 @@ public:
   std::string FindVariableName(int vi);
 
   // is this expression linear?
-  bool IsLinear(void) const;
+  bool IsLinear() const;
 
   // is this expression a quadratic product of variables?
   // If yes, return the product type: PRODUCT, POWER or VAR
   bool IsQuadratic(int & prodtype) const;
-  bool IsQuadratic(void) const;
+  bool IsQuadratic() const;
 
   // return info about the linear part (assumes Simplify() has already been
   // called on this) - return false if expression has no linear part
@@ -216,23 +216,23 @@ public:
                          double & c);
 
   // get the linear part - x in x+y+y^2
-  Expression GetLinearPart(void);
+  Expression GetLinearPart();
 
   // get the pure linar part - x+y in x+y+y^2
-  Expression GetPureLinearPart(void);
+  Expression GetPureLinearPart();
 
   // get the nonlinear part - nonlin(y) in expr(x,y) = lin(x) + nonlin(y)
-  Expression GetNonlinearPart(void);
+  Expression GetNonlinearPart();
 
   // get the purely nonlinear part - eg. y^2 in x+y+y^2
-  Expression GetPureNonlinearPart(void);
+  Expression GetPureNonlinearPart();
 
   // return the additive constant of the expression
-  double GetConstantPart(void);
+  double GetConstantPart();
 
   // return the additive constant of the expression and remove it from the
   // expression itself
-  double RemoveAdditiveConstant(void);
+  double RemoveAdditiveConstant();
 };
 
 std::ostream & operator<< (std::ostream & out, const BasicExpression & expr);
@@ -256,7 +256,7 @@ Expression ProductLink(Expression a,
                        Expression b);
 // divide a by a link of b, return link of a
 Expression FractionLink(Expression a,
-                        Expression b) throw(ErrDivideByZero);
+                        Expression b);
 // raise a to power b, return link of a
 Expression PowerLink(Expression a,
                      Expression b);
@@ -275,16 +275,16 @@ Expression TanhLink(Expression a);
 Expression AsinhLink(Expression a);
 Expression AcoshLink(Expression a);
 Expression AtanhLink(Expression a);
-Expression Log2Link(Expression a) throw(ErrNotPermitted);
-Expression Log10Link(Expression a) throw(ErrNotPermitted);
-Expression LogLink(Expression a) throw(ErrNotPermitted);
-Expression LnLink(Expression a) throw(ErrNotPermitted);
+Expression Log2Link(Expression a);
+Expression Log10Link(Expression a);
+Expression LogLink(Expression a);
+Expression LnLink(Expression a);
 Expression LngammaLink(Expression a);
 Expression GammaLink(Expression a);
 Expression ExpLink(Expression a);
 Expression ErfLink(Expression a);
 Expression ErfcLink(Expression a);
-Expression SqrtLink(Expression a) throw(ErrNotPermitted);
+Expression SqrtLink(Expression a);
 Expression CbrtLink(Expression a);
 Expression BesselJ0Link(Expression a);
 Expression BesselJ1Link(Expression a);
@@ -293,8 +293,8 @@ Expression BesselY1Link(Expression a);
 Expression SignLink(Expression a);
 Expression RintLink(Expression a);
 Expression AbsLink(Expression a);
-Expression CotLink(Expression a) throw(ErrNotPermitted);
-Expression CothLink(Expression a) throw(ErrNotPermitted);
+Expression CotLink(Expression a);
+Expression CothLink(Expression a);
 
 // these are equivalent to the above but they don't change the arguments
 Expression operator + (Expression a,
@@ -304,7 +304,7 @@ Expression operator - (Expression a,
 Expression operator * (Expression a,
                        Expression b);
 Expression operator / (Expression a,
-                       Expression b) throw(ErrDivideByZero);
+                       Expression b);
 Expression operator ^ (Expression a,
                        Expression b);
 Expression operator - (Expression a);
@@ -320,16 +320,16 @@ Expression Tanh(Expression a);
 Expression Asinh(Expression a);
 Expression Acosh(Expression a);
 Expression Atanh(Expression a);
-Expression Log2(Expression a) throw(ErrNotPermitted);
-Expression Log10(Expression a) throw(ErrNotPermitted);
-Expression Log(Expression a) throw(ErrNotPermitted);
-Expression Ln(Expression a) throw(ErrNotPermitted);
+Expression Log2(Expression a);
+Expression Log10(Expression a);
+Expression Log(Expression a);
+Expression Ln(Expression a);
 Expression Lngamma(Expression a);
 Expression Gamma(Expression a);
 Expression Exp(Expression a);
 Expression Erf(Expression a);
 Expression Erfc(Expression a);
-Expression Sqrt(Expression a) throw(ErrNotPermitted);
+Expression Sqrt(Expression a);
 Expression Cbrt(Expression a);
 Expression BesselJ0(Expression a);
 Expression BesselJ1(Expression a);
@@ -338,8 +338,8 @@ Expression BesselY1(Expression a);
 Expression Sign(Expression a);
 Expression Rint(Expression a);
 Expression Abs(Expression a);
-Expression Cot(Expression a) throw(ErrNotPermitted);
-Expression Coth(Expression a) throw(ErrNotPermitted);
+Expression Cot(Expression a);
+Expression Coth(Expression a);
 
 // symbolic differentiation of a w.r.t. variable with index vi,
 // return the created expression (a is not changed)
