@@ -92,10 +92,16 @@ bool ExpressionParser::IsVariableName(const std::string & vname)
 Expression ExpressionParser::Parse(const char* buf,
                                    int & nerrors)
 {
-
   curr_tok_ = PEV3PRINT;
+  std::string buf_str(buf);
+
+  // explicit unary minuses at beginning or after a closing parenthesis
+  for (size_t i = 0; i < buf_str.size(); ++ i)
+    if ((buf_str[i] == PEV3MINUS) && ((i == 0) || ((i > 0) && (buf_str[i - 1] == '('))))
+      buf_str[i] = PEV3UNARYMINUS;
+
   Expression ret;
-  input_ = new std::stringstream(buf);
+  input_ = new std::stringstream(buf_str);
   no_of_functions_ = 0;
   no_of_errors_ = 0;
 
@@ -148,7 +154,7 @@ Expression ExpressionParser::prim(const bool get)
   {
     case PEV3NUMBER:
     {
-      ret = number_value_;
+      ret = Expression(number_value_);
       get_token();
     }
     break;
@@ -159,7 +165,7 @@ Expression ExpressionParser::prim(const bool get)
       double v = table_[string_value_];
       if (v != 0)
       {
-        ret = v;
+        ret = Expression(v);
         get_token();
       }
       else if (vid == PEV3UNKNOWNVAR && !isinitialized_)
@@ -230,6 +236,9 @@ Expression ExpressionParser::prim(const bool get)
     case PEV3MINUS:
       ret = MinusLink(prim(true));
       break;
+    case PEV3UNARYMINUS:
+      ret = MinusLink(ret);
+      break;
     case PEV3LP:
     {
       ret = expr(true);
@@ -261,20 +270,36 @@ Expression ExpressionParser::power(const bool get)
   }
 }
 
+Expression ExpressionParser::uminus(const bool get)
+{
+  Expression ret = power(get);
+  for (;;)
+  {
+    switch (curr_tok_)
+    {
+      case PEV3UNARYMINUS:
+        ret = DifferenceLink(ret, power(true));
+        break;
+      default:
+        return ret;
+    }
+  }
+}
+
 // parser: products and fractions (private method)
 Expression ExpressionParser::term(const bool get)
 {
-  Expression ret = power(get);
+  Expression ret = uminus(get);
 
   for (;;)
   {
     switch (curr_tok_)
     {
       case PEV3MUL:
-        ret = ProductLink(ret, power(true));
+        ret = ProductLink(ret, uminus(true));
         break;
       case PEV3DIV:
-        ret = FractionLink(ret, power(true));
+        ret = FractionLink(ret, uminus(true));
         break;
       default:
         return ret;
@@ -331,6 +356,7 @@ Token_value ExpressionParser::get_token()
     case ')':
     case '=':
     case '^':
+    case '#':
       return curr_tok_ = Token_value(ch);
     case '0':
     case '1':
