@@ -5,7 +5,7 @@
  *         form a numerical math evaluation implementation by using centered
  *         finite difference formula.
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -54,7 +54,7 @@ FiniteDifferenceHessian::FiniteDifferenceHessian(
     throw InvalidDimensionException(HERE) << "Epsilon dimension is incompatible with the given evaluation";
 
   /* Check if any epsilon component is exactly zero */
-  for (UnsignedLong i = 0; i < epsilon.getDimension(); i++)
+  for (UnsignedInteger i = 0; i < epsilon.getDimension(); i++)
     if (epsilon[i] == 0.0) throw InvalidArgumentException(HERE) << "At least one of the components of epsilon is equal to 0.0, namely component " << i;
 }
 
@@ -82,7 +82,7 @@ FiniteDifferenceHessian::FiniteDifferenceHessian(
   if (epsilon.getDimension() != p_evaluation->getInputDimension()) throw InvalidDimensionException(HERE) << "Epsilon dimension is incompatible with the given evaluation";
 
   //Check if any epsilon component is exactly zero
-  for (UnsignedLong i = 0; i < epsilon.getDimension(); i++)
+  for (UnsignedInteger i = 0; i < epsilon.getDimension(); i++)
     if (epsilon[i] == 0.0) throw InvalidArgumentException(HERE) << "At least one of the components of epsilon is equal to 0.0, namely component " << i;
 }
 
@@ -123,13 +123,13 @@ FiniteDifferenceHessian::EvaluationImplementation FiniteDifferenceHessian::getEv
 }
 
 /* Accessor for input point dimension */
-UnsignedLong FiniteDifferenceHessian::getInputDimension() const
+UnsignedInteger FiniteDifferenceHessian::getInputDimension() const
 {
   return p_evaluation_->getInputDimension();
 }
 
 /* Accessor for output point dimension */
-UnsignedLong FiniteDifferenceHessian::getOutputDimension() const
+UnsignedInteger FiniteDifferenceHessian::getOutputDimension() const
 {
   return p_evaluation_->getOutputDimension();
 }
@@ -148,7 +148,7 @@ FiniteDifferenceStep FiniteDifferenceHessian::getFiniteDifferenceStep() const
 /* Evaluation method */
 SymmetricTensor FiniteDifferenceHessian::hessian(const NumericalPoint & inP) const
 {
-  throw NotYetImplementedException(HERE);
+  throw NotYetImplementedException(HERE) << "In FiniteDifferenceHessian::hessian(const NumericalPoint & inP) const";
 }
 
 /* Method save() stores the object through the StorageManager */
