@@ -3,7 +3,7 @@
  *  @file  Box.cxx
  *  @brief Implementation of the box experiment plane
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -26,22 +26,22 @@
 #include "Box.hxx"
 #include "Indices.hxx"
 #include "Tuples.hxx"
+#include "SpecFunc.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
 CLASSNAMEINIT(Box);
 
 /* Default constructor */
-Box::Box(const String & name)
-  : StratifiedExperiment(name)
+Box::Box()
+  : StratifiedExperiment()
 {
   // Nothing to do
 }
 
 /* Constructor with parameters */
-Box::Box(const NumericalPoint & levels,
-         const String & name)
-  : StratifiedExperiment(NumericalPoint(levels.getDimension(), 0.0), levels, name)
+Box::Box(const NumericalPoint & levels)
+  : StratifiedExperiment(NumericalPoint(levels.getDimension(), 0.0), levels)
 {
   // Check if there is the same number of levels than the dimension of the experiment plane
   if (levels.getDimension() == 0) throw InvalidArgumentException(HERE) << "Error: the levels dimension must be > 0";
@@ -49,14 +49,13 @@ Box::Box(const NumericalPoint & levels,
 }
 
 /* Constructor with parameters */
-Box::Box(const Indices & levels,
-         const String & name)
-  : StratifiedExperiment(NumericalPoint(levels.getSize(), 0.0), NumericalPoint(levels.getSize(), 0.0), name)
+Box::Box(const Indices & levels)
+  : StratifiedExperiment(NumericalPoint(levels.getSize(), 0.0), NumericalPoint(levels.getSize(), 0.0))
 {
   // Check if there is the same number of levels than the dimension of the experiment plane
-  const UnsignedLong size(levels.getSize());
+  const UnsignedInteger size(levels.getSize());
   if (size == 0) throw InvalidArgumentException(HERE) << "Error: the levels dimension must be > 0";
-  setLevels(NumericalPoint(levels));
+  setLevels(Collection<NumericalScalar>(levels.begin(), levels.end()));
 }
 
 /* Virtual constructor */
@@ -70,14 +69,14 @@ Box * Box::clone() const
    levels counts the number of interior points in each dimension */
 NumericalSample Box::generate()
 {
-  const UnsignedLong dimension(levels_.getDimension());
+  const UnsignedInteger dimension(levels_.getDimension());
   Indices bounds(dimension);
-  for (UnsignedLong i = 0; i < dimension; ++i) bounds[i] = static_cast< UnsignedLong > (round(levels_[i] + 2.0));
+  for (UnsignedInteger i = 0; i < dimension; ++i) bounds[i] = static_cast< UnsignedInteger > (round(levels_[i] + 2.0));
   Tuples::IndicesCollection tuples(Tuples(bounds).generate());
-  const UnsignedLong size(tuples.getSize());
+  const UnsignedInteger size(tuples.getSize());
   NumericalSample boxPlane(size, dimension);
-  for (UnsignedLong i = 0; i < size; ++i)
-    for (UnsignedLong j = 0; j < dimension; ++j)
+  for (UnsignedInteger i = 0; i < size; ++i)
+    for (UnsignedInteger j = 0; j < dimension; ++j)
       boxPlane[i][j] = tuples[i][j] / (levels_[j] + 1.0);
   return boxPlane;
 } // generate()
@@ -95,10 +94,10 @@ String Box::__repr__() const
 /** Specific levels accessor */
 void Box::setLevels(const NumericalPoint & levels)
 {
-  UnsignedLong dimension(center_.getDimension());
-  UnsignedLong size(levels.getDimension());
+  UnsignedInteger dimension(center_.getDimension());
+  UnsignedInteger size(levels.getDimension());
   if (size != dimension) throw InvalidArgumentException(HERE) << "Error: levels dimension must equal center dimension for the Box design of experiment, here levels dimension=" << size << " and center dimension=" << dimension;
-  for (UnsignedLong i = 0; i < dimension; ++i) if (levels[i] < 0.0) throw InvalidArgumentException(HERE) << "Error: levels values must be greater or equal to 0 for the Box design of experiment";
+  for (UnsignedInteger i = 0; i < dimension; ++i) if (levels[i] < 0.0) throw InvalidArgumentException(HERE) << "Error: levels values must be greater or equal to 0 for the Box design of experiment";
   StratifiedExperiment::setLevels(levels);
 }
 
