@@ -3,7 +3,7 @@
  *  @file  CombinatorialGeneratorImplementation.cxx
  *  @brief Abstract top-level view of an combinatorialGenerator plane
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -54,7 +54,7 @@ String CombinatorialGeneratorImplementation::__repr__() const
 /* Sample generation */
 CombinatorialGeneratorImplementation::IndicesCollection CombinatorialGeneratorImplementation::generate()
 {
-  throw NotYetImplementedException(HERE);
+  throw NotYetImplementedException(HERE) << "In CombinatorialGeneratorImplementation::generate()";
 }
 
 END_NAMESPACE_OPENTURNS
