@@ -3,7 +3,7 @@
  *  @file  Experiment.cxx
  *  @brief Abstract top-level view of an experiment plane
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -29,23 +29,21 @@ BEGIN_NAMESPACE_OPENTURNS
 CLASSNAMEINIT(Experiment);
 
 /* Default constructor */
-Experiment::Experiment(const String & name)
-  : TypedInterfaceObject<ExperimentImplementation>(new Axial(name))
+Experiment::Experiment()
+  : TypedInterfaceObject<ExperimentImplementation>(new Axial())
 {
   // Nothing to do
 }
 
 /* Constructor from implementation pointer */
-Experiment::Experiment(const Implementation & p_implementation,
-                       const String & name)
+Experiment::Experiment(const Implementation & p_implementation)
   : TypedInterfaceObject<ExperimentImplementation>(p_implementation)
 {
   // Nothing to do
 }
 
 /* Constructor from implementation */
-Experiment::Experiment(const ExperimentImplementation & implementation,
-                       const String & name)
+Experiment::Experiment(const ExperimentImplementation & implementation)
   : TypedInterfaceObject<ExperimentImplementation>(implementation.clone())
 {
   // Nothing to do
