@@ -3,7 +3,7 @@
  *  @file  ExperimentImplementation.cxx
  *  @brief Abstract top-level view of an experiment plane
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -30,8 +30,8 @@ BEGIN_NAMESPACE_OPENTURNS
 CLASSNAMEINIT(ExperimentImplementation);
 
 /* Default constructor */
-ExperimentImplementation::ExperimentImplementation(const String & name)
-  : PersistentObject(name)
+ExperimentImplementation::ExperimentImplementation()
+  : PersistentObject()
 {
   // Nothing to do
 }
@@ -54,7 +54,7 @@ String ExperimentImplementation::__repr__() const
 /* Sample generation */
 NumericalSample ExperimentImplementation::generate()
 {
-  throw NotYetImplementedException(HERE);
+  throw NotYetImplementedException(HERE) << "In ExperimentImplementation::generate()";
 }
 
 END_NAMESPACE_OPENTURNS
