@@ -3,7 +3,7 @@
  *  @file  Factorial.cxx
  *  @brief Implementation of the factorial experiment plane
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -23,6 +23,7 @@
  */
 #include "OTprivate.hxx"
 #include "Factorial.hxx"
+#include "SpecFunc.hxx"
 #include <cmath>
 
 BEGIN_NAMESPACE_OPENTURNS
@@ -30,26 +31,24 @@ BEGIN_NAMESPACE_OPENTURNS
 CLASSNAMEINIT(Factorial);
 
 /* Default constructor */
-Factorial::Factorial(const String & name)
-  : StratifiedExperiment(name)
+Factorial::Factorial()
+  : StratifiedExperiment()
 {
   // Nothing to do
 }
 
 /* Constructor with parameters */
 Factorial::Factorial(const NumericalPoint & center,
-                     const NumericalPoint & levels,
-                     const String & name)
-  : StratifiedExperiment(center, levels, name)
+                     const NumericalPoint & levels)
+  : StratifiedExperiment(center, levels)
 {
   // Nothing to do
 }
 
 /* Constructor with parameters */
-Factorial::Factorial(const UnsignedLong dimension,
-                     const NumericalPoint & levels,
-                     const String & name)
-  : StratifiedExperiment(NumericalPoint(dimension, 0.0), levels, name)
+Factorial::Factorial(const UnsignedInteger dimension,
+                     const NumericalPoint & levels)
+  : StratifiedExperiment(NumericalPoint(dimension, 0.0), levels)
 {
   // Nothing to do
 }
@@ -64,26 +63,26 @@ Factorial * Factorial::clone() const
 NumericalSample Factorial::generate()
 {
   /* Dimension of the realizations */
-  const UnsignedLong dimension(center_.getDimension());
+  const UnsignedInteger dimension(center_.getDimension());
   /* Hypercube number of vertices */
-  const UnsignedLong verticesNumber((UnsignedLong)round(pow(2, dimension)));
+  const UnsignedInteger verticesNumber((UnsignedInteger)round(pow(2.0, static_cast<int>(dimension))));
   /* Number of levels to be generated */
-  const UnsignedLong levelNumber(levels_.getDimension());
+  const UnsignedInteger levelNumber(levels_.getDimension());
   /* Size of the sample to be generated: 1 + number of levels x 2^dimension */
-  const UnsignedLong size(1 + levelNumber * verticesNumber);
+  const UnsignedInteger size(1 + levelNumber * verticesNumber);
   NumericalSample factorialPlane(size, center_);
   factorialPlane.setName("Factorial plane");
-  UnsignedLong index(1);
+  UnsignedInteger index(1);
   /* For each level of the factorial plane */
-  for(UnsignedLong levelIndex = 0; levelIndex < levelNumber; ++levelIndex)
+  for(UnsignedInteger levelIndex = 0; levelIndex < levelNumber; ++levelIndex)
   {
     const NumericalScalar levelValue(levels_[levelIndex]);
     /* For each vertex of the current level */
-    for(UnsignedLong vertex = 0; vertex < verticesNumber; ++vertex)
+    for(UnsignedInteger vertex = 0; vertex < verticesNumber; ++vertex)
     {
       /* Compute the coordinates of the current vertex */
-      UnsignedLong binaryIndex(vertex);
-      for(UnsignedLong coordinate = 0; coordinate < dimension; ++coordinate)
+      UnsignedInteger binaryIndex(vertex);
+      for(UnsignedInteger coordinate = 0; coordinate < dimension; ++coordinate)
       {
         /* If the current bit of binaryIndex is 1, set the coordinate to center[coordinate]+levelValue, else set it to center[coordinate]-levelValue */
         factorialPlane[index][coordinate] += (2.0 * (binaryIndex % 2) - 1.0) * levelValue;
