@@ -3,7 +3,7 @@
  *  @file  KPermutations.cxx
  *  @brief Implementation of the kPermutations experiment plane
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -44,7 +44,7 @@ KPermutations::KPermutations()
 }
 
 /* Constructor with parameters */
-KPermutations::KPermutations(const UnsignedLong n)
+KPermutations::KPermutations(const UnsignedInteger n)
   : CombinatorialGeneratorImplementation()
   , k_(n)
   , n_(n)
@@ -52,8 +52,8 @@ KPermutations::KPermutations(const UnsignedLong n)
   // Nothing to do
 }
 
-KPermutations::KPermutations(const UnsignedLong k,
-                             const UnsignedLong n)
+KPermutations::KPermutations(const UnsignedInteger k,
+                             const UnsignedInteger n)
   : CombinatorialGeneratorImplementation()
   , k_(k)
   , n_(n)
@@ -78,11 +78,11 @@ CombinatorialGeneratorImplementation::IndicesCollection KPermutations::generate(
   Indices indices(k_);
   indices.fill();
   /* Size of the sample to be generated: A(k, n) */
-  const UnsignedLong size(static_cast< UnsignedLong >(round(exp(SpecFunc::LogGamma(n_ + 1) - SpecFunc::LogGamma(n_ - k_ + 1)))));
+  const UnsignedInteger size(static_cast< UnsignedInteger >(round(exp(SpecFunc::LogGamma(n_ + 1) - SpecFunc::LogGamma(n_ - k_ + 1)))));
   IndicesCollection allKPermutations(size, indices);
   /* First, generate all the permutations of k integers */
-  IndicesCollection allPermutations(static_cast< UnsignedLong >(round(exp(SpecFunc::LogGamma(k_ + 1)))), indices);
-  UnsignedLong flatIndex(1);
+  IndicesCollection allPermutations(static_cast< UnsignedInteger >(round(exp(SpecFunc::LogGamma(k_ + 1)))), indices);
+  UnsignedInteger flatIndex(1);
   while (std::next_permutation(indices.begin(), indices.end()))
   {
     std::copy(indices.begin(), indices.end(), allPermutations[flatIndex].begin());
@@ -93,18 +93,18 @@ CombinatorialGeneratorImplementation::IndicesCollection KPermutations::generate(
   /* Second, generate all the combinations of k out of n elements */
   IndicesCollection allCombinations(Combinations(k_, n_).generate());
   flatIndex = 0;
-  const UnsignedLong combinationSize(allCombinations.getSize());
-  const UnsignedLong permutationSize(allPermutations.getSize());
-  for (UnsignedLong i = 0; i < combinationSize; ++i)
+  const UnsignedInteger combinationSize(allCombinations.getSize());
+  const UnsignedInteger permutationSize(allPermutations.getSize());
+  for (UnsignedInteger i = 0; i < combinationSize; ++i)
   {
     /* Base combination */
     const Indices & combination(allCombinations[i]);
     /* Generate all the permutations of the base combination */
-    for (UnsignedLong j = 0; j < permutationSize; ++j)
+    for (UnsignedInteger j = 0; j < permutationSize; ++j)
     {
       /* Current permutation */
       const Indices & permutation(allPermutations[j]);
-      for (UnsignedLong k = 0; k < k_; ++k) allKPermutations[flatIndex][k] = combination[permutation[k]];
+      for (UnsignedInteger k = 0; k < k_; ++k) allKPermutations[flatIndex][k] = combination[permutation[k]];
       ++flatIndex;
     }
   }
@@ -123,23 +123,23 @@ String KPermutations::__repr__() const
 }
 
 /* Subset size accessor */
-void KPermutations::setK(const UnsignedLong k)
+void KPermutations::setK(const UnsignedInteger k)
 {
   k_ = k;
 }
 
-UnsignedLong KPermutations::getK() const
+UnsignedInteger KPermutations::getK() const
 {
   return k_;
 }
 
 /* Set size accessor */
-void KPermutations::setN(const UnsignedLong n)
+void KPermutations::setN(const UnsignedInteger n)
 {
   n_ = n;
 }
 
-UnsignedLong KPermutations::getN() const
+UnsignedInteger KPermutations::getN() const
 {
   return n_;
 }
