@@ -3,7 +3,7 @@
  *  @file  StratifiedExperiment.cxx
  *  @brief Abstract top-level view of a stratified experiment plane
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -29,8 +29,8 @@ BEGIN_NAMESPACE_OPENTURNS
 CLASSNAMEINIT(StratifiedExperiment);
 
 /* Default constructor */
-StratifiedExperiment::StratifiedExperiment(const String & name)
-  : ExperimentImplementation(name)
+StratifiedExperiment::StratifiedExperiment()
+  : ExperimentImplementation()
   , center_(NumericalPoint(0))
   , levels_(NumericalPoint(0))
 {
@@ -39,9 +39,8 @@ StratifiedExperiment::StratifiedExperiment(const String & name)
 
 /* Constructor with parameters */
 StratifiedExperiment::StratifiedExperiment(const NumericalPoint & center,
-    const NumericalPoint & levels,
-    const String & name)
-  : ExperimentImplementation(name)
+    const NumericalPoint & levels)
+  : ExperimentImplementation()
   , center_(center)
   , levels_(levels)
 {
