@@ -3,7 +3,7 @@
  * @file  NumericalMathEvaluationImplementation.cxx
  * @brief Abstract top-level class for all distributions
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -42,16 +42,13 @@
 BEGIN_NAMESPACE_OPENTURNS
 
 typedef NumericalMathEvaluationImplementation::CacheType NumericalMathEvaluationImplementationCache;
-TEMPLATE_CLASSNAMEINIT(NumericalMathEvaluationImplementationCache);
 
-static Factory<NumericalMathEvaluationImplementationCache> RegisteredFactory_Cache("NumericalMathEvaluationImplementationCache");
+static Factory<NumericalMathEvaluationImplementationCache> RegisteredFactory_Cache("Cache<PersistentCollection<NumericalScalar>, PersistentCollection<NumericalScalar>>");
 
 /* These methods are implemented here for the needs of Cache */
 /* We should be careful because they may interfere with other definitions placed elsewhere */
-TEMPLATE_CLASSNAMEINIT(PersistentCollection<UnsignedLong>);
-static Factory<PersistentCollection<UnsignedLong> > RegisteredFactory_alt1("PersistentCollection<UnsignedLong>");
+static Factory<PersistentCollection<UnsignedInteger> > RegisteredFactory_alt1("PersistentCollection<UnsignedInteger>");
 #ifndef OPENTURNS_UNSIGNEDLONG_SAME_AS_UINT64
-TEMPLATE_CLASSNAMEINIT(PersistentCollection<Unsigned64BitsInteger>);
 static Factory<PersistentCollection<Unsigned64BitsInteger> > RegisteredFactory_alt1b("PersistentCollection<Unsigned64BitsInteger>");
 #endif
 
@@ -66,15 +63,15 @@ static Factory<NumericalMathEvaluationImplementation> RegisteredFactory("Numeric
 
 /* Default constructor */
 NumericalMathEvaluationImplementation::NumericalMathEvaluationImplementation()
-  : PersistentObject(),
-    callsNumber_(0),
-    p_cache_(new CacheType),
-    inputStrategy_(Full()),
-    outputStrategy_(Full()),
-    isHistoryEnabled_(false),
-    inputDescription_(0),
-    outputDescription_(0),
-    parameters_(0)
+  : PersistentObject()
+  , callsNumber_(0)
+  , p_cache_(new CacheType)
+  , inputStrategy_(Full())
+  , outputStrategy_(Full())
+  , isHistoryEnabled_(false)
+  , parameters_(0)
+  , inputDescription_(0)
+  , outputDescription_(0)
 {
   // We disable the cache by default
   p_cache_->disable();
@@ -127,7 +124,7 @@ Description NumericalMathEvaluationImplementation::getDescription() const
 {
   Description description(getInputDescription());
   Description outputDescription(getOutputDescription());
-  for (UnsignedLong i = 0; i < getOutputDimension(); ++i) description.add(outputDescription[i]);
+  for (UnsignedInteger i = 0; i < getOutputDimension(); ++i) description.add(outputDescription[i]);
   return description;
 }
 
@@ -140,7 +137,7 @@ void NumericalMathEvaluationImplementation::setInputDescription(const Descriptio
 
 Description NumericalMathEvaluationImplementation::getInputDescription() const
 {
-  if (inputDescription_.getSize() == 0) return BuildDefaultDescription(getInputDimension(), "x");
+  if (inputDescription_.getSize() == 0) return Description::BuildDefault(getInputDimension(), "x");
   return inputDescription_;
 }
 
@@ -153,7 +150,7 @@ void NumericalMathEvaluationImplementation::setOutputDescription(const Descripti
 
 Description NumericalMathEvaluationImplementation::getOutputDescription() const
 {
-  if (outputDescription_.getSize() == 0) return BuildDefaultDescription(getOutputDimension(), "y");
+  if (outputDescription_.getSize() == 0) return Description::BuildDefault(getOutputDimension(), "y");
   return outputDescription_;
 }
 
@@ -168,14 +165,14 @@ Bool NumericalMathEvaluationImplementation::isActualImplementation() const
 /* Operator () */
 NumericalSample NumericalMathEvaluationImplementation::operator() (const NumericalSample & inSample) const
 {
-  const UnsignedLong inputDimension(getInputDimension());
+  const UnsignedInteger inputDimension(getInputDimension());
   if (inSample.getDimension() != inputDimension) throw InvalidArgumentException(HERE) << "Error: the given sample has an invalid dimension. Expect a dimension " << inputDimension << ", got " << inSample.getDimension();
 
-  const UnsignedLong size(inSample.getSize());
+  const UnsignedInteger size(inSample.getSize());
   NumericalSample outSample(size, getOutputDimension());
   // Simple loop over the evaluation operator based on point
   // The calls number is updated by these calls
-  for (UnsignedLong i = 0; i < size; ++i) outSample[i] = operator()(inSample[i]);
+  for (UnsignedInteger i = 0; i < size; ++i) outSample[i] = operator()(inSample[i]);
   outSample.setDescription(getOutputDescription());
   return outSample;
 }
@@ -184,7 +181,7 @@ NumericalSample NumericalMathEvaluationImplementation::operator() (const Numeric
 /* Operator () */
 Field NumericalMathEvaluationImplementation::operator() (const Field & inField) const
 {
-  const UnsignedLong inputDimension(getInputDimension());
+  const UnsignedInteger inputDimension(getInputDimension());
   if (inField.getDimension() != inputDimension) throw InvalidArgumentException(HERE) << "Error: the given time series has an invalid dimension. Expect a dimension " << inputDimension << ", got " << inField.getDimension();
   return Field(inField.getMesh(), operator()(inField.getValues()));
 }
@@ -206,7 +203,7 @@ Bool NumericalMathEvaluationImplementation::isCacheEnabled() const
   return p_cache_->isEnabled();
 }
 
-UnsignedLong NumericalMathEvaluationImplementation::getCacheHits() const
+UnsignedInteger NumericalMathEvaluationImplementation::getCacheHits() const
 {
   return p_cache_->getHits();
 }
@@ -214,8 +211,8 @@ UnsignedLong NumericalMathEvaluationImplementation::getCacheHits() const
 void NumericalMathEvaluationImplementation::addCacheContent(const NumericalSample& inSample, const NumericalSample& outSample)
 {
   p_cache_->enable();
-  const UnsignedLong size = inSample.getSize();
-  for ( UnsignedLong i = 0; i < size; ++ i )
+  const UnsignedInteger size = inSample.getSize();
+  for ( UnsignedInteger i = 0; i < size; ++ i )
   {
     p_cache_->add( inSample[i], outSample[i] );
   }
@@ -229,7 +226,7 @@ NumericalSample NumericalMathEvaluationImplementation::getCacheInput() const
   if ( ! cacheEnabled )
     disableCache();
   NumericalSample inSample(0, getInputDimension());
-  for ( UnsignedLong i = 0; i < keyColl.getSize(); ++ i ) inSample.add( keyColl[i] );
+  for ( UnsignedInteger i = 0; i < keyColl.getSize(); ++ i ) inSample.add( keyColl[i] );
   return inSample;
 }
 
@@ -241,7 +238,7 @@ NumericalSample NumericalMathEvaluationImplementation::getCacheOutput() const
   if ( ! cacheEnabled )
     disableCache();
   NumericalSample outSample(0, getOutputDimension());
-  for ( UnsignedLong i = 0; i < valuesColl.getSize(); ++ i )
+  for ( UnsignedInteger i = 0; i < valuesColl.getSize(); ++ i )
   {
     outSample.add( valuesColl[i] );
   }
@@ -275,13 +272,25 @@ void NumericalMathEvaluationImplementation::clearHistory() const
   outputStrategy_ = Full();
 }
 
-HistoryStrategy NumericalMathEvaluationImplementation::getInputHistory() const
+HistoryStrategy NumericalMathEvaluationImplementation::getHistoryInput() const
 {
   return inputStrategy_;
 }
 
+HistoryStrategy NumericalMathEvaluationImplementation::getInputHistory() const
+{
+  Log::Info(OSS() << "NumericalMathEvaluationImplementation::getInputHistory is deprecated in favor of NumericalMathEvaluationImplementation::getHistoryInput");
+  return inputStrategy_;
+}
+
+HistoryStrategy NumericalMathEvaluationImplementation::getHistoryOutput() const
+{
+  return outputStrategy_;
+}
+
 HistoryStrategy NumericalMathEvaluationImplementation::getOutputHistory() const
 {
+  Log::Info(OSS() << "NumericalMathEvaluationImplementation::getOutputHistory is deprecated in favor of NumericalMathEvaluationImplementation::getHistoryOutput");
   return outputStrategy_;
 }
 
@@ -302,26 +311,50 @@ void NumericalMathEvaluationImplementation::setParameters(const NumericalPointWi
   parameters_ = parameters;
 }
 
+void NumericalMathEvaluationImplementation::setParameters(const NumericalPoint & parameters)
+{
+  parameters_ = parameters;
+}
+
 /* Operator () */
 NumericalPoint NumericalMathEvaluationImplementation::operator() (const NumericalPoint & inP) const
 {
-  throw NotYetImplementedException(HERE);
+  throw NotYetImplementedException(HERE) << "In NumericalMathEvaluationImplementation::operator() (const NumericalPoint & inP) const";
+}
+
+NumericalPoint NumericalMathEvaluationImplementation::operator() (const NumericalPoint & inP,
+    const NumericalPoint & parameters)
+{
+  setParameters(parameters);
+  return (*this)(inP);
+}
+
+/* Accessor for parameter dimension */
+UnsignedInteger NumericalMathEvaluationImplementation::getParameterDimension() const
+{
+  return parameters_.getDimension();
 }
 
 /* Accessor for input point dimension */
-UnsignedLong NumericalMathEvaluationImplementation::getInputDimension() const
+UnsignedInteger NumericalMathEvaluationImplementation::getInputDimension() const
 {
-  throw NotYetImplementedException(HERE);
+  throw NotYetImplementedException(HERE) << "In NumericalMathEvaluationImplementation::getInputDimension() const";
 }
 
 /* Accessor for output point dimension */
-UnsignedLong NumericalMathEvaluationImplementation::getOutputDimension() const
+UnsignedInteger NumericalMathEvaluationImplementation::getOutputDimension() const
 {
-  throw NotYetImplementedException(HERE);
+  throw NotYetImplementedException(HERE) << "In NumericalMathEvaluationImplementation::getOutputDimension() const";
+}
+
+/* Accessor for input point dimension */
+UnsignedInteger NumericalMathEvaluationImplementation::getParametersDimension() const
+{
+  return parameters_.getDimension();
 }
 
 /* Get the i-th marginal function */
-NumericalMathEvaluationImplementation::Implementation NumericalMathEvaluationImplementation::getMarginal(const UnsignedLong i) const
+NumericalMathEvaluationImplementation::Implementation NumericalMathEvaluationImplementation::getMarginal(const UnsignedInteger i) const
 {
   if (i >= getOutputDimension()) throw InvalidArgumentException(HERE) << "Error: the index of a marginal function must be in the range [0, outputDimension-1]";
   return getMarginal(Indices(1, i));
@@ -335,17 +368,17 @@ NumericalMathEvaluationImplementation::Implementation NumericalMathEvaluationImp
   // If X1,...,XN are the descriptions of the input of this function, it is a function from R^n to R^p
   // with formula Yk = Xindices[k] for k=1,...,p
   // Build non-ambigous names for the inputs. We cannot simply use the output description, as it must be valid muParser identifiers
-  const UnsignedLong inputDimension(getOutputDimension());
-  const UnsignedLong outputDimension(indices.getSize());
+  const UnsignedInteger inputDimension(getOutputDimension());
+  const UnsignedInteger outputDimension(indices.getSize());
 #ifdef OPENTURNS_HAVE_MUPARSER
   Description input(inputDimension);
-  for (UnsignedLong index = 0; index < inputDimension; ++index)
+  for (UnsignedInteger index = 0; index < inputDimension; ++index)
     input[index] = OSS() << "x" << index;
   // Extract the components
   Description output(outputDimension);
   Description formulas(outputDimension);
   Description currentOutputDescription(getOutputDescription());
-  for (UnsignedLong index = 0; index < outputDimension; ++index)
+  for (UnsignedInteger index = 0; index < outputDimension; ++index)
   {
     output[index] = currentOutputDescription[indices[index]];
     formulas[index] = input[indices[index]];
@@ -354,7 +387,7 @@ NumericalMathEvaluationImplementation::Implementation NumericalMathEvaluationImp
 #else
   NumericalPoint center(inputDimension);
   Matrix linear(inputDimension, outputDimension);
-  for ( UnsignedLong index = 0; index < outputDimension; ++ index )
+  for ( UnsignedInteger index = 0; index < outputDimension; ++ index )
     linear(indices[index], index) = 1.0;
   NumericalPoint constant(outputDimension);
   const LinearNumericalMathEvaluationImplementation left(center, constant, linear);
@@ -368,26 +401,26 @@ NumericalMathEvaluationImplementation::Implementation NumericalMathEvaluationImp
 }
 
 /* Get the number of calls to operator() */
-UnsignedLong NumericalMathEvaluationImplementation::getCallsNumber() const
+UnsignedInteger NumericalMathEvaluationImplementation::getCallsNumber() const
 {
   return callsNumber_;
 }
 
 
 /* Draw the given 1D marginal output as a function of the given 1D marginal input around the given central point */
-Graph NumericalMathEvaluationImplementation::draw(const UnsignedLong inputMarginal,
-    const UnsignedLong outputMarginal,
+Graph NumericalMathEvaluationImplementation::draw(const UnsignedInteger inputMarginal,
+    const UnsignedInteger outputMarginal,
     const NumericalPoint & centralPoint,
     const NumericalScalar xMin,
     const NumericalScalar xMax,
-    const UnsignedLong pointNumber) const
+    const UnsignedInteger pointNumber) const
 {
   if (getInputDimension() < 1) throw InvalidArgumentException(HERE) << "Error: cannot use this version of the draw() method with a function of input dimension less than 1";
   if (inputMarginal >= getInputDimension()) throw InvalidArgumentException(HERE) << "Error: the given input marginal index=" << inputMarginal << " must be less than the input dimension=" << getInputDimension();
   if (outputMarginal >= getOutputDimension()) throw InvalidArgumentException(HERE) << "Error: the given output marginal index=" << outputMarginal << " must be less than the output dimension=" << getOutputDimension();
   NumericalSample inputData(pointNumber, centralPoint);
   const NumericalScalar dx((xMax - xMin) / (pointNumber - 1.0));
-  for (UnsignedLong i = 0; i < pointNumber; ++i)
+  for (UnsignedInteger i = 0; i < pointNumber; ++i)
     inputData[i][inputMarginal] = xMin + i * dx;
   // Evaluate the function over all its input in one call in order to benefit from potential parallelism
   const NumericalSample outputData((*this)(inputData));
@@ -409,9 +442,9 @@ Graph NumericalMathEvaluationImplementation::draw(const UnsignedLong inputMargin
 }
 
 /* Draw the given 1D marginal output as a function of the given 2D marginal input around the given central point */
-Graph NumericalMathEvaluationImplementation::draw(const UnsignedLong firstInputMarginal,
-    const UnsignedLong secondInputMarginal,
-    const UnsignedLong outputMarginal,
+Graph NumericalMathEvaluationImplementation::draw(const UnsignedInteger firstInputMarginal,
+    const UnsignedInteger secondInputMarginal,
+    const UnsignedInteger outputMarginal,
     const NumericalPoint & centralPoint,
     const NumericalPoint & xMin,
     const NumericalPoint & xMax,
@@ -429,24 +462,24 @@ Graph NumericalMathEvaluationImplementation::draw(const UnsignedLong firstInputM
   NumericalSample x(Box(NumericalPoint(1, nX)).generate());
   origin[0] = xMin[0];
   scaling[0] = xMax[0] - xMin[0];
-  x.scale(NumericalPoint(1, scaling[0]));
-  x.translate(NumericalPoint(1, origin[0]));
+  x *= NumericalPoint(1, scaling[0]);
+  x += NumericalPoint(1, origin[0]);
   const NumericalScalar nY(pointNumber[1] - 2);
   discretization[1] = nY;
   // Discretization of the second component
   NumericalSample y(Box(NumericalPoint(1, nY)).generate());
   origin[1] = xMin[1];
   scaling[1] = xMax[1] - xMin[1];
-  y.scale(NumericalPoint(1, scaling[1]));
-  y.translate(NumericalPoint(1, origin[1]));
+  y *= NumericalPoint(1, scaling[1]);
+  y += NumericalPoint(1, origin[1]);
   // Discretization of the XY plane
   NumericalSample xy(Box(discretization).generate());
-  xy.scale(scaling);
-  xy.translate(origin);
+  xy *= scaling;
+  xy += origin;
   // Prepare the input sample
-  const UnsignedLong sizeXY(xy.getSize());
+  const UnsignedInteger sizeXY(xy.getSize());
   NumericalSample inputSample(sizeXY, centralPoint);
-  for (UnsignedLong i = 0; i < sizeXY; ++i)
+  for (UnsignedInteger i = 0; i < sizeXY; ++i)
   {
     inputSample[i][firstInputMarginal]  = xy[i][0];
     inputSample[i][secondInputMarginal] = xy[i][1];
@@ -457,18 +490,29 @@ Graph NumericalMathEvaluationImplementation::draw(const UnsignedLong firstInputM
   const String yName(getInputDescription()[secondInputMarginal]);
   String title(OSS() << getOutputDescription()[outputMarginal] << " as a function of (" << xName << "," << yName << ")");
   if (centralPoint.getDimension() > 2) title = String(OSS(false) << title << " around " << centralPoint);
-  Graph graph(title, xName, yName, true, "");
+  Graph graph(title, xName, yName, true, "topright");
   Contour isoValues(Contour(x, y, z, NumericalPoint(0), Description(0), true, title));
   isoValues.buildDefaultLevels();
   isoValues.buildDefaultLabels();
-  graph.add(isoValues);
+  NumericalPoint levels(isoValues.getLevels());
+  Description labels(isoValues.getLabels());
+  for (UnsignedInteger i = 0; i < levels.getDimension(); ++i)
+  {
+    Contour current(isoValues);
+    current.setLevels(NumericalPoint(1, levels[i]));
+    current.setLabels(Description(1, labels[i]));
+    current.setDrawLabels(false);
+    current.setLegend(labels[i]);
+    current.setColor(Contour::ConvertFromHSV((360.0 * i / levels.getDimension()), 1.0, 1.0));
+    graph.add(current);
+  }
   return graph;
 }
 
 /* Draw the output of the function with respect to its input when the input and output dimensions are 1 */
 Graph NumericalMathEvaluationImplementation::draw(const NumericalScalar xMin,
     const NumericalScalar xMax,
-    const UnsignedLong pointNumber) const
+    const UnsignedInteger pointNumber) const
 {
   if (getInputDimension() != 1) throw InvalidArgumentException(HERE) << "Error: cannot draw a function with input dimension=" << getInputDimension() << " different from 1 using this method. See the other draw() methods.";
   if (getOutputDimension() != 1) throw InvalidArgumentException(HERE) << "Error: cannot draw a function with output dimension=" << getInputDimension() << " different from 1 using this method. See the other draw() methods.";
@@ -485,14 +529,6 @@ Graph NumericalMathEvaluationImplementation::draw(const NumericalPoint & xMin,
   return draw(0, 1, 0, NumericalPoint(2), xMin, xMax, pointNumber);
 }
 
-/* Build a default description */
-Description NumericalMathEvaluationImplementation::BuildDefaultDescription(const UnsignedLong dimension,
-    const String & prefix)
-{
-  Description description(dimension);
-  for (UnsignedLong k = 0; k < dimension; ++k) description[k] =  String(OSS() << prefix << k);
-  return description;
-}
 
 /* Method save() stores the object through the StorageManager */
 void NumericalMathEvaluationImplementation::save(Advocate & adv) const
