@@ -3,7 +3,7 @@
  *  @file  NumericalMathFunction.cxx
  *  @brief Abstract top-level class for all distributions
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -35,13 +35,14 @@
 #include "LinearCombinationHessianImplementation.hxx"
 #include "NoNumericalMathGradientImplementation.hxx"
 #include "NoNumericalMathHessianImplementation.hxx"
+#include "ParametricEvaluationImplementation.hxx"
+#include "ParametricGradientImplementation.hxx"
+#include "ParametricHessianImplementation.hxx"
 #include "Log.hxx"
 #include "Os.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
-
-
 CLASSNAMEINIT(NumericalMathFunction);
 
 
@@ -111,9 +112,9 @@ NumericalMathFunction::NumericalMathFunction(const Description & inputVariablesN
     const Description & formulas)
   : TypedInterfaceObject<NumericalMathFunctionImplementation>()
 {
-  const UnsignedLong size(formulas.getSize());
+  const UnsignedInteger size(formulas.getSize());
   Description outputVariablesNames(size);
-  for (UnsignedLong i = 0; i < size; ++i)
+  for (UnsignedInteger i = 0; i < size; ++i)
     outputVariablesNames[i] = String(OSS() << "y" << i);
   *this = NumericalMathFunction(inputVariablesNames, outputVariablesNames, formulas);
 }
@@ -131,10 +132,10 @@ NumericalMathFunction::NumericalMathFunction(const NumericalMathFunction & funct
 NumericalMathFunction::NumericalMathFunction(const NumericalMathFunctionCollection & functionCollection)
   : TypedInterfaceObject<NumericalMathFunctionImplementation>(new NumericalMathFunctionImplementation())
 {
-  AggregatedNumericalMathEvaluationImplementation evaluation(functionCollection);
-  setEvaluationImplementation(evaluation.clone());
-  setGradientImplementation(new AggregatedNumericalMathGradientImplementation(evaluation));
-  setHessianImplementation(new AggregatedNumericalMathHessianImplementation(evaluation));
+  const AggregatedNumericalMathEvaluationImplementation evaluation(functionCollection);
+  setEvaluation(evaluation.clone());
+  setGradient(new AggregatedNumericalMathGradientImplementation(evaluation));
+  setHessian(new AggregatedNumericalMathHessianImplementation(evaluation));
 }
 
 /* Linear combination function constructor */
@@ -142,10 +143,10 @@ NumericalMathFunction::NumericalMathFunction(const NumericalMathFunctionCollecti
     const NumericalPoint & coefficients)
   : TypedInterfaceObject<NumericalMathFunctionImplementation>(new NumericalMathFunctionImplementation())
 {
-  LinearCombinationEvaluationImplementation evaluation(functionCollection, coefficients);
-  setEvaluationImplementation(evaluation.clone());
-  setGradientImplementation(new LinearCombinationGradientImplementation(evaluation));
-  setHessianImplementation(new LinearCombinationHessianImplementation(evaluation));
+  const LinearCombinationEvaluationImplementation evaluation(functionCollection, coefficients);
+  setEvaluation(evaluation.clone());
+  setGradient(new LinearCombinationGradientImplementation(evaluation));
+  setHessian(new LinearCombinationHessianImplementation(evaluation));
 }
 
 /* Dual linear combination function constructor */
@@ -153,10 +154,10 @@ NumericalMathFunction::NumericalMathFunction(const NumericalMathFunctionCollecti
     const NumericalSample & coefficients)
   : TypedInterfaceObject<NumericalMathFunctionImplementation>(new NumericalMathFunctionImplementation())
 {
-  DualLinearCombinationEvaluationImplementation evaluation(functionCollection, coefficients);
-  setEvaluationImplementation(evaluation.clone());
-  setGradientImplementation(new DualLinearCombinationGradientImplementation(evaluation));
-  setHessianImplementation(new DualLinearCombinationHessianImplementation(evaluation));
+  const DualLinearCombinationEvaluationImplementation evaluation(functionCollection, coefficients);
+  setEvaluation(evaluation.clone());
+  setGradient(new DualLinearCombinationGradientImplementation(evaluation));
+  setHessian(new DualLinearCombinationHessianImplementation(evaluation));
 }
 
 /* Simplified analytical formula constructor */
@@ -192,10 +193,36 @@ NumericalMathFunction::NumericalMathFunction(const NumericalSample & inputSample
   // Nothing to do
 }
 
+/* Constructor by splitting the input of a function between variables and parameters */
+NumericalMathFunction::NumericalMathFunction(const NumericalMathFunction & function,
+    const Indices & set,
+    const Bool parametersSet)
+  : TypedInterfaceObject<NumericalMathFunctionImplementation>(new NumericalMathFunctionImplementation())
+{
+  const Pointer<ParametricEvaluationImplementation> p_evaluation = new ParametricEvaluationImplementation(function, set, NumericalPoint(function.getInputDimension()), parametersSet);
+  setEvaluation(p_evaluation);
+  setGradient(new ParametricGradientImplementation(p_evaluation));
+  setHessian(new ParametricHessianImplementation(p_evaluation));
+}
+
+
+NumericalMathFunction::NumericalMathFunction(const NumericalMathFunction & function,
+    const Indices & set,
+    const NumericalPoint & referencePoint,
+    const Bool parametersSet)
+  : TypedInterfaceObject<NumericalMathFunctionImplementation>(new NumericalMathFunctionImplementation())
+{
+  const Pointer<ParametricEvaluationImplementation> p_evaluation = new ParametricEvaluationImplementation(function, set, referencePoint, parametersSet);
+  setEvaluation(p_evaluation);
+  setGradient(new ParametricGradientImplementation(p_evaluation));
+  setHessian(new ParametricHessianImplementation(p_evaluation));
+}
+
 /* Comparison operator */
 Bool NumericalMathFunction::operator ==(const NumericalMathFunction & other) const
 {
-  return true;
+  if (this == &other) return true;
+  return *getImplementation() == *other.getImplementation();
 }
 
 /* String converter */
@@ -209,7 +236,7 @@ String NumericalMathFunction::__repr__() const
 /* String converter */
 String NumericalMathFunction::__str__(const String & offset) const
 {
-  return OSS(false) << offset << getClassName() << " :\n" << getImplementation()->__str__( offset + "  ");
+  return getImplementation()->__str__(offset);
 }
 
 /* Description Accessor */
@@ -253,7 +280,7 @@ Bool NumericalMathFunction::isCacheEnabled() const
   return getImplementation()->isCacheEnabled();
 }
 
-UnsignedLong NumericalMathFunction::getCacheHits() const
+UnsignedInteger NumericalMathFunction::getCacheHits() const
 {
   return getImplementation()->getCacheHits();
 }
@@ -299,74 +326,151 @@ void NumericalMathFunction::clearHistory() const
   return getImplementation()->clearHistory();
 }
 
+HistoryStrategy NumericalMathFunction::getHistoryInput() const
+{
+  return getImplementation()->getHistoryInput();
+}
+
 HistoryStrategy NumericalMathFunction::getInputHistory() const
 {
-  return getImplementation()->getInputHistory();
+  Log::Info(OSS() << "NumericalMathFunction::getInputHistory is deprecated in favor of NumericalMathFunction::getHistoryInput");
+  return getImplementation()->getHistoryInput();
+}
+
+HistoryStrategy NumericalMathFunction::getHistoryOutput() const
+{
+  return getImplementation()->getHistoryOutput();
 }
 
 HistoryStrategy NumericalMathFunction::getOutputHistory() const
 {
-  return getImplementation()->getOutputHistory();
+  Log::Info(OSS() << "NumericalMathFunction::getOutputHistory is deprecated in favor of NumericalMathFunction::getHistoryOutput");
+  return getImplementation()->getHistoryOutput();
 }
 
 /* Multiplication operator between two functions with the same input dimension and 1D output dimension */
-NumericalMathFunction NumericalMathFunction::operator * (const NumericalMathFunction & right) const
+ProductNumericalMathFunction NumericalMathFunction::operator * (const NumericalMathFunction & right) const
 {
-  return getImplementation()->operator * (*(right.getImplementation()));
+  return ProductNumericalMathFunction(getImplementation(), right.getImplementation());
+}
+
+/* Addition operator between two functions with the same input dimension and output dimension */
+NumericalMathFunction NumericalMathFunction::operator + (const NumericalMathFunction & right) const
+{
+  const NumericalPoint coefficients(2, 1.0);
+  NumericalMathFunctionCollection collection(2);
+  collection[0] = *this;
+  collection[1] = right;
+  const LinearCombinationEvaluationImplementation evaluation(collection, coefficients);
+  return NumericalMathFunction(evaluation.clone(), LinearCombinationGradientImplementation(evaluation).clone(), LinearCombinationHessianImplementation(evaluation).clone());
+}
+
+/* Soustraction operator between two functions with the same input dimension and output dimension */
+NumericalMathFunction NumericalMathFunction::operator - (const NumericalMathFunction & right) const
+{
+  NumericalPoint coefficients(2, 1.0);
+  coefficients[1] = -1.0;
+  NumericalMathFunctionCollection collection(2);
+  collection[0] = *this;
+  collection[1] = right;
+  const LinearCombinationEvaluationImplementation evaluation(collection, coefficients);
+  return NumericalMathFunction(evaluation.clone(), LinearCombinationGradientImplementation(evaluation).clone(), LinearCombinationHessianImplementation(evaluation).clone());
 }
 
 /* Function implementation accessors */
+void NumericalMathFunction::setEvaluation(const EvaluationImplementation & functionImplementation)
+{
+  copyOnWrite();
+  getImplementation()->setEvaluation(functionImplementation);
+}
+
+const NumericalMathFunction::EvaluationImplementation & NumericalMathFunction::getEvaluation() const
+{
+  return getImplementation()->getEvaluation();
+}
+
 void NumericalMathFunction::setEvaluationImplementation(const EvaluationImplementation & functionImplementation)
 {
-  copyOnWrite();
-  getImplementation()->setEvaluationImplementation(functionImplementation);
+  Log::Info(OSS() << "NumericalMathFunction::setEvaluationImplementation is deprecated in favor of NumericalMathFunction::setEvaluation");
+  setEvaluation(functionImplementation);
 }
 
-/* Function implementation accessors */
 const NumericalMathFunction::EvaluationImplementation & NumericalMathFunction::getEvaluationImplementation() const
 {
-  return getImplementation()->getEvaluationImplementation();
+  Log::Info(OSS() << "NumericalMathFunction::getEvaluationImplementation is deprecated in favor of NumericalMathFunction::getEvaluation");
+  return getEvaluation();
 }
 
-
 /* Gradient implementation accessors */
+void NumericalMathFunction::setGradient(const NumericalMathGradientImplementation & gradientImplementation)
+{
+  copyOnWrite();
+  getImplementation()->setGradient(GradientImplementation(gradientImplementation.clone()));
+}
+
+void NumericalMathFunction::setGradient(const GradientImplementation & gradientImplementation)
+{
+  copyOnWrite();
+  getImplementation()->setGradient(gradientImplementation);
+}
+
+const NumericalMathFunction::GradientImplementation & NumericalMathFunction::getGradient() const
+{
+  return getImplementation()->getGradient();
+}
+
 void NumericalMathFunction::setGradientImplementation(const NumericalMathGradientImplementation & gradientImplementation)
 {
-  copyOnWrite();
-  getImplementation()->setGradientImplementation(GradientImplementation(gradientImplementation.clone()));
+  Log::Info(OSS() << "NumericalMathFunction::setGradientImplementation is deprecated in favor of NumericalMathFunction::setGradient");
+  setGradient(GradientImplementation(gradientImplementation.clone()));
 }
 
-/* Gradient implementation accessors */
 void NumericalMathFunction::setGradientImplementation(const GradientImplementation & gradientImplementation)
 {
-  copyOnWrite();
-  getImplementation()->setGradientImplementation(gradientImplementation);
+  Log::Info(OSS() << "NumericalMathFunction::setGradientImplementation is deprecated in favor of NumericalMathFunction::setGradient");
+  setGradient(gradientImplementation);
 }
 
-/* Gradient implementation accessors */
 const NumericalMathFunction::GradientImplementation & NumericalMathFunction::getGradientImplementation() const
 {
-  return getImplementation()->getGradientImplementation();
+  Log::Info(OSS() << "NumericalMathFunction::getGradientImplementation is deprecated in favor of NumericalMathFunction::getGradient");
+  return getGradient();
 }
 
-
 /* Hessian implementation accessors */
-void NumericalMathFunction::setHessianImplementation(const NumericalMathHessianImplementation & hessianImplementation)
+void NumericalMathFunction::setHessian(const NumericalMathHessianImplementation & hessianImplementation)
 {
   copyOnWrite();
-  getImplementation()->setHessianImplementation(HessianImplementation(hessianImplementation.clone()));
+  getImplementation()->setHessian(HessianImplementation(hessianImplementation.clone()));
+}
+
+void NumericalMathFunction::setHessian(const HessianImplementation & hessianImplementation)
+{
+  copyOnWrite();
+  getImplementation()->setHessian(hessianImplementation);
+}
+
+const NumericalMathFunction::HessianImplementation & NumericalMathFunction::getHessian() const
+{
+  return getImplementation()->getHessianImplementation();
+}
+
+void NumericalMathFunction::setHessianImplementation(const NumericalMathHessianImplementation & hessianImplementation)
+{
+  Log::Info(OSS() << "NumericalMathFunction::setHessianImplementation is deprecated in favor of NumericalMathFunction::setHessian");
+  setHessian(hessianImplementation);
 }
 
 void NumericalMathFunction::setHessianImplementation(const HessianImplementation & hessianImplementation)
 {
-  copyOnWrite();
-  getImplementation()->setHessianImplementation(hessianImplementation);
+  Log::Info(OSS() << "NumericalMathFunction::setHessianImplementation is deprecated in favor of NumericalMathFunction::setHessian");
+  setHessian(hessianImplementation);
 }
 
-/* Hessian implementation accessors */
 const NumericalMathFunction::HessianImplementation & NumericalMathFunction::getHessianImplementation() const
 {
-  return getImplementation()->getHessianImplementation();
+  Log::Info(OSS() << "NumericalMathFunction::getHessianImplementation is deprecated in favor of NumericalMathFunction::getHessian");
+  return getImplementation()->getHessian();
 }
 
 /* Initial Function implementation accessors */
@@ -418,6 +522,13 @@ Matrix NumericalMathFunction::parametersGradient(const NumericalPoint & inP) con
   return getImplementation()->parametersGradient(inP);
 }
 
+Matrix NumericalMathFunction::parametersGradient(const NumericalPoint & inP,
+    const NumericalPoint & parameters)
+{
+  copyOnWrite();
+  return getImplementation()->parametersGradient(inP, parameters);
+}
+
 /* Parameters value and description accessor */
 NumericalPointWithDescription NumericalMathFunction::getParameters() const
 {
@@ -437,6 +548,13 @@ NumericalPoint NumericalMathFunction::operator() (const NumericalPoint & inP) co
   return getImplementation()->operator()(inP);
 }
 
+NumericalPoint NumericalMathFunction::operator() (const NumericalPoint & inP,
+    const NumericalPoint & parameters)
+{
+  copyOnWrite();
+  return getImplementation()->operator()(inP, parameters);
+}
+
 /* Operator () */
 NumericalSample NumericalMathFunction::operator() (const NumericalSample & inSample) const
 {
@@ -455,30 +573,48 @@ Matrix NumericalMathFunction::gradient(const NumericalPoint & inP) const
   return getImplementation()->gradient(inP);
 }
 
+Matrix NumericalMathFunction::gradient(const NumericalPoint & inP,
+                                       const NumericalPoint & parameters)
+{
+  copyOnWrite();
+  return getImplementation()->gradient(inP, parameters);
+}
+
 /* Method hessian() returns the symmetric tensor of the function at point */
 SymmetricTensor NumericalMathFunction::hessian(const NumericalPoint & inP) const
 {
   return getImplementation()->hessian(inP);
 }
 
+SymmetricTensor NumericalMathFunction::hessian(const NumericalPoint & inP,
+    const NumericalPoint & parameters)
+{
+  copyOnWrite();
+  return getImplementation()->hessian(inP, parameters);
+}
 
 
+/* Accessor for parameter dimension */
+UnsignedInteger NumericalMathFunction::getParameterDimension() const
+{
+  return getImplementation()->getParameterDimension();
+}
 
 /* Accessor for input point dimension */
-UnsignedLong NumericalMathFunction::getInputDimension() const
+UnsignedInteger NumericalMathFunction::getInputDimension() const
 {
   return getImplementation()->getInputDimension();
 }
 
 /* Accessor for output point dimension */
-UnsignedLong NumericalMathFunction::getOutputDimension() const
+UnsignedInteger NumericalMathFunction::getOutputDimension() const
 {
   return getImplementation()->getOutputDimension();
 
 }
 
 /* Get the i-th marginal function */
-NumericalMathFunction NumericalMathFunction::getMarginal(const UnsignedLong i) const
+NumericalMathFunction NumericalMathFunction::getMarginal(const UnsignedInteger i) const
 {
   return *(getImplementation()->getMarginal(i));
 }
@@ -490,43 +626,43 @@ NumericalMathFunction NumericalMathFunction::getMarginal(const Indices & indices
 }
 
 /* Number of calls to the evaluation */
-UnsignedLong NumericalMathFunction::getCallsNumber() const
+UnsignedInteger NumericalMathFunction::getCallsNumber() const
 {
   return getEvaluationCallsNumber();
 }
 
-UnsignedLong NumericalMathFunction::getEvaluationCallsNumber() const
+UnsignedInteger NumericalMathFunction::getEvaluationCallsNumber() const
 {
   return getImplementation()->getEvaluationCallsNumber();
 }
 
 /* Number of calls to the gradient */
-UnsignedLong NumericalMathFunction::getGradientCallsNumber() const
+UnsignedInteger NumericalMathFunction::getGradientCallsNumber() const
 {
   return getImplementation()->getGradientCallsNumber();
 }
 
 /* Number of calls to the hessian */
-UnsignedLong NumericalMathFunction::getHessianCallsNumber() const
+UnsignedInteger NumericalMathFunction::getHessianCallsNumber() const
 {
   return getImplementation()->getHessianCallsNumber();
 }
 
 /* Draw the given 1D marginal output as a function of the given 1D marginal input around the given central point */
-Graph NumericalMathFunction::draw(const UnsignedLong inputMarginal,
-                                  const UnsignedLong outputMarginal,
+Graph NumericalMathFunction::draw(const UnsignedInteger inputMarginal,
+                                  const UnsignedInteger outputMarginal,
                                   const NumericalPoint & centralPoint,
                                   const NumericalScalar xMin,
                                   const NumericalScalar xMax,
-                                  const UnsignedLong pointNumber) const
+                                  const UnsignedInteger pointNumber) const
 {
   return getImplementation()->draw(inputMarginal, outputMarginal, centralPoint, xMin, xMax, pointNumber);
 }
 
 /* Draw the given 1D marginal output as a function of the given 1D marginal input around the given central point */
-Graph NumericalMathFunction::draw(const UnsignedLong firstInputMarginal,
-                                  const UnsignedLong secondInputMarginal,
-                                  const UnsignedLong outputMarginal,
+Graph NumericalMathFunction::draw(const UnsignedInteger firstInputMarginal,
+                                  const UnsignedInteger secondInputMarginal,
+                                  const UnsignedInteger outputMarginal,
                                   const NumericalPoint & centralPoint,
                                   const NumericalPoint & xMin,
                                   const NumericalPoint & xMax,
@@ -538,7 +674,7 @@ Graph NumericalMathFunction::draw(const UnsignedLong firstInputMarginal,
 /* Draw the output of the function with respect to its input when the input and output dimensions are 1 */
 Graph NumericalMathFunction::draw(const NumericalScalar xMin,
                                   const NumericalScalar xMax,
-                                  const UnsignedLong pointNumber) const
+                                  const UnsignedInteger pointNumber) const
 {
   return getImplementation()->draw(xMin, xMax, pointNumber);
 }
