@@ -3,7 +3,7 @@
  *  @file  NumericalMathFunctionImplementation.cxx
  *  @brief Abstract top-level class for all distributions
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -75,7 +75,7 @@ NumericalMathFunctionImplementation::NumericalMathFunctionImplementation()
 
 /* Constructor from a wrapper name */
 NumericalMathFunctionImplementation::NumericalMathFunctionImplementation(const String & name)
-  : PersistentObject(name)
+  : PersistentObject()
   , p_evaluationImplementation_(new NoNumericalMathEvaluationImplementation)
   , p_gradientImplementation_(new NoNumericalMathGradientImplementation)
   , p_hessianImplementation_(new NoNumericalMathHessianImplementation)
@@ -85,6 +85,7 @@ NumericalMathFunctionImplementation::NumericalMathFunctionImplementation(const S
   , useDefaultGradientImplementation_(false)
   , useDefaultHessianImplementation_(false)
 {
+  setName(name);
   // Read the description file of the wrapper
   WrapperFile wrapperFile = WrapperFile::FindWrapperByName( name );
 
@@ -94,7 +95,7 @@ NumericalMathFunctionImplementation::NumericalMathFunctionImplementation(const S
 
 /* Constructor from a wrapper file */
 NumericalMathFunctionImplementation::NumericalMathFunctionImplementation(const WrapperFile & wrapperFile)
-  : PersistentObject(wrapperFile.getName())
+  : PersistentObject()
   , p_evaluationImplementation_(new NoNumericalMathEvaluationImplementation)
   , p_gradientImplementation_(new NoNumericalMathGradientImplementation)
   , p_hessianImplementation_(new NoNumericalMathHessianImplementation)
@@ -104,6 +105,7 @@ NumericalMathFunctionImplementation::NumericalMathFunctionImplementation(const W
   , useDefaultGradientImplementation_(false)
   , useDefaultHessianImplementation_(false)
 {
+  setName(wrapperFile.getName());
   // We set the implementations
   initImplementations( wrapperFile );
 }
@@ -181,7 +183,7 @@ NumericalMathFunctionImplementation::NumericalMathFunctionImplementation(const D
   }
   p_initialHessianImplementation_ = p_hessianImplementation_;
 #else
-  throw NotYetImplementedException(HERE) << "Analytical function requires muParser";
+  throw NotYetImplementedException(HERE) << "In NumericalMathFunctionImplementation::NumericalMathFunctionImplementation(const Description & inputVariablesNames, const Description & outputVariablesNames, const Description & formulas): Analytical function requires muParser";
 #endif
 }
 
@@ -244,7 +246,8 @@ NumericalMathFunctionImplementation * NumericalMathFunctionImplementation::clone
 /* Comparison operator */
 Bool NumericalMathFunctionImplementation::operator ==(const NumericalMathFunctionImplementation & other) const
 {
-  return true;
+  if (this == &other) return true;
+  return (*p_evaluationImplementation_ == *other.p_evaluationImplementation_) && (*p_gradientImplementation_ == *other.p_gradientImplementation_) && (*p_hessianImplementation_ == *other.p_hessianImplementation_);
 }
 
 /* String converter */
@@ -263,13 +266,7 @@ String NumericalMathFunctionImplementation::__repr__() const
 /* String converter */
 String NumericalMathFunctionImplementation::__str__(const String & offset) const
 {
-  OSS oss(false);
-  oss << offset << "input  : " << getInputDescription() << Os::GetEndOfLine()
-      << offset << "output : " << getOutputDescription() << Os::GetEndOfLine()
-      << offset << "evaluation : " << p_evaluationImplementation_->__str__(offset) << Os::GetEndOfLine()
-      << offset << "gradient   : " << p_gradientImplementation_->__str__(offset) << Os::GetEndOfLine()
-      << offset << "hessian    : " << p_hessianImplementation_->__str__(offset);
-  return oss;
+  return p_evaluationImplementation_->__str__(offset);
 }
 
 /* Description Accessor */
@@ -312,7 +309,7 @@ Bool NumericalMathFunctionImplementation::isCacheEnabled() const
   return p_evaluationImplementation_->isCacheEnabled();
 }
 
-UnsignedLong NumericalMathFunctionImplementation::getCacheHits() const
+UnsignedInteger NumericalMathFunctionImplementation::getCacheHits() const
 {
   return p_evaluationImplementation_->getCacheHits();
 }
@@ -359,14 +356,26 @@ void NumericalMathFunctionImplementation::clearHistory() const
   p_evaluationImplementation_->clearHistory();
 }
 
+HistoryStrategy NumericalMathFunctionImplementation::getHistoryInput() const
+{
+  return p_evaluationImplementation_->getHistoryInput();
+}
+
 HistoryStrategy NumericalMathFunctionImplementation::getInputHistory() const
 {
-  return p_evaluationImplementation_->getInputHistory();
+  Log::Info(OSS() << "NumericalMathFunctionImplementation::getInputHistory is deprecated in favor of NumericalMathFunctionImplementation::getHistoryInput");
+  return p_evaluationImplementation_->getHistoryInput();
+}
+
+HistoryStrategy NumericalMathFunctionImplementation::getHistoryOutput() const
+{
+  return p_evaluationImplementation_->getHistoryOutput();
 }
 
 HistoryStrategy NumericalMathFunctionImplementation::getOutputHistory() const
 {
-  return p_evaluationImplementation_->getOutputHistory();
+  Log::Info(OSS() << "NumericalMathFunctionImplementation::getOutputHistory is deprecated in favor of NumericalMathFunctionImplementation::getHistoryOutput");
+  return p_evaluationImplementation_->getHistoryOutput();
 }
 
 /* Multiplication operator between two functions with the same input dimension and 1D output dimension */
@@ -382,50 +391,83 @@ NumericalMathFunctionImplementation NumericalMathFunctionImplementation::operato
 }
 
 /* Function implementation accessors */
-void NumericalMathFunctionImplementation::setEvaluationImplementation(const EvaluationImplementation & evaluationImplementation)
+void NumericalMathFunctionImplementation::setEvaluation(const EvaluationImplementation & evaluation)
 {
-  p_evaluationImplementation_ = evaluationImplementation;
+  p_evaluationImplementation_ = evaluation;
 }
 
-/* Function implementation accessors */
-const NumericalMathFunctionImplementation::EvaluationImplementation & NumericalMathFunctionImplementation::getEvaluationImplementation() const
+const NumericalMathFunctionImplementation::EvaluationImplementation & NumericalMathFunctionImplementation::getEvaluation() const
 {
   return p_evaluationImplementation_;
 }
 
+void NumericalMathFunctionImplementation::setEvaluationImplementation(const EvaluationImplementation & evaluation)
+{
+  Log::Info(OSS() << "NumericalMathFunctionImplementation::setEvaluationImplementation is deprecated in favor of NumericalMathFunctionImplementation::setEvaluation");
+  setEvaluation(evaluation);
+}
+
+const NumericalMathFunctionImplementation::EvaluationImplementation & NumericalMathFunctionImplementation::getEvaluationImplementation() const
+{
+  Log::Info(OSS() << "NumericalMathFunctionImplementation::getEvaluationImplementation is deprecated in favor of NumericalMathFunctionImplementation::getEvaluation");
+  return getEvaluation();
+}
 
 /* Gradient implementation accessors */
-void NumericalMathFunctionImplementation::setGradientImplementation(const GradientImplementation & gradientImplementation)
+void NumericalMathFunctionImplementation::setGradient(const GradientImplementation & gradientImplementation)
 {
   p_gradientImplementation_ = gradientImplementation;
   useDefaultGradientImplementation_ = false;
 }
 
-/* Gradient implementation accessors */
-const NumericalMathFunctionImplementation::GradientImplementation & NumericalMathFunctionImplementation::getGradientImplementation() const
+const NumericalMathFunctionImplementation::GradientImplementation & NumericalMathFunctionImplementation::getGradient() const
 {
   return p_gradientImplementation_;
 }
 
+void NumericalMathFunctionImplementation::setGradientImplementation(const GradientImplementation & gradientImplementation)
+{
+  Log::Info(OSS() << "NumericalMathFunctionImplementation::setGradientImplementation is deprecated in favor of NumericalMathFunctionImplementation::setGradient");
+  setGradient(gradientImplementation);
+}
+
+const NumericalMathFunctionImplementation::GradientImplementation & NumericalMathFunctionImplementation::getGradientImplementation() const
+{
+  Log::Info(OSS() << "NumericalMathFunctionImplementation::getGradientImplementation is deprecated in favor of NumericalMathFunctionImplementation::getGradient");
+  return getGradient();
+}
 
 /* Hessian implementation accessors */
-void NumericalMathFunctionImplementation::setHessianImplementation(const HessianImplementation & hessianImplementation)
+void NumericalMathFunctionImplementation::setHessian(const HessianImplementation & hessianImplementation)
 {
   p_hessianImplementation_ = hessianImplementation;
   useDefaultHessianImplementation_ = false;
 }
 
-/* Hessian implementation accessors */
-const NumericalMathFunctionImplementation::HessianImplementation & NumericalMathFunctionImplementation::getHessianImplementation() const
+const NumericalMathFunctionImplementation::HessianImplementation & NumericalMathFunctionImplementation::getHessian() const
 {
   return p_hessianImplementation_;
 }
 
+void NumericalMathFunctionImplementation::setHessianImplementation(const HessianImplementation & hessianImplementation)
+{
+  Log::Info(OSS() << "NumericalMathFunctionImplementation::setHessianImplementation is deprecated in favor of NumericalMathFunctionImplementation::setHessian");
+  setHessian(hessianImplementation);
+}
+
+const NumericalMathFunctionImplementation::HessianImplementation & NumericalMathFunctionImplementation::getHessianImplementation() const
+{
+  Log::Info(OSS() << "NumericalMathFunctionImplementation::setHessianImplementation is deprecated in favor of NumericalMathFunctionImplementation::getHessian");
+  return getHessian();
+}
+
+
 /* Initial Function implementation accessors */
 const NumericalMathFunctionImplementation::EvaluationImplementation & NumericalMathFunctionImplementation::getInitialEvaluationImplementation() const
 {
   return p_initialEvaluationImplementation_;
 }
+
 void NumericalMathFunctionImplementation::setInitialEvaluationImplementation(const EvaluationImplementation & initialEvaluationImplementation)
 {
   p_evaluationImplementation_ = initialEvaluationImplementation;
@@ -480,6 +522,14 @@ Matrix NumericalMathFunctionImplementation::parametersGradient(const NumericalPo
   return p_evaluationImplementation_->parametersGradient(inP);
 }
 
+/* Gradient according to the marginal parameters */
+Matrix NumericalMathFunctionImplementation::parametersGradient(const NumericalPoint & inP,
+    const NumericalPoint & parameters)
+{
+  setParameters(parameters);
+  return p_evaluationImplementation_->parametersGradient(inP);
+}
+
 /* Parameters value and description accessor */
 NumericalPointWithDescription NumericalMathFunctionImplementation::getParameters() const
 {
@@ -489,6 +539,15 @@ NumericalPointWithDescription NumericalMathFunctionImplementation::getParameters
 void NumericalMathFunctionImplementation::setParameters(const NumericalPointWithDescription & parameters)
 {
   p_evaluationImplementation_->setParameters(parameters);
+  p_gradientImplementation_->setParameters(parameters);
+  p_hessianImplementation_->setParameters(parameters);
+}
+
+void NumericalMathFunctionImplementation::setParameters(const NumericalPoint & parameters)
+{
+  p_evaluationImplementation_->setParameters(parameters);
+  p_gradientImplementation_->setParameters(parameters);
+  p_hessianImplementation_->setParameters(parameters);
 }
 
 
@@ -498,6 +557,13 @@ NumericalPoint NumericalMathFunctionImplementation::operator() (const NumericalP
   return p_evaluationImplementation_->operator()(inP);
 }
 
+NumericalPoint NumericalMathFunctionImplementation::operator() (const NumericalPoint & inP,
+    const NumericalPoint & parameters)
+{
+  setParameters(parameters);
+  return p_evaluationImplementation_->operator()(inP);
+}
+
 /* Operator () */
 NumericalSample NumericalMathFunctionImplementation::operator() (const NumericalSample & inSample) const
 {
@@ -517,6 +583,14 @@ Matrix NumericalMathFunctionImplementation::gradient(const NumericalPoint & inP)
   return p_gradientImplementation_->gradient(inP);
 }
 
+Matrix NumericalMathFunctionImplementation::gradient(const NumericalPoint & inP,
+    const NumericalPoint & parameters)
+{
+  if (useDefaultGradientImplementation_) LOGWARN(OSS() << "You are using a default implementation for the gradient. Be careful, your computation can be severely wrong!");
+  setParameters(parameters);
+  return p_gradientImplementation_->gradient(inP);
+}
+
 /* Method hessian() returns the symetric tensor of the function at point */
 SymmetricTensor NumericalMathFunctionImplementation::hessian(const NumericalPoint & inP) const
 {
@@ -524,37 +598,34 @@ SymmetricTensor NumericalMathFunctionImplementation::hessian(const NumericalPoin
   return p_hessianImplementation_->hessian(inP);
 }
 
+SymmetricTensor NumericalMathFunctionImplementation::hessian(const NumericalPoint & inP,
+    const NumericalPoint & parameters)
+{
+  if (useDefaultHessianImplementation_) LOGWARN(OSS() << "You are using a default implementation for the hessian. Be careful, your computation can be severely wrong!");
+  setParameters(parameters);
+  return p_hessianImplementation_->hessian(inP);
+}
 
-
+/* Accessor for parameter dimension */
+UnsignedInteger NumericalMathFunctionImplementation::getParameterDimension() const
+{
+  return p_evaluationImplementation_->getParameterDimension();
+}
 
 /* Accessor for input point dimension */
-UnsignedLong NumericalMathFunctionImplementation::getInputNumericalPointDimension() const
+UnsignedInteger NumericalMathFunctionImplementation::getInputDimension() const
 {
   return p_evaluationImplementation_->getInputDimension();
 }
 
 /* Accessor for output point dimension */
-UnsignedLong NumericalMathFunctionImplementation::getOutputNumericalPointDimension() const
+UnsignedInteger NumericalMathFunctionImplementation::getOutputDimension() const
 {
   return p_evaluationImplementation_->getOutputDimension();
-
-}
-
-/* Accessor for input point dimension */
-UnsignedLong NumericalMathFunctionImplementation::getInputDimension() const
-{
-  return p_evaluationImplementation_->getInputDimension();
-}
-
-/* Accessor for output point dimension */
-UnsignedLong NumericalMathFunctionImplementation::getOutputDimension() const
-{
-  return p_evaluationImplementation_->getOutputDimension();
-
 }
 
 /* Get the i-th marginal function */
-NumericalMathFunctionImplementation::Implementation NumericalMathFunctionImplementation::getMarginal(const UnsignedLong i) const
+NumericalMathFunctionImplementation::Implementation NumericalMathFunctionImplementation::getMarginal(const UnsignedInteger i) const
 {
   if (i >= getOutputDimension()) throw InvalidArgumentException(HERE) << "Error: the index of a marginal function must be in the range [0, outputDimension-1]";
   return getMarginal(Indices(1, i));
@@ -568,19 +639,19 @@ NumericalMathFunctionImplementation::Implementation NumericalMathFunctionImpleme
 }
 
 /* Number of calls to the evaluation */
-UnsignedLong NumericalMathFunctionImplementation::getEvaluationCallsNumber() const
+UnsignedInteger NumericalMathFunctionImplementation::getEvaluationCallsNumber() const
 {
   return p_evaluationImplementation_->getCallsNumber();
 }
 
 /* Number of calls to the gradient */
-UnsignedLong NumericalMathFunctionImplementation::getGradientCallsNumber() const
+UnsignedInteger NumericalMathFunctionImplementation::getGradientCallsNumber() const
 {
   return p_gradientImplementation_->getCallsNumber();
 }
 
 /* Number of calls to the hessian */
-UnsignedLong NumericalMathFunctionImplementation::getHessianCallsNumber() const
+UnsignedInteger NumericalMathFunctionImplementation::getHessianCallsNumber() const
 {
   return p_hessianImplementation_->getCallsNumber();
 }
@@ -634,7 +705,7 @@ void NumericalMathFunctionImplementation::InitializeDocumentation()
   ValidFunctions_.add("round(arg) -> round to nearest integer");
   ValidFunctions_.add("rint(arg) -> round to nearest integer");
   ValidFunctions_.add("sign(arg) -> sign function -1 if x<0; 1 if x>0");
-  ValidFunctions_.add("if(arg1, arg2, arg3) -> if arg1 then arg2 else arg3");
+  ValidFunctions_.add("(condition ? value1 : value2) -> if condition then value1 else value2");
   ValidFunctions_.add("sum(arg1, ..., argn) -> sum of all arguments");
   ValidFunctions_.add("avg(arg1, ..., argn) -> mean value of all arguments");
   ValidFunctions_.add("min(arg1, ..., argn) -> min of all arguments");
@@ -682,20 +753,20 @@ Description NumericalMathFunctionImplementation::GetValidOperators()
 }
 
 /* Draw the given 1D marginal output as a function of the given 1D marginal input around the given central point */
-Graph NumericalMathFunctionImplementation::draw(const UnsignedLong inputMarginal,
-    const UnsignedLong outputMarginal,
+Graph NumericalMathFunctionImplementation::draw(const UnsignedInteger inputMarginal,
+    const UnsignedInteger outputMarginal,
     const NumericalPoint & centralPoint,
     const NumericalScalar xMin,
     const NumericalScalar xMax,
-    const UnsignedLong pointNumber) const
+    const UnsignedInteger pointNumber) const
 {
   return p_evaluationImplementation_->draw(inputMarginal, outputMarginal, centralPoint, xMin, xMax, pointNumber);
 }
 
 /* Draw the given 1D marginal output as a function of the given 1D marginal input around the given central point */
-Graph NumericalMathFunctionImplementation::draw(const UnsignedLong firstInputMarginal,
-    const UnsignedLong secondInputMarginal,
-    const UnsignedLong outputMarginal,
+Graph NumericalMathFunctionImplementation::draw(const UnsignedInteger firstInputMarginal,
+    const UnsignedInteger secondInputMarginal,
+    const UnsignedInteger outputMarginal,
     const NumericalPoint & centralPoint,
     const NumericalPoint & xMin,
     const NumericalPoint & xMax,
@@ -707,7 +778,7 @@ Graph NumericalMathFunctionImplementation::draw(const UnsignedLong firstInputMar
 /* Draw the output of the function with respect to its input when the input and output dimensions are 1 */
 Graph NumericalMathFunctionImplementation::draw(const NumericalScalar xMin,
     const NumericalScalar xMax,
-    const UnsignedLong pointNumber) const
+    const UnsignedInteger pointNumber) const
 {
   return p_evaluationImplementation_->draw(xMin, xMax, pointNumber);
 }
