@@ -4,7 +4,7 @@
  *  @brief Efficient implementation of the computation of the incomplete
  *         regularized beta function and related functions
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -28,7 +28,7 @@
 #include "Exception.hxx"
 #include "Log.hxx"
 #include "SpecFunc.hxx"
-#ifdef HAVE_BOOST
+#ifdef OPENTURNS_HAVE_BOOST
 #include <boost/math/special_functions/beta.hpp>
 #endif
 
@@ -62,11 +62,12 @@ NumericalScalar RegularizedIncompleteBeta(const NumericalScalar a,
     const NumericalScalar x,
     const Bool tail)
 {
-  if (a <= 0.0) throw InvalidArgumentException(HERE) << "Error: a must be positive, here a=" << a;
-  if (b <= 0.0) throw InvalidArgumentException(HERE) << "Error: b must be positive, here b=" << b;
+  if (a < 0.0) throw InvalidArgumentException(HERE) << "Error: a must be positive, here a=" << a;
+  if (b < 0.0) throw InvalidArgumentException(HERE) << "Error: b must be positive, here b=" << b;
+  if ((a <= 0.0) && (b <= 0.0)) throw InvalidArgumentException(HERE) << "Error: a and b cannot be null at the same time";
   if (x <= 0.0) return (tail ? 1.0 : 0.0);
   if (x >= 1.0) return (tail ? 0.0 : 1.0);
-#ifdef HAVE_BOOST
+#ifdef OPENTURNS_HAVE_BOOST
   return (tail ? boost::math::ibetac(a, b, x) : boost::math::ibeta(a, b, x));
 #else
   if (tail) return RegularizedIncompleteBetaQ(a, b, x);
@@ -140,14 +141,14 @@ NumericalScalar RegularizedIncompleteBetaInverse(const NumericalScalar a,
   if (b <= 0.0) throw InvalidArgumentException(HERE) << "Error: b must be positive, here b=" << b;
   if (x <= 0.0) return (tail ? 1.0 : 0.0);
   if (x >= 1.0) return (tail ? 0.0 : 1.0);
-#ifdef HAVE_BOOST
+#ifdef OPENTURNS_HAVE_BOOST
   return (tail ? boost::math::ibetac_inv(a, b, x) : boost::math::ibeta_inv(a, b, x));
 #else
   NumericalScalar lower(0.0);
   NumericalScalar betaLower(tail ? 1.0 : 0.0);
   NumericalScalar upper(1.0);
   const Bool lowerLessThanX(betaLower < x);
-  for (UnsignedLong k = 0; k < SpecFunc::MaximumIteration; ++k)
+  for (UnsignedInteger k = 0; k < SpecFunc::MaximumIteration; ++k)
   {
     if (fabs(upper - lower) <= SpecFunc::Precision) break;
     const NumericalScalar middle(0.5 * (lower + upper));
@@ -164,8 +165,9 @@ NumericalScalar RegularizedIncompleteBetaP(const NumericalScalar a,
     const NumericalScalar b,
     const NumericalScalar x)
 {
-  if (a <= 0.0) throw InvalidArgumentException(HERE) << "Error: a must be positive, here a=" << a;
-  if (b <= 0.0) throw InvalidArgumentException(HERE) << "Error: b must be positive, here b=" << b;
+  if (a < 0.0) throw InvalidArgumentException(HERE) << "Error: a must be positive, here a=" << a;
+  if (b < 0.0) throw InvalidArgumentException(HERE) << "Error: b must be positive, here b=" << b;
+  if ((a <= 0.0) && (b <= 0.0)) throw InvalidArgumentException(HERE) << "Error: a and b cannot be null at the same time";
   if (x <= 0.0) return 0.0;
   if (x >= 1.0) return 1.0;
   if (x * (a + b + 2) < a + 1.0) return RegularizedIncompleteBetaContinuedFraction(a, b, x) * exp(lgamma(a + b) - lgamma(a) - lgamma(b) + a * log(x) + b * log1p(-x)) / a;
@@ -176,8 +178,9 @@ NumericalScalar RegularizedIncompleteBetaQ(const NumericalScalar a,
     const NumericalScalar b,
     const NumericalScalar x)
 {
-  if (a <= 0.0) throw InvalidArgumentException(HERE) << "Error: a must be positive, here a=" << a;
-  if (b <= 0.0) throw InvalidArgumentException(HERE) << "Error: b must be positive, here b=" << b;
+  if (a < 0.0) throw InvalidArgumentException(HERE) << "Error: a must be positive, here a=" << a;
+  if (b < 0.0) throw InvalidArgumentException(HERE) << "Error: b must be positive, here b=" << b;
+  if ((a <= 0.0) && (b <= 0.0)) throw InvalidArgumentException(HERE) << "Error: a and b cannot be null at the same time";
   if (x >= 1.0) return 0.0;
   if (x <= 0.0) return 1.0;
   if (x * (a + b + 2) < a + 1.0) return 1.0 - RegularizedIncompleteBetaContinuedFraction(a, b, x) * exp(lgamma(a + b) - lgamma(a) - lgamma(b) + a * log(x) + b * log1p(-x)) / a;
@@ -344,7 +347,7 @@ NumericalScalar BPSER(const NumericalScalar a,
   {
     term *= x * (0.5 + (0.5 - b / j));
     sum += term / (a + j);
-    if (abs(term) < epsilon) break;
+    if (fabs(term) < epsilon) break;
   }
   return value * (1.0 + a * sum);
 }
@@ -388,11 +391,11 @@ NumericalScalar BUP(const NumericalScalar a,
                     const NumericalScalar b,
                     const NumericalScalar x,
                     const NumericalScalar y,
-                    const UnsignedLong n)
+                    const UnsignedInteger n)
 {
   NumericalScalar value(1.0);
   NumericalScalar term(a * x * (1.0 - b) / (1.0 + a));
-  for (UnsignedLong k = 1; k <= SpecFunc::MaximumIteration; ++k)
+  for (UnsignedInteger k = 1; k <= SpecFunc::MaximumIteration; ++k)
   {
     value += term;
     if (fabs(term) <= value * SpecFunc::Precision) break;
@@ -415,8 +418,9 @@ NumericalScalar RegularizedIncompleteBetaContinuedFraction(const NumericalScalar
     const NumericalScalar b,
     const NumericalScalar x)
 {
-  if (a <= 0.0) throw InvalidArgumentException(HERE) << "Error: a must be positive, here a=" << a;
-  if (b <= 0.0) throw InvalidArgumentException(HERE) << "Error: b must be positive, here b=" << b;
+  if (a < 0.0) throw InvalidArgumentException(HERE) << "Error: a must be positive, here a=" << a;
+  if (b < 0.0) throw InvalidArgumentException(HERE) << "Error: b must be positive, here b=" << b;
+  if ((a <= 0.0) && (b <= 0.0)) throw InvalidArgumentException(HERE) << "Error: a and b cannot be null at the same time";
   if (x <= 0.0) return 1.0;
   const NumericalScalar epsilon(SpecFunc::Precision * SpecFunc::Precision);
   const NumericalScalar aPb(a + b);
@@ -426,9 +430,9 @@ NumericalScalar RegularizedIncompleteBetaContinuedFraction(const NumericalScalar
   NumericalScalar d(1.0 - aPb * x / aP1);
   if (fabs(d) < epsilon) d = epsilon;
   NumericalScalar value(c / d);
-  for (UnsignedLong k = 1; k <= SpecFunc::MaximumIteration; ++k)
+  for (UnsignedInteger k = 1; k <= SpecFunc::MaximumIteration; ++k)
   {
-    const UnsignedLong k2(2 * k);
+    const UnsignedInteger k2(2 * k);
     NumericalScalar aK(k * (k - b) * x / ((aM1 + k2) * (a + k2)));
     d = 1.0 - aK / d;
     if (fabs(d) < epsilon) d = epsilon;
