@@ -3,7 +3,7 @@
  *  @file  SpecFunc.cxx
  *  @brief OpenTURNS wrapper to a library of special functions
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -33,6 +33,27 @@
 #include "Faddeeva.hh"
 #include "Exception.hxx"
 #include "ResourceMap.hxx"
+#include "NumericalMathFunction.hxx"
+#include "GaussKronrod.hxx"
+
+#ifdef OPENTURNS_HAVE_BOOST
+
+#include <boost/math/special_functions/bessel.hpp>
+#include <boost/version.hpp>
+
+#if (BOOST_VERSION >= 105600)
+
+#include <boost/math/special_functions/bessel_prime.hpp>
+
+#endif
+
+#else
+
+#include "GaussKronrod.hxx"
+#include "NumericalMathFunction.hxx"
+#include "Interval.hxx"
+
+#endif
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -65,16 +86,32 @@ const NumericalScalar SpecFunc::MaxNumericalScalar    = std::numeric_limits<Nume
 const NumericalScalar SpecFunc::LogMaxNumericalScalar = log(MaxNumericalScalar);
 const NumericalScalar SpecFunc::NumericalScalarEpsilon = std::numeric_limits<NumericalScalar>::epsilon();
 // Maximum number of iterations for the algorithms
-const UnsignedLong SpecFunc::MaximumIteration = ResourceMap::GetAsUnsignedLong("SpecFunc-MaximumIteration");
+const UnsignedInteger SpecFunc::MaximumIteration = ResourceMap::GetAsUnsignedInteger("SpecFunc-MaximumIteration");
 const NumericalScalar SpecFunc::Precision = ResourceMap::GetAsNumericalScalar("SpecFunc-Precision");
 
+// Some facilities for NaN and inf
+Bool SpecFunc::IsNaN(const NumericalScalar value)
+{
+  return value != value;
+}
+
+Bool SpecFunc::IsInf(const NumericalScalar value)
+{
+  return (value == value) && IsNaN(value - value);
+}
+
+Bool SpecFunc::IsNormal(const NumericalScalar value)
+{
+  return value - value == 0.0;
+}
+
 // Modified first kind Bessel function of order 0: BesselI0(x) = \sum_{m=0}\infty\frac{1}{m!^2}\left(\frac{x}{2}\right)^{2m}
 NumericalScalar SpecFunc::SmallCaseBesselI0(const NumericalScalar x)
 {
   const NumericalScalar x2(x * x);
   NumericalScalar value(1.0);
   NumericalScalar r(1.0);
-  UnsignedLong k(1);
+  UnsignedInteger k(1);
   while ((fabs(r / value) > 0.0) && (k < SpecFunc::MaximumIteration))
   {
     r *= 0.25 * x2 / (k * k);
@@ -94,13 +131,13 @@ NumericalScalar SpecFunc::LargeCaseLogBesselI0(const NumericalScalar x)
                                   5.5133589612202e+02, 3.0380905109224e+03
                                  };
   const NumericalScalar ax(fabs(x));
-  UnsignedLong k0(12);
+  UnsignedInteger k0(12);
   if (ax >= 35.0) k0 = 9;
   if (ax >= 50.0) k0 = 7;
   NumericalScalar value(1.0);
   const NumericalScalar xR(1.0 / ax);
   NumericalScalar xRPow(xR);
-  for (UnsignedLong k = 0; k < k0; ++k)
+  for (UnsignedInteger k = 0; k < k0; ++k)
   {
     value += A[k] * xRPow;
     xRPow *= xR;
@@ -133,7 +170,7 @@ NumericalScalar SpecFunc::SmallCaseBesselI1(const NumericalScalar x)
   const NumericalScalar x2(x * x);
   NumericalScalar value(1.0);
   NumericalScalar r(1.0);
-  UnsignedLong k(1);
+  UnsignedInteger k(1);
   while ((fabs(r / value) > 0.0) && (k < SpecFunc::MaximumIteration))
   {
     r *= 0.25 * x2 / (k * (k + 1));
@@ -154,13 +191,13 @@ NumericalScalar SpecFunc::LargeCaseLogBesselI1(const NumericalScalar x)
                                    -6.0384407670507e+02, -3.3022722944809e+03
                                  };
   const NumericalScalar ax(fabs(x));
-  UnsignedLong k0(12);
+  UnsignedInteger k0(12);
   if (ax >= 35.0) k0 = 9;
   if (ax >= 50.0) k0 = 7;
   NumericalScalar value(1.0);
   const NumericalScalar xR(1.0 / ax);
   NumericalScalar xRPow(xR);
-  for (UnsignedLong k = 0; k < k0; ++k)
+  for (UnsignedInteger k = 0; k < k0; ++k)
   {
     value += B[k] * xRPow;
     xRPow *= xR;
@@ -190,6 +227,115 @@ NumericalScalar SpecFunc::LogBesselI1(const NumericalScalar x)
   else return LargeCaseLogBesselI1(x);
 }
 
+// Difference between the logarithms of BesselI1 and BesselI0:
+// DeltaLogBesselI10(x) = log(BesselI1(x)) - log(BesselI0(x))
+NumericalScalar SpecFunc::LargeCaseDeltaLogBesselI10(const NumericalScalar x)
+{
+  static NumericalScalar A[12] = {0.125, 7.03125e-02,
+                                  7.32421875e-02, 1.1215209960938e-01,
+                                  2.2710800170898e-01, 5.7250142097473e-01,
+                                  1.7277275025845, 6.0740420012735,
+                                  2.4380529699556e+01, 1.1001714026925e+02,
+                                  5.5133589612202e+02, 3.0380905109224e+03
+                                 };
+  static NumericalScalar B[12] = { -0.375, -1.171875e-01,
+                                   -1.025390625e-01, -1.4419555664063e-01,
+                                   -2.7757644653320e-01, -6.7659258842468e-01,
+                                   -1.9935317337513, -6.8839142681099,
+                                   -2.7248827311269e+01, -1.2159789187654e+02,
+                                   -6.0384407670507e+02, -3.3022722944809e+03
+                                 };
+  const NumericalScalar ax(fabs(x));
+  UnsignedInteger k0(12);
+  if (ax >= 35.0) k0 = 9;
+  if (ax >= 50.0) k0 = 7;
+  NumericalScalar valueI0(1.0);
+  NumericalScalar valueI1(1.0);
+  const NumericalScalar xR(1.0 / ax);
+  NumericalScalar xRPow(xR);
+  for (UnsignedInteger k = 0; k < k0; ++k)
+  {
+    valueI0 += A[k] * xRPow;
+    valueI1 += B[k] * xRPow;
+    xRPow *= xR;
+  }
+  return log(valueI1) - log(valueI0);
+}
+
+NumericalScalar SpecFunc::DeltaLogBesselI10(const NumericalScalar x)
+{
+  if (x <= 0.0) return -MaxNumericalScalar;
+  // Small argument
+  if (fabs(x) <= 22.0) return log(SmallCaseBesselI1(x) / SmallCaseBesselI0(x));
+  else return LargeCaseDeltaLogBesselI10(x);
+}
+
+// Logarithm of the modified second kind Bessel function of order nu: LogBesselK(nu, x)=log(\frac{\pi}{2}\frac{I_{-\nu}(x)-I_[\nu}(x)}{\sin{\nu\pi}})
+NumericalScalar SpecFunc::LogBesselK(const NumericalScalar nu,
+                                     const NumericalScalar x)
+{
+  if (x <= 0.0) throw InvalidArgumentException(HERE) << "Error: x must be positive, here x=" << x;
+  // Reflection formula
+  if (nu < 0.0) return LogBesselK(-nu, x);
+  NumericalScalar logFactor;
+  NumericalMathFunction integrand;
+  NumericalScalar upper;
+  if (nu == 0.0)
+  {
+    logFactor = 0.0;
+    integrand = NumericalMathFunction("t", String(OSS() << "exp(-" << x << "*cosh(t))"));
+    upper = std::log(-2.0 * std::log(NumericalScalarEpsilon) / x);
+  }
+  else
+  {
+    logFactor = nu * std::log(0.5 * x) - LogGamma(0.5 + nu) + 0.5 * std::log(M_PI);
+    integrand = NumericalMathFunction("t", String(OSS() << "exp(-" << x << "*cosh(t))*(sinh(t))^" << 2.0 * nu));
+    upper = std::log(NumericalScalarEpsilon) / (2.0 * nu) - LambertW(-0.25 * x * std::exp(0.5 * std::log(NumericalScalarEpsilon) / nu) / nu, false);
+  }
+  NumericalScalar epsilon;
+  const NumericalScalar integral(GaussKronrod().integrate(integrand, Interval(NumericalScalarEpsilon, upper), epsilon)[0]);
+  if (!IsNormal(integral) || (integral == 0.0)) return -LogMaxNumericalScalar;
+  return logFactor + std::log(integral);
+}
+
+// Modified second kind Bessel function of order nu: BesselK(nu, x)=\frac{\pi}{2}\frac{I_{-\nu}(x)-I_[\nu}(x)}{\sin{\nu\pi}}
+NumericalScalar SpecFunc::BesselK(const NumericalScalar nu,
+                                  const NumericalScalar x)
+{
+#ifdef OPENTURNS_HAVE_BOOST
+  return boost::math::cyl_bessel_k(nu, x);
+#else
+  if (x <= 0.0) throw InvalidArgumentException(HERE) << "Error: x must be positive, here x=" << x;
+  // Reflection formula
+  if (nu < 0.0) return BesselK(-nu, x);
+  // First the limit cases
+  if ((std::abs(x) < 0.0056) && (nu == 0.0))
+  {
+    const NumericalScalar logX(log(x));
+    const NumericalScalar x2(0.25 * x * x);
+    return M_LN2 - logX - EulerConstant + x2 * (M_LN2 - logX + 1.0 - EulerConstant + 0.25 * x2 * (M_LN2 - logX + 1.5 - EulerConstant));
+  }
+  if (std::abs(x) < 1e-8) return 0.5 * exp(LogGamma(nu) - nu * std::log(0.5 * x));
+  if ((std::abs(x) > 1e4) && (x > nu)) return std::sqrt(M_PI / (2.0 * x)) * exp(-x);
+  const NumericalScalar logK(LogBesselK(nu, x));
+  if (logK <= -LogMaxNumericalScalar) return 0.0;
+  if (logK >= LogMaxNumericalScalar) return MaxNumericalScalar;
+  return std::exp(logK);
+#endif
+}
+
+// Modified second kind Bessel derivative function of order nu: BesselKDerivative(nu, x)=dBesselK(nu, x) / dx
+NumericalScalar SpecFunc::BesselKDerivative(const NumericalScalar nu,
+    const NumericalScalar x)
+{
+#if defined(OPENTURNS_HAVE_BOOST) && (BOOST_VERSION >= 105600)
+  return boost::math::cyl_bessel_k_prime(nu, x);
+#else
+  if (x == 0.0) return -MaxNumericalScalar;
+  return -0.5 * (BesselK(nu - 1, x) + BesselK(nu + 1.0, x));
+#endif
+}
+
 // LnBeta function: LnBeta(a, b) = \log(Beta(a, b))
 NumericalScalar SpecFunc::LnBeta(const NumericalScalar a,
                                  const NumericalScalar b)
@@ -200,14 +346,32 @@ NumericalScalar SpecFunc::LnBeta(const NumericalScalar a,
   const NumericalScalar sum(a + b);
   // Common case: a and b small
   if (second < 7.75) return lgamma(first) - lgamma(sum) + lgamma(second);
-  const NumericalScalar ratio(first / sum);
   const NumericalScalar correctionSecond(GammaCorrection(second));
   const NumericalScalar correctionSum(GammaCorrection(sum));
-  const NumericalScalar log1pRatio(log1p(-ratio));
   // Case a and b large
-  if (first >= 7.75) return -0.5 * log(second) + SQRT2PI + GammaCorrection(first) + correctionSecond - correctionSum + (first + 0.5) * log(ratio) + second * log1pRatio;
+  if (first >= 7.75)
+  {
+    // b not very large wrt a
+    if (second < 103.25 * first) return correctionSecond - correctionSum + GammaCorrection(first) - 0.5 * log(second) + second * log(second / first) + (sum - 0.5) * log1p(-second / sum) + LOGSQRT2PI;
+    else
+    {
+      const NumericalScalar epsilon(1.0 / second);
+      NumericalScalar value(log(epsilon));
+      // Here we use an expansion of (log(Gamma(b)) - log(Gamma(a+b))) / a - log(b) pour a << b
+      // The expansion is in double Padé form wrt a and b
+      const NumericalScalar c1(-1.0 + first);
+      const NumericalScalar c2(c1 * (2 * first - 1));
+      const NumericalScalar c3(c1 * c1);
+      const NumericalScalar c4(-6.0 + 3.0 * first);
+      const NumericalScalar c5(first * first);
+      value += epsilon * (-0.5 * c1 + epsilon * (c2 / 12.0 + epsilon * (-(c3 * first) / 12.0 + epsilon * (((-1.0 + 3.0 * first * c1) * c2) / 120.0 + epsilon * (-(c3 * (-1.0 + 2.0 * first * c1) * first) / 60.0 + epsilon * (((1.0 + first * (3.0 + c5 * c4)) * c2) / 252.0 + epsilon * (-(c3 * (2.0 + first * (4.0 + first * (-1.0 + first * c4))) * first) / 168.0 + ((-3.0 + (-9.0 + (-1.0 + (15.0 + (5.0 + (-15.0 + 5.0 * first) * first) * first) * first) * first) * first) * epsilon * c2) / 720.0)))))));
+      value *= first;
+      value += LogGamma(first);
+      return value;
+    }
+  }
   // Case one of a,b large, the other small
-  return LogGamma(first) + correctionSecond - correctionSum + first * (1.0 - log(sum)) + (second - 0.5) * log1pRatio;
+  return LogGamma(first) + correctionSecond - correctionSum + first * (1.0 - log(sum)) + (second - 0.5) * log1p(-first / sum);
 }
 
 // LogBeta = LnBeta
@@ -230,7 +394,7 @@ NumericalScalar SpecFunc::IncompleteBeta(const NumericalScalar a,
     const NumericalScalar x,
     const Bool tail)
 {
-  return IncompleteBeta(a, b, x, tail) * Beta(a, b);
+  return RegularizedIncompleteBeta(a, b, x, tail) * Beta(a, b);
 }
 
 // Incomplete Beta function inverse
@@ -273,13 +437,13 @@ NumericalComplex SpecFunc::Dawson(const NumericalComplex & z)
 
 // Debye function of order n: DebyeN(x, n) = n / x^n \int_0^x t^n/(\exp(t)-1) dt
 NumericalScalar SpecFunc::Debye(const NumericalScalar x,
-                                const UnsignedLong n)
+                                const UnsignedInteger n)
 {
   if ((n == 0) || (n > 20)) throw InvalidArgumentException(HERE) << "Error: cannot compute Debye function of order outside of {1,...,20}";
-  if (x < 0.0) return 0.0;
+  if (x < 0.0) return Debye(-x, n) - n * x / (n + 1.0);
   // The threshold is such that the overall error is less than 1.0e-16
   if (x < 1.0e-8) return 1.0 - n * x / (2.0 * (n + 1.0));
-  return debyen(x, static_cast<int>(n)) * n / pow(x, n);
+  return debyen(x, static_cast<int>(n)) * n / pow(x, static_cast<int>(n));
 }
 
 // DiLog function: DiLog(x) = -\int_0^x \log(1-t)/t dt
@@ -302,10 +466,10 @@ NumericalScalar SpecFunc::DiLog(const NumericalScalar x)
   // DiLog(x)=\sum_{k=1}^{\infty} x^k/k^2
   // for (0, 1/2)
   // This upper bound is an easy-to compute tight upper bound of the number of iterations
-  const UnsignedLong nMax(static_cast<UnsignedLong>(round(8 + 68 * x)));
+  const UnsignedInteger nMax(static_cast<UnsignedInteger>(round(8 + 68 * x)));
   NumericalScalar value(0.0);
   NumericalScalar powerX(1.0);
-  for (UnsignedLong n = 1; n <= nMax; ++n)
+  for (UnsignedInteger n = 1; n <= nMax; ++n)
   {
     powerX *= x;
     value += powerX / (n * n);
@@ -383,7 +547,7 @@ NumericalComplex SpecFunc::LogGamma(const NumericalComplex & a)
     z = -z;
     flip = true;
   }
-  const UnsignedLong coefficientsSize(11);
+  const UnsignedInteger coefficientsSize(11);
   static const NumericalScalar coefficients[coefficientsSize] =
   {
     1.000000000000000174663,      5716.400188274341379136,
@@ -397,7 +561,7 @@ NumericalComplex SpecFunc::LogGamma(const NumericalComplex & a)
   NumericalComplex t(z + g);
   NumericalComplex s(0.0);
   NumericalComplex ss(t - 0.5);
-  for (UnsignedLong k = coefficientsSize - 1; k > 0; --k)
+  for (UnsignedInteger k = coefficientsSize - 1; k > 0; --k)
   {
     s += coefficients[k] / t;
     t -= 1.0;
@@ -510,7 +674,7 @@ NumericalScalar SpecFunc::DiGammaInv(const NumericalScalar a)
   NumericalScalar x( a < -2.22 ? -1.0 / (a - EulerConstant) : exp(a) + 0.5);
   // Use a Newton scheme
   NumericalScalar d(0.0);
-  for (UnsignedLong k = 0; k < 6; ++k)
+  for (UnsignedInteger k = 0; k < 6; ++k)
   {
     d = (DiGamma(x) - a) / TriGamma(x);
     if (d == 0.0) break;
@@ -563,7 +727,7 @@ NumericalScalar SpecFunc::HyperGeom_1_1(const NumericalScalar p1,
   NumericalScalar factorial(1.0);
   NumericalScalar sum(term);
   NumericalScalar eps;
-  UnsignedLong k(0);
+  UnsignedInteger k(0);
   do
   {
     term *= pochhammerP1 * t / (pochhammerQ1 * factorial);
@@ -589,7 +753,7 @@ NumericalComplex SpecFunc::HyperGeom_1_1(const NumericalScalar p1,
   NumericalComplex term(1.0);
   NumericalComplex sum(term);
   NumericalComplex eps(0.0);
-  UnsignedLong k(0);
+  UnsignedInteger k(0);
   do
   {
     term *= pochhammerP1 * x / (pochhammerQ1 * factorial);
@@ -600,7 +764,9 @@ NumericalComplex SpecFunc::HyperGeom_1_1(const NumericalScalar p1,
     eps = term / sum;
     ++k;
   }
-  while ((abs(eps) > 0.0) && (k < SpecFunc::MaximumIteration));
+  // std::abs() for complex argument
+  while ((std::abs(eps) > 0.0) && (k < SpecFunc::MaximumIteration));
+
   return sum;
 }
 
@@ -617,7 +783,7 @@ NumericalScalar SpecFunc::HyperGeom_2_1(const NumericalScalar p1,
   NumericalScalar term(1.0);
   NumericalScalar sum(term);
   NumericalScalar eps(0.0);
-  UnsignedLong k(0);
+  UnsignedInteger k(0);
   do
   {
     term *= pochhammerP1 * pochhammerP2 * x / (pochhammerQ1 * factorial);
@@ -652,7 +818,7 @@ NumericalScalar SpecFunc::HyperGeom_2_2(const NumericalScalar p1,
   const NumericalScalar logX(log(fabs(x)));
   NumericalScalar signX(x > 0.0 ? 1.0 : -1.0);
   NumericalScalar signTerm(1.0);
-  UnsignedLong k(0);
+  UnsignedInteger k(0);
   do
   {
     term += log(pochhammerP1) + log(pochhammerP2) + logX - log(pochhammerQ1) - log(pochhammerQ2) - log(factorial);
@@ -796,7 +962,7 @@ NumericalScalar SpecFunc::LambertW(const NumericalScalar x,
   // Second real branch, defined over [-1/e, 0[, LambertW <= -1
   else
   {
-    if (x >= 0.0) return -INFINITY;
+    if (x >= 0.0) return - std::numeric_limits<NumericalScalar>::infinity();
     if (x < -0.1) w = -2.0;
     else
     {
@@ -805,7 +971,7 @@ NumericalScalar SpecFunc::LambertW(const NumericalScalar x,
     }
   }
   // Halley's iteration
-  for (UnsignedLong i = 0; i < 3; ++i)
+  for (UnsignedInteger i = 0; i < 3; ++i)
   {
     const NumericalScalar expW(exp(w));
     const NumericalScalar numerator(w * expW - x);
@@ -822,6 +988,13 @@ NumericalComplex SpecFunc::Log1p(const NumericalComplex & z)
   return log(1.0 + z);
 }
 
+// Accurate evaluation of exp(z)-1 for |z|<<1
+NumericalComplex SpecFunc::Expm1(const NumericalComplex & z)
+{
+  if (std::norm(z) < 1e-5) return z * (1.0 + 0.5 * z * (1.0 + z / 3.0));
+  return exp(z) - 1.0;
+}
+
 // Accurate evaluation of log(1-exp(-x)) for all x > 0
 NumericalComplex SpecFunc::Log1MExp(const NumericalScalar x)
 {
@@ -831,11 +1004,36 @@ NumericalComplex SpecFunc::Log1MExp(const NumericalScalar x)
 }
 
 // Compute the smallest power of two greater or equal to the given n
-UnsignedLong SpecFunc::NextPowerOfTwo(const UnsignedLong n)
+UnsignedInteger SpecFunc::NextPowerOfTwo(const UnsignedInteger n)
 {
-  UnsignedLong powerOfTwo(1);
+  UnsignedInteger powerOfTwo(1);
   while (powerOfTwo < n) powerOfTwo <<= 1;
   return powerOfTwo;
 }
 
+// Missing functions in cmath wrt math.h as of C++98
+NumericalScalar SpecFunc::Acosh(const NumericalScalar x)
+{
+  if (x < 1.0) throw InvalidArgumentException(HERE) << "Error: acosh is not defined for x<1, here x=" << x;
+  return 2.0 * log(sqrt(0.5 * (x + 1.0)) + sqrt(0.5 * (x - 1.0)));
+}
+
+NumericalScalar SpecFunc::Asinh(const NumericalScalar x)
+{
+  if (std::abs(x) < 0.0081972522783123062436) return x * (1.0 + x * x * (-1.0 / 6.0 + 3.0 * x * x / 40.0));
+  return log(x + sqrt(1.0 + x * x));
+}
+
+NumericalScalar SpecFunc::Atanh(const NumericalScalar x)
+{
+  if (std::abs(x) < 0.0069422277258991260322) return x * (1.0 + x * x * (1.0 / 3.0 + x * x / 5.0));
+  return 0.5 * (log1p(x) - log1p(-x));
+}
+
+NumericalScalar SpecFunc::Cbrt(const NumericalScalar x)
+{
+  if (x == 0.0) return 0.0;
+  return (x < 0.0 ? -exp(log(-x) / 3.0) : exp(log(x) / 3.0));
+}
+
 END_NAMESPACE_OPENTURNS
