@@ -3,7 +3,7 @@
  *  @file  TrendTransform.cxx
  *  @brief Abstract top-level class for all distributions
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -43,29 +43,32 @@ TrendTransform::TrendTransform()
 
 /* Parameter constructor */
 TrendTransform::TrendTransform(const NumericalMathFunction & function)
-  : TemporalFunction()
+  : TemporalFunction(function.getInputDimension())
 {
-  p_evaluation_ = function.getEvaluationImplementation() ;
+  p_evaluation_ = function.getEvaluation() ;
   // Set the descriptions
-  setInputDescription(p_evaluation_->getInputDescription());
+  setInputDescription(p_evaluation_->getOutputDescription());
   setOutputDescription(p_evaluation_->getOutputDescription());
 }
 
 /* Parameter constructor */
 TrendTransform::TrendTransform(const EvaluationImplementation & p_evaluation)
-  : TemporalFunction()
+  : TemporalFunction(p_evaluation->getInputDimension())
 {
   p_evaluation_ = p_evaluation;
   // Set the descriptions
-  setInputDescription(p_evaluation_->getInputDescription());
+  setInputDescription(p_evaluation_->getOutputDescription());
   setOutputDescription(p_evaluation_->getOutputDescription());
 }
 
 /* Parameter constructor */
 TrendTransform::TrendTransform(const NumericalMathEvaluationImplementation & evaluation)
-  : TemporalFunction()
+  : TemporalFunction(evaluation.getInputDimension())
 {
   p_evaluation_ = evaluation.clone();
+  // Set the descriptions
+  setInputDescription(p_evaluation_->getOutputDescription());
+  setOutputDescription(p_evaluation_->getOutputDescription());
 }
 
 /* Virtual constructor */
@@ -98,11 +101,11 @@ String TrendTransform::__str__(const String & offset) const
 /* Operator () */
 Field TrendTransform::operator() (const Field & inFld) const
 {
-  if (inFld.getMeshDimension() != p_evaluation_->getInputDimension()) throw InvalidArgumentException(HERE) << "Error: expected a Field with mesh dimension=" << p_evaluation_->getInputDimension() << ", got mesh dimension=" << inFld.getMeshDimension();
+  if (inFld.getSpatialDimension() != p_evaluation_->getInputDimension()) throw InvalidArgumentException(HERE) << "Error: expected a Field with mesh dimension=" << p_evaluation_->getInputDimension() << ", got mesh dimension=" << inFld.getSpatialDimension();
   if (inFld.getDimension() != p_evaluation_->getOutputDimension()) throw InvalidArgumentException(HERE) << "Error: expected a Field with dimension=" << p_evaluation_->getOutputDimension() << ", got dimension=" << inFld.getDimension();
   NumericalSample outputSample((*p_evaluation_)(inFld.getMesh().getVertices()));
   // finally as the function adds a trend, result
-  for (UnsignedLong k = 0; k < outputSample.getSize(); ++k) outputSample[k] = inFld.getValueAtIndex(k) + outputSample[k];
+  for (UnsignedInteger k = 0; k < outputSample.getSize(); ++k) outputSample[k] = inFld.getValueAtIndex(k) + outputSample[k];
   ++callsNumber_;
   return Field(inFld.getMesh(), outputSample);
 }
