@@ -3,7 +3,7 @@
  *  @file  WrapperData.cxx
  *  @brief This class declares the wrapper data that are exchanged with the platform
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -599,14 +599,14 @@ struct WrapperExchangedData * WrapperData::getNewWrapperExchangedDataForCInterfa
   p_exchangedData->parameters_   = getNewParametersForCInterface();
   p_exchangedData->platform_     = newC<PlatformConfiguration>();
 
-  p_exchangedData->platform_->generalTemporaryDirectory_ = strdup( Path::GetTemporaryDirectory().c_str() );;
-  p_exchangedData->platform_->realRegexpShortcut_        = ResourceMap::GetAsNewCharArray("real-regexp-shortcut");
-  p_exchangedData->platform_->integerRegexpShortcut_     = ResourceMap::GetAsNewCharArray("integer-regexp-shortcut");
-  p_exchangedData->platform_->separatorRegexpShortcut_   = ResourceMap::GetAsNewCharArray("separator-regexp-shortcut");
+  p_exchangedData->platform_->generalTemporaryDirectory_ = strdup(Path::GetTemporaryDirectory().c_str());
+  p_exchangedData->platform_->realRegexpShortcut_        = strdup(ResourceMap::Get("real-regexp-shortcut").c_str());
+  p_exchangedData->platform_->integerRegexpShortcut_     = strdup(ResourceMap::Get("integer-regexp-shortcut").c_str());
+  p_exchangedData->platform_->separatorRegexpShortcut_   = strdup(ResourceMap::Get("separator-regexp-shortcut").c_str());
 
-  p_exchangedData->platform_->nbCpus_             = ResourceMap::GetAsUnsignedLong("parallel-threads");
-  p_exchangedData->platform_->outputFilesTimeout_ = ResourceMap::GetAsUnsignedLong("output-files-timeout");
-  p_exchangedData->platform_->retries_            = ResourceMap::GetAsUnsignedLong("run-command-retries");
+  p_exchangedData->platform_->nbCpus_             = ResourceMap::GetAsUnsignedInteger("parallel-threads");
+  p_exchangedData->platform_->outputFilesTimeout_ = ResourceMap::GetAsUnsignedInteger("output-files-timeout");
+  p_exchangedData->platform_->retries_            = ResourceMap::GetAsUnsignedInteger("run-command-retries");
   p_exchangedData->platform_->command_path_       = 0; // malloc() here because command_path_ allocated in C
 
   // Initialize the embedded mutex
