@@ -3,7 +3,7 @@
  *  @file  WrapperObject.cxx
  *  @brief A WrapperObject binds a dynamic library symbol to itself
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -38,7 +38,7 @@
 #include "WrapperMacros.h"
 #include "TBB.hxx"
 #include "FieldImplementation.hxx"
-#ifdef WIN32
+#ifdef __MINGW32__
 #include <sys/time.h> // gettimeofday
 #endif
 #include "AtomicFunctions.hxx"
@@ -266,7 +266,7 @@ struct WrapperSymbols : public Object
   }
 
 
-#ifdef HAVE_TBB
+#ifdef OPENTURNS_HAVE_TBB
   struct RunCodeFunctor
   {
     ExecutionFunctionPointer func_;
@@ -295,7 +295,7 @@ struct WrapperSymbols : public Object
         p_error_(p_error),
         count_(count),
         size_(inSample ? inSample->size_ : 0),
-        width_( size_ != 0 ? ceil( log10( size_ ) ) : 1 ),
+        width_( size_ != 0 ? ceil( log10( 1.0 * size_ ) ) : 1 ),
         modulo_( size_ > 1000 ? size_ / 1000 : size_ )
     {}
 
@@ -314,10 +314,10 @@ struct WrapperSymbols : public Object
       }
     }
 
-    void operator() ( const tbb::blocked_range<UnsignedLong> & r ) const
+    void operator() ( const tbb::blocked_range<UnsignedInteger> & r ) const
     {
       enum WrapperErrorCode rc;
-      for( UnsignedLong i = r.begin(); i != r.end(); ++i )
+      for( UnsignedInteger i = r.begin(); i != r.end(); ++i )
       {
         struct point inPoint;
         inPoint.size_ = inSample_->dimension_;
@@ -346,14 +346,14 @@ struct WrapperSymbols : public Object
     wrapper_printState(FUNCTIONNAME, p_state);
     wrapper_printSample(FUNCTIONNAME, inSample);
 
-    const UnsignedLong size = inSample->size_;
-    const UnsignedLong grainSize = ResourceMap::GetAsUnsignedLong( "parallel-execution-grainsize" );
+    const UnsignedInteger size = inSample->size_;
+    const UnsignedInteger grainSize = ResourceMap::GetAsUnsignedInteger( "parallel-execution-grainsize" );
 
     AtomicInt count;
     RunCodeFunctor functor( execSymbol_, p_state, inSample, outSample, p_exchangedData, p_error, count );
     try
     {
-      tbb::parallel_for( tbb::blocked_range<UnsignedLong>( 0, size, grainSize ), functor );
+      tbb::parallel_for( tbb::blocked_range<UnsignedInteger>( 0, size, grainSize ), functor );
       functor.incrementCount();
 
     }
@@ -375,7 +375,19 @@ struct WrapperSymbols : public Object
     return WRAPPER_OK;
   }
 
-#else /* HAVE_TBB */
+#elif defined(_MSC_VER) /* OPENTURNS_HAVE_TBB */
+#pragma message ( "WARNING: WrapperObject.cxx has currently been ported on Windows MSVC only with TBB enabled" )
+
+  enum WrapperErrorCode defaultWrapperExecSampleFunction_PTHREAD(void * p_state,
+      const struct sample * inSample,
+      struct sample * outSample,
+      const struct WrapperExchangedData * p_exchangedData,
+      void * p_error) const
+  {
+    LOGINFO( OSS() << "Build OpenTURNS with TBB to use wrappers on Windows" );
+    return WRAPPER_NOT_IMPLEMENTED;
+  }
+#else /* OPENTURNS_HAVE_TBB */
 
   struct AdapterArguments
   {
@@ -467,7 +479,7 @@ struct WrapperSymbols : public Object
 
 
       double ratio = 100.0 * args->count / args->size;
-      int width = static_cast<int>( (args->size != 0 ? ceil( log10( args->size ) ) : 1) );
+      int width = static_cast<int>( (args->size != 0 ? ceil( log10( 1.0 * args->size ) ) : 1) );
       LOGINFO( OSS() << "Progression : "
                << std::setw(7) << ratio << "% ( "
                << std::setw(width) << args->count << " / "
@@ -503,13 +515,10 @@ struct WrapperSymbols : public Object
       if (args->count == args->size) break;
 
       // Go to sleep
-      const long T = ResourceMap::GetAsUnsignedLong("computation-progression-update-interval");
+      const long T = ResourceMap::GetAsUnsignedInteger("computation-progression-update-interval");
       for (long i = 0; i < T; ++i)
       {
-#ifndef WIN32
-        pthread_testcancel();
-        sleep(1);
-#else
+#ifdef __MINGW32__
         struct timeval  tp;
         gettimeofday( &tp, NULL );
         struct timespec ts;
@@ -521,6 +530,9 @@ struct WrapperSymbols : public Object
         if (args->cancel == 0)
           pthread_cond_timedwait( &(args->cancelCond), &cancelMutex, &ts );
         pthread_mutex_unlock( &cancelMutex );
+#else
+        pthread_testcancel();
+        sleep(1);
 #endif
       }
     } /* end while */
@@ -751,7 +763,7 @@ OK:
     wrapper_printExit(FUNCTIONNAME);
     return WRAPPER_OK;
   }
-#endif /* HAVE_TBB */
+#endif /* OPENTURNS_HAVE_TBB */
 
   enum WrapperErrorCode defaultWrapperExecSampleFunction(void * p_state,
       const struct sample * inSample,
@@ -759,11 +771,11 @@ OK:
       const struct WrapperExchangedData * p_exchangedData,
       void * p_error) const
   {
-#ifdef HAVE_TBB
+#ifdef OPENTURNS_HAVE_TBB
     return defaultWrapperExecSampleFunction_TBB( p_state, inSample, outSample, p_exchangedData, p_error );
-#else /* HAVE_TBB */
+#else /* OPENTURNS_HAVE_TBB */
     return defaultWrapperExecSampleFunction_PTHREAD( p_state, inSample, outSample, p_exchangedData, p_error );
-#endif /* HAVE_TBB */
+#endif /* OPENTURNS_HAVE_TBB */
   }
 
   enum WrapperErrorCode defaultWrapperExecFieldFunction(void * p_state,
@@ -772,11 +784,11 @@ OK:
       const struct WrapperExchangedData * p_exchangedData,
       void * p_error) const
   {
-    // #ifdef HAVE_TBB
+    // #ifdef OPENTURNS_HAVE_TBB
     //     return defaultWrapperExecSampleFunction_TBB( p_state, inSample, outSample, p_exchangedData, p_error );
-    // #else /* HAVE_TBB */
+    // #else /* OPENTURNS_HAVE_TBB */
     //     return defaultWrapperExecSampleFunction_PTHREAD( p_state, inSample, outSample, p_exchangedData, p_error );
-    // #endif /* HAVE_TBB */
+    // #endif /* OPENTURNS_HAVE_TBB */
     return WRAPPER_OK;
   }
 
@@ -804,7 +816,7 @@ WrapperObject::WrapperObject(const FileName & libraryPath,
                              const WrapperData & data,
                              ObjectType o
                             )
-  : PersistentObject(symbolName),
+  : PersistentObject(),
     handle_(LibraryLoader::GetInstance().load(libraryPath)),
     data_(data),
     p_exchangedData_(data.getNewWrapperExchangedDataForCInterface()),
@@ -813,6 +825,7 @@ WrapperObject::WrapperObject(const FileName & libraryPath,
     wrapperSymbols_(new WrapperSymbols),
     wrapperInfo_(0)
 {
+  setName(symbolName);
   if (symbolName.empty())
   {
     String name;
@@ -871,7 +884,7 @@ WrapperObject::WrapperObject(const FileName & libraryPath,
   BIND_METHODS;
 
   // fill in the array with the pointer of the functions
-  METHODS methodsToBind[ nbMethods ];
+  METHODS * methodsToBind = new METHODS[nbMethods];
   METHODS * ptr = methodsToBind;
 #undef BIND_ACTION
 #define BIND_ACTION(rtype, name, args) *ptr++ = reinterpret_cast<METHODS>( wrapper_ ## name );
@@ -882,6 +895,7 @@ WrapperObject::WrapperObject(const FileName & libraryPath,
   assert( bindMethodsSymbol_ != 0 );
   enum WrapperErrorCode returnCode = (* bindMethodsSymbol_)( methodsToBind );
   if (returnCode != WRAPPER_OK) throw DynamicLibraryException(HERE) << "Method binding error. Report bug.";
+  delete [] methodsToBind;
 }
 
 /* Destructor */
@@ -940,7 +954,7 @@ String WrapperObject::getFunctionName(FunctionType f) const
 
 
 /* Method getInNumericalPointDimension returns the dimension of the in point */
-UnsignedLong WrapperObject::getInNumericalPointDimension(void * p_state) const
+UnsignedInteger WrapperObject::getInNumericalPointDimension(void * p_state) const
 {
   if (wrapperInfo_.isNull() )
   {
@@ -960,13 +974,13 @@ Description WrapperObject::getDescription() const
 {
   Description description;
   WrapperData::VariableListType variableList(data_.getVariableList());
-  for (UnsignedLong i = 0; i < variableList.getSize(); ++i) description.add(variableList[i].id_);
+  for (UnsignedInteger i = 0; i < variableList.getSize(); ++i) description.add(variableList[i].id_);
   return description;
 }
 
 
 /* Method getInNumericalPointDimension returns the dimension of the out point */
-UnsignedLong WrapperObject::getOutNumericalPointDimension(void * p_state) const
+UnsignedInteger WrapperObject::getOutNumericalPointDimension(void * p_state) const
 {
   if (wrapperInfo_.isNull() )
   {
@@ -1060,14 +1074,14 @@ NumericalPoint WrapperObject::execute(void * p_state,
 NumericalSample WrapperObject::execute(void * p_state,
                                        const NumericalSample & inS) const
 {
-  const UnsignedLong inDimension = getInNumericalPointDimension(p_state);
+  const UnsignedInteger inDimension = getInNumericalPointDimension(p_state);
   // Check the inS argument
   if (inS.getDimension() != inDimension)
     throw InvalidArgumentException(HERE)
         << "Argument 'inS' has incorrect dimension (" << inS.getDimension()
         << "). Expected = " << inDimension;
 
-  const UnsignedLong size = inS.getSize();
+  const UnsignedInteger size = inS.getSize();
   const NumericalSampleImplementation & inSi = * inS.getImplementation();
 
   // We create a point structure to embed the in NumericalPoint passed as argument
@@ -1077,7 +1091,7 @@ NumericalSample WrapperObject::execute(void * p_state,
   inSample.data_      = const_cast<NumericalScalar *>( &inSi[0][0] );
 
   // We create the output sample
-  const UnsignedLong outDimension = getOutNumericalPointDimension(p_state);
+  const UnsignedInteger outDimension = getOutNumericalPointDimension(p_state);
   NumericalSample outS(size, outDimension);
   NumericalSampleImplementation & outSi = * outS.getImplementation();
 
@@ -1115,14 +1129,14 @@ NumericalSample WrapperObject::execute(void * p_state,
 Field WrapperObject::execute(void * p_state,
                              const Field & inFld) const
 {
-  const UnsignedLong inDimension = getInNumericalPointDimension(p_state);
+  const UnsignedInteger inDimension = getInNumericalPointDimension(p_state);
   // Check the inFld argument
   if (inFld.getDimension() != inDimension)
     throw InvalidArgumentException(HERE)
         << "Argument 'inFld' has incorrect dimension (" << inFld.getDimension()
         << "). Expected = " << inDimension;
 
-  const UnsignedLong size = inFld.getSize();
+  const UnsignedInteger size = inFld.getSize();
 
   // We create a point structure to embed the in NumericalPoint passed as argument
   struct field inField;
@@ -1132,7 +1146,7 @@ Field WrapperObject::execute(void * p_state,
   //  inField.data_      = const_cast<NumericalScalar *>( &inFieldi->getValues()[0] );
   //  inField.vertices_  = const_cast<UnsignedScalar *>( &inFieldi->getMesh().
   // We create the output sample
-  const UnsignedLong outDimension = getOutNumericalPointDimension(p_state);
+  const UnsignedInteger outDimension = getOutNumericalPointDimension(p_state);
   Field outFld;
 
   // We create a point structure to embed the returned outS NumericalSample
