@@ -3,7 +3,7 @@
  *  @file  Domain.cxx
  *  @brief Domain is the interface of DomainImplementation.cxx
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -51,7 +51,7 @@ Domain::Domain(const DomainImplementation & implementation):
 }
 
 /* Dimension accessor */
-UnsignedLong Domain::getDimension() const
+UnsignedInteger Domain::getDimension() const
 {
   return getImplementation()->getDimension();
 }
