@@ -3,7 +3,7 @@
  *  @file  DomainImplementation.cxx
  *  @brief DomainImplementation is defined as a domain of \mathbb{R}^d
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -34,7 +34,7 @@ static Factory<DomainImplementation> RegisteredFactory("DomainImplementation");
 
 
 /* Default constructor */
-DomainImplementation::DomainImplementation(UnsignedLong dimension)
+DomainImplementation::DomainImplementation(UnsignedInteger dimension)
   : PersistentObject()
   , dimension_(dimension)
   , volume_(0.0)
@@ -66,7 +66,7 @@ String DomainImplementation::__str__(const String & offset) const
 /* Check if the given point is inside of the domain */
 Bool DomainImplementation::contains(const NumericalPoint & point) const
 {
-  throw NotYetImplementedException(HERE);
+  throw NotYetImplementedException(HERE) << "In DomainImplementation::contains(const NumericalPoint & point) const";
 }
 
 /* Check if the given point is inside of the discretization of the domain */
@@ -107,7 +107,7 @@ void DomainImplementation::computeVolume() const
 }
 
 /* Get the dimension of the domain*/
-UnsignedLong DomainImplementation::getDimension() const
+UnsignedInteger DomainImplementation::getDimension() const
 {
   return dimension_;
 }
