@@ -3,7 +3,7 @@
  *  @file  Interval.cxx
  *  @brief Interval is defined as the cartesian product of n 1D intervalls ]low_1, up_1]x...x]low_n,up_n]
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -26,6 +26,7 @@
 #include "Log.hxx"
 #include "Os.hxx"
 #include "Exception.hxx"
+#include "Mesh.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -33,9 +34,8 @@ CLASSNAMEINIT(Interval);
 
 static Factory<Interval> RegisteredFactory("Interval");
 
-
 /* Default constructor */
-Interval::Interval(const UnsignedLong dimension)
+Interval::Interval(const UnsignedInteger dimension)
   : DomainImplementation(dimension)
   , lowerBound_(dimension, 0.0)
   , upperBound_(dimension, 1.0)
@@ -109,7 +109,7 @@ Interval Interval::intersect(const Interval & other) const
   NumericalPoint intersectUpper(getDimension());
   BoolCollection intersectFiniteLower(getDimension());
   BoolCollection intersectFiniteUpper(getDimension());
-  for (UnsignedLong i = 0; i < getDimension(); ++i)
+  for (UnsignedInteger i = 0; i < getDimension(); ++i)
   {
     intersectLower[i] = std::max(lowerBound_[i], otherLower[i]);
     intersectUpper[i] = std::min(upperBound_[i], otherUpper[i]);
@@ -136,7 +136,7 @@ Interval Interval::join(const Interval & other) const
   NumericalPoint intersectUpper(getDimension());
   BoolCollection intersectFiniteLower(getDimension());
   BoolCollection intersectFiniteUpper(getDimension());
-  for (UnsignedLong i = 0; i < getDimension(); ++i)
+  for (UnsignedInteger i = 0; i < getDimension(); ++i)
   {
     intersectLower[i] = std::min(lowerBound_[i], otherLower[i]);
     intersectUpper[i] = std::max(upperBound_[i], otherUpper[i]);
@@ -149,14 +149,14 @@ Interval Interval::join(const Interval & other) const
 /* Check if the interval is empty, i.e. if we have lowerBound >= upperBound for at least one component with finite bounds. */
 Bool Interval::isEmpty() const
 {
-  for (UnsignedLong i = 0; i < getDimension(); ++i) if (finiteLowerBound_[i] && finiteUpperBound_[i] && (lowerBound_[i] > upperBound_[i])) return true;
+  for (UnsignedInteger i = 0; i < getDimension(); ++i) if (finiteLowerBound_[i] && finiteUpperBound_[i] && (lowerBound_[i] > upperBound_[i])) return true;
   return false;
 }
 
 /* Check if the given point is inside of the closed interval */
 Bool Interval::contains(const NumericalPoint & point) const
 {
-  for (UnsignedLong i = 0; i < getDimension(); ++i)
+  for (UnsignedInteger i = 0; i < getDimension(); ++i)
   {
     // Check against the lower bound
     if (finiteLowerBound_[i] && (point[i] < lowerBound_[i])) return false;
@@ -176,7 +176,7 @@ void Interval::computeVolume() const
     return;
   }
   volume_ = 1.0;
-  for (UnsignedLong i = 0; i < dimension; ++i)
+  for (UnsignedInteger i = 0; i < dimension; ++i)
   {
     volume_ *= upperBound_[i] - lowerBound_[i];
     if (volume_ <= 0.0)
@@ -190,7 +190,7 @@ void Interval::computeVolume() const
 /* Check if the given point is numerically inside of the closed interval, i.e. using only the bounds part of the interval */
 Bool Interval::numericallyContains(const NumericalPoint & point) const
 {
-  for (UnsignedLong i = 0; i < getDimension(); ++i)
+  for (UnsignedInteger i = 0; i < getDimension(); ++i)
     if ((point[i] < lowerBound_[i]) || (point[i] > upperBound_[i])) return false;
   return true;
 }
@@ -208,7 +208,7 @@ Interval Interval::operator +(const Interval & rhs) const
   const NumericalPoint upperBound(upperBound_ + rhs.getUpperBound());
   Interval::BoolCollection finiteLowerBound(rhs.getFiniteLowerBound());
   Interval::BoolCollection finiteUpperBound(rhs.getFiniteUpperBound());
-  for(UnsignedLong i = 0; i < (getDimension()); ++i)
+  for(UnsignedInteger i = 0; i < (getDimension()); ++i)
   {
     finiteLowerBound[i] = finiteLowerBound[i] && finiteLowerBound_[i];
     finiteUpperBound[i] = finiteUpperBound[i] && finiteUpperBound_[i];
@@ -232,7 +232,7 @@ Interval & Interval::operator +=(const Interval & other)
   upperBound_ += other.getUpperBound();
   Interval::BoolCollection finiteLowerBound(other.getFiniteLowerBound());
   Interval::BoolCollection finiteUpperBound(other.getFiniteUpperBound());
-  for(UnsignedLong i = 0; i < (getDimension()); ++i)
+  for(UnsignedInteger i = 0; i < (getDimension()); ++i)
   {
     finiteLowerBound_[i] = finiteLowerBound[i] && finiteLowerBound_[i];
     finiteUpperBound_[i] = finiteUpperBound[i] && finiteUpperBound_[i];
@@ -254,7 +254,7 @@ Interval Interval::operator -(const Interval & rhs) const
   const NumericalPoint upperBound(upperBound_ - rhs.getLowerBound());
   Interval::BoolCollection finiteLowerBound(rhs.getFiniteLowerBound());
   Interval::BoolCollection finiteUpperBound(rhs.getFiniteUpperBound());
-  for(UnsignedLong i = 0; i < (getDimension()); ++i)
+  for(UnsignedInteger i = 0; i < (getDimension()); ++i)
   {
     finiteLowerBound[i] = finiteLowerBound[i] && finiteUpperBound_[i];
     finiteUpperBound[i] = finiteUpperBound[i] && finiteLowerBound_[i];
@@ -278,7 +278,7 @@ Interval & Interval::operator -=(const Interval & other)
   upperBound_ -= other.getLowerBound();
   Interval::BoolCollection finiteLowerBound(other.getFiniteLowerBound());
   Interval::BoolCollection finiteUpperBound(other.getFiniteUpperBound());
-  for(UnsignedLong i = 0; i < (getDimension()); ++i)
+  for(UnsignedInteger i = 0; i < (getDimension()); ++i)
   {
     finiteLowerBound_[i] = finiteLowerBound[i] && finiteUpperBound_[i];
     finiteUpperBound_[i] = finiteUpperBound[i] && finiteLowerBound_[i];
@@ -329,21 +329,13 @@ Interval & Interval::operator *=(const NumericalScalar scalar)
 
 
 /* Comparison operator */
-Bool Interval::operator == (const Interval & rhs) const
+Bool Interval::operator == (const Interval & other) const
 {
-  const Interval &lhs(*this);
-  Bool equality(true);
-
-  if (&lhs != &rhs)   // Not the same object
-  {
-    equality = (getDimension() == rhs.getDimension())
-               && (lowerBound_ == rhs.lowerBound_)
-               && (upperBound_ == rhs.upperBound_)
-               && (finiteLowerBound_ == rhs.finiteLowerBound_)
-               && (finiteUpperBound_ == rhs.finiteUpperBound_);
-  }
-
-  return equality;
+  if (this == &other) return true;
+  return (lowerBound_ == other.lowerBound_)
+         && (upperBound_ == other.upperBound_)
+         && (finiteLowerBound_ == other.finiteLowerBound_)
+         && (finiteUpperBound_ == other.finiteUpperBound_);
 }
 
 /* Lower bound accessor */
@@ -408,8 +400,9 @@ String Interval::__repr__() const
 
 String Interval::__str__(const String & offset) const
 {
+  if (getDimension() == 0) return "empty";
   OSS oss(false);
-  for (UnsignedLong i = 0; i < getDimension(); ++i)
+  for (UnsignedInteger i = 0; i < getDimension(); ++i)
   {
     if (i > 0) oss << Os::GetEndOfLine();
     if (finiteLowerBound_[i]) oss << offset << "[" << lowerBound_[i] << ", ";
