@@ -3,7 +3,7 @@
  *  @file  Graph.cxx
  *  @brief Graph implements graphic devices for plotting through R
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -27,13 +27,6 @@
 BEGIN_NAMESPACE_OPENTURNS
 CLASSNAMEINIT(Graph);
 
-
-/* Initialize valid legend positions */
-void Graph::initializeValidLegendPositions()
-{
-  getImplementation()->initializeValidLegendPositions();
-}
-
 /* Default constructor */
 Graph::Graph(const String & title):
   TypedInterfaceObject<GraphImplementation>(new GraphImplementation(title))
@@ -97,7 +90,7 @@ void Graph::add(const DrawableCollection & drawableCollection)
 }
 
 /* Erase a drawable instance from the collection of drawables contained in GraphImplementation */
-void Graph::erase(const UnsignedLong i)
+void Graph::erase(const UnsignedInteger i)
 {
   copyOnWrite();
   getImplementation()->erase(i);
@@ -115,13 +108,13 @@ void Graph::setDrawables(const DrawableCollection & drawableCollection)
   getImplementation()->setDrawables(drawableCollection);
 }
 /* Individual drawable accessor */
-Drawable Graph::getDrawable(const UnsignedLong index) const
+Drawable Graph::getDrawable(const UnsignedInteger index) const
 {
   return getImplementation()->getDrawable(index);
 }
 
 void Graph::setDrawable(const Drawable & drawable,
-                        const UnsignedLong index)
+                        const UnsignedInteger index)
 {
   copyOnWrite();
   getImplementation()->setDrawable(drawable, index);
@@ -251,12 +244,14 @@ void Graph::setTitle(const String & title)
 /* Accessor for path */
 String Graph::getPath() const
 {
+  LOGINFO("Graph::getPath is deprecated and will be removed");
   return getImplementation()->getPath();
 }
 
 /* Accessor for file name */
 String Graph::getFileName() const
 {
+  LOGINFO("Graph::getFileName is deprecated and will be removed");
   return getImplementation()->getFileName();
 }
 
@@ -265,8 +260,9 @@ void Graph::draw(const String & path,
                  const String & file,
                  const NumericalScalar width,
                  const NumericalScalar height,
-                 const Format format)
+                 SignedInteger format)
 {
+  LOGINFO("Graph::draw(path, file, width, height, format) is deprecated and will be removed");
   getImplementation()->draw(path, file, width, height, format);
 }
 
@@ -274,7 +270,7 @@ void Graph::draw(const String & path,
 void Graph::draw(const String & file,
                  const NumericalScalar width,
                  const NumericalScalar height,
-                 const Format format)
+                 SignedInteger format)
 {
   getImplementation()->draw(file, width, height, format);
 }
@@ -294,18 +290,21 @@ void Graph::clean()
 /* The method returning absolute path of the bitmap graphic file */
 String Graph::getBitmap() const
 {
+  LOGINFO("Graph::getBitmap is deprecated and will be removed");
   return getImplementation()->getBitmap();
 }
 
 /* The method returning absolute path of the postscript graphic file */
 String Graph::getPostscript() const
 {
+  LOGINFO("Graph::getPostscript is deprecated and will be removed");
   return getImplementation()->getPostscript();
 }
 
 /* The method returning absolute path of the vectorial graphic file */
 String Graph::getVectorial() const
 {
+  LOGINFO("Graph::getVectorial is deprecated and will be removed");
   return getImplementation()->getVectorial();
 }
 
@@ -353,12 +352,6 @@ void Graph::setLegendPosition(const String & position)
   return getImplementation()->setLegendPosition(position);
 }
 
-/* Gives all the valid legend positions */
-Description Graph::getValidLegendPositions()
-{
-  return getImplementation()->GetValidLegendPositions();
-}
-
 /* Get the legend font size */
 NumericalScalar Graph::getLegendFontSize() const
 {
