@@ -3,7 +3,7 @@
  *  @file  GraphImplementation.cxx
  * @brief Graph implements graphic devices for plotting through R
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -33,6 +33,7 @@
 #include "Log.hxx"
 #include "OTconfig.hxx"
 #include "Os.hxx"
+#include "Pie.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -50,7 +51,7 @@ Bool GraphImplementation::IsFirstInitialization = true;
 Description GraphImplementation::ValidLegendPositions;
 
 /* Initialize valid legend positions */
-void GraphImplementation::initializeValidLegendPositions()
+void GraphImplementation::InitializeValidLegendPositions()
 {
   ValidLegendPositions.setName("ValidLegendPositions");
   ValidLegendPositions.add("");
@@ -80,12 +81,11 @@ GraphImplementation::GraphImplementation(const String & title)
   , automaticBoundingBox_(true)
   , boundingBox_(4)
   , drawablesCollection_(0)
-  , path_()
   , fileName_()
 {
   if(IsFirstInitialization)
   {
-    initializeValidLegendPositions();
+    InitializeValidLegendPositions();
     IsFirstInitialization = false;
   }
 }
@@ -98,7 +98,7 @@ GraphImplementation::GraphImplementation(const String & title,
     const String & legendPosition,
     const NumericalScalar legendFontSize,
     const LogScale logScale)
-  : PersistentObject(title)
+  : PersistentObject()
   , title_(title)
   , legendFontSize_(legendFontSize)
   , xTitle_(xTitle)
@@ -110,12 +110,12 @@ GraphImplementation::GraphImplementation(const String & title,
   , automaticBoundingBox_(true)
   , boundingBox_(4)
   , drawablesCollection_(0)
-  , path_()
   , fileName_()
 {
+  setName(title);
   if(IsFirstInitialization)
   {
-    initializeValidLegendPositions();
+    InitializeValidLegendPositions();
     IsFirstInitialization = false;
   }
   // Check if the given legend position is valid
@@ -156,7 +156,7 @@ void GraphImplementation::add(const Drawable & aDrawable)
 }
 
 /* Erase a drawable instance from the collection of drawables contained in GraphImplementation */
-void GraphImplementation::erase(const UnsignedLong i)
+void GraphImplementation::erase(const UnsignedInteger i)
 {
   drawablesCollection_.erase(drawablesCollection_.begin() + i);
 }
@@ -164,7 +164,7 @@ void GraphImplementation::erase(const UnsignedLong i)
 /* Adds a collection of drawable instances to the collection of drawables contained in GraphImplementation */
 void GraphImplementation::add(const DrawableCollection & drawableCollection)
 {
-  for (UnsignedLong i = 0; i < drawableCollection.getSize(); ++i) drawablesCollection_.add(drawableCollection[i]);
+  for (UnsignedInteger i = 0; i < drawableCollection.getSize(); ++i) drawablesCollection_.add(drawableCollection[i]);
 }
 
 /* Adds a collection of drawable instances to the collection of drawables contained in GraphImplementation */
@@ -193,14 +193,14 @@ void GraphImplementation::setDrawables(const DrawableCollection & drawableCollec
 }
 
 /* Individual drawable accessor */
-Drawable GraphImplementation::getDrawable(const UnsignedLong index) const
+Drawable GraphImplementation::getDrawable(const UnsignedInteger index) const
 {
   if (index >= drawablesCollection_.getSize()) throw InvalidRangeException(HERE) << "Error: trying to get a drawable at position " << index << " from a collection of size " << drawablesCollection_.getSize();
   return drawablesCollection_[index];
 }
 
 void GraphImplementation::setDrawable(const Drawable & drawable,
-                                      const UnsignedLong index)
+                                      const UnsignedInteger index)
 {
   if (index >= drawablesCollection_.getSize()) throw InvalidRangeException(HERE) << "Error: trying to set a drawable at position " << index << " into a collection of size " << drawablesCollection_.getSize();
   drawablesCollection_[index] = drawable;
@@ -209,39 +209,39 @@ void GraphImplementation::setDrawable(const Drawable & drawable,
 /** Global color accessor */
 Description GraphImplementation::getColors() const
 {
-  const UnsignedLong size(drawablesCollection_.getSize());
+  const UnsignedInteger size(drawablesCollection_.getSize());
   Description colors(size);
-  for (UnsignedLong i = 0; i < size; ++i) colors[i] = drawablesCollection_[i].getColor();
+  for (UnsignedInteger i = 0; i < size; ++i) colors[i] = drawablesCollection_[i].getColor();
   return colors;
 }
 
 void GraphImplementation::setColors(const Description & colors)
 {
-  const UnsignedLong size(drawablesCollection_.getSize());
-  const UnsignedLong inputSize(colors.getSize());
-  for (UnsignedLong i = 0; i < size; ++i) drawablesCollection_[i].setColor(colors[i % inputSize]);
+  const UnsignedInteger size(drawablesCollection_.getSize());
+  const UnsignedInteger inputSize(colors.getSize());
+  for (UnsignedInteger i = 0; i < size; ++i) drawablesCollection_[i].setColor(colors[i % inputSize]);
 }
 
 void GraphImplementation::setDefaultColors()
 {
-  const UnsignedLong size(drawablesCollection_.getSize());
+  const UnsignedInteger size(drawablesCollection_.getSize());
   setColors(Drawable::BuildDefaultPalette(size));
 }
 
 /** Global legend accessor */
 Description GraphImplementation::getLegends() const
 {
-  const UnsignedLong size(drawablesCollection_.getSize());
+  const UnsignedInteger size(drawablesCollection_.getSize());
   Description legends(size);
-  for (UnsignedLong i = 0; i < size; ++i) legends[i] = drawablesCollection_[i].getLegend();
+  for (UnsignedInteger i = 0; i < size; ++i) legends[i] = drawablesCollection_[i].getLegend();
   return legends;
 }
 
 void GraphImplementation::setLegends(const Description & legends)
 {
-  const UnsignedLong size(drawablesCollection_.getSize());
-  const UnsignedLong inputSize(legends.getSize());
-  for (UnsignedLong i = 0; i < size; ++i) drawablesCollection_[i].setLegend(legends[i % inputSize]);
+  const UnsignedInteger size(drawablesCollection_.getSize());
+  const UnsignedInteger inputSize(legends.getSize());
+  for (UnsignedInteger i = 0; i < size; ++i) drawablesCollection_[i].setLegend(legends[i % inputSize]);
 }
 
 
@@ -335,7 +335,14 @@ void GraphImplementation::setTitle(const String & title)
 /* Accessor for path */
 String GraphImplementation::getPath() const
 {
-  return path_;
+  String path;
+  if (fileName_.size() > 0)
+  {
+    size_t pos = fileName_.find_last_of(Os::GetDirectorySeparator());
+    if (pos != String::npos)
+      path = fileName_.substr(0, std::min(pos + 1, fileName_.size()));
+  }
+  return path;
 }
 
 /* Accessor for file name */
@@ -422,7 +429,32 @@ String GraphImplementation::getRCommand() const
 /* Make R header commande */
 String GraphImplementation::makeRHeaderCommand() const
 {
-  return OSS() << R_LEGEND << "\n" << "\n" << R_PIE << "\n" << "options(digits=17)" << "\n" << "options(warn=-1)" << "\n";
+  OSS oss;
+  // Check if we want to print a legend and if there is a legend to print before to include the corresponding R code
+  // First, do we want a legend?
+  if (legendPosition_ != "")
+  {
+    // Secodn, is there a legend to print?
+    for (UnsignedInteger i = 0; i < drawablesCollection_.getSize(); ++i)
+    {
+      if (drawablesCollection_[i].getLegend().size() > 0)
+      {
+        oss << R_LEGEND << "\n";
+        break;
+      }
+    }
+  }
+  // Check if we want to draw a Pie before to include the corresponding R code
+  for (UnsignedInteger i = 0; i < drawablesCollection_.getSize(); ++i)
+  {
+    if (drawablesCollection_[i].getImplementation()->getClassName() == Pie::GetClassName())
+    {
+      oss << "\n" << R_PIE << "\n";
+      break;
+    }
+  }
+  oss << "options(digits=17)" << "\n" << "options(warn=-1)" << "\n";
+  return oss;
 }
 
 /* Make R core command */
@@ -462,14 +494,12 @@ String GraphImplementation::makeRCoreCommand() const
     case LOGXY:
       graphCommand << ", log=\"xy\"";
       break;
-    default:
-      break;
   }
   graphCommand << ", cex.main=2, cex.axis=1.5, cex.lab=1.5)\n";
 
   // add the R code attached to each drawable
-  UnsignedLong drawablesSize(drawablesCollection_.getSize());
-  for(UnsignedLong i = 0; i < drawablesSize; ++i)
+  UnsignedInteger drawablesSize(drawablesCollection_.getSize());
+  for(UnsignedInteger i = 0; i < drawablesSize; ++i)
   {
     if (drawablesCollection_[i].getData().getSize() != 0)
       graphCommand << drawablesCollection_[i].draw() << "\n";
@@ -479,39 +509,69 @@ String GraphImplementation::makeRCoreCommand() const
   return graphCommand;
 }
 
+
+std::map<SignedInteger, String> GraphImplementation::GetExtensionMap()
+{
+  std::map<SignedInteger, String> m;
+  m[PNG] = ".png";
+  m[EPS] = ".eps";
+  m[FIG] = ".fig";
+  m[PDF] = ".pdf";
+  return m;
+}
+
 /* The method that generates the graphic files */
-void GraphImplementation::draw(const String & path,
-                               const String & file,
+void GraphImplementation::draw(const String & file,
                                const NumericalScalar width,
                                const NumericalScalar height,
-                               const Format format)
+                               SignedInteger drawingFormat)
 {
-  path_ = path;
   fileName_ = file;
-  Format drawingFormat(format);
-  // Check the needed drawingFormat. If it is invalid, ste it to ALL
-  if ((drawingFormat != ALL) && (drawingFormat != PNG) && (drawingFormat != EPS) && (drawingFormat != FIG) && (drawingFormat != PDF))
+
+  // Override format base on extension
+  size_t pos = file.find_last_of(".");
+  Bool matchedExtension = false;
+  if (pos != String::npos)
   {
+    String extension = file.substr(pos, file.length());
+    std::transform(extension.begin(), extension.end(), extension.begin(), ::tolower);
+    static std::map<SignedInteger, String> extensionMap = GetExtensionMap();
+    for(std::map<SignedInteger, String>::iterator iter = extensionMap.begin(); iter != extensionMap.end(); ++iter)
+    {
+      if (!extension.compare(iter->second))
+      {
+        drawingFormat = iter->first;
+        matchedExtension = true;
+        break;
+      }
+    }
+  }
+
+  // Check the needed drawingFormat. If it is invalid, set it to ALL
+  if (!(drawingFormat & (PNG | EPS | FIG | PDF)))
+  {
+    LOGINFO(OSS() << "Warning: invalid drawing format: " << drawingFormat << ", selecting all formats.");
     drawingFormat = ALL;
   }
+
   OSS rCommand;
   rCommand << makeRHeaderCommand();
   String rCoreCommand(makeRCoreCommand());
-  if ((drawingFormat == ALL) || (drawingFormat == EPS))
+  if (drawingFormat & EPS)
   {
-    rCommand << "postscript(\"" << getPostscript() << "\", horizontal = FALSE, onefile = FALSE, paper = \"special\", height=" << height / 72. << ", width=" << width / 72. << ")" << "\n" << rCoreCommand << "\n" << "dev.off()" << "\n";
+    rCommand << "postscript(\"" << getPostscript(matchedExtension) << "\", horizontal = FALSE, onefile = FALSE, paper = \"special\", height=" << height / 72. << ", width=" << width / 72. << ")" << "\n" << rCoreCommand << "\n" << "dev.off()" << "\n";
   }
-  if ((drawingFormat == ALL) || (drawingFormat == PDF))
+  if (drawingFormat & PDF)
   {
-    rCommand << "pdf(\"" << getPDF() << "\", onefile = FALSE, paper = \"special\", height=" << height / 72. << ", width=" << width / 72. << ")" << "\n" << rCoreCommand << "\n" << "dev.off()" << "\n";
+    rCommand << "pdf(\"" << getPDF(matchedExtension) << "\", onefile = FALSE, paper = \"special\", height=" << height / 72. << ", width=" << width / 72. << ")" << "\n" << rCoreCommand << "\n" << "dev.off()" << "\n";
   }
-  if ((drawingFormat == ALL) || (drawingFormat == PNG))
+  if (drawingFormat & PNG)
   {
-    rCommand << "png(\"" << getBitmap() << "\",height=" << height << ", width=" << width << ",res=72)" << "\n" << rCoreCommand << "\n" << "dev.off()" << "\n";
+    rCommand << "png(\"" << getBitmap(matchedExtension) << "\",height=" << height << ", width=" << width << ",res=72)" << "\n" << rCoreCommand << "\n" << "dev.off()" << "\n";
   }
-  if ((drawingFormat == ALL) || (drawingFormat == FIG))
+  if (drawingFormat & FIG)
   {
-    rCommand << "xfig(\"" << getVectorial() << "\", horizontal = FALSE, onefile = FALSE, paper = \"A4\", height=" << height / 72. << ", width=" << width / 72. << ")" << "\n" << rCoreCommand << "\n" << "dev.off()" << "\n";
+    rCommand << "xfig(\"" << getVectorial(matchedExtension) << "\", horizontal = FALSE, onefile = FALSE, paper = \"A4\", height=" << height / 72. << ", width=" << width / 72. << ")" << "\n" << rCoreCommand << "\n" << "dev.off()" << "\n";
   }
   LOGDEBUG(OSS() << "R command=" << String(rCommand));
 
@@ -526,87 +586,56 @@ void GraphImplementation::draw(const String & path,
   const String RExecutable(ResourceMap::Get("R-executable-command"));
   OSS systemCommand;
   if (RExecutable != "") systemCommand << "" << RExecutable << "" << " --no-save --silent < \"" << temporaryFileName << "\"" << Os::GetDeleteCommandOutput();
-  else throw NotYetImplementedException(HERE) << "GraphImplementation::draw() needs R. Please install it and set the absolute path of the R executable in ResourceMap.";
+  else throw NotYetImplementedException(HERE) << "In GraphImplementation::draw(): needs R. Please install it and set the absolute path of the R executable in ResourceMap.";
   if (Os::ExecuteCommand(systemCommand) != 0) throw InternalException(HERE) << "GraphImplementation: error trying to execute R command=" << String(systemCommand);
-  if (remove(temporaryFileName.c_str()) == -1) LOGWARN(OSS() << "GraphImplementation: error trying to remove file " << temporaryFileName);
+  Os::Remove(temporaryFileName);
   clean();
 }
 
+/* The method that generates the graphic files */
+void GraphImplementation::draw(const String & path,
+                               const String & file,
+                               const NumericalScalar width,
+                               const NumericalScalar height,
+                               SignedInteger format)
+{
+  draw(path + file, width, height, format);
+}
+
 /* Clean temporary files */
 void GraphImplementation::clean()
 {
-  UnsignedLong drawableNumber(drawablesCollection_.getSize());
+  UnsignedInteger drawableNumber(drawablesCollection_.getSize());
   // Clean all the temporary data created by the drawables during their drawing
-  for (UnsignedLong i = 0; i < drawableNumber; ++i)
+  for (UnsignedInteger i = 0; i < drawableNumber; ++i)
   {
     if (drawablesCollection_[i].getData().getSize() != 0)
       drawablesCollection_[i].clean();
   }
 }
 
-/* The method that generates the graphic files */
-void GraphImplementation::draw(const String & file,
-                               const NumericalScalar width,
-                               const NumericalScalar height,
-                               const Format format)
-{
-  draw("", file, width, height, format);
-}
-
 /* The method returning absolute path of the bitmap graphic file */
-String GraphImplementation::getBitmap() const
+String GraphImplementation::getBitmap(Bool matchedExtension) const
 {
-  String bitmap(path_);
-  if (path_.size() > 0)
-    if ( bitmap.find_last_of(Os::GetDirectorySeparator()) != (bitmap.length() - 1) )
-    {
-      bitmap += Os::GetDirectorySeparator();
-      bitmap += Os::GetDirectorySeparator();
-    }
-  bitmap += fileName_ + ".png";
-  return bitmap;
+  return fileName_ + (matchedExtension ? "" : ".png");
 }
 
 /* The method returning absolute path of the postscript graphic file */
-String GraphImplementation::getPostscript() const
+String GraphImplementation::getPostscript(Bool matchedExtension) const
 {
-  String postScript(path_);
-  if (path_.size() > 0)
-    if ( postScript.find_last_of(Os::GetDirectorySeparator()) != (postScript.length() - 1) )
-    {
-      postScript += Os::GetDirectorySeparator();
-      postScript += Os::GetDirectorySeparator();
-    }
-  postScript += fileName_ + ".eps";
-  return postScript;
+  return fileName_ + (matchedExtension ? "" : ".eps");
 }
 
 /* The method returning absolute path of the PDF graphic file */
-String GraphImplementation::getPDF() const
+String GraphImplementation::getPDF(Bool matchedExtension) const
 {
-  String pdf(path_);
-  if (path_.size() > 0)
-    if ( pdf.find_last_of(Os::GetDirectorySeparator()) != (pdf.length() - 1) )
-    {
-      pdf += Os::GetDirectorySeparator();
-      pdf += Os::GetDirectorySeparator();
-    }
-  pdf += fileName_ + ".pdf";
-  return pdf;
+  return fileName_ + (matchedExtension ? "" : ".pdf");
 }
 
 /* The method returning absolute path of the vectorial graphic file */
-String GraphImplementation::getVectorial() const
+String GraphImplementation::getVectorial(Bool matchedExtension) const
 {
-  String vectorial(path_);
-  if (path_.size() > 0)
-    if ( vectorial.find_last_of(Os::GetDirectorySeparator()) != (vectorial.length() - 1) )
-    {
-      vectorial += Os::GetDirectorySeparator();
-      vectorial += Os::GetDirectorySeparator();
-    }
-  vectorial += fileName_ + ".fig";
-  return vectorial;
+  return fileName_ + (matchedExtension ? "" : ".fig");
 }
 
 /* Get the bounding box of the whole plot */
@@ -619,14 +648,14 @@ GraphImplementation::BoundingBox GraphImplementation::getBoundingBox() const
 /* Set the bounding box of the whole plot */
 void GraphImplementation::setBoundingBox(const BoundingBox & boundingBox)
 {
-  if (boundingBox.getDimension() != 4) throw InvalidArgumentException(HERE) << "Error: the given bounding box must have a dimension equals to 4, here boundingBox=" << boundingBox;
+  if (boundingBox.getDimension() != 4) throw InvalidArgumentException(HERE) << "Error: the given bounding box must have a dimension equal to 4, here boundingBox=" << boundingBox;
   boundingBox_ = boundingBox;
   automaticBoundingBox_ = false;
 }
 
 void GraphImplementation::setBoundingBox(const Interval & boundingBox)
 {
-  if (boundingBox.getDimension() != 2) throw InvalidArgumentException(HERE) << "Error: the given bounding box must have a dimension equals to 2";
+  if (boundingBox.getDimension() != 2) throw InvalidArgumentException(HERE) << "Error: the given bounding box must have a dimension equal to 2";
   if (!boundingBox.getFiniteLowerBound()[0])  throw InvalidArgumentException(HERE) << "Error: the lower bound of the first component must be finite";
   if (!boundingBox.getFiniteLowerBound()[1])  throw InvalidArgumentException(HERE) << "Error: the lower bound of the second component must be finite";
   if (!boundingBox.getFiniteUpperBound()[0])  throw InvalidArgumentException(HERE) << "Error: the upper bound of the first component must be finite";
@@ -652,7 +681,7 @@ void GraphImplementation::setAutomaticBoundingBox(const Bool automaticBoundingBo
 /* Compute the best bounding box to enclose all the drawables */
 void GraphImplementation::computeBoundingBox() const
 {
-  UnsignedLong size(drawablesCollection_.getSize());
+  UnsignedInteger size(drawablesCollection_.getSize());
   boundingBox_ = BoundingBox(4);
   // First exceptional case: no drawable, we default to default bounding box
   if (size == 0)
@@ -667,7 +696,7 @@ void GraphImplementation::computeBoundingBox() const
   NumericalSample boxes(size, 4);
 
   // first, get each Drawable's bounding box and drawing command
-  for(UnsignedLong i = 0; i < size; ++i)
+  for(UnsignedInteger i = 0; i < size; ++i)
   {
     if (drawablesCollection_[i].getData().getSize() != 0)
       boxes[i] = drawablesCollection_[i].getBoundingBox();
@@ -712,7 +741,7 @@ Description GraphImplementation::GetValidLegendPositions()
 {
   if(IsFirstInitialization)
   {
-    initializeValidLegendPositions();
+    InitializeValidLegendPositions();
     IsFirstInitialization = false;
   }
   return ValidLegendPositions;
@@ -751,7 +780,6 @@ void GraphImplementation::save(Advocate & adv) const
   adv.saveAttribute( "yTitle_", yTitle_ );
   adv.saveAttribute( "showAxes_", showAxes_ );
   adv.saveAttribute( "drawablesCollection_", drawablesCollection_ );
-  adv.saveAttribute( "path_", path_ );
   adv.saveAttribute( "fileName_", fileName_ );
 }
 
@@ -766,7 +794,6 @@ void GraphImplementation::load(Advocate & adv)
   adv.loadAttribute( "yTitle_", yTitle_ );
   adv.loadAttribute( "showAxes_", showAxes_ );
   adv.loadAttribute( "drawablesCollection_", drawablesCollection_ );
-  adv.loadAttribute( "path_", path_ );
   adv.loadAttribute( "fileName_", fileName_ );
 }
 
