@@ -3,7 +3,7 @@
  *  @file  Pairs.cxx
  *  @brief Pairs class for contourchart plots
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -27,6 +27,7 @@
 
 #include "PersistentObjectFactory.hxx"
 #include "Log.hxx"
+#include "Os.hxx"
 #include "ResourceMap.hxx"
 #include "Pairs.hxx"
 
@@ -95,7 +96,7 @@ void Pairs::setLabels(const Description & labels)
 void Pairs::clean() const
 {
   DrawableImplementation::clean();
-  if ((dataFileName_ != "") && (remove(dataFileName_.c_str()) == -1)) LOGWARN(OSS() << "Could not remove file " << dataFileName_);
+  if (dataFileName_ != "") Os::Remove(dataFileName_);
 }
 
 /* Draw method */
@@ -111,8 +112,8 @@ String Pairs::draw() const
     oss << "size_ <- " << data_.getSize() << "\n";
     oss << DrawableImplementation::draw() << "\n";
     oss << "description=c(";
-    const UnsignedLong length(data_.getDimension());
-    for(UnsignedLong i = 0; i < length - 1; ++i) oss << "\"" << labels_[i] << "\"" << ",";
+    const UnsignedInteger length(data_.getDimension());
+    for(UnsignedInteger i = 0; i < length - 1; ++i) oss << "\"" << labels_[i] << "\"" << ",";
     oss << "\"" << labels_[length - 1] << "\"" << ") \n";
     // DataFrame organisation
     const String code((OSS() << getPointCode(pointStyle_)));
@@ -153,25 +154,25 @@ void Pairs::checkData(const NumericalSample & data) const
 /* Build default labels by taking the level values */
 void Pairs::buildDefaultLabels()
 {
-  const UnsignedLong number(data_.getDimension());
+  const UnsignedInteger number(data_.getDimension());
   labels_ = Description(number);
-  for (UnsignedLong i = 0; i < number; ++i) labels_[i] = OSS() << "V" << i + 1;
+  for (UnsignedInteger i = 0; i < number; ++i) labels_[i] = OSS() << "V" << i + 1;
 }
 
 /* Method save() stores the object through the StorageManager */
 void Pairs::save(Advocate & adv) const
 {
   DrawableImplementation::save(adv);
-  adv.saveAttribute( "title_", title_ );
   adv.saveAttribute( "labels_", labels_ );
+  adv.saveAttribute( "title_", title_ );
 }
 
 /* Method load() reloads the object from the StorageManager */
 void Pairs::load(Advocate & adv)
 {
   DrawableImplementation::load(adv);
-  adv.loadAttribute( "title_", title_ );
   adv.loadAttribute( "labels_", labels_ );
+  adv.loadAttribute( "title_", title_ );
 }
 
 
