@@ -3,7 +3,7 @@
  *  @file  Pie.cxx
  *  @brief Pie class for piechart plots
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -27,6 +27,7 @@
 #include "PersistentObjectFactory.hxx"
 #include "ResourceMap.hxx"
 #include "Log.hxx"
+#include "SpecFunc.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -160,13 +161,13 @@ String Pie::draw() const
   oss << "pie(dataOT[,1],"
       << "center=c(" << center_[0] << "," << center_[1]
       << "),radius=" << radius_;
-  UnsignedLong size(labels_.getSize());
+  UnsignedInteger size(labels_.getSize());
   // If there is any label defined
   if (size > 0)
   {
     oss << ",labels=c(\"";
     String separator("");
-    for(UnsignedLong i = 0; i < size; ++i, separator = "\",\"") oss << separator << (data_[i][0] >= labelThreshold ? labels_[i] : "");
+    for(UnsignedInteger i = 0; i < size; ++i, separator = "\",\"") oss << separator << (data_[i][0] >= labelThreshold ? labels_[i] : "");
     oss << "\")";
   }
   size = palette_.getSize();
@@ -175,7 +176,7 @@ String Pie::draw() const
   {
     oss << ",col=c(\"";
     String separator("");
-    for(UnsignedLong i = 0; i < size; ++i, separator = "\",\"") oss << separator << palette_[i];
+    for(UnsignedInteger i = 0; i < size; ++i, separator = "\",\"") oss << separator << palette_[i];
     oss << "\")";
   }
   oss << ")";
@@ -200,7 +201,7 @@ Bool Pie::IsValidColorPalette(const Description & palette)
 
 void Pie::checkData(const NumericalPoint & data) const
 {
-  const UnsignedLong size(data.getSize());
+  const UnsignedInteger size(data.getSize());
   // Check if there is any data to display
   if (size == 0)
   {
@@ -209,7 +210,7 @@ void Pie::checkData(const NumericalPoint & data) const
 
   // Then, check the positivity of the data
   NumericalScalar max(0.0);
-  for (UnsignedLong i = 0; i < size; ++i)
+  for (UnsignedInteger i = 0; i < size; ++i)
   {
     NumericalScalar x(data[i]);
     if (x < 0.0)
@@ -237,11 +238,11 @@ void Pie::buildDefaultPalette()
 /* Build default labels */
 void Pie::buildDefaultLabels()
 {
-  const UnsignedLong size(data_.getSize());
+  const UnsignedInteger size(data_.getSize());
   labels_ = Description(size);
   NumericalScalar sum(0.0);
-  for (UnsignedLong i = 0; i < size; ++i) sum += data_[i][0];
-  for (UnsignedLong i = 0; i < size; ++i) labels_[i] = String(OSS() << "L" << i << " " << 0.1 * round(1000.0 * data_[i][0] / sum) << "%");
+  for (UnsignedInteger i = 0; i < size; ++i) sum += data_[i][0];
+  for (UnsignedInteger i = 0; i < size; ++i) labels_[i] = String(OSS() << "L" << i << " " << 0.1 * round(1000.0 * data_[i][0] / sum) << "%");
 }
 
 /* Method save() stores the object through the StorageManager */
