@@ -3,7 +3,7 @@
  *  @file  Polygon.cxx
  *  @brief Polygon class for polygon plots
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -34,6 +34,7 @@ static Factory<Polygon> RegisteredFactory("Polygon");
 /* Default constructor */
 Polygon::Polygon(const String & legend)
   : DrawableImplementation(NumericalSample(0, 2), legend)
+  , edgeColor_("")
 {
   // Nothing to do
   setEdgeColor(getColor());
@@ -43,6 +44,7 @@ Polygon::Polygon(const String & legend)
 Polygon::Polygon(const NumericalSample & data,
                  const String & legend)
   : DrawableImplementation(NumericalSample(0, 2), legend)
+  , edgeColor_("")
 {
   // Check data validity
   setData(data);
@@ -54,12 +56,13 @@ Polygon::Polygon(const NumericalSample & dataX,
                  const NumericalSample & dataY,
                  const String & legend)
   : DrawableImplementation(NumericalSample(0, 2), legend)
+  , edgeColor_("")
 {
-  const UnsignedLong size(dataX.getSize());
+  const UnsignedInteger size(dataX.getSize());
   if (dataY.getSize() != size) throw InvalidArgumentException(HERE) << "Error: cannot build a Polygon based on two numerical samples with different size.";
   if ((dataX.getDimension() != 1) || (dataY.getDimension() != 1)) throw InvalidArgumentException(HERE) << "Error: cannot build a Polygon based on two numerical samples of dimension greater than 1.";
   NumericalSample dataFull(size, 2);
-  for (UnsignedLong i = 0; i < size; ++i)
+  for (UnsignedInteger i = 0; i < size; ++i)
   {
     dataFull[i][0] = dataX[i][0];
     dataFull[i][1] = dataY[i][0];
@@ -74,11 +77,12 @@ Polygon::Polygon(const NumericalPoint & dataX,
                  const NumericalPoint & dataY,
                  const String & legend)
   : DrawableImplementation(NumericalSample(0, 2), legend)
+  , edgeColor_("")
 {
-  const UnsignedLong size(dataX.getDimension());
+  const UnsignedInteger size(dataX.getDimension());
   if (dataY.getDimension() != size) throw InvalidArgumentException(HERE) << "Error: cannot build a Polygon based on two numerical points with different size.";
   NumericalSample dataFull(size, 2);
-  for (UnsignedLong i = 0; i < size; ++i)
+  for (UnsignedInteger i = 0; i < size; ++i)
   {
     dataFull[i][0] = dataX[i];
     dataFull[i][1] = dataY[i];
@@ -94,14 +98,15 @@ Polygon::Polygon(const NumericalSample & data,
                  const String & edgeColor,
                  const String & legend)
   : DrawableImplementation(NumericalSample(0, 2), legend)
+  , edgeColor_("")
 {
   NumericalSample dataFull;
   // If data is unidimensional, assume that it means Y values with indices as X values
   if (data.getDimension() == 1)
   {
-    const UnsignedLong size(data.getSize());
+    const UnsignedInteger size(data.getSize());
     dataFull = NumericalSample(size, 2);
-    for (UnsignedLong i = 0; i < size; ++i)
+    for (UnsignedInteger i = 0; i < size; ++i)
     {
       dataFull[i][0] = i;
       dataFull[i][1] = data[i][0];
@@ -111,7 +116,7 @@ Polygon::Polygon(const NumericalSample & data,
   // Check data validity
   setData(dataFull);
   setColor(color);
-  setEdgeColor(getColor());
+  setEdgeColor(edgeColor);
 }
 
 /* String converter */
@@ -131,22 +136,19 @@ String Polygon::draw() const
   dataFileName_ = "";
   OSS oss;
   // Stores the data in a temporary file
-  oss << DrawableImplementation::draw() << "\n";
+  oss << DrawableImplementation::draw();
   // The specific R command for drawing
   oss << "polygon(dataOT[,1], dataOT[,2]"
-      << ", border=\"" << edgeColor_
-      << "\", lty=\"" << lineStyle_
-      << "\", col=\"" << color_
-      << "\", lwd=" << lineWidth_;
+      << ", border="
+      << "\"" << edgeColor_ << "\""
+      << ", lty=\"" << lineStyle_ << "\""
+      << ", col="
+      << "\"" << color_ << "\""
+      << ", lwd=" << lineWidth_;
   if (pointStyle_ != "none")
   {
     const String code((OSS() << getPointCode(pointStyle_)));
-    oss << ", type=\"b\""
-        << ", pch=" << (pointStyle_ == "dot" ? "\".\"" : code);
-  }
-  else
-  {
-    oss << ", type=\"l\"";
+    oss << ", pch=" << (pointStyle_ == "dot" ? "\".\"" : code);
   }
   oss << ")";
 
@@ -185,12 +187,14 @@ void Polygon::setEdgeColor(const String & edgeColor)
 void Polygon::save(Advocate & adv) const
 {
   DrawableImplementation::save(adv);
+  adv.saveAttribute( "edgeColor_", edgeColor_ );
 }
 
 /* Method load() reloads the object from the StorageManager */
 void Polygon::load(Advocate & adv)
 {
   DrawableImplementation::load(adv);
+  adv.loadAttribute( "edgeColor_", edgeColor_ );
 }
 
 END_NAMESPACE_OPENTURNS
