@@ -3,7 +3,7 @@
  *  @file  Staircase.cxx
  *  @brief Staircase class for staircase plots
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -54,7 +54,7 @@ Staircase::Staircase(const NumericalSample & data,
 Staircase::Staircase(const NumericalSample & data,
                      const String & color,
                      const String & lineStyle,
-                     const UnsignedLong lineWidth,
+                     const UnsignedInteger lineWidth,
                      const String & pattern,
                      const String & legend)
   : DrawableImplementation(data, legend)
