@@ -3,7 +3,7 @@
  *  @file  LinearLeastSquares.cxx
  *  @brief First order polynomial response surface by least square
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -36,24 +36,22 @@ CLASSNAMEINIT(LinearLeastSquares);
 
 /* Constructor with parameters */
 LinearLeastSquares::LinearLeastSquares(const NumericalSample & dataIn,
-                                       const NumericalMathFunction & inputFunction,
-                                       const String & name)
-  : PersistentObject(name),
+                                       const NumericalMathFunction & inputFunction)
+  : PersistentObject(),
     dataIn_(dataIn),
     dataOut_(0, inputFunction.getOutputDimension()),
     inputFunction_(inputFunction),
     constant_(inputFunction.getOutputDimension()),
     linear_(inputFunction.getInputDimension(), inputFunction.getOutputDimension())
 {
-  if (!inputFunction.getEvaluationImplementation()->isActualImplementation()) throw InvalidArgumentException(HERE) << "Error: the given function must have an actual implementation";
+  if (!inputFunction.getEvaluation()->isActualImplementation()) throw InvalidArgumentException(HERE) << "Error: the given function must have an actual implementation";
   if (inputFunction.getInputDimension() != dataIn.getDimension()) throw InvalidArgumentException(HERE) << "Error: the input data dimension and the input dimension of the function must be the same, here input dimension=" << dataIn.getDimension() << " and input dimension of the function=" << inputFunction.getInputDimension();
 }
 
 /* Constructor with parameters */
 LinearLeastSquares::LinearLeastSquares(const NumericalSample & dataIn,
-                                       const NumericalSample & dataOut,
-                                       const String & name)
-  : PersistentObject(name),
+                                       const NumericalSample & dataOut)
+  : PersistentObject(),
     dataIn_(dataIn),
     dataOut_(0, dataOut.getDimension()),
     inputFunction_(),
@@ -92,32 +90,32 @@ void LinearLeastSquares::run()
     /* Compute the given function over the given sample */
     dataOut_ = inputFunction_(dataIn_);
   }
-  const UnsignedLong inputDimension(dataIn_.getDimension());
-  const UnsignedLong outputDimension(dataOut_.getDimension());
-  const UnsignedLong dataInSize(dataIn_.getSize());
-  const UnsignedLong coefficientsDimension(1 + inputDimension);
+  const UnsignedInteger inputDimension(dataIn_.getDimension());
+  const UnsignedInteger outputDimension(dataOut_.getDimension());
+  const UnsignedInteger dataInSize(dataIn_.getSize());
+  const UnsignedInteger coefficientsDimension(1 + inputDimension);
   /* Matrix of the least-square problem */
   Matrix componentMatrix(dataInSize, coefficientsDimension);
   /* Matrix for the several right-hand sides */
   Matrix rightHandSides(dataInSize, outputDimension);
   /* For each sample of the input data... */
-  for(UnsignedLong sampleIndex = 0; sampleIndex < dataInSize; ++sampleIndex)
+  for(UnsignedInteger sampleIndex = 0; sampleIndex < dataInSize; ++sampleIndex)
   {
     /* build the componentMatrix */
     /* get the current sample x */
     const NumericalPoint currentSample(dataIn_[sampleIndex]);
-    UnsignedLong rowIndex(0);
+    UnsignedInteger rowIndex(0);
     /* First the constant term */
     componentMatrix(sampleIndex, rowIndex) = 1.0;
     ++rowIndex;
     /* Then the linear term x' */
-    for(UnsignedLong componentIndex = 0; componentIndex < inputDimension; ++componentIndex)
+    for(UnsignedInteger componentIndex = 0; componentIndex < inputDimension; ++componentIndex)
     {
       componentMatrix(sampleIndex, rowIndex) = currentSample[componentIndex];
       ++rowIndex;
     } // linear term
     /* build the right-hand side */
-    for(UnsignedLong outputIndex = 0; outputIndex < outputDimension; ++outputIndex)
+    for(UnsignedInteger outputIndex = 0; outputIndex < outputDimension; ++outputIndex)
     {
       rightHandSides(sampleIndex, outputIndex) = dataOut_[sampleIndex][outputIndex];
     }
@@ -125,14 +123,14 @@ void LinearLeastSquares::run()
   // Now, solve simultaneously the least-squares solutions for all the outputs
   const Matrix coefficients(componentMatrix.solveLinearSystem(rightHandSides));
   // Fill-in the elements of the meta-model
-  for(UnsignedLong outputComponent = 0; outputComponent < outputDimension; ++outputComponent)
+  for(UnsignedInteger outputComponent = 0; outputComponent < outputDimension; ++outputComponent)
   {
     /* First, the constant term */
-    UnsignedLong coefficientsIndex(0);
+    UnsignedInteger coefficientsIndex(0);
     constant_[outputComponent] = coefficients(coefficientsIndex, outputComponent);
     ++coefficientsIndex;
     /* Second, the linear term */
-    for(UnsignedLong componentIndex = 0; componentIndex < inputDimension; ++componentIndex)
+    for(UnsignedInteger componentIndex = 0; componentIndex < inputDimension; ++componentIndex)
     {
       linear_(componentIndex, outputComponent) = coefficients(coefficientsIndex, outputComponent);
       ++coefficientsIndex;
@@ -140,9 +138,9 @@ void LinearLeastSquares::run()
   } // output components
   const NumericalPoint center(inputDimension, 0.0);
   /* Build the several implementations and set them into the response surface */
-  responseSurface_.setEvaluationImplementation(new LinearNumericalMathEvaluationImplementation(center, constant_, linear_));
-  responseSurface_.setGradientImplementation(new ConstantNumericalMathGradientImplementation(linear_));
-  responseSurface_.setHessianImplementation(new ConstantNumericalMathHessianImplementation(SymmetricTensor(center.getDimension(), constant_.getDimension())));
+  responseSurface_.setEvaluation(new LinearNumericalMathEvaluationImplementation(center, constant_, linear_));
+  responseSurface_.setGradient(new ConstantNumericalMathGradientImplementation(linear_));
+  responseSurface_.setHessian(new ConstantNumericalMathHessianImplementation(SymmetricTensor(center.getDimension(), constant_.getDimension())));
 }
 
 /* DataIn accessor */
@@ -152,16 +150,16 @@ NumericalSample LinearLeastSquares::getDataIn() const
 }
 
 /* DataOut accessor */
-NumericalSample LinearLeastSquares::getDataOut()
+NumericalSample LinearLeastSquares::getDataOut() const
 {
   // If the response surface has been defined with an input function and the output data have not already been computed, compute them
-  if (inputFunction_.getEvaluationImplementation()->isActualImplementation() && (dataOut_.getSize() == 0)) dataOut_ = inputFunction_(dataIn_);
+  if (inputFunction_.getEvaluation()->isActualImplementation() && (dataOut_.getSize() == 0)) dataOut_ = inputFunction_(dataIn_);
   return dataOut_;
 }
 
 void LinearLeastSquares::setDataOut(const NumericalSample & dataOut)
 {
-  if (inputFunction_.getEvaluationImplementation()->isActualImplementation()) throw InvalidArgumentException(HERE) << "Error: cannot set the output data in a response surface defined with a function, here function=" << inputFunction_;
+  if (inputFunction_.getEvaluation()->isActualImplementation()) throw InvalidArgumentException(HERE) << "Error: cannot set the output data in a response surface defined with a function, here function=" << inputFunction_;
   if (dataOut.getSize() != dataIn_.getSize()) throw InvalidArgumentException(HERE) << "Error: the output data must have the same size than the input data, here output size=" << dataOut.getSize() << " and input size=" << dataIn_.getSize();
   dataOut_ = dataOut;
 }
