@@ -3,7 +3,7 @@
  *  @file  RungeKutta.cxx
  *  @brief This class implements the fourth order fixed-step Runge-Kutta ODE integrator
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -63,13 +63,13 @@ NumericalSample RungeKutta::solve(const NumericalPoint & initialState,
 {
   if (initialState.getDimension() != transitionFunction_.getInputDimension()) throw InvalidArgumentException(HERE) << "Error: the initial state has a dimension=" << initialState.getDimension() << ", expected dimension=" << transitionFunction_.getInputDimension();
   // Quick return if the time grid is empty
-  const UnsignedLong steps(timeGrid.getSize());
+  const UnsignedInteger steps(timeGrid.getSize());
   NumericalSample result(steps, transitionFunction_.getOutputDimension());
   if (steps == 0) return result;
   NumericalScalar t(timeGrid[0]);
   NumericalPoint state(initialState);
   result[0] = state;
-  for (UnsignedLong i = 1; i < steps; ++i)
+  for (UnsignedInteger i = 1; i < steps; ++i)
   {
     const NumericalScalar newT(timeGrid[i]);
     const NumericalScalar timeStep(newT - t);
