@@ -3,7 +3,7 @@
  *  @file  Solver.cxx
  *  @brief Interface class for a nonlinear scalar solver
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -52,7 +52,7 @@ Solver::Solver():
 Solver::Solver(const NumericalScalar absoluteError,
                const NumericalScalar relativeError,
                const NumericalScalar residualError,
-               const UnsignedLong maximumFunctionEvaluation):
+               const UnsignedInteger maximumFunctionEvaluation):
   TypedInterfaceObject<SolverImplementation>(new SolverImplementation(absoluteError, relativeError, residualError, maximumFunctionEvaluation))
 {
   // Nothing to do
@@ -130,15 +130,21 @@ NumericalScalar Solver::getResidualError() const
 }
 
 /* Maximum function evaluation accessor */
-void Solver::setMaximumFunctionEvaluation(const UnsignedLong maximumFunctionEvaluation)
+void Solver::setMaximumFunctionEvaluation(const UnsignedInteger maximumFunctionEvaluation)
 {
   copyOnWrite();
   getImplementation()->setMaximumFunctionEvaluation(maximumFunctionEvaluation);
 }
 
-UnsignedLong Solver::getMaximumFunctionEvaluation() const
+UnsignedInteger Solver::getMaximumFunctionEvaluation() const
 {
   return getImplementation()->getMaximumFunctionEvaluation();
 }
 
+UnsignedInteger Solver::getUsedFunctionEvaluation() const
+{
+  return getImplementation()->getUsedFunctionEvaluation();
+}
+
+
 END_NAMESPACE_OPENTURNS
