@@ -3,7 +3,7 @@
  *  @file  CorrelationMatrix.cxx
  *  @brief The class CorrelationMatrix implements correlation matrices
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -25,8 +25,6 @@
 
 BEGIN_NAMESPACE_OPENTURNS
 
-
-
 CLASSNAMEINIT(CorrelationMatrix);
 
 /* Default constructor */
@@ -36,8 +34,23 @@ CorrelationMatrix::CorrelationMatrix()
   // Nothing to do
 }
 
+/* Constructor with implementation */
+CorrelationMatrix::CorrelationMatrix(const Implementation & i)
+  : CovarianceMatrix(i)
+{
+  // Nothing to do
+}
+
+
+/* Constructor with implementation */
+CorrelationMatrix::CorrelationMatrix(const MatrixImplementation & i)
+  : CovarianceMatrix(i)
+{
+  // Nothing to do
+}
+
 /* Constructor with size (dim, which is the same for nbRows_ and nbColumns_ )*/
-CorrelationMatrix::CorrelationMatrix(const UnsignedLong dim)
+CorrelationMatrix::CorrelationMatrix(const UnsignedInteger dim)
   : CovarianceMatrix(dim)
 {
   // Nothing to do
@@ -47,20 +60,13 @@ CorrelationMatrix::CorrelationMatrix(const UnsignedLong dim)
 /* If the dimensions of the matrix and of the collection */
 /* do not match, either the collection is truncated */
 /* or the rest of the matrix is filled with zeros */
-CorrelationMatrix::CorrelationMatrix(const UnsignedLong dim,
+CorrelationMatrix::CorrelationMatrix(const UnsignedInteger dim,
                                      const Collection<NumericalScalar> &elementsValues)
   : CovarianceMatrix(dim, elementsValues)
 {
   // Nothing to do
 }
 
-/* Constructor with implementation */
-CorrelationMatrix::CorrelationMatrix(const Implementation & i)
-  : CovarianceMatrix(i)
-{
-  // Nothing to do
-}
-
 /* String converter */
 String CorrelationMatrix::__repr__() const
 {
