@@ -3,7 +3,7 @@
  *  @file  CovarianceModelFactory.cxx
  *  @brief Top-level class for all spectral model factories
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -23,42 +23,39 @@
  *  @date:   $LastChangedDate$
  *  Id:      $Id$
  */
-#include "CovarianceModelFactory.hxx"
 
+#include "CovarianceModelFactory.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
 CLASSNAMEINIT(CovarianceModelFactory);
 
 /* Default constructor */
-CovarianceModelFactory::CovarianceModelFactory(const String & name)
-  : TypedInterfaceObject<CovarianceModelFactoryImplementation>(new CovarianceModelFactoryImplementation(name))
+CovarianceModelFactory::CovarianceModelFactory()
+  : TypedInterfaceObject<CovarianceModelFactoryImplementation>(new CovarianceModelFactoryImplementation())
 {
   // Nothing to do
 }
 
 /* Parameters constructor */
-CovarianceModelFactory::CovarianceModelFactory(const CovarianceModelFactoryImplementation & implementation,
-    const String & name)
+CovarianceModelFactory::CovarianceModelFactory(const CovarianceModelFactoryImplementation & implementation)
   : TypedInterfaceObject<CovarianceModelFactoryImplementation>(implementation.clone())
 {
-  getImplementation()->setName(name);
+  // Nothing to do
 }
 
 /* Constructor from implementation */
-CovarianceModelFactory::CovarianceModelFactory(const Implementation & p_implementation,
-    const String & name)
+CovarianceModelFactory::CovarianceModelFactory(const Implementation & p_implementation)
   : TypedInterfaceObject<CovarianceModelFactoryImplementation>(p_implementation)
 {
-  getImplementation()->setName(name);
+  // Nothing to do
 }
 
 /* Constructor from implementation pointer */
-CovarianceModelFactory::CovarianceModelFactory(CovarianceModelFactoryImplementation * p_implementation,
-    const String & name)
+CovarianceModelFactory::CovarianceModelFactory(CovarianceModelFactoryImplementation * p_implementation)
   : TypedInterfaceObject<CovarianceModelFactoryImplementation>(p_implementation)
 {
-  getImplementation()->setName(name);
+  // Nothing to do
 }
 
 
