@@ -3,7 +3,7 @@
  *  @file  CovarianceModelFactoryImplementation.cxx
  *  @brief Top-level class for all spectral model factories
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -33,11 +33,9 @@ BEGIN_NAMESPACE_OPENTURNS
 CLASSNAMEINIT(CovarianceModelFactoryImplementation);
 static Factory<CovarianceModelFactoryImplementation> RegisteredFactory("CovarianceModelFactoryImplementation");
 
-typedef NotYetImplementedException NotYetImplementedException;
-
 /* Default constructor */
-CovarianceModelFactoryImplementation::CovarianceModelFactoryImplementation(const String & name)
-  : PersistentObject(name)
+CovarianceModelFactoryImplementation::CovarianceModelFactoryImplementation()
+  : PersistentObject()
 {
   // Nothing to do
 }
@@ -66,12 +64,12 @@ String CovarianceModelFactoryImplementation::__str__(const String & offset) cons
 
 CovarianceModelImplementation::Implementation CovarianceModelFactoryImplementation::build(const ProcessSample & sample) const
 {
-  throw NotYetImplementedException(HERE);
+  throw NotYetImplementedException(HERE) << "In CovarianceModelFactoryImplementation::build(const ProcessSample & sample) const";
 }
 
 CovarianceModelImplementation::Implementation CovarianceModelFactoryImplementation::build(const Field & timeSeries) const
 {
-  throw NotYetImplementedException(HERE);
+  throw NotYetImplementedException(HERE) << "In CovarianceModelFactoryImplementation::build(const Field & timeSeries) const";
 }
 
 /* Method save() stores the object through the StorageManager */
