@@ -4,7 +4,7 @@
  *  @brief The class FieldImplementation implements values indexed by
  *  the vertices of a Mesh
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -35,9 +35,10 @@
 #include "Path.hxx"
 #include "Cloud.hxx"
 #include "Curve.hxx"
+#include "PolygonArray.hxx"
 #include "Os.hxx"
-#include "TBB.hxx"
 #include "PlatformInfo.hxx"
+#include "SpecFunc.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -55,22 +56,26 @@ FieldImplementation::FieldImplementation()
   , mesh_()
   , values_(0, 0)
   , description_(mesh_.getDescription())
+  , spatialMean_(0)
+  , isAlreadyComputedSpatialMean_(false)
 {
   // Nothing to do
 }
 
 /* Standard constructor */
 FieldImplementation::FieldImplementation(const Mesh & mesh,
-    const UnsignedLong dim)
+    const UnsignedInteger dim)
   : PersistentObject()
   , mesh_(mesh)
   , values_(mesh.getVerticesNumber(), dim)
   , description_(0)
+  , spatialMean_(dim)
+  , isAlreadyComputedSpatialMean_(false)
 {
   // Build the default description
-  Description description(getMeshDimension() + getDimension());
-  for (UnsignedLong i = 0; i < getMeshDimension(); ++i) description[i] = mesh_.getVertices().getDescription()[i];
-  for (UnsignedLong i = 0; i < getDimension(); ++i) description[getMeshDimension() + i] = values_.getDescription()[i];
+  Description description(getSpatialDimension() + getDimension());
+  for (UnsignedInteger i = 0; i < getSpatialDimension(); ++i) description[i] = mesh_.getVertices().getDescription()[i];
+  for (UnsignedInteger i = 0; i < getDimension(); ++i) description[getSpatialDimension() + i] = values_.getDescription()[i];
   setDescription(description);
 }
 
@@ -81,11 +86,13 @@ FieldImplementation::FieldImplementation(const Mesh & mesh,
   , mesh_(mesh)
   , values_(values)
   , description_()
+  , spatialMean_(values.getDimension())
+  , isAlreadyComputedSpatialMean_(false)
 {
   if (mesh.getVerticesNumber() != values.getSize()) throw InvalidArgumentException(HERE) << "Error: cannot build a Field with a number of values=" << values.getSize() << " different from the number of vertices=" << mesh.getVerticesNumber();
-  Description description(getMeshDimension() + getDimension());
-  for (UnsignedLong i = 0; i < getMeshDimension(); ++i) description[i] = mesh_.getVertices().getDescription()[i];
-  for (UnsignedLong i = 0; i < getDimension(); ++i) description[getMeshDimension() + i] = values_.getDescription()[i];
+  Description description(getSpatialDimension() + getDimension());
+  for (UnsignedInteger i = 0; i < getSpatialDimension(); ++i) description[i] = mesh_.getVertices().getDescription()[i];
+  for (UnsignedInteger i = 0; i < getDimension(); ++i) description[getSpatialDimension() + i] = values_.getDescription()[i];
   setDescription(description);
 }
 
@@ -96,18 +103,18 @@ FieldImplementation * FieldImplementation::clone() const
 }
 
 /* Size accessor */
-UnsignedLong FieldImplementation::getSize() const
+UnsignedInteger FieldImplementation::getSize() const
 {
   return values_.getSize();
 }
 
 /* Dimension accessor */
-UnsignedLong FieldImplementation::getMeshDimension() const
+UnsignedInteger FieldImplementation::getSpatialDimension() const
 {
   return mesh_.getDimension();
 }
 
-UnsignedLong FieldImplementation::getDimension() const
+UnsignedInteger FieldImplementation::getDimension() const
 {
   return values_.getDimension();
 }
@@ -124,19 +131,21 @@ RegularGrid FieldImplementation::getTimeGrid() const
 }
 
 /* Individual value accessor */
-NSI_point FieldImplementation::operator[](const UnsignedLong index)
+NSI_point FieldImplementation::operator[](const UnsignedInteger index)
+{
+  isAlreadyComputedSpatialMean_ = false;
+  return values_[index];
+}
+
+NSI_const_point FieldImplementation::operator[](const UnsignedInteger index) const
 {
   return values_[index];
 }
 
-NSI_const_point FieldImplementation::operator[](const UnsignedLong index) const
-{
-  return values_[index];
-}
-
-NumericalScalar & FieldImplementation::operator () (const UnsignedLong i,
-    const UnsignedLong j)
+NumericalScalar & FieldImplementation::operator () (const UnsignedInteger i,
+    const UnsignedInteger j)
 {
+  isAlreadyComputedSpatialMean_ = false;
 #ifdef DEBUG_BOUNDCHECKING
   // No copyOnWrite() as the at() method already do it
   return at(i, j);
@@ -145,8 +154,8 @@ NumericalScalar & FieldImplementation::operator () (const UnsignedLong i,
 #endif /* DEBUG_BOUNDCHECKING */
 }
 
-const NumericalScalar & FieldImplementation::operator () (const UnsignedLong i,
-    const UnsignedLong j) const
+const NumericalScalar & FieldImplementation::operator () (const UnsignedInteger i,
+    const UnsignedInteger j) const
 {
 #ifdef DEBUG_BOUNDCHECKING
   return at(i, j);
@@ -156,28 +165,30 @@ const NumericalScalar & FieldImplementation::operator () (const UnsignedLong i,
 }
 
 
-NSI_point FieldImplementation::at (const UnsignedLong index)
+NSI_point FieldImplementation::at (const UnsignedInteger index)
+{
+  if (index >= getSize()) throw OutOfBoundException(HERE) << "Index (" << index << ") is not less than size (" << getSize() << ")";
+  isAlreadyComputedSpatialMean_ = false;
+  return (*this)[index];
+}
+
+NSI_const_point FieldImplementation::at (const UnsignedInteger index) const
 {
   if (index >= getSize()) throw OutOfBoundException(HERE) << "Index (" << index << ") is not less than size (" << getSize() << ")";
   return (*this)[index];
 }
 
-NSI_const_point FieldImplementation::at (const UnsignedLong index) const
-{
-  if (index >= getSize()) throw OutOfBoundException(HERE) << "Index (" << index << ") is not less than size (" << getSize() << ")";
-  return (*this)[index];
-}
-
-NumericalScalar & FieldImplementation::at (const UnsignedLong i,
-    const UnsignedLong j)
+NumericalScalar & FieldImplementation::at (const UnsignedInteger i,
+    const UnsignedInteger j)
 {
   if (i >= getSize()) throw OutOfBoundException(HERE) << "i (" << i << ") is not less than size (" << getSize() << ")";
   if (j >= getDimension()) throw OutOfBoundException(HERE) << "j (" << j << ") is not less than dimension (" << getDimension() << ")";
+  isAlreadyComputedSpatialMean_ = false;
   return (*this)[i][j];
 }
 
-const NumericalScalar & FieldImplementation::at (const UnsignedLong i,
-    const UnsignedLong j) const
+const NumericalScalar & FieldImplementation::at (const UnsignedInteger i,
+    const UnsignedInteger j) const
 {
   if (i >= getSize()) throw OutOfBoundException(HERE) << "i (" << i << ") is not less than size (" << getSize() << ")";
   if (j >= getDimension()) throw OutOfBoundException(HERE) << "j (" << j << ") is not less than dimension (" << getDimension() << ")";
@@ -185,14 +196,15 @@ const NumericalScalar & FieldImplementation::at (const UnsignedLong i,
 }
 
 /* Data accessors */
-NumericalPoint FieldImplementation::getValueAtIndex(const UnsignedLong index) const
+NumericalPoint FieldImplementation::getValueAtIndex(const UnsignedInteger index) const
 {
   return values_[index];
 }
 
-void FieldImplementation::setValueAtIndex(const UnsignedLong index,
+void FieldImplementation::setValueAtIndex(const UnsignedInteger index,
     const NumericalPoint & val)
 {
+  isAlreadyComputedSpatialMean_ = false;
   values_[index] = val;
 }
 
@@ -204,6 +216,7 @@ NumericalPoint FieldImplementation::getValueAtNearestPosition(const NumericalPoi
 void FieldImplementation::setValueAtNearestPosition(const NumericalPoint & position,
     const NumericalPoint & val)
 {
+  isAlreadyComputedSpatialMean_ = false;
   values_[mesh_.getNearestVertexIndex(position)] = val;
 }
 
@@ -215,11 +228,12 @@ NumericalPoint FieldImplementation::getValueAtNearestTime(const NumericalScalar
 
 void FieldImplementation::setValueAtNearestTime(const NumericalScalar timestamp, const NumericalPoint & val)
 {
+  isAlreadyComputedSpatialMean_ = false;
   setValueAtNearestPosition(NumericalPoint(1, timestamp), val);
 }
 
 /* Method __len__() is for Python */
-UnsignedLong FieldImplementation::__len__() const
+UnsignedInteger FieldImplementation::__len__() const
 {
   return getSize();
 }
@@ -227,16 +241,16 @@ UnsignedLong FieldImplementation::__len__() const
 /* Method __contains__() is for Python */
 Bool FieldImplementation::__contains__(const NumericalPoint & val) const
 {
-  for (UnsignedLong i = 0; i < getSize(); ++i) if ( getValueAtIndex(i) == val ) return true;
+  for (UnsignedInteger i = 0; i < getSize(); ++i) if ( getValueAtIndex(i) == val ) return true;
   return false;
 }
 
-const NumericalPoint FieldImplementation::__getitem__ (const UnsignedLong index) const
+const NumericalPoint FieldImplementation::__getitem__ (const UnsignedInteger index) const
 {
   return at(index);
 }
 
-void FieldImplementation::__setitem__ (const UnsignedLong index,
+void FieldImplementation::__setitem__ (const UnsignedInteger index,
                                        const NumericalPoint & val)
 {
   at(index) = val;
@@ -245,7 +259,7 @@ void FieldImplementation::__setitem__ (const UnsignedLong index,
 /* Description Accessor */
 void FieldImplementation::setDescription(const Description & description)
 {
-  if (description.getSize() != (getMeshDimension() + getDimension())) throw InvalidArgumentException(HERE) << "Error: the given description does not match the field input+output dimension.";
+  if (description.getSize() != (getSpatialDimension() + getDimension())) throw InvalidArgumentException(HERE) << "Error: the given description does not match the field input+output dimension.";
   description_ = description;
 }
 
@@ -280,11 +294,58 @@ String FieldImplementation::__str__(const String & offset) const
   return data.__str__(offset);
 }
 
+/* TBB functor to speed-up spatial mean computation */
+struct FieldSpatialMeanFunctor
+{
+  const FieldImplementation & field_;
+  NumericalScalar volumeAccumulator_;
+  NumericalPoint accumulator_;
+
+  FieldSpatialMeanFunctor(const FieldImplementation & field)
+    : field_(field), volumeAccumulator_(0.0), accumulator_(field.getDimension(), 0.0) {}
+
+  FieldSpatialMeanFunctor(const FieldSpatialMeanFunctor & other, TBB::Split)
+    : field_(other.field_), volumeAccumulator_(0.0), accumulator_(other.field_.getDimension(), 0.0) {}
+
+  void operator() (const TBB::BlockedRange<UnsignedInteger> & r)
+  {
+    const UnsignedInteger meshDimension(field_.getSpatialDimension());
+    const UnsignedInteger dimension(field_.getDimension());
+    for (UnsignedInteger i = r.begin(); i != r.end(); ++i)
+    {
+      const NumericalScalar volume(field_.mesh_.computeSimplexVolume(i));
+      const Indices simplex(field_.mesh_.getSimplex(i));
+      NumericalPoint meanValue(dimension, 0.0);
+      for (UnsignedInteger j = 0; j <= meshDimension; ++j) meanValue += field_.values_[simplex[j]];
+      volumeAccumulator_ += volume;
+      accumulator_ += (volume / dimension) * meanValue;
+    }
+  }
+
+  void join(const FieldSpatialMeanFunctor & other)
+  {
+    volumeAccumulator_ += other.volumeAccumulator_;
+    accumulator_ += other.accumulator_;
+  }
+
+}; /* end struct FieldSpatialMeanFunctor */
+
+/* Compute the spatial mean of the field */
+void FieldImplementation::computeSpatialMean() const
+{
+  FieldSpatialMeanFunctor functor( *this );
+  TBB::ParallelReduce( 0, mesh_.getSimplicesNumber(), functor );
+  if (functor.volumeAccumulator_ == 0.0) throw InternalException(HERE) << "Error: cannot compute the spatial mean of a field supported by a mesh of zero volume.";
+  spatialMean_ = functor.accumulator_ / functor.volumeAccumulator_;
+  isAlreadyComputedSpatialMean_ = true;
+}
+
 
 /* Compute the spatial mean of the field */
 NumericalPoint FieldImplementation::getSpatialMean() const
 {
-  return values_.computeMean();
+  if (!isAlreadyComputedSpatialMean_) computeSpatialMean();
+  return spatialMean_;
 }
 
 /* Compute the spatial mean of the field */
@@ -305,6 +366,12 @@ NumericalSample FieldImplementation::getValues() const
   return values_;
 }
 
+void FieldImplementation::setValues(const NumericalSample & values)
+{
+  if (values.getSize() != mesh_.getVerticesNumber()) throw InvalidArgumentException(HERE) << "Error: expected a sample of size=" << mesh_.getVerticesNumber() << ", got size=" << values.getSize();
+  values_ = values;
+}
+
 /* Return the field as a sample, ie its values and positions */
 NumericalSample FieldImplementation::asSample() const
 {
@@ -313,13 +380,27 @@ NumericalSample FieldImplementation::asSample() const
   return data;
 }
 
+/* Return the field as a defomed mesh, ie its values are added to the components of the vertices if the dimensions match */
+Mesh FieldImplementation::asDeformedMesh() const
+{
+  if (getDimension() != getSpatialDimension()) throw InternalException(HERE) << "Error: cannot deform the mesh if the dimension of the values=" << values_.getDimension() << " does not match the mesh dimension=" << getSpatialDimension();
+  NumericalSample data(mesh_.getVertices());
+  data += values_;
+  return Mesh(data, mesh_.getSimplices());
+}
+
 /* Draw a marginal of the Field */
-Graph FieldImplementation::drawMarginal(const UnsignedLong index,
+Graph FieldImplementation::draw() const
+{
+  return drawMarginal(0, false);
+}
+
+Graph FieldImplementation::drawMarginal(const UnsignedInteger index,
                                         const Bool interpolate) const
 {
   if (index >= getDimension() ) throw InvalidArgumentException(HERE) << "Error : indice should be between [0, " << getDimension() - 1 << "]";
-  const UnsignedInteger meshDimension(getMeshDimension());
-  if (meshDimension > 2) throw NotYetImplementedException(HERE) << "Error: cannot draw a Field of mesh dimension greater than 2. Try the export to VTK for higher dimension.";
+  const UnsignedInteger meshDimension(getSpatialDimension());
+  if (meshDimension > 2) throw NotYetImplementedException(HERE) << "In FieldImplementation::drawMarginal(const UnsignedInteger index, const Bool interpolate) const: cannot draw a Field of mesh dimension greater than 2. Try the export to VTK for higher dimension.";
   const NumericalSample marginalValues(values_.getMarginal(index));
   const String title(OSS() << getName() << " - " << index << " marginal" );
   Graph graph(title, description_[0], "Values", true, "topright");
@@ -341,18 +422,19 @@ Graph FieldImplementation::drawMarginal(const UnsignedLong index,
   else if (meshDimension == 2)
   {
     graph.setYTitle(description_[1]);
+    const UnsignedInteger levelsNumber(ResourceMap::GetAsUnsignedInteger("FieldImplementation-LevelNumber"));
     if (interpolate)
     {
       // Compute the iso-values
-      const UnsignedInteger levelsNumber(1 + 0 * ResourceMap::GetAsUnsignedLong("FieldImplementation-LevelNumber"));
       NumericalPoint levels(levelsNumber);
+      Description palette(levelsNumber);
       for (UnsignedInteger i = 0; i < levelsNumber; ++i)
       {
         const NumericalScalar q((i + 1.0) / (levelsNumber + 1.0));
         levels[i] = marginalValues.computeQuantile(q)[0];
+        palette[i] = Curve::ConvertFromHSV((270.0 * (levelsNumber - i - 1)) / levelsNumber, 1.0, 1.0);
       }
       // Loop over the simplices to draw the segments (if any) associated with the different levels
-      const Description palette(Curve::BuildDefaultPalette(levelsNumber));
       const UnsignedInteger simplicesNumber(mesh_.getSimplicesNumber());
       for (UnsignedInteger i = 0; i < simplicesNumber; ++i)
       {
@@ -396,17 +478,65 @@ Graph FieldImplementation::drawMarginal(const UnsignedLong index,
           } // (level >= v0) && (level <= v2)
         } // j
       } // i
+      // Simple colorbar
+      const NumericalScalar minValue(marginalValues.getMin()[0]);
+      const NumericalScalar maxValue(marginalValues.getMax()[0]);
+      const NumericalPoint xMin(mesh_.getVertices().getMin());
+      for (SignedInteger i = levelsNumber - 1; i >= 0; --i)
+      {
+        Cloud point(NumericalSample(1, xMin));
+        point.setPointStyle("none");
+        point.setColor(palette[i]);
+        if ((i == static_cast<SignedInteger>(levelsNumber) - 1) || (i == 0)) point.setLegend(String(OSS() << 0.001 * round(1000.0 * (minValue + i * (maxValue - minValue) / (levelsNumber - 1)))));
+        else point.setLegend(" ");
+        graph.add(point);
+      }
     } // interpolate
     else
     {
       const UnsignedInteger size(marginalValues.getSize());
-      const Description palette(Cloud::BuildDefaultPalette(size));
-      const NumericalSample ranks(marginalValues.rank());
-      for (UnsignedInteger i = 0; i < size; ++i)
+      Description palette(size);
+      for (UnsignedInteger i = 0; i < size; ++i) palette[i] = Curve::ConvertFromHSV((270.0 * (size - i - 1)) / size, 1.0, 1.0);
+      const NumericalScalar minValue(marginalValues.getMin()[0]);
+      const NumericalScalar maxValue(marginalValues.getMax()[0]);
+      const UnsignedInteger simplicesNumber(mesh_.getSimplicesNumber());
+      if (simplicesNumber > 0)
       {
-        Cloud point(NumericalSample(1, mesh_.getVertex(i)));
-        point.setColor(palette[static_cast<UnsignedInteger>(round(ranks[i][0]))]);
-        point.setPointStyle("bullet");
+        NumericalSample data(0, 2);
+        Description colors(0);
+        for (UnsignedInteger i = 0; i < simplicesNumber; ++i)
+        {
+          const Indices simplex(mesh_.getSimplex(i));
+          data.add(mesh_.getVertex(simplex[0]));
+          data.add(mesh_.getVertex(simplex[1]));
+          data.add(mesh_.getVertex(simplex[2]));
+          const NumericalScalar meanValue((marginalValues[simplex[0]][0] + marginalValues[simplex[1]][0] + marginalValues[simplex[2]][0]) / 3.0);
+          const String color(palette[static_cast<UnsignedInteger>(round((size - 1) * (meanValue - minValue) / (maxValue - minValue)))]);
+          colors.add(color);
+        }
+        graph.add(PolygonArray(data, 3, colors));
+        graph.setGrid(false);
+      } // Simplices
+      else
+      {
+        for (UnsignedInteger i = 0; i < size; ++i)
+        {
+          Cloud point(NumericalSample(1, mesh_.getVertex(i)));
+          const String color(palette[static_cast<UnsignedInteger>(round((size - 1) * (marginalValues[i][0] - minValue) / (maxValue - minValue)))]);
+          point.setColor(color);
+          point.setPointStyle("bullet");
+          graph.add(point);
+        }
+      } // No simplex
+      // Simple colorbar
+      const NumericalPoint xMin(mesh_.getVertices().getMin());
+      for (SignedInteger i = levelsNumber - 1; i >= 0; --i)
+      {
+        Cloud point(NumericalSample(1, xMin));
+        point.setPointStyle("none");
+        point.setColor(palette[(i * (size - 1)) / (levelsNumber - 1)]);
+        if ((i == static_cast<SignedInteger>(levelsNumber) - 1) || (i == 0)) point.setLegend(String(OSS() << 0.001 * round(1000.0 * (minValue + i * (maxValue - minValue) / (levelsNumber - 1)))));
+        else point.setLegend(" ");
         graph.add(point);
       }
     } // !interpolate
@@ -422,6 +552,8 @@ void FieldImplementation::save(Advocate & adv) const
   adv.saveAttribute( "mesh_", mesh_);
   adv.saveAttribute( "values_", values_);
   adv.saveAttribute( "description_", description_);
+  adv.saveAttribute( "spatialMean_", spatialMean_);
+  adv.saveAttribute( "isAlreadyComputedSpatialMean_", isAlreadyComputedSpatialMean_);
 }
 
 
@@ -432,6 +564,8 @@ void FieldImplementation::load(Advocate & adv)
   adv.loadAttribute( "mesh_", mesh_);
   adv.loadAttribute( "values_", values_);
   adv.loadAttribute( "description_", description_);
+  adv.loadAttribute( "spatialMean_", spatialMean_);
+  adv.loadAttribute( "isAlreadyComputedSpatialMean_", isAlreadyComputedSpatialMean_);
 }
 
 /* Export to VTK file */
@@ -440,17 +574,17 @@ void FieldImplementation::exportToVTKFile(const String & fileName) const
   std::ofstream file(fileName.c_str(), std::ios::out);
   if (!file) throw FileNotFoundException(HERE) << "Error: can't open file " << fileName;
   const String content(mesh_.streamToVTKFormat());
-  const UnsignedLong oldPrecision(PlatformInfo::GetNumericalPrecision());
+  const UnsignedInteger oldPrecision(PlatformInfo::GetNumericalPrecision());
   PlatformInfo::SetNumericalPrecision(16);
   file << content << "\nPOINT_DATA " << getSize() << "\n";
 
-  for (UnsignedLong i = 0; i < getDimension(); ++i)
+  for (UnsignedInteger i = 0; i < getDimension(); ++i)
   {
-    String fieldName(getDescription()[getMeshDimension() + i]);
+    String fieldName(getDescription()[getSpatialDimension() + i]);
     replace(fieldName.begin(), fieldName.end(), ' ', '~');
     if (fieldName.size() == 0) fieldName = String(OSS() << "v_" << i);
     file << "SCALARS " << fieldName << " float\nLOOKUP_TABLE default\n";
-    for (UnsignedLong j = 0; j < getSize(); ++j) file << values_[j][i] << "\n";
+    for (UnsignedInteger j = 0; j < getSize(); ++j) file << values_[j][i] << "\n";
   }
   PlatformInfo::SetNumericalPrecision(oldPrecision);
   file.close();
