@@ -3,7 +3,7 @@
  *  @file  Hamming.cxx
  *  @brief
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -36,8 +36,8 @@ CLASSNAMEINIT(Hamming);
 static Factory<Hamming> RegisteredFactory("Hamming");
 
 /* Constructor with parameters */
-Hamming::Hamming(const String & name)
-  : FilteringWindowsImplementation(name)
+Hamming::Hamming()
+  : FilteringWindowsImplementation()
 {
   // Nothing to do
 }
