@@ -3,7 +3,7 @@
  *  @file  HistoryStrategyImplementation.cxx
  *  @brief
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -57,13 +57,13 @@ HistoryStrategyImplementation * HistoryStrategyImplementation::clone() const
 /* Store the point according to the strategy */
 void HistoryStrategyImplementation::store(const NumericalPoint & point)
 {
-  throw NotYetImplementedException(HERE);
+  throw NotYetImplementedException(HERE) << "In HistoryStrategyImplementation::store(const NumericalPoint & point)";
 }
 
 /* Store the sample according to the strategy */
 void HistoryStrategyImplementation::store(const NumericalSample & sample)
 {
-  for (UnsignedLong i = 0; i < sample.getSize(); ++i) store(sample[i]);
+  for (UnsignedInteger i = 0; i < sample.getSize(); ++i) store(sample[i]);
 }
 
 /* Clear the history storage */
