@@ -3,7 +3,7 @@
  *  @file  NumericalSample.cxx
  *  @brief The class NumericalSample implements blank free samples
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -24,6 +24,7 @@
 #include <iomanip>
 #include <fstream>
 #include "NumericalSample.hxx"
+#include "Log.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -73,8 +74,8 @@ NumericalSample::NumericalSample()
 }
 
 /* Constructor with size and dimension */
-NumericalSample::NumericalSample(const UnsignedLong size,
-                                 const UnsignedLong dim)
+NumericalSample::NumericalSample(const UnsignedInteger size,
+                                 const UnsignedInteger dim)
   : TypedInterfaceObject<NumericalSampleImplementation>(new NumericalSampleImplementation(size, dim))
 {
   // Nothing to do
@@ -95,7 +96,7 @@ NumericalSample::NumericalSample(const Implementation & implementation)
 }
 
 /* Constructor from a NumericalPoint (all elements are equal to the NumericalPoint) */
-NumericalSample::NumericalSample(const UnsignedLong size,
+NumericalSample::NumericalSample(const UnsignedInteger size,
                                  const NumericalPoint & point)
   : TypedInterfaceObject<NumericalSampleImplementation>(new NumericalSampleImplementation(size, point))
 {
@@ -122,8 +123,14 @@ Bool NumericalSample::operator ==(const NumericalSample & other) const
   return *getImplementation() == *(other.getImplementation());
 }
 
+/* Comparison operator */
+Bool NumericalSample::operator !=(const NumericalSample & other) const
+{
+  return !operator==(other);
+}
 
-NSI_point NumericalSample::operator [] (const UnsignedLong index)
+
+NSI_point NumericalSample::operator [] (const UnsignedInteger index)
 {
 #ifdef DEBUG_BOUNDCHECKING
   copyOnWrite();
@@ -134,7 +141,7 @@ NSI_point NumericalSample::operator [] (const UnsignedLong index)
 #endif /* DEBUG_BOUNDCHECKING */
 }
 
-NSI_const_point NumericalSample::operator [] (const UnsignedLong index) const
+NSI_const_point NumericalSample::operator [] (const UnsignedInteger index) const
 {
 #ifdef DEBUG_BOUNDCHECKING
   return this->at(index);
@@ -144,8 +151,8 @@ NSI_const_point NumericalSample::operator [] (const UnsignedLong index) const
 }
 
 
-NumericalScalar & NumericalSample::operator () (const UnsignedLong i,
-    const UnsignedLong j)
+NumericalScalar & NumericalSample::operator () (const UnsignedInteger i,
+    const UnsignedInteger j)
 {
 #ifdef DEBUG_BOUNDCHECKING
   // No copyOnWrite() as the at() method already do it
@@ -156,8 +163,8 @@ NumericalScalar & NumericalSample::operator () (const UnsignedLong i,
 #endif /* DEBUG_BOUNDCHECKING */
 }
 
-const NumericalScalar & NumericalSample::operator () (const UnsignedLong i,
-    const UnsignedLong j) const
+const NumericalScalar & NumericalSample::operator () (const UnsignedInteger i,
+    const UnsignedInteger j) const
 {
 #ifdef DEBUG_BOUNDCHECKING
   return this->at(i, j);
@@ -167,21 +174,21 @@ const NumericalScalar & NumericalSample::operator () (const UnsignedLong i,
 }
 
 
-NSI_point NumericalSample::at (const UnsignedLong index)
+NSI_point NumericalSample::at (const UnsignedInteger index)
 {
   if (index >= getSize()) throw OutOfBoundException(HERE) << "Index (" << index << ") is not less than size (" << getSize() << ")";
   copyOnWrite();
   return (*getImplementation())[index];
 }
 
-NSI_const_point NumericalSample::at (const UnsignedLong index) const
+NSI_const_point NumericalSample::at (const UnsignedInteger index) const
 {
   if (index >= getSize()) throw OutOfBoundException(HERE) << "Index (" << index << ") is not less than size (" << getSize() << ")";
   return (*getImplementation())[index];
 }
 
-NumericalScalar & NumericalSample::at (const UnsignedLong i,
-                                       const UnsignedLong j)
+NumericalScalar & NumericalSample::at (const UnsignedInteger i,
+                                       const UnsignedInteger j)
 {
   if (i >= getSize()) throw OutOfBoundException(HERE) << "i (" << i << ") must be less than size (" << getSize() << ")";
   if (j >= getDimension()) throw OutOfBoundException(HERE) << "j (" << j << ") must be less than dimension (" << getDimension() << ")";
@@ -189,20 +196,20 @@ NumericalScalar & NumericalSample::at (const UnsignedLong i,
   return (*getImplementation())[i][j];
 }
 
-const NumericalScalar & NumericalSample::at (const UnsignedLong i,
-    const UnsignedLong j) const
+const NumericalScalar & NumericalSample::at (const UnsignedInteger i,
+    const UnsignedInteger j) const
 {
   if (i >= getSize()) throw OutOfBoundException(HERE) << "i (" << i << ") must be less than size (" << getSize() << ")";
   if (j >= getDimension()) throw OutOfBoundException(HERE) << "j (" << j << ") must be less than dimension (" << getDimension() << ")";
   return (*getImplementation())[i][j];
 }
 
-const NumericalPoint NumericalSample::__getitem__ (const UnsignedLong index) const
+const NumericalPoint NumericalSample::__getitem__ (const UnsignedInteger index) const
 {
   return this->at(index);
 }
 
-void NumericalSample::__setitem__ (const UnsignedLong index,
+void NumericalSample::__setitem__ (const UnsignedInteger index,
                                    const NumericalPoint & val)
 {
   copyOnWrite();
@@ -214,7 +221,7 @@ const NumericalScalar * NumericalSample::__baseaddress__ () const
   return getImplementation()->__baseaddress__();
 }
 
-UnsignedLong NumericalSample::__elementsize__ () const
+UnsignedInteger NumericalSample::__elementsize__ () const
 {
   return getImplementation()->__elementsize__();
 }
@@ -222,7 +229,7 @@ UnsignedLong NumericalSample::__elementsize__ () const
 
 
 /* Method __len__() is for Python */
-UnsignedLong NumericalSample::__len__() const
+UnsignedInteger NumericalSample::__len__() const
 {
   return getSize();
 }
@@ -267,14 +274,14 @@ Description NumericalSample::getDescription() const
 
 
 /* Dimension accessor */
-UnsignedLong NumericalSample::getDimension() const
+UnsignedInteger NumericalSample::getDimension() const
 {
   return getImplementation()->getDimension();
 }
 
 
 /* Size accessor */
-UnsignedLong NumericalSample::getSize() const
+UnsignedInteger NumericalSample::getSize() const
 {
   return getImplementation()->getSize();
 }
@@ -324,15 +331,15 @@ void NumericalSample::stack(const NumericalSample & sample)
 }
 
 
-void NumericalSample::erase(const UnsignedLong first,
-                            const UnsignedLong last)
+void NumericalSample::erase(const UnsignedInteger first,
+                            const UnsignedInteger last)
 {
   copyOnWrite();
   getImplementation()->erase(first, last);
 }
 
 
-void NumericalSample::erase(const UnsignedLong index)
+void NumericalSample::erase(const UnsignedInteger index)
 {
   copyOnWrite();
   getImplementation()->erase(index, index + 1);
@@ -355,11 +362,11 @@ void NumericalSample::clear()
  * and returns the remainder as new sample. This method tries its best not for doubling
  * memory usage.
  */
-NumericalSample NumericalSample::split(const UnsignedLong index)
+NumericalSample NumericalSample::split(const UnsignedInteger index)
 {
   copyOnWrite();
   // We first save the size of the original sample
-  UnsignedLong theSize = getSize();
+  UnsignedInteger theSize = getSize();
 
   // We first check that the index is in the sample's range
   if (index > theSize) throw OutOfBoundException(HERE) << "Index over size. Index=" << index << " size=" << theSize;
@@ -425,7 +432,7 @@ CovarianceMatrix NumericalSample::computeCovariance() const
 /*
  * Method computeStandardDeviation() gives the standard deviation of the sample
  */
-SquareMatrix NumericalSample::computeStandardDeviation() const
+TriangularMatrix NumericalSample::computeStandardDeviation() const
 {
   return getImplementation()->computeStandardDeviation();
 }
@@ -470,58 +477,99 @@ CorrelationMatrix NumericalSample::computeKendallTau() const
 /*
  * Method computeRangePerComponent gives the range of the sample (by component)
  */
+NumericalPoint NumericalSample::computeRange() const
+{
+  return getImplementation()->computeRange();
+}
+
 NumericalPoint NumericalSample::computeRangePerComponent() const
 {
-  return getImplementation()->computeRangePerComponent();
+  Log::Info(OSS() << "NumericalSample::computeRangePerComponent is deprecated in favor of NumericalSample::computeRange");
+  return computeRange();
 }
 
 /*
  * Method computeMedian() gives the median of the sample (by component)
  */
-NumericalPoint NumericalSample::computeMedianPerComponent() const
+NumericalPoint NumericalSample::computeMedian() const
 {
-  return getImplementation()->computeMedianPerComponent();
+  return getImplementation()->computeMedian();
 }
 
+NumericalPoint NumericalSample::computeMedianPerComponent() const
+{
+  Log::Info(OSS() << "NumericalSample::computeMedianPerComponent is deprecated in favor of NumericalSample::computeMedian");
+  return computeMedian();
+}
 
 /*
  * Method computeVariance() gives the variance of the sample (by component)
  */
+NumericalPoint NumericalSample::computeVariance() const
+{
+  return getImplementation()->computeVariance();
+}
+
 NumericalPoint NumericalSample::computeVariancePerComponent() const
 {
-  return getImplementation()->computeVariancePerComponent();
+  Log::Info(OSS() << "NumericalSample::computeVariancePerComponent is deprecated in favor of NumericalSample::computeVariance");
+  return computeVariance();
 }
 
 /*
  * Method computeSkewness() gives the skewness of the sample (by component)
  */
+NumericalPoint NumericalSample::computeSkewness() const
+{
+  return getImplementation()->computeSkewness();
+}
+
 NumericalPoint NumericalSample::computeSkewnessPerComponent() const
 {
-  return getImplementation()->computeSkewnessPerComponent();
+  Log::Info(OSS() << "NumericalSample::computeSkewnessPerComponent is deprecated in favor of NumericalSample::computeSkewness");
+  return computeSkewness();
 }
 
 /*
  * Method computeKurtosis() gives the kurtosis of the sample (by component)
  */
+NumericalPoint NumericalSample::computeKurtosis() const
+{
+  return getImplementation()->computeKurtosis();
+}
+
 NumericalPoint NumericalSample::computeKurtosisPerComponent() const
 {
-  return getImplementation()->computeKurtosisPerComponent();
+  Log::Info(OSS() << "NumericalSample::computeKurtosisPerComponent is deprecated in favor of NumericalSample::computeKurtosis");
+  return computeKurtosis();
 }
 
 /*
  * Gives the centered moment of order k of the sample (by component)
  */
-NumericalPoint NumericalSample::computeCenteredMomentPerComponent(const UnsignedLong k) const
+NumericalPoint NumericalSample::computeCenteredMoment(const UnsignedInteger k) const
 {
-  return getImplementation()->computeCenteredMomentPerComponent(k);
+  return getImplementation()->computeCenteredMoment(k);
+}
+
+NumericalPoint NumericalSample::computeCenteredMomentPerComponent(const UnsignedInteger k) const
+{
+  Log::Info(OSS() << "NumericalSample::computeCenteredMomentPerComponent is deprecated in favor of NumericalSample::computeCenteredMoment");
+  return computeCenteredMoment(k);
 }
 
 /*
  * Gives the raw moment of order k of the sample (by component)
  */
-NumericalPoint NumericalSample::computeRawMomentPerComponent(const UnsignedLong k) const
+NumericalPoint NumericalSample::computeRawMoment(const UnsignedInteger k) const
 {
-  return getImplementation()->computeRawMomentPerComponent(k);
+  return getImplementation()->computeRawMoment(k);
+}
+
+NumericalPoint NumericalSample::computeRawMomentPerComponent(const UnsignedInteger k) const
+{
+  Log::Info(OSS() << "NumericalSample::computeRawMomentPerComponent is deprecated in favor of NumericalSample::computeRawMoment");
+  return computeRawMoment(k);
 }
 
 /*
@@ -553,7 +601,7 @@ NumericalScalar NumericalSample::computeEmpiricalCDF(const NumericalPoint & poin
  * Get the position of a point in the sample.
  * Returns size+1 if the point does not belong to the sample.
  */
-UnsignedLong NumericalSample::find(const NumericalPoint & point) const
+UnsignedInteger NumericalSample::find(const NumericalPoint & point) const
 {
   return std::find(getImplementation()->begin(),  getImplementation()->end(), point) - getImplementation()->begin();
 }
@@ -561,10 +609,11 @@ UnsignedLong NumericalSample::find(const NumericalPoint & point) const
 /*
  * Translate realizations in-place
  */
-void NumericalSample::translate(const NumericalPoint & translation)
+NumericalSample & NumericalSample::operator += (const NumericalScalar translation)
 {
   copyOnWrite();
-  getImplementation()->translate(translation);
+  if (translation != 0.0) getImplementation()->operator +=(NumericalPoint(getDimension(), translation));
+  return *this;
 }
 
 NumericalSample & NumericalSample::operator += (const NumericalPoint & translation)
@@ -581,6 +630,13 @@ NumericalSample & NumericalSample::operator += (const NumericalSample & translat
   return *this;
 }
 
+NumericalSample & NumericalSample::operator -= (const NumericalScalar translation)
+{
+  copyOnWrite();
+  if (translation != 0.0) getImplementation()->operator -=(NumericalPoint(getDimension(), translation));
+  return *this;
+}
+
 NumericalSample & NumericalSample::operator -= (const NumericalPoint & translation)
 {
   copyOnWrite();
@@ -595,56 +651,56 @@ NumericalSample & NumericalSample::operator -= (const NumericalSample & translat
   return *this;
 }
 
+NumericalSample NumericalSample::operator + (const NumericalScalar translation) const
+{
+  const NumericalSample sample(getImplementation()->operator + (translation));
+  return sample;
+}
+
 NumericalSample NumericalSample::operator + (const NumericalPoint & translation) const
 {
-  NumericalSample sample(getImplementation()->operator + (translation));
+  const NumericalSample sample(getImplementation()->operator + (translation));
   return sample;
 }
 
 NumericalSample NumericalSample::operator + (const NumericalSample & translation) const
 {
-  NumericalSample sample(getImplementation()->operator + (*translation.getImplementation()));
+  const NumericalSample sample(getImplementation()->operator + (*translation.getImplementation()));
+  return sample;
+}
+
+NumericalSample NumericalSample::operator - (const NumericalScalar translation) const
+{
+  const NumericalSample sample(getImplementation()->operator - (translation));
   return sample;
 }
 
 NumericalSample NumericalSample::operator - (const NumericalPoint & translation) const
 {
-  NumericalSample sample(getImplementation()->operator - (translation));
+  const NumericalSample sample(getImplementation()->operator - (translation));
   return sample;
 }
 
 NumericalSample NumericalSample::operator - (const NumericalSample & translation) const
 {
-  NumericalSample sample(getImplementation()->operator - (*translation.getImplementation()));
+  const NumericalSample sample(getImplementation()->operator - (*translation.getImplementation()));
   return sample;
 }
 
 /*
  * Scale realizations componentwise in-place
  */
-void NumericalSample::scale(const NumericalPoint & scaling)
-{
-  copyOnWrite();
-  getImplementation()->scale(scaling);
-}
-
-void NumericalSample::scale(const SquareMatrix & scaling)
-{
-  copyOnWrite();
-  getImplementation()->scale(scaling);
-}
-
-NumericalSample & NumericalSample::operator *= (const NumericalPoint & scaling)
+NumericalSample & NumericalSample::operator *= (const NumericalScalar scaling)
 {
   copyOnWrite();
   getImplementation()->operator *=(scaling);
   return *this;
 }
 
-NumericalSample & NumericalSample::operator /= (const NumericalPoint & scaling)
+NumericalSample & NumericalSample::operator *= (const NumericalPoint & scaling)
 {
   copyOnWrite();
-  getImplementation()->operator /=(scaling);
+  getImplementation()->operator *=(scaling);
   return *this;
 }
 
@@ -655,6 +711,20 @@ NumericalSample & NumericalSample::operator *= (const SquareMatrix & scaling)
   return *this;
 }
 
+NumericalSample & NumericalSample::operator /= (const NumericalScalar scaling)
+{
+  copyOnWrite();
+  getImplementation()->operator /=(scaling);
+  return *this;
+}
+
+NumericalSample & NumericalSample::operator /= (const NumericalPoint & scaling)
+{
+  copyOnWrite();
+  getImplementation()->operator /=(scaling);
+  return *this;
+}
+
 NumericalSample & NumericalSample::operator /= (const SquareMatrix & scaling)
 {
   copyOnWrite();
@@ -662,27 +732,39 @@ NumericalSample & NumericalSample::operator /= (const SquareMatrix & scaling)
   return *this;
 }
 
-NumericalSample NumericalSample::operator * (const NumericalPoint & scaling)
+NumericalSample NumericalSample::operator * (const NumericalScalar scaling) const
 {
-  NumericalSample sample(getImplementation()->operator * (scaling));
+  const NumericalSample sample(getImplementation()->operator * (scaling));
   return sample;
 }
 
-NumericalSample NumericalSample::operator / (const NumericalPoint & scaling)
+NumericalSample NumericalSample::operator * (const NumericalPoint & scaling) const
 {
-  NumericalSample sample(getImplementation()->operator / (scaling));
+  const NumericalSample sample(getImplementation()->operator * (scaling));
   return sample;
 }
 
-NumericalSample NumericalSample::operator * (const SquareMatrix & scaling)
+NumericalSample NumericalSample::operator * (const SquareMatrix & scaling) const
 {
-  NumericalSample sample(getImplementation()->operator * (scaling));
+  const NumericalSample sample(getImplementation()->operator * (scaling));
   return sample;
 }
 
-NumericalSample NumericalSample::operator / (const SquareMatrix & scaling)
+NumericalSample NumericalSample::operator / (const NumericalScalar scaling) const
 {
-  NumericalSample sample(getImplementation()->operator / (scaling));
+  const NumericalSample sample(getImplementation()->operator / (scaling));
+  return sample;
+}
+
+NumericalSample NumericalSample::operator / (const NumericalPoint & scaling) const
+{
+  const NumericalSample sample(getImplementation()->operator / (scaling));
+  return sample;
+}
+
+NumericalSample NumericalSample::operator / (const SquareMatrix & scaling) const
+{
+  const NumericalSample sample(getImplementation()->operator / (scaling));
   return sample;
 }
 
@@ -693,7 +775,7 @@ NumericalSample NumericalSample::rank() const
 }
 
 /* Ranked component */
-NumericalSample NumericalSample::rank(const UnsignedLong index) const
+NumericalSample NumericalSample::rank(const UnsignedInteger index) const
 {
   return getImplementation()->rank(index);
 }
@@ -705,19 +787,19 @@ NumericalSample NumericalSample::sort() const
 }
 
 /* Sorted component */
-NumericalSample NumericalSample::sort(const UnsignedLong index) const
+NumericalSample NumericalSample::sort(const UnsignedInteger index) const
 {
   return getImplementation()->sort(index);
 }
 
 /* Sorted component */
-NumericalSample NumericalSample::sortAccordingToAComponent(const UnsignedLong index) const
+NumericalSample NumericalSample::sortAccordingToAComponent(const UnsignedInteger index) const
 {
   return getImplementation()->sortAccordingToAComponent(index);
 }
 
 /* Get the i-th marginal sample */
-NumericalSample NumericalSample::getMarginal(const UnsignedLong index) const
+NumericalSample NumericalSample::getMarginal(const UnsignedInteger index) const
 {
   return getImplementation()->getMarginal(index);
 }
