@@ -3,7 +3,7 @@
  *  @file  SpectralModelFactory.cxx
  *  @brief Top-level class for all spectral model factories
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -30,34 +30,31 @@ BEGIN_NAMESPACE_OPENTURNS
 CLASSNAMEINIT(SpectralModelFactory);
 
 /* Default constructor */
-SpectralModelFactory::SpectralModelFactory(const String & name)
-  : TypedInterfaceObject<SpectralModelFactoryImplementation>(new SpectralModelFactoryImplementation(name))
+SpectralModelFactory::SpectralModelFactory()
+  : TypedInterfaceObject<SpectralModelFactoryImplementation>(new SpectralModelFactoryImplementation())
 {
   // Nothing to do
 }
 
 /* Parameters constructor */
-SpectralModelFactory::SpectralModelFactory(const SpectralModelFactoryImplementation & implementation,
-    const String & name)
+SpectralModelFactory::SpectralModelFactory(const SpectralModelFactoryImplementation & implementation)
   : TypedInterfaceObject<SpectralModelFactoryImplementation>(implementation.clone())
 {
-  getImplementation()->setName(name);
+  // Nothing to do
 }
 
 /* Constructor from implementation */
-SpectralModelFactory::SpectralModelFactory(const Implementation & p_implementation,
-    const String & name)
+SpectralModelFactory::SpectralModelFactory(const Implementation & p_implementation)
   : TypedInterfaceObject<SpectralModelFactoryImplementation>(p_implementation)
 {
-  getImplementation()->setName(name);
+  // Nothing to do
 }
 
 /* Constructor from implementation pointer */
-SpectralModelFactory::SpectralModelFactory(SpectralModelFactoryImplementation * p_implementation,
-    const String & name)
+SpectralModelFactory::SpectralModelFactory(SpectralModelFactoryImplementation * p_implementation)
   : TypedInterfaceObject<SpectralModelFactoryImplementation>(p_implementation)
 {
-  getImplementation()->setName(name);
+  // Nothing to do
 }
 
 
