@@ -3,7 +3,7 @@
  *  @file  SpectralModelFactoryImplementation.cxx
  *  @brief Top-level class for all spectral model factories
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -32,11 +32,9 @@ BEGIN_NAMESPACE_OPENTURNS
 CLASSNAMEINIT(SpectralModelFactoryImplementation);
 static Factory<SpectralModelFactoryImplementation> RegisteredFactory("SpectralModelFactoryImplementation");
 
-typedef NotYetImplementedException NotYetImplementedException;
-
 /* Default constructor */
-SpectralModelFactoryImplementation::SpectralModelFactoryImplementation(const String & name)
-  : PersistentObject(name),
+SpectralModelFactoryImplementation::SpectralModelFactoryImplementation()
+  : PersistentObject(),
     frequencyGrid_(),
     fftAlgorithm_()
 {
@@ -93,12 +91,12 @@ String SpectralModelFactoryImplementation::__str__(const String & offset) const
 
 SpectralModelImplementation * SpectralModelFactoryImplementation::build(const ProcessSample & sample) const
 {
-  throw NotYetImplementedException(HERE);
+  throw NotYetImplementedException(HERE) << "In SpectralModelFactoryImplementation::build(const ProcessSample & sample) const";
 }
 
 SpectralModelImplementation * SpectralModelFactoryImplementation::build(const Field & timeSeries) const
 {
-  throw NotYetImplementedException(HERE);
+  throw NotYetImplementedException(HERE) << "In SpectralModelFactoryImplementation::build(const Field & timeSeries) const";
 }
 
 /* Method save() stores the object through the StorageManager */
