@@ -3,7 +3,7 @@
  *  @file  SpectralModelImplementation.cxx
  *  @brief
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -32,8 +32,8 @@ CLASSNAMEINIT(SpectralModelImplementation);
 static Factory<SpectralModelImplementation> RegisteredFactory("SpectralModelImplementation");
 
 /* Constructor with parameters */
-SpectralModelImplementation::SpectralModelImplementation(const String & name)
-  : PersistentObject(name),
+SpectralModelImplementation::SpectralModelImplementation()
+  : PersistentObject(),
     dimension_(0),
     frequencyGrid_()
 {
@@ -47,13 +47,13 @@ SpectralModelImplementation * SpectralModelImplementation::clone() const
 }
 
 /* Dimension accessor */
-UnsignedLong SpectralModelImplementation::getDimension() const
+UnsignedInteger SpectralModelImplementation::getDimension() const
 {
   return dimension_;
 }
 
 /* Dimension accessor */
-void SpectralModelImplementation::setDimension(const UnsignedLong dimension)
+void SpectralModelImplementation::setDimension(const UnsignedInteger dimension)
 {
   dimension_ = dimension;
 }
@@ -70,15 +70,9 @@ void SpectralModelImplementation::setFrequencyGrid(const RegularGrid & frequency
 }
 
 /* Computation of the spectral density function */
-HermitianMatrix SpectralModelImplementation::computeSpectralDensity(const NumericalScalar frequency) const
-{
-  LOGUSER(OSS() << "The computeSpectralDensity(const NumericalScalar frequency) method is deprecated in favor of the operator() (const NumericalScalar frequency method");
-  return operator()(frequency);
-}
-
 HermitianMatrix SpectralModelImplementation::operator() (const NumericalScalar frequency) const
 {
-  throw NotYetImplementedException(HERE);
+  throw NotYetImplementedException(HERE) << "In SpectralModelImplementation::operator() (const NumericalScalar frequency) const";
 }
 
 
