@@ -3,7 +3,7 @@
  *  @file  UserDefinedStationaryCovarianceModel.cxx
  *  @brief
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -36,33 +36,34 @@ CLASSNAMEINIT(UserDefinedStationaryCovarianceModel);
 static Factory<UserDefinedStationaryCovarianceModel> RegisteredFactory("UserDefinedStationaryCovarianceModel");
 
 /* Constructor with parameters */
-UserDefinedStationaryCovarianceModel::UserDefinedStationaryCovarianceModel(const String & name)
-  : StationaryCovarianceModel(name),
-    covarianceCollection_(0)
+UserDefinedStationaryCovarianceModel::UserDefinedStationaryCovarianceModel()
+  : StationaryCovarianceModel()
+  , covarianceCollection_(0)
+  , p_mesh_(Mesh().clone())
 {
+  spatialDimension_ = 1;
   dimension_ = 0;
 }
 
 // Classical constructor
 // For a stationary model, we need N covariance matrices with N the number of time stamps in the time grid
-UserDefinedStationaryCovarianceModel::UserDefinedStationaryCovarianceModel(const RegularGrid & timeGrid,
-    const CovarianceMatrixCollection & covarianceFunction,
-    const String & name)
-  : StationaryCovarianceModel(name),
-    covarianceCollection_(0)
+UserDefinedStationaryCovarianceModel::UserDefinedStationaryCovarianceModel(const Mesh & mesh,
+    const CovarianceMatrixCollection & covarianceFunction)
+  : StationaryCovarianceModel()
+  , covarianceCollection_(0)
 {
-  const UnsignedLong size(timeGrid.getN());
+  const UnsignedInteger size(mesh.getVerticesNumber());
   if (size != covarianceFunction.getSize())
     throw InvalidArgumentException(HERE) << "Error: for a non stationary covariance model, sizes are incoherents"
-                                         << " timeGrid size = " << size << "covariance function size = " << covarianceFunction.getSize();
-  timeGrid_ = timeGrid;
-
+                                         << " mesh size = " << size << "covariance function size = " << covarianceFunction.getSize();
+  p_mesh_ = mesh.clone();
+  spatialDimension_ = mesh.getDimension();
   covarianceCollection_ = CovarianceMatrixCollection(size);
   // put the first element
   covarianceCollection_[0] = covarianceFunction[0];
   dimension_ = covarianceCollection_[0].getDimension();
   // put the next elements if dimension is ok
-  for (UnsignedLong k = 1; k < size; ++k)
+  for (UnsignedInteger k = 1; k < size; ++k)
   {
     if (covarianceFunction[k].getDimension() != dimension_)
       throw InvalidArgumentException(HERE) << " Error with dimension; the covariance matrices should be of same dimension";
@@ -77,26 +78,26 @@ UserDefinedStationaryCovarianceModel * UserDefinedStationaryCovarianceModel::clo
 }
 
 /* Computation of the covariance function */
-CovarianceMatrix UserDefinedStationaryCovarianceModel::operator()(const NumericalPoint & t) const
+CovarianceMatrix UserDefinedStationaryCovarianceModel::operator()(const NumericalPoint & tau) const
 {
-  if (t.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: cannot evaluate a UserDefinedStationaryCovarianceModel on multidimensional locations.";
+  if (tau.getDimension() != spatialDimension_) throw InvalidArgumentException(HERE) << "Error: expected a shift of dimension=" << spatialDimension_ << ", got dimension=" << tau.getDimension();
   // If the grid size is one, return the covariance function
   // else find in the grid the nearest instant values
-  if (timeGrid_.getN() == 1) return covarianceCollection_[0];
+  if (p_mesh_->getVerticesNumber() == 1) return covarianceCollection_[0];
 
-  // We consider that the time step is positive
-  const NumericalScalar initialInstant(timeGrid_.getStart());
-  const NumericalScalar N(timeGrid_.getN());
-  const NumericalScalar step(timeGrid_.getStep());
-  const SignedInteger index(static_cast<SignedInteger>(std::min(N - 1.0, std::max(0.0,  nearbyint( ( t[0] - initialInstant ) / step) ))));
-
-  return covarianceCollection_[index];
+  return covarianceCollection_[p_mesh_->getNearestVertexIndex(tau)];
 }
 
-/* Time grid accessor */
+/* Time grid/mesh accessor */
+Mesh UserDefinedStationaryCovarianceModel::getMesh() const
+{
+  return *p_mesh_;
+}
+
+/* Mesh accessor */
 RegularGrid UserDefinedStationaryCovarianceModel::getTimeGrid() const
 {
-  return timeGrid_;
+  return RegularGrid(*p_mesh_);
 }
 
 /* String converter */
@@ -104,11 +105,9 @@ String UserDefinedStationaryCovarianceModel::__repr__() const
 {
   OSS oss(true);
   oss << "class=" << UserDefinedStationaryCovarianceModel::GetClassName()
-      << " timeGrid=" << timeGrid_
-      << " dimension=" << dimension_
+      << " mesh=" << p_mesh_->__repr__()
       << " covarianceCollection=" << covarianceCollection_;
   return oss;
-
 }
 
 /* String converter */
@@ -121,7 +120,7 @@ String UserDefinedStationaryCovarianceModel::__str__(const String & offset) cons
 void UserDefinedStationaryCovarianceModel::save(Advocate & adv) const
 {
   StationaryCovarianceModel::save(adv);
-  adv.saveAttribute( "timeGrid_", timeGrid_);
+  adv.saveAttribute( "mesh_", *p_mesh_);
   adv.saveAttribute( "covarianceCollection_", covarianceCollection_);
 }
 
@@ -129,7 +128,9 @@ void UserDefinedStationaryCovarianceModel::save(Advocate & adv) const
 void UserDefinedStationaryCovarianceModel::load(Advocate & adv)
 {
   StationaryCovarianceModel::load(adv);
-  adv.loadAttribute( "timeGrid_", timeGrid_);
+  TypedInterfaceObject<Mesh> mesh;
+  adv.loadAttribute( "mesh_", mesh);
+  p_mesh_ = mesh.getImplementation();
   adv.loadAttribute( "covarianceCollection_", covarianceCollection_);
 }
 
