@@ -3,7 +3,7 @@
  *  @file  ComplexMatrixImplementation.cxx
  *  @brief ComplexMatrixImplementation implements the classical mathematicalComplexMatrixImplementation
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -27,6 +27,7 @@
 #include "PersistentObjectFactory.hxx"
 #include "Lapack.hxx"
 #include "ResourceMap.hxx"
+#include "SpecFunc.hxx"
 #include "Os.hxx"
 #include "Exception.hxx"
 
@@ -39,9 +40,9 @@ static Factory<ComplexMatrixImplementation> RegisteredFactory("ComplexMatrixImpl
 
 /* Default constructor */
 ComplexMatrixImplementation::ComplexMatrixImplementation()
-  : PersistentCollection<NumericalComplex>(),
-    nbRows_(0),
-    nbColumns_(0)
+  : PersistentCollection<NumericalComplex>()
+  , nbRows_(0)
+  , nbColumns_(0)
 {
   // Nothing to do
 }
@@ -49,49 +50,49 @@ ComplexMatrixImplementation::ComplexMatrixImplementation()
 /* Constructor with size (rowDim and colDim) */
 /* The ComplexMatrixImplementation is made up of a collection of rowDim*colDim elements */
 /* The ComplexMatrixImplementation is viewed as a set of column vectors read one after another */
-ComplexMatrixImplementation::ComplexMatrixImplementation(const UnsignedLong rowDim,
-    const UnsignedLong colDim)
-  : PersistentCollection<NumericalComplex>(rowDim * colDim, NumericalComplex(0.0, 0.0)),
-    nbRows_(rowDim),
-    nbColumns_(colDim)
+ComplexMatrixImplementation::ComplexMatrixImplementation(const UnsignedInteger rowDim,
+    const UnsignedInteger colDim)
+  : PersistentCollection<NumericalComplex>(rowDim * colDim, NumericalComplex(0.0, 0.0))
+  , nbRows_(rowDim)
+  , nbColumns_(colDim)
 {
   // Nothing to do
 }
 
 /* Constructor from external collection */
-ComplexMatrixImplementation::ComplexMatrixImplementation(const UnsignedLong rowDim,
-    const UnsignedLong colDim,
+ComplexMatrixImplementation::ComplexMatrixImplementation(const UnsignedInteger rowDim,
+    const UnsignedInteger colDim,
     const Collection<NumericalComplex> & elementsValues)
-  : PersistentCollection<NumericalComplex>(rowDim * colDim, NumericalComplex(0.0, 0.0)),
-    nbRows_(rowDim),
-    nbColumns_(colDim)
+  : PersistentCollection<NumericalComplex>(rowDim * colDim, NumericalComplex(0.0, 0.0))
+  , nbRows_(rowDim)
+  , nbColumns_(colDim)
 {
-  const UnsignedLong matrixSize(std::min(rowDim * colDim, elementsValues.getSize()));
-  for(UnsignedLong i = 0; i < matrixSize; ++i) operator[](i) = elementsValues[i];
+  const UnsignedInteger matrixSize(std::min(rowDim * colDim, elementsValues.getSize()));
+  for(UnsignedInteger i = 0; i < matrixSize; ++i) operator[](i) = elementsValues[i];
 }
 
 /* Constructor from external collection */
-ComplexMatrixImplementation::ComplexMatrixImplementation(const UnsignedLong rowDim,
-    const UnsignedLong colDim,
+ComplexMatrixImplementation::ComplexMatrixImplementation(const UnsignedInteger rowDim,
+    const UnsignedInteger colDim,
     const Collection<NumericalScalar> & elementsValues)
-  : PersistentCollection<NumericalComplex>(rowDim * colDim, NumericalComplex(0.0, 0.0)),
-    nbRows_(rowDim),
-    nbColumns_(colDim)
+  : PersistentCollection<NumericalComplex>(rowDim * colDim, NumericalComplex(0.0, 0.0))
+  , nbRows_(rowDim)
+  , nbColumns_(colDim)
 {
-  const UnsignedLong matrixSize(std::min(rowDim * colDim, elementsValues.getSize()));
+  const UnsignedInteger matrixSize(std::min(rowDim * colDim, elementsValues.getSize()));
   //  Implicit cast from NumericalScalar into NumericalComplex
-  for(UnsignedLong i = 0; i < matrixSize; ++i) operator[](i) = elementsValues[i];
+  for(UnsignedInteger i = 0; i < matrixSize; ++i) operator[](i) = elementsValues[i];
 }
 
 
 ComplexMatrixImplementation::ComplexMatrixImplementation(const MatrixImplementation & matrix)
-  : PersistentCollection<NumericalComplex>(matrix.getNbRows() * matrix.getNbColumns(), 0.0),
-    nbRows_(matrix.getNbRows()),
-    nbColumns_(matrix.getNbColumns())
+  : PersistentCollection<NumericalComplex>(matrix.getNbRows() * matrix.getNbColumns(), 0.0)
+  , nbRows_(matrix.getNbRows())
+  , nbColumns_(matrix.getNbColumns())
 {
   // Copy from matrix
-  const UnsignedLong matrixSize(nbRows_ * nbColumns_);
-  for(UnsignedLong i = 0; i < matrixSize; ++i) operator[](i) = matrix[i];
+  const UnsignedInteger matrixSize(nbRows_ * nbColumns_);
+  for(UnsignedInteger i = 0; i < matrixSize; ++i) operator[](i) = matrix[i];
 }
 
 /* Virtual constructor */
@@ -100,18 +101,81 @@ ComplexMatrixImplementation * ComplexMatrixImplementation::clone() const
   return new ComplexMatrixImplementation(*this);
 }
 
+/* Resolution of a linear system : rectangular matrix
+ * MX = b, M is an mxn matrix, b is an mxq matrix and
+ * X is an nxq matrix */
+ComplexMatrixImplementation ComplexMatrixImplementation::solveLinearSystemRect (const ComplexMatrixImplementation & b,
+    const Bool keepIntact)
+{
+  if (nbRows_ != b.nbRows_) throw InvalidDimensionException(HERE);
+  if ((nbRows_ == 0) || (nbColumns_ == 0) || (b.nbColumns_ == 0)) throw InvalidDimensionException(HERE);
+  int m(nbRows_);
+  int n(nbColumns_);
+  // B is an extended copy of b, it must be large enought to store the solution, see LAPACK documentation
+  int p(std::max(m, n));
+  int q(b.nbColumns_);
+  ComplexMatrixImplementation B(p, q);
+  for(UnsignedInteger j = 0; j < static_cast<UnsignedInteger>(q); ++j)
+    for (UnsignedInteger i = 0; i < static_cast<UnsignedInteger>(m); ++i)
+      B(i, j) = b(i, j);
+  int nrhs(q);
+  int lwork(-1);
+  NumericalComplexCollection work(1);
+  NumericalPoint rwork(2 * n);
+  int info;
+  std::vector<int> jpiv(n);
+  double rcond(ResourceMap::GetAsNumericalScalar("MatrixImplementation-DefaultSmallPivot"));
+  int rank;
+
+  ComplexMatrixImplementation Q;
+  if (keepIntact) Q = ComplexMatrixImplementation(*this);
+  ComplexMatrixImplementation & A = keepIntact ? Q : *this;
+
+  // (int *m, int *n, int *nrhs, std::complex<double> *A, int *lda, std::complex<double> *B, int *ldb, int *jpvt, double *rcond, int *rank, std::complex<double> *work, int *lwork, double *rwork, int *info)
+  zgelsy_(&m, &n, &nrhs, &A[0], &m, &B[0], &p, &jpiv[0], &rcond, &rank, &work[0], &lwork, &rwork[0], &info);
+  lwork = static_cast<int>(std::real(work[0]));
+  work = NumericalComplexCollection(lwork);
+  zgelsy_(&m, &n, &nrhs, &A[0], &m, &B[0], &p, &jpiv[0], &rcond, &rank, &work[0], &lwork, &rwork[0], &info);
+
+  ComplexMatrixImplementation result(n, q);
+  for(UnsignedInteger j = 0; j < static_cast<UnsignedInteger>(q); ++j)
+    for (UnsignedInteger i = 0; i < static_cast<UnsignedInteger>(n); ++i)
+      result(i, j) = B(i, j);
+  return result;
+}
+
+/* Resolution of a linear system : rectangular matrix
+ * Mx = b, M is an mxn matrix, b is an m-dimensional
+ * vector and x is an n-dimensional vector */
+ComplexMatrixImplementation::NumericalComplexCollection ComplexMatrixImplementation::solveLinearSystemRect (const NumericalComplexCollection & b,
+    const Bool keepIntact)
+{
+  const UnsignedInteger m(b.getSize());
+  if (nbRows_ != m) throw InvalidDimensionException(HERE);
+  if (nbRows_ == 0) throw InvalidDimensionException(HERE);
+  // Solve the matrix linear system
+  // A ComplexMatrixImplementation is also a collection of NumericalComplex, so it is automatically converted into a NumericalComplexCollection
+  return solveLinearSystemRect(ComplexMatrixImplementation(m, 1, b), keepIntact);
+}
+
+
+
 /* Set small elements to zero */
 ComplexMatrixImplementation ComplexMatrixImplementation::clean(const NumericalScalar threshold) const
 {
+  // Nothing to do for nonpositive threshold
+  if (threshold <= 0.0) return *this;
   ComplexMatrixImplementation result(nbRows_, nbColumns_);
-  for (UnsignedLong j = 0; j < nbColumns_; ++j)
-    for (UnsignedLong i = 0; i < nbRows_; ++i)
+  for (UnsignedInteger j = 0; j < nbColumns_; ++j)
+    for (UnsignedInteger i = 0; i < nbRows_; ++i)
     {
-      const NumericalComplex value(this->operator[](convertPosition(i, j)));
+      const NumericalComplex value((*this)[convertPosition(i, j)]);
       NumericalScalar realPart(std::real(value));
       NumericalScalar imagPart(std::imag(value));
-      if (fabs(realPart) <= threshold) realPart = 0.0;
-      if (fabs(imagPart) <= threshold) imagPart = 0.0;
+      if (std::abs(realPart) < 0.5 * threshold) realPart = 0.0;
+      else realPart = threshold * round(realPart / threshold);
+      if (std::abs(imagPart) < 0.5 * threshold) imagPart = 0.0;
+      else imagPart = threshold * round(imagPart / threshold);
       result(i, j) = NumericalComplex(realPart, imagPart);
     }
   return result;
@@ -120,18 +184,8 @@ ComplexMatrixImplementation ComplexMatrixImplementation::clean(const NumericalSc
 /* Set small elements to zero */
 ComplexMatrixImplementation ComplexMatrixImplementation::cleanHerm(const NumericalScalar threshold) const
 {
-  ComplexMatrixImplementation result(nbRows_, nbColumns_);
-  for (UnsignedLong j = 0; j < nbColumns_; ++j)
-    for (UnsignedLong i = j; i < nbRows_; ++i)
-    {
-      const NumericalComplex value(this->operator[](convertPosition(i, j)));
-      NumericalScalar realPart(std::real(value));
-      NumericalScalar imagPart(std::imag(value));
-      if (fabs(realPart) <= threshold) realPart = 0.0;
-      if (fabs(imagPart) <= threshold) imagPart = 0.0;
-      result(i, j) = NumericalComplex(realPart, imagPart);
-    }
-  return result;
+  hermitianize();
+  return clean(threshold);
 }
 
 /* String converter */
@@ -153,24 +207,24 @@ String ComplexMatrixImplementation::__str__(const String & offset) const
   if (nbRows_ == 1)
   {
     oss << offset << "(";
-    for (UnsignedLong j = 0; j < nbColumns_; ++j)
+    for (UnsignedInteger j = 0; j < nbColumns_; ++j)
       oss << (j > 0 ? " " : "") << operator()(0, j);
     oss << ")" << Os::GetEndOfLine();
     return oss;
   }
   // Array for the widths of the different components
-  Collection<UnsignedLong> widthColumns(nbColumns_, 0);
+  Collection<UnsignedInteger> widthColumns(nbColumns_, 0);
   // First loop across the values to determine the optimal width for printing
-  for (UnsignedLong i = 0; i < nbRows_; ++i)
+  for (UnsignedInteger i = 0; i < nbRows_; ++i)
   {
-    for (UnsignedLong j = 0; j < nbColumns_; ++j)
-      widthColumns[j] = std::max(widthColumns[j], static_cast<UnsignedLong>(String(OSS() << operator()(i, j)).length()));
+    for (UnsignedInteger j = 0; j < nbColumns_; ++j)
+      widthColumns[j] = std::max(widthColumns[j], static_cast<UnsignedInteger>(String(OSS() << operator()(i, j)).length()));
   }
   // Second loop
-  for (UnsignedLong i = 0; i < nbRows_; ++i)
+  for (UnsignedInteger i = 0; i < nbRows_; ++i)
   {
     oss << (i == 0 ? "/" : (i == nbRows_ - 1 ? "\\" : "|"));
-    for (UnsignedLong j = 0; j < nbColumns_; ++j)
+    for (UnsignedInteger j = 0; j < nbColumns_; ++j)
       oss << (j > 0 ? " " : "") << std::setw(widthColumns[j]) << operator()(i, j);
     if (i == 0) oss << "\\" << Os::GetEndOfLine();
     else if (i == nbRows_ - 1) oss << "/";
@@ -182,8 +236,8 @@ String ComplexMatrixImplementation::__str__(const String & offset) const
 /* Operator () gives access to the elements of theComplexMatrixImplementation (to modify these elements) */
 /* The element of theComplexMatrixImplementation is designated by its row number i and its column number j */
 /* the first element of theComplexMatrixImplementation is m(0,0) */
-NumericalComplex & ComplexMatrixImplementation::operator () (const UnsignedLong i,
-    const UnsignedLong j)
+NumericalComplex & ComplexMatrixImplementation::operator () (const UnsignedInteger i,
+    const UnsignedInteger j)
 {
   if ((i >= nbRows_) || (j >= nbColumns_)) throw InvalidDimensionException(HERE);
 
@@ -192,8 +246,8 @@ NumericalComplex & ComplexMatrixImplementation::operator () (const UnsignedLong
 
 /* Operator () gives access to the elements of theComplexMatrixImplementation (read only) */
 /* The element of theComplexMatrixImplementation is designated by its row number i and its column number j */
-const NumericalComplex & ComplexMatrixImplementation::operator () (const UnsignedLong i,
-    const UnsignedLong j)  const
+const NumericalComplex & ComplexMatrixImplementation::operator () (const UnsignedInteger i,
+    const UnsignedInteger j)  const
 {
   if ((i >= nbRows_) || (j >= nbColumns_)) throw InvalidDimensionException(HERE);
 
@@ -202,19 +256,19 @@ const NumericalComplex & ComplexMatrixImplementation::operator () (const Unsigne
 
 
 /* Get the dimensions of the ComplexMatrixImplementation : number of rows */
-const UnsignedLong ComplexMatrixImplementation::getNbRows() const
+UnsignedInteger ComplexMatrixImplementation::getNbRows() const
 {
   return nbRows_;
 }
 
 /* Get the dimensions of the ComplexMatrixImplementation : number of columns */
-const UnsignedLong ComplexMatrixImplementation::getNbColumns() const
+UnsignedInteger ComplexMatrixImplementation::getNbColumns() const
 {
   return nbColumns_;
 }
 
 /* Get the dimensions of the ComplexMatrixImplementation : dimension (square matrix : nbRows_) */
-const UnsignedLong ComplexMatrixImplementation::getDimension() const
+UnsignedInteger ComplexMatrixImplementation::getDimension() const
 {
   return nbRows_;
 }
@@ -224,8 +278,8 @@ ComplexMatrixImplementation ComplexMatrixImplementation::transpose () const
 {
   ComplexMatrixImplementation trans(nbColumns_, nbRows_);
   // The source matrix is accessed columnwise in the natural order
-  for (UnsignedLong j = 0; j < nbColumns_; ++j)
-    for (UnsignedLong i = 0; i < nbRows_; ++i)
+  for (UnsignedInteger j = 0; j < nbColumns_; ++j)
+    for (UnsignedInteger i = 0; i < nbRows_; ++i)
       trans(j, i) = operator()(i, j);
   return trans;
 }
@@ -237,8 +291,8 @@ ComplexMatrixImplementation ComplexMatrixImplementation::transposeHerm () const
 {
   ComplexMatrixImplementation result(nbColumns_, nbRows_);
   // The lower triangle of the source matrix is accessed columnwise in the natural order
-  for (UnsignedLong j = 0; j < nbColumns_; ++j)
-    for (UnsignedLong i = j; i < nbRows_; ++i)
+  for (UnsignedInteger j = 0; j < nbColumns_; ++j)
+    for (UnsignedInteger i = j; i < nbRows_; ++i)
       result(i, j) = std::conj(operator()(i, j));
   return result;
 }
@@ -248,8 +302,8 @@ ComplexMatrixImplementation ComplexMatrixImplementation::conjugate () const
 {
   ComplexMatrixImplementation result(nbRows_, nbColumns_);
   // The source matrix is accessed columnwise in the natural order
-  for (UnsignedLong j = 0; j < nbColumns_; ++j)
-    for (UnsignedLong i = 0; i < nbRows_; ++i)
+  for (UnsignedInteger j = 0; j < nbColumns_; ++j)
+    for (UnsignedInteger i = 0; i < nbRows_; ++i)
       result(i, j) = std::conj(operator()(i, j));
   return result;
 }
@@ -264,8 +318,8 @@ ComplexMatrixImplementation ComplexMatrixImplementation::conjugateHerm () const
 ComplexMatrixImplementation ComplexMatrixImplementation::conjugateTranspose () const
 {
   ComplexMatrixImplementation result(nbColumns_, nbRows_);
-  for (UnsignedLong j = 0; j < nbColumns_; ++j)
-    for (UnsignedLong i = 0; i < nbRows_; ++i)
+  for (UnsignedInteger j = 0; j < nbColumns_; ++j)
+    for (UnsignedInteger i = 0; i < nbRows_; ++i)
       result(j, i) = std::conj(operator()(i, j));
   return result;
 }
@@ -275,9 +329,13 @@ void ComplexMatrixImplementation::hermitianize() const
 {
   ComplexMatrixImplementation *refThis(const_cast<ComplexMatrixImplementation *>(this));
   // The lower triangle of the source matrix is accessed columnwise in the natural order
-  for (UnsignedLong j = 0; j < nbColumns_; ++j)
-    for (UnsignedLong i = j + 1; i < nbRows_; ++i)
-      refThis->operator[](convertPosition(j, i)) = std::conj(operator[](convertPosition(i, j)));
+  for (UnsignedInteger j = 0; j < nbColumns_; ++j)
+    for (UnsignedInteger i = j + 1; i < nbRows_; ++i)
+    {
+      const NumericalComplex value(operator[](convertPosition(i, j)));
+      if (std::abs(value.imag()) == 0.0) refThis->operator[](convertPosition(j, i)) = value.real();
+      else refThis->operator[](convertPosition(j, i)) = std::conj(value);
+    }
 }
 
 
@@ -285,8 +343,8 @@ void ComplexMatrixImplementation::hermitianize() const
 MatrixImplementation ComplexMatrixImplementation::realRect() const
 {
   MatrixImplementation result(nbRows_, nbColumns_);
-  for (UnsignedLong j = 0; j < nbColumns_; ++j)
-    for (UnsignedLong i = 0; i < nbRows_; ++i)
+  for (UnsignedInteger j = 0; j < nbColumns_; ++j)
+    for (UnsignedInteger i = 0; i < nbRows_; ++i)
       result(i, j) = (*this)(i, j).real();
   return result;
 }
@@ -294,8 +352,8 @@ MatrixImplementation ComplexMatrixImplementation::realRect() const
 MatrixImplementation ComplexMatrixImplementation::realSym() const
 {
   MatrixImplementation result(nbRows_, nbColumns_);
-  for (UnsignedLong j = 0; j < nbColumns_; ++j)
-    for (UnsignedLong i = j; i < nbRows_; ++i)
+  for (UnsignedInteger j = 0; j < nbColumns_; ++j)
+    for (UnsignedInteger i = j; i < nbRows_; ++i)
       result(i, j) = (*this)(i, j).real();
   return result;
 }
@@ -304,8 +362,8 @@ MatrixImplementation ComplexMatrixImplementation::realSym() const
 MatrixImplementation ComplexMatrixImplementation::imagRect() const
 {
   MatrixImplementation result(nbRows_, nbColumns_);
-  for (UnsignedLong j = 0; j < nbColumns_; ++j)
-    for (UnsignedLong i = 0; i < nbRows_; ++i)
+  for (UnsignedInteger j = 0; j < nbColumns_; ++j)
+    for (UnsignedInteger i = 0; i < nbRows_; ++i)
       result(i, j) = (*this)(i, j).imag();
   return result;
 }
@@ -313,27 +371,27 @@ MatrixImplementation ComplexMatrixImplementation::imagRect() const
 MatrixImplementation ComplexMatrixImplementation::imagSym() const
 {
   MatrixImplementation result(nbRows_, nbColumns_);
-  for (UnsignedLong j = 0; j < nbColumns_; ++j)
-    for (UnsignedLong i = j; i < nbRows_; ++i)
+  for (UnsignedInteger j = 0; j < nbColumns_; ++j)
+    for (UnsignedInteger i = j; i < nbRows_; ++i)
       result(i, j) = (*this)(i, j).imag();
   return result;
 }
 
 
 /* Empty returns true if there is no element in theComplexMatrixImplementation */
-const Bool ComplexMatrixImplementation::isEmpty() const
+Bool ComplexMatrixImplementation::isEmpty() const
 {
   return ((nbRows_ == 0)  || (nbColumns_ == 0) || (PersistentCollection<NumericalComplex>::isEmpty()));
 }
 
 /* Returns true if triangular lower or upper */
-const Bool ComplexMatrixImplementation::isTriangular(Bool lower) const
+Bool ComplexMatrixImplementation::isTriangular(Bool lower) const
 {
   if ( nbRows_ == nbColumns_ )
   {
-    for ( UnsignedLong j = 1; j < nbColumns_; ++ j )
-      for ( UnsignedLong i = 0; i < j; ++ i )
-        if ( std::abs( (*this)[lower ?  convertPosition(i, j) : convertPosition(j, i)] ) > 0. )
+    for ( UnsignedInteger j = 1; j < nbColumns_; ++ j )
+      for ( UnsignedInteger i = 0; i < j; ++ i )
+        if ( std::abs( (*this)[lower ?  convertPosition(i, j) : convertPosition(j, i)] ) > 0.0 )
           return false;
     return true;
   }
@@ -351,7 +409,7 @@ ComplexMatrixImplementation ComplexMatrixImplementation::operator + (const Compl
   NumericalComplex alpha(1.0, 0.0);
   int one(1);
   // Lapack routine
-  ZAXPY_F77(&size, &alpha, const_cast<std::complex<double>*>(&((*this)[0])), &one, &add[0], &one);
+  zaxpy_(&size, &alpha, const_cast<std::complex<double>*>(&((*this)[0])), &one, &add[0], &one);
 
   return add;
 }
@@ -366,7 +424,7 @@ ComplexMatrixImplementation ComplexMatrixImplementation::operator + (const Matri
   NumericalComplex alpha(1.0, 0.0);
   int one(1);
   // Lapack routine
-  ZAXPY_F77(&size, &alpha, const_cast<std::complex<double>*>(&((*this)[0])), &one, &add[0], &one);
+  zaxpy_(&size, &alpha, const_cast<std::complex<double>*>(&((*this)[0])), &one, &add[0], &one);
 
   return add;
 }
@@ -381,7 +439,7 @@ ComplexMatrixImplementation ComplexMatrixImplementation::operator - (const Compl
   NumericalComplex alpha(-1.0, 0.0);
   int one(1);
 
-  ZAXPY_F77(&size, &alpha, const_cast<std::complex<double>*>(&(matrix)[0]), &one, &sub[0], &one);
+  zaxpy_(&size, &alpha, const_cast<std::complex<double>*>(&(matrix)[0]), &one, &sub[0], &one);
 
   return sub;
 }
@@ -405,7 +463,7 @@ ComplexMatrixImplementation ComplexMatrixImplementation::operator * (const Numer
   int one(1);
   int n_(nbRows_ * nbColumns_);
   // Lapack routine
-  ZSCAL_F77(&n_, &alpha, &scalprod[0], &one);
+  zscal_(&n_, &alpha, &scalprod[0], &one);
 
   return scalprod;
 }
@@ -439,7 +497,7 @@ ComplexMatrixImplementation ComplexMatrixImplementation::genProd(const ComplexMa
   int ltransb(1);
 
   //Lapack routine
-  ZGEMM_F77(&transa, &transb, &m, &n, &k, &alpha, const_cast<std::complex<double>*>(&((*this)[0])), &m, const_cast<std::complex<double>*>(&(matrix[0])), &k, &beta, &mult[0], &m, &ltransa, &ltransb);
+  zgemm_(&transa, &transb, &m, &n, &k, &alpha, const_cast<std::complex<double>*>(&((*this)[0])), &m, const_cast<std::complex<double>*>(&(matrix[0])), &k, &beta, &mult[0], &m, &ltransa, &ltransb);
   return mult;
 }
 
@@ -464,7 +522,7 @@ ComplexMatrixImplementation ComplexMatrixImplementation::symProd (const ComplexM
   int luplo(1);
 
   // Lapack routine
-  ZSYMM_F77(&side, &uplo, &m, &n, &alpha, const_cast<std::complex<double>*>(&((*this)[0])), &m, const_cast<std::complex<double>*>(&(matrix[0])), &k, &beta, &mult[0], &m, &lside, &luplo);
+  zsymm_(&side, &uplo, &m, &n, &alpha, const_cast<std::complex<double>*>(&((*this)[0])), &m, const_cast<std::complex<double>*>(&(matrix[0])), &k, &beta, &mult[0], &m, &lside, &luplo);
 
   return mult;
 }
@@ -490,8 +548,8 @@ ComplexMatrixImplementation ComplexMatrixImplementation::hermProd(const ComplexM
   int luplo(1);
 
   // Lapack routine
-  if (hermSide == 'L') ZHEMM_F77(&side, &uplo, &m, &n, &alpha, const_cast<std::complex<double>*>(&((*this)[0])), &m, const_cast<std::complex<double>*>(&(matrix[0])), &k, &beta, &mult[0], &m, &lside, &luplo);
-  else ZHEMM_F77(&side, &uplo, &m, &n, &alpha, const_cast<std::complex<double>*>(&(matrix[0])), &k, const_cast<std::complex<double>*>(&((*this)[0])), &m, &beta, &mult[0], &m, &lside, &luplo);
+  if (hermSide == 'L') zhemm_(&side, &uplo, &m, &n, &alpha, const_cast<std::complex<double>*>(&((*this)[0])), &m, const_cast<std::complex<double>*>(&(matrix[0])), &k, &beta, &mult[0], &m, &lside, &luplo);
+  else zhemm_(&side, &uplo, &m, &n, &alpha, const_cast<std::complex<double>*>(&(matrix[0])), &k, const_cast<std::complex<double>*>(&((*this)[0])), &m, &beta, &mult[0], &m, &lside, &luplo);
 
   return mult;
 }
@@ -525,21 +583,21 @@ ComplexMatrixImplementation ComplexMatrixImplementation::triangularProd(const Co
   NumericalComplex alpha(1.0);
 
   // Lapack routine
-  ZTRMM_F77(&side, &uplo, &trans, &diag, &m, &n, &alpha , const_cast<std::complex<double>*>(&((*this)[0])),  &m, const_cast<std::complex<double>*>(&(mult[0])), &m, &lside , &luplo, &ltrans,  &ldiag);
+  ztrmm_(&side, &uplo, &trans, &diag, &m, &n, &alpha , const_cast<std::complex<double>*>(&((*this)[0])),  &m, const_cast<std::complex<double>*>(&(mult[0])), &m, &lside , &luplo, &ltrans,  &ldiag);
   return mult;
 }
 
 /* Integer power, general matrix */
-ComplexMatrixImplementation ComplexMatrixImplementation::genPower(const UnsignedLong n) const
+ComplexMatrixImplementation ComplexMatrixImplementation::genPower(const UnsignedInteger n) const
 {
   Bool first(true);
-  UnsignedLong exponent(n);
+  UnsignedInteger exponent(n);
   ComplexMatrixImplementation y;
   ComplexMatrixImplementation z(*this);
   while (exponent > 0)
   {
     // t is the right bit of exponent
-    const UnsignedLong t(exponent % 2);
+    const UnsignedInteger t(exponent % 2);
     // remove last bit from exponent
     exponent /= 2;
     // if right bit is 1
@@ -562,16 +620,16 @@ ComplexMatrixImplementation ComplexMatrixImplementation::genPower(const Unsigned
 }
 
 /* Integer power, symmetric matrix */
-ComplexMatrixImplementation ComplexMatrixImplementation::symPower(const UnsignedLong n) const
+ComplexMatrixImplementation ComplexMatrixImplementation::symPower(const UnsignedInteger n) const
 {
   Bool first(true);
-  UnsignedLong exponent(n);
+  UnsignedInteger exponent(n);
   ComplexMatrixImplementation y;
   ComplexMatrixImplementation z(*this);
   while (exponent > 0)
   {
     // t is the right bit of exponent
-    const UnsignedLong t(exponent % 2);
+    const UnsignedInteger t(exponent % 2);
     // remove last bit from exponent
     exponent /= 2;
     // if right bit is 1
@@ -594,16 +652,16 @@ ComplexMatrixImplementation ComplexMatrixImplementation::symPower(const Unsigned
 }
 
 /* Integer power, hermitian matrix */
-ComplexMatrixImplementation ComplexMatrixImplementation::hermPower(const UnsignedLong n) const
+ComplexMatrixImplementation ComplexMatrixImplementation::hermPower(const UnsignedInteger n) const
 {
   Bool first(true);
-  UnsignedLong exponent(n);
+  UnsignedInteger exponent(n);
   ComplexMatrixImplementation y;
   ComplexMatrixImplementation z(*this);
   while (exponent > 0)
   {
     // t is the right bit of exponent
-    const UnsignedLong t(exponent % 2);
+    const UnsignedInteger t(exponent % 2);
     // remove last bit from exponent
     exponent /= 2;
     // if right bit is 1
@@ -640,7 +698,7 @@ ComplexMatrixImplementation::NumericalComplexCollection ComplexMatrixImplementat
   NumericalComplex beta(0.0, 0.0);
   int ltrans(1);
 
-  ZGEMV_F77(&trans, &m_, &n_, &alpha, const_cast<std::complex<double>*>(&((*this)[0])), &m_, const_cast<std::complex<double>*>(&(pt[0])), &one, &beta, &prod[0], &one, &ltrans);
+  zgemv_(&trans, &m_, &n_, &alpha, const_cast<std::complex<double>*>(&((*this)[0])), &m_, const_cast<std::complex<double>*>(&(pt[0])), &one, &beta, &prod[0], &one, &ltrans);
 
   return prod;
 }
@@ -653,7 +711,7 @@ ComplexMatrixImplementation::NumericalComplexCollection ComplexMatrixImplementat
   NumericalComplexCollection prod(nbRows_);
   if ((nbRows_ == 0) || (nbColumns_ == 0)) return prod;
   NumericalComplexCollection copyPoint(nbRows_);
-  for (UnsignedLong i = 0; i < pt.getSize(); ++i) copyPoint[i] = pt[i];
+  for (UnsignedInteger i = 0; i < pt.getSize(); ++i) copyPoint[i] = pt[i];
   char trans('N');
   int m_(nbRows_);
   int n_(nbColumns_);
@@ -662,7 +720,7 @@ ComplexMatrixImplementation::NumericalComplexCollection ComplexMatrixImplementat
   NumericalComplex beta(0.0, 0.0);
   int ltrans(1);
 
-  ZGEMV_F77(&trans, &m_, &n_, &alpha, const_cast<std::complex<double>*>(&((*this)[0])), &m_, const_cast<std::complex<double>*>(&(copyPoint[0])), &one, &beta, &prod[0], &one, &ltrans);
+  zgemv_(&trans, &m_, &n_, &alpha, const_cast<std::complex<double>*>(&((*this)[0])), &m_, const_cast<std::complex<double>*>(&(copyPoint[0])), &one, &beta, &prod[0], &one, &ltrans);
 
   return prod;
 }
@@ -675,7 +733,7 @@ ComplexMatrixImplementation::NumericalComplexCollection ComplexMatrixImplementat
   NumericalComplexCollection prod(nbRows_);
   if ((nbRows_ == 0) || (nbColumns_ == 0)) return prod;
   NumericalComplexCollection copyPoint(nbRows_);
-  for (UnsignedLong i = 0; i < pt.getSize(); ++i) copyPoint[i] = pt[i];
+  for (UnsignedInteger i = 0; i < pt.getSize(); ++i) copyPoint[i] = pt[i];
   char trans('N');
   int m_(nbRows_);
   int n_(nbColumns_);
@@ -684,7 +742,7 @@ ComplexMatrixImplementation::NumericalComplexCollection ComplexMatrixImplementat
   NumericalComplex beta(0.0, 0.0);
   int ltrans(1);
 
-  ZGEMV_F77(&trans, &m_, &n_, &alpha, const_cast<std::complex<double>*>(&((*this)[0])), &m_, const_cast<std::complex<double>*>(&(copyPoint[0])), &one, &beta, &prod[0], &one, &ltrans);
+  zgemv_(&trans, &m_, &n_, &alpha, const_cast<std::complex<double>*>(&((*this)[0])), &m_, const_cast<std::complex<double>*>(&(copyPoint[0])), &one, &beta, &prod[0], &one, &ltrans);
 
   return prod;
 }
@@ -702,7 +760,7 @@ ComplexMatrixImplementation::NumericalComplexCollection ComplexMatrixImplementat
   NumericalComplex alpha(1.0, 0.0);
   NumericalComplex beta(0.0, 0.0);
   int luplo(1);
-  ZHEMV_F77(&uplo, &n, &alpha, const_cast<std::complex<double>*>(&((*this)[0])), &n, const_cast<std::complex<double>*>(&(pt[0])), &one, &beta, &prod[0], &one, &luplo);
+  zhemv_(&uplo, &n, &alpha, const_cast<std::complex<double>*>(&((*this)[0])), &n, const_cast<std::complex<double>*>(&(pt[0])), &one, &beta, &prod[0], &one, &luplo);
 
   return prod;
 }
@@ -715,14 +773,14 @@ ComplexMatrixImplementation::NumericalComplexCollection ComplexMatrixImplementat
   // In this case, nbRows_ == nbColumns_
   if (nbRows_ == 0) return prod;
   NumericalComplexCollection copyPoint(nbRows_);
-  for (UnsignedLong i = 0; i < pt.getSize(); ++i) copyPoint[i] = pt[i];
+  for (UnsignedInteger i = 0; i < pt.getSize(); ++i) copyPoint[i] = pt[i];
   char uplo('L');
   int n(nbRows_);
   int one(1);
   NumericalComplex alpha(1.0, 0.0);
   NumericalComplex beta(0.0, 0.0);
   int luplo(1);
-  ZHEMV_F77(&uplo, &n, &alpha, const_cast<std::complex<double>*>(&((*this)[0])), &n, const_cast<std::complex<double>*>(&(copyPoint[0])), &one, &beta, &prod[0], &one, &luplo);
+  zhemv_(&uplo, &n, &alpha, const_cast<std::complex<double>*>(&((*this)[0])), &n, const_cast<std::complex<double>*>(&(copyPoint[0])), &one, &beta, &prod[0], &one, &luplo);
 
   return prod;
 }
@@ -735,14 +793,14 @@ ComplexMatrixImplementation::NumericalComplexCollection ComplexMatrixImplementat
   // In this case, nbRows_ == nbColumns_
   if (nbRows_ == 0) return prod;
   NumericalComplexCollection copyPoint(nbRows_);
-  for (UnsignedLong i = 0; i < pt.getSize(); ++i) copyPoint[i] = pt[i];
+  for (UnsignedInteger i = 0; i < pt.getSize(); ++i) copyPoint[i] = pt[i];
   char uplo('L');
   int n(nbRows_);
   int one(1);
   NumericalComplex alpha(1.0, 0.0);
   NumericalComplex beta(0.0, 0.0);
   int luplo(1);
-  ZHEMV_F77(&uplo, &n, &alpha, const_cast<std::complex<double>*>(&((*this)[0])), &n, const_cast<std::complex<double>*>(&(copyPoint[0])), &one, &beta, &prod[0], &one, &luplo);
+  zhemv_(&uplo, &n, &alpha, const_cast<std::complex<double>*>(&((*this)[0])), &n, const_cast<std::complex<double>*>(&(copyPoint[0])), &one, &beta, &prod[0], &one, &luplo);
 
   return prod;
 }
@@ -771,7 +829,7 @@ ComplexMatrixImplementation::NumericalComplexCollection ComplexMatrixImplementat
   int one(1);
 
   NumericalComplexCollection x(pt);
-  ZTRMV_F77(&uplo, &trans, &diag, &n, const_cast<std::complex<double>*>(&((*this)[0])), &lda, const_cast<std::complex<double>*>(&(x[0])), &one, &luplo, &ltrans, &ldiag);
+  ztrmv_(&uplo, &trans, &diag, &n, const_cast<std::complex<double>*>(&((*this)[0])), &lda, const_cast<std::complex<double>*>(&(x[0])), &one, &luplo, &ltrans, &ldiag);
   return x;
 }
 
@@ -797,9 +855,9 @@ ComplexMatrixImplementation::NumericalComplexCollection ComplexMatrixImplementat
   int one(1);
 
   NumericalComplexCollection x(nbRows_);
-  for (UnsignedLong i = 0; i < pt.getSize(); ++i) x[i] = pt[i];
+  for (UnsignedInteger i = 0; i < pt.getSize(); ++i) x[i] = pt[i];
 
-  ZTRMV_F77(&uplo, &trans, &diag, &n, const_cast<std::complex<double>*>(&((*this)[0])), &lda, const_cast<std::complex<double>*>(&(x[0])), &one, &luplo, &ltrans, &ldiag);
+  ztrmv_(&uplo, &trans, &diag, &n, const_cast<std::complex<double>*>(&((*this)[0])), &lda, const_cast<std::complex<double>*>(&(x[0])), &one, &luplo, &ltrans, &ldiag);
   return x;
 }
 
@@ -825,9 +883,9 @@ ComplexMatrixImplementation::NumericalComplexCollection ComplexMatrixImplementat
   int one(1);
 
   NumericalComplexCollection x(nbRows_);
-  for (UnsignedLong i = 0; i < pt.getSize(); ++i) x[i] = pt[i];
+  for (UnsignedInteger i = 0; i < pt.getSize(); ++i) x[i] = pt[i];
 
-  ZTRMV_F77(&uplo, &trans, &diag, &n, const_cast<std::complex<double>*>(&((*this)[0])), &lda, const_cast<std::complex<double>*>(&(x[0])), &one, &luplo, &ltrans, &ldiag);
+  ztrmv_(&uplo, &trans, &diag, &n, const_cast<std::complex<double>*>(&((*this)[0])), &lda, const_cast<std::complex<double>*>(&(x[0])), &one, &luplo, &ltrans, &ldiag);
   return x;
 }
 
@@ -836,8 +894,8 @@ Bool ComplexMatrixImplementation::isHermitian() const
 {
   if ( nbRows_ == nbColumns_ )
   {
-    for ( UnsignedLong i = 1; i < nbRows_; ++ i )
-      for ( UnsignedLong j = 0; j < i; ++ j )
+    for ( UnsignedInteger i = 1; i < nbRows_; ++ i )
+      for ( UnsignedInteger j = 0; j < i; ++ j )
         if ( operator[](convertPosition(i, j)) != std::conj(operator[](convertPosition(j, i))) )
           return false;
     return true;
@@ -859,12 +917,12 @@ Bool ComplexMatrixImplementation::isHermitianPositiveDefinite(const Bool keepInt
   if (keepIntact)
   {
     ComplexMatrixImplementation A(*this);
-    ZPOTRF_F77(&uplo, &n, &A[0], &n, &info, &luplo);
+    zpotrf_(&uplo, &n, &A[0], &n, &info, &luplo);
     if (info != 0) throw InternalException(HERE) << "Lapack ZPOTRF: error code=" << info;
   }
   else
   {
-    ZPOTRF_F77(&uplo, &n, &(*this)[0], &n, &info, &luplo);
+    zpotrf_(&uplo, &n, &(*this)[0], &n, &info, &luplo);
     if (info != 0) throw InternalException(HERE) << "Lapack ZPOTRF: error code=" << info;
   }
   return (info == 0) ;
@@ -879,31 +937,20 @@ ComplexMatrixImplementation ComplexMatrixImplementation::computeCholesky(const B
   int n(nbRows_);
   char uplo('L');
   int luplo(1);
-  if (keepIntact)
-  {
-    ComplexMatrixImplementation A(*this);
-    ZPOTRF_F77(&uplo, &n, &A[0], &n, &info, &luplo);
-    if (info != 0) throw InternalException(HERE) << "Lapack ZPOTRF: error code=" << info;
-    for (UnsignedLong j = 0; j < (UnsignedLong)(n); ++j)
-      for (UnsignedLong i = 0; i < (UnsignedLong)(j); ++i)
-        A(i, j) = NumericalComplex(0.0, 0.0);
-    // Check return code from Lapack
-    if(info != 0)
-      throw InvalidArgumentException(HERE) << " Error - Matrix is not positive definite" ;
-    return A;
-  }
-  else
-  {
-    ZPOTRF_F77(&uplo, &n, &(*this)[0], &n, &info, &luplo);
-    if (info != 0) throw InternalException(HERE) << "Lapack ZPOTRF: error code=" << info;
-    for (UnsignedLong j = 0; j < (UnsignedLong)(n); ++j)
-      for (UnsignedLong i = 0; i < (UnsignedLong)(j); ++i)
-        (*this)(i, j) = NumericalComplex(0.0, 0.0);
-    // Check return code from Lapack
-    if(info != 0)
-      throw InvalidArgumentException(HERE) << " Error - Matrix is not positive definite" ;
-    return (*this);
-  }
+
+  ComplexMatrixImplementation Q;
+  if (keepIntact) Q = ComplexMatrixImplementation(*this);
+  ComplexMatrixImplementation & A = keepIntact ? Q : *this;
+
+  zpotrf_(&uplo, &n, &A[0], &n, &info, &luplo);
+  if (info != 0) throw InternalException(HERE) << "Lapack ZPOTRF: error code=" << info;
+  for (UnsignedInteger j = 0; j < (UnsignedInteger)(n); ++j)
+    for (UnsignedInteger i = 0; i < (UnsignedInteger)(j); ++i)
+      A(i, j) = 0.0;//NumericalComplex(0.0, 0.0);
+  // Check return code from Lapack
+  if(info != 0)
+    throw InvalidArgumentException(HERE) << " Error - Matrix is not positive definite" ;
+  return A;
 }
 
 /* Comparison operator */
@@ -948,15 +995,15 @@ const NumericalComplex* ComplexMatrixImplementation::__baseaddress__() const
 }
 
 
-UnsignedLong ComplexMatrixImplementation::__elementsize__() const
+UnsignedInteger ComplexMatrixImplementation::__elementsize__() const
 {
   return sizeof(NumericalComplex);
 }
 
 
-UnsignedLong ComplexMatrixImplementation::__stride__(UnsignedLong dim) const
+UnsignedInteger ComplexMatrixImplementation::__stride__(UnsignedInteger dim) const
 {
-  UnsignedLong stride = __elementsize__();
+  UnsignedInteger stride = __elementsize__();
   if (dim > 0)
     stride *= nbRows_;
   return stride;
