@@ -3,7 +3,7 @@
  *  @file  Description.cxx
  *  @brief Description is a collection of string for human usage
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -22,53 +22,43 @@
  *  @date   2012-02-17 19:35:43 +0100 (Fri, 17 Feb 2012)
  */
 #include "Description.hxx"
+#include "PersistentObjectFactory.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
 CLASSNAMEINIT(Description);
 
+static Factory<PersistentCollection<String> > RegisteredFactory2("PersistentCollection<String>");
+
+static Factory<Description> RegisteredFactory("Description");
+
 /* Default constructor */
 Description::Description()
-  : TypedCollectionInterfaceObject<DescriptionImplementation>(new DescriptionImplementation)
+  : InternalType()
 {
   // Nothing to do
 }
 
 
 /* Constructor with size */
-Description::Description(const UnsignedLong size)
-  : TypedCollectionInterfaceObject<DescriptionImplementation>(new DescriptionImplementation(size))
-{
-  // Nothing to do
-}
-
-
-/* Constructor with value */
-Description::Description(const String & value)
-  : TypedCollectionInterfaceObject<DescriptionImplementation>(new DescriptionImplementation(value))
+Description::Description(const UnsignedInteger size)
+  : InternalType(size)
 {
   // Nothing to do
 }
 
 
 /* Constructor with size and default value */
-Description::Description(const UnsignedLong size,
+Description::Description(const UnsignedInteger size,
                          const String & value)
-  : TypedCollectionInterfaceObject<DescriptionImplementation>(new DescriptionImplementation(size, value))
+  : InternalType(size, value)
 {
   // Nothing to do
 }
 
 /* Constructor with size and default value */
 Description::Description(const Collection<String> & coll)
-  : TypedCollectionInterfaceObject<DescriptionImplementation>(new DescriptionImplementation(coll))
-{
-  // Nothing to do
-}
-
-/* Constructor from implementation */
-Description::Description(const DescriptionImplementation & implementation)
-  : TypedCollectionInterfaceObject<DescriptionImplementation>(implementation.clone())
+  : InternalType(coll)
 {
   // Nothing to do
 }
@@ -76,7 +66,16 @@ Description::Description(const DescriptionImplementation & implementation)
 /* Check if the content is blank */
 Bool Description::isBlank() const
 {
-  return getImplementation()->isBlank();
+  for (UnsignedInteger i = 0; i < getSize(); ++i)
+  {
+    const UnsignedInteger length((*this)[i].size());
+    for (UnsignedInteger j = 0; j < length; ++j)
+    {
+      const char c = (*this)[i][j];
+      if (c != ' ' && c != '\t') return false;
+    }
+  }
+  return true;
 }
 
 /* Destructor */
@@ -85,13 +84,20 @@ Description::~Description()
   // Nothing to do
 }
 
-
 void Description::sort()
 {
-  copyOnWrite();
   std::sort(begin(), end());
 }
 
+Description Description::BuildDefault(const UnsignedInteger dimension,
+                                      const String & prefix)
+{
+  if (dimension == 1) return Description(1, prefix);
+  Description description(dimension);
+  for (UnsignedInteger k = 0; k < dimension; ++k) description[k] =  String(OSS() << prefix << k);
+  return description;
+}
+
 END_NAMESPACE_OPENTURNS
 
 
