@@ -1,9 +1,9 @@
 //                                               -*- C++ -*-
 /**
  *  @file  Indices.cxx
- *  @brief Set of indices defined as a Collection of UnsignedLong class
+ *  @brief Set of indices defined as a Collection of UnsignedInteger class
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -23,12 +23,17 @@
  */
 #include <algorithm>
 #include "Indices.hxx"
+#include "PersistentObjectFactory.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
+CLASSNAMEINIT(Indices);
+static Factory<Indices> RegisteredFactory("Indices");
+
 /* Check that no value is repeated and no value exceed the given bound */
-Bool Indices::check(const UnsignedLong bound) const
+Bool Indices::check(const UnsignedInteger bound) const
 {
+  if (getSize() == 0) return true;
   // Check if the values are all different
   Indices copy(*this);
   std::sort(copy.begin(), copy.end());
@@ -39,13 +44,23 @@ Bool Indices::check(const UnsignedLong bound) const
   return true;
 }
 
-/* Fill the indices with a linear progression, starting from start value by step stepsize */
-void Indices::fill(const UnsignedLong initialValue,
-                   const UnsignedLong stepSize)
+/* Check if the indices are increasing */
+Bool Indices::isIncreasing() const
 {
-  const UnsignedLong size(getSize());
-  UnsignedLong value(initialValue);
-  for (UnsignedLong i = 0; i < size; ++i)
+  const UnsignedInteger size(getSize());
+  if (size <= 1) return true;
+  for (UnsignedInteger i = 1; i < size; ++i)
+    if (operator[](i) < operator[](i - 1)) return false;
+  return true;
+}
+
+/* Fill the indices with a linear progression, starting from start value by step stepsize */
+void Indices::fill(const UnsignedInteger initialValue,
+                   const UnsignedInteger stepSize)
+{
+  const UnsignedInteger size(getSize());
+  UnsignedInteger value(initialValue);
+  for (UnsignedInteger i = 0; i < size; ++i)
   {
     operator[](i) = value;
     value += stepSize;
