@@ -3,7 +3,7 @@
  *  @file  SquareMatrix.cxx
  *  @brief SquareMatrix implements the classical mathematical square matrix
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -28,8 +28,6 @@
 
 BEGIN_NAMESPACE_OPENTURNS
 
-
-
 CLASSNAMEINIT(SquareMatrix);
 
 /* Default constructor */
@@ -40,25 +38,6 @@ SquareMatrix::SquareMatrix()
 }
 
 
-/* Constructor with size (dim, which is the same for nbRows_ and nbColumns_ )*/
-SquareMatrix::SquareMatrix(const UnsignedLong dim)
-  : Matrix(dim, dim)
-{
-  // Nothing to do
-}
-
-/* Constructor from external collection */
-/* If the dimensions of the matrix and of the collection */
-/* do not match, either the collection is truncated */
-/* or the rest of the matrix is filled with zeros */
-SquareMatrix::SquareMatrix(const UnsignedLong dim,
-                           const NumericalScalarCollection & elementsValues)
-  : Matrix(dim, dim, elementsValues)
-{
-  // Nothing to do
-}
-
-
 /* Constructor with implementation */
 SquareMatrix::SquareMatrix(const Implementation & i)
   : Matrix(i)
@@ -68,6 +47,34 @@ SquareMatrix::SquareMatrix(const Implementation & i)
 }
 
 
+/* Constructor with implementation */
+SquareMatrix::SquareMatrix(const MatrixImplementation & i)
+  : Matrix(i)
+{
+  if (getNbRows() != getNbColumns())
+    throw InvalidDimensionException(HERE) << "The matrix provided is not square : rows=" << getNbRows() << " columns=" << getNbColumns();
+}
+
+
+/* Constructor with size (dim, which is the same for nbRows_ and nbColumns_ )*/
+SquareMatrix::SquareMatrix(const UnsignedInteger dim)
+  : Matrix(dim, dim)
+{
+  // Nothing to do
+}
+
+/* Constructor from external collection */
+/* If the dimensions of the matrix and of the collection */
+/* do not match, either the collection is truncated */
+/* or the rest of the matrix is filled with zeros */
+SquareMatrix::SquareMatrix(const UnsignedInteger dim,
+                           const NumericalScalarCollection & elementsValues)
+  : Matrix(dim, dim, elementsValues)
+{
+  // Nothing to do
+}
+
+
 /* String converter */
 String SquareMatrix::__repr__() const
 {
@@ -77,7 +84,7 @@ String SquareMatrix::__repr__() const
 }
 
 /* Get the dimension of the matrix */
-const UnsignedLong SquareMatrix::getDimension() const
+UnsignedInteger SquareMatrix::getDimension() const
 {
   return getImplementation()->getDimension();
 }
@@ -149,7 +156,7 @@ SquareMatrix SquareMatrix::operator / (const NumericalScalar s) const
 }
 
 /* SquareMatrix integer power */
-SquareMatrix SquareMatrix::power(const UnsignedLong n) const
+SquareMatrix SquareMatrix::power(const UnsignedInteger n) const
 {
   return Implementation(getImplementation()->genPower(n).clone());
 }
@@ -179,16 +186,22 @@ NumericalScalar SquareMatrix::computeDeterminant(const Bool keepIntact)
   return getImplementation()->computeDeterminant(keepIntact);
 }
 
+/* Compute trace */
+NumericalScalar SquareMatrix::computeTrace() const
+{
+  return getImplementation()->computeTrace();
+}
+
 /* Compute eigenvalues */
 SquareMatrix::NumericalComplexCollection SquareMatrix::computeEigenValues(const Bool keepIntact)
 {
   return getImplementation()->computeEigenValuesSquare(keepIntact);
 }
 
-SquareMatrix::NumericalComplexCollection SquareMatrix::computeEigenValues(SquareComplexMatrix & v,
+SquareMatrix::NumericalComplexCollection SquareMatrix::computeEV(SquareComplexMatrix & v,
     const Bool keepIntact)
 {
-  return getImplementation()->computeEigenValuesSquare(*(v.getImplementation()), keepIntact);
+  return getImplementation()->computeEVSquare(*(v.getImplementation()), keepIntact);
 }
 
 /* Check if the matrix is diagonal */
@@ -196,11 +209,11 @@ Bool SquareMatrix::isDiagonal() const
 {
   // The loops must be done in this order in order to use the quick accessor
   // of the underlying implementation.
-  for (UnsignedLong j = 0; j < getDimension(); ++j)
+  for (UnsignedInteger j = 0; j < getDimension(); ++j)
   {
-    for (UnsignedLong i = 0; i < j; ++i)
+    for (UnsignedInteger i = 0; i < j; ++i)
       if ((*getImplementation())(i, j) != 0.0) return false;
-    for (UnsignedLong i = j + 1; i < getDimension(); ++i)
+    for (UnsignedInteger i = j + 1; i < getDimension(); ++i)
       if ((*getImplementation())(i, j) != 0.0) return false;
   }
   return true;
