@@ -3,7 +3,7 @@
  *  @file  TensorImplementation.cxx
  *  @brief TensorImplementation implements the Tensor classes
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -27,19 +27,16 @@
 
 BEGIN_NAMESPACE_OPENTURNS
 
-
-
 CLASSNAMEINIT(TensorImplementation);
 
 static Factory<TensorImplementation> RegisteredFactory("TensorImplementation");
 
-
 /* Default constructor */
 TensorImplementation::TensorImplementation()
-  : PersistentCollection<NumericalScalar>(),
-    nbRows_(0),
-    nbColumns_(0),
-    nbSheets_(0)
+  : PersistentCollection<NumericalScalar>()
+  , nbRows_(0)
+  , nbColumns_(0)
+  , nbSheets_(0)
 {
   // Nothing to do
 }
@@ -47,32 +44,29 @@ TensorImplementation::TensorImplementation()
 /* Constructor with size (rowDim, colDim and sheetDim) */
 /* The TensorImplementation is made up of a collection of rowDim*colDim*sheetDim elements */
 /* The TensorImplementation is viewed as a set of column vectors read one after another, one sheet after another */
-TensorImplementation::TensorImplementation(const UnsignedLong rowDim,
-    const UnsignedLong colDim,
-    const UnsignedLong sheetDim)
-  : PersistentCollection<NumericalScalar>(rowDim * colDim * sheetDim, 0.0),
-    nbRows_(rowDim),
-    nbColumns_(colDim),
-    nbSheets_(sheetDim)
+TensorImplementation::TensorImplementation(const UnsignedInteger rowDim,
+    const UnsignedInteger colDim,
+    const UnsignedInteger sheetDim)
+  : PersistentCollection<NumericalScalar>(rowDim * colDim * sheetDim, 0.0)
+  , nbRows_(rowDim)
+  , nbColumns_(colDim)
+  , nbSheets_(sheetDim)
 {
   // Nothing to do
 }
 
 /* Constructor from external collection */
-TensorImplementation::TensorImplementation(const UnsignedLong rowDim,
-    const UnsignedLong colDim,
-    const UnsignedLong sheetDim,
+TensorImplementation::TensorImplementation(const UnsignedInteger rowDim,
+    const UnsignedInteger colDim,
+    const UnsignedInteger sheetDim,
     const Collection<NumericalScalar> & elementsValues)
-  : PersistentCollection<NumericalScalar>(rowDim * colDim * sheetDim, 0.0),
-    nbRows_(rowDim),
-    nbColumns_(colDim),
-    nbSheets_(sheetDim)
+  : PersistentCollection<NumericalScalar>(rowDim * colDim * sheetDim, 0.0)
+  , nbRows_(rowDim)
+  , nbColumns_(colDim)
+  , nbSheets_(sheetDim)
 {
-  const UnsignedLong tensorSize = std::min(rowDim * colDim * sheetDim, elementsValues.getSize());
-  for(UnsignedLong i = 0; i < tensorSize; ++i)
-  {
-    (*this)[i] = elementsValues[i];
-  }
+  const UnsignedInteger tensorSize = std::min(rowDim * colDim * sheetDim, elementsValues.getSize());
+  memcpy(&(*this)[0], &elementsValues[0], tensorSize * sizeof(NumericalScalar));
 }
 
 
@@ -83,6 +77,17 @@ TensorImplementation * TensorImplementation::clone() const
 }
 
 
+/* Set small elements to zero */
+TensorImplementation TensorImplementation::clean(const NumericalScalar threshold) const
+{
+  // Nothing to do for nonpositive threshold
+  if (threshold <= 0.0) return *this;
+  TensorImplementation result(nbRows_, nbColumns_, nbSheets_);
+  for (UnsignedInteger k = 0; k < nbSheets_; ++k)
+    result.setSheet(k, getSheet(k).clean(threshold));
+  return result;
+}
+
 /* String converter */
 String TensorImplementation::__repr__() const
 {
@@ -97,7 +102,7 @@ String TensorImplementation::__repr__() const
 String TensorImplementation::__str__(const String & offset) const
 {
   OSS oss(false);
-  for (UnsignedLong k = 0; k < getNbSheets(); ++k)
+  for (UnsignedInteger k = 0; k < getNbSheets(); ++k)
   {
     oss << (k == 0 ? "" : Os::GetEndOfLine()) << offset << "sheet " << k << ":" << Os::GetEndOfLine();
     oss << offset << getSheet(k).__str__(offset) << Os::GetEndOfLine();
@@ -106,19 +111,19 @@ String TensorImplementation::__str__(const String & offset) const
 }
 
 /* Get the dimensions of the TensorImplementation : number of rows */
-const UnsignedLong TensorImplementation::getNbRows() const
+UnsignedInteger TensorImplementation::getNbRows() const
 {
   return nbRows_;
 }
 
 /* Get the dimensions of the TensorImplementation : number of columns */
-const UnsignedLong TensorImplementation::getNbColumns() const
+UnsignedInteger TensorImplementation::getNbColumns() const
 {
   return nbColumns_;
 }
 
 /* Get the dimensions of the TensorImplementation : number of sheets */
-const UnsignedLong TensorImplementation::getNbSheets() const
+UnsignedInteger TensorImplementation::getNbSheets() const
 {
   return nbSheets_;
 }
@@ -126,9 +131,9 @@ const UnsignedLong TensorImplementation::getNbSheets() const
 /* Operator () gives access to the elements of the TensorImplementation (to modify these elements) */
 /* The element of the TensorImplementation is designated by its row number i, its column number j and its sheet number k */
 /* the first element of the TensorImplementation is t(0,0,0) */
-NumericalScalar & TensorImplementation::operator() (const UnsignedLong i,
-    const UnsignedLong j,
-    const UnsignedLong k)
+NumericalScalar & TensorImplementation::operator() (const UnsignedInteger i,
+    const UnsignedInteger j,
+    const UnsignedInteger k)
 {
   if ((i >= nbRows_) || (j >= nbColumns_) || (k >= nbSheets_)) throw InvalidDimensionException(HERE);
 
@@ -137,9 +142,9 @@ NumericalScalar & TensorImplementation::operator() (const UnsignedLong i,
 
 /* Operator () gives access to the elements of the TensorImplementation (read only) */
 /* The element of the TensorImplementation is designated by its row number i, its column number j and its sheet number k */
-const NumericalScalar & TensorImplementation::operator() (const UnsignedLong i,
-    const UnsignedLong j,
-    const UnsignedLong k)  const
+const NumericalScalar & TensorImplementation::operator() (const UnsignedInteger i,
+    const UnsignedInteger j,
+    const UnsignedInteger k)  const
 {
   if ((i >= nbRows_) || (j >= nbColumns_) || (k >= nbSheets_)) throw InvalidDimensionException(HERE);
 
@@ -147,58 +152,44 @@ const NumericalScalar & TensorImplementation::operator() (const UnsignedLong i,
 }
 
 /* getSheet returns the sheet specified by its sheet number k */
-Matrix TensorImplementation::getSheet(const UnsignedLong k) const
+Matrix TensorImplementation::getSheet(const UnsignedInteger k) const
 {
   if (k >= nbSheets_) throw InvalidDimensionException(HERE);
 
-  Matrix sheet(nbRows_, nbColumns_);
-  for (UnsignedLong i = 0; i < nbRows_; ++i)
-    for (UnsignedLong j = 0; j < nbColumns_; ++j)
-      sheet(i, j) = (*this)(i, j, k);
-
+  MatrixImplementation sheet(nbRows_, nbColumns_);
+  memcpy( &sheet[0], &(*this)[this->convertPosition(0, 0, k)], nbRows_ * nbColumns_ * sizeof(NumericalScalar) );
   return sheet;
 }
 
 /* setSheet sets matrix m as the sheet specified by its sheet number k  */
-void TensorImplementation::setSheet(const UnsignedLong k,
+void TensorImplementation::setSheet(const UnsignedInteger k,
                                     const Matrix & m)
 {
   if (k >= nbSheets_) throw InvalidDimensionException(HERE);
-
-  for (UnsignedLong i = 0; i < nbRows_; ++i)
-    for (UnsignedLong j = 0; j < nbColumns_; ++j)
-      (*this)(i, j, k) = m(i, j);
+  if (m.getNbRows() != nbRows_) throw InvalidDimensionException(HERE);
+  if (m.getNbColumns() != nbColumns_) throw InvalidDimensionException(HERE);
+  memcpy( &(*this)[this->convertPosition(0, 0, k)], &m.getImplementation()->operator[](0), nbRows_ * nbColumns_ * sizeof(NumericalScalar) );
 }
 
 /* getSheetSym returns the symmetric sheet specified by its sheet number k */
-SymmetricMatrix TensorImplementation::getSheetSym(const UnsignedLong k) const
+SymmetricMatrix TensorImplementation::getSheetSym(const UnsignedInteger k) const
 {
-  if (k >= nbSheets_) throw InvalidDimensionException(HERE);
-  if (nbRows_ != nbColumns_) throw InvalidDimensionException(HERE);
-  SymmetricMatrix sheet(nbRows_);
-  for (UnsignedLong j = 0; j < nbColumns_; ++j)
-    for (UnsignedLong i = j; i < nbRows_; ++i)
-      sheet(i, j) = (*this)(i, j, k);
+  Pointer<MatrixImplementation> sheet(getSheet(k).getImplementation());
+  sheet->symmetrize();
   return sheet;
 }
 
 /* setSheetSym sets symmetric matrix m as the sheet specified by its sheet number k  */
-void TensorImplementation::setSheetSym(const UnsignedLong k,
+void TensorImplementation::setSheetSym(const UnsignedInteger k,
                                        const SymmetricMatrix & m)
 {
-  if (k >= nbSheets_) throw InvalidDimensionException(HERE);
-
-  if (m.getDimension() != nbRows_) throw InvalidArgumentException(HERE);
-  if (nbRows_ != nbColumns_) throw InvalidDimensionException(HERE);
-
-  for (UnsignedLong j = 0; j < nbColumns_; ++j)
-    for (UnsignedLong i = j; i < nbRows_; ++i)
-      (*this)(i, j, k) = m(i, j);
+  Pointer<MatrixImplementation> sheet(m.getImplementation());
+  sheet->symmetrize();
+  setSheet(k, m);
 }
 
-
 /* Empty returns true if there is no element in the TensorImplementation */
-const Bool TensorImplementation::isEmpty() const
+Bool TensorImplementation::isEmpty() const
 {
   return ((nbRows_ == 0)  || (nbColumns_ == 0) || (nbSheets_ == 0) || (PersistentCollection<NumericalScalar>::isEmpty())) ;
 }
@@ -207,9 +198,9 @@ const Bool TensorImplementation::isEmpty() const
 Bool TensorImplementation::isSymmetric() const
 {
   if (nbColumns_ != nbRows_) return false;
-  for (UnsignedLong k = 0; k < nbSheets_; ++k)
-    for (UnsignedLong j = 0; j < nbColumns_; ++j)
-      for (UnsignedLong i = 0; i < j; ++i)
+  for (UnsignedInteger k = 0; k < nbSheets_; ++k)
+    for (UnsignedInteger j = 0; j < nbColumns_; ++j)
+      for (UnsignedInteger i = 0; i < j; ++i)
         if((*this)[this->convertPosition(i, j, k)] != (*this)[this->convertPosition(j, i, k)]) return false;
   return true;
 }
@@ -218,9 +209,9 @@ Bool TensorImplementation::isSymmetric() const
 void TensorImplementation::symmetrize() const
 {
   TensorImplementation & refThis = * const_cast<TensorImplementation *>(this);
-  for (UnsignedLong k = 0; k < nbSheets_; ++k)
-    for (UnsignedLong j = 0; j < nbColumns_; ++j)
-      for (UnsignedLong i = 0; i < j; ++i)
+  for (UnsignedInteger k = 0; k < nbSheets_; ++k)
+    for (UnsignedInteger j = 0; j < nbColumns_; ++j)
+      for (UnsignedInteger i = 0; i < j; ++i)
         refThis[this->convertPosition(i, j, k)] = (*this)[this->convertPosition(j, i, k)];
 }
 
@@ -267,15 +258,15 @@ const NumericalScalar* TensorImplementation::__baseaddress__() const
 }
 
 
-UnsignedLong TensorImplementation::__elementsize__() const
+UnsignedInteger TensorImplementation::__elementsize__() const
 {
   return sizeof(NumericalScalar);
 }
 
 
-UnsignedLong TensorImplementation::__stride__(UnsignedLong dim) const
+UnsignedInteger TensorImplementation::__stride__(UnsignedInteger dim) const
 {
-  UnsignedLong stride = __elementsize__();
+  UnsignedInteger stride = __elementsize__();
   if (dim > 0)
     stride *= nbRows_;
   if (dim > 1)
