@@ -3,7 +3,7 @@
  *  @file  Analytical.cxx
  *  @brief Analytical implements an algorithm to find the design point
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -45,7 +45,7 @@ Analytical::Analytical(const NearestPointAlgorithm & nearestPointAlgorithm,
     event_(event),
     physicalStartingPoint_(physicalStartingPoint)
 {
-  const UnsignedLong dimension = event.getImplementation()->getFunction().getInputDimension();
+  const UnsignedInteger dimension = event.getImplementation()->getFunction().getInputDimension();
   if (physicalStartingPoint.getDimension() != dimension) throw InvalidArgumentException(HERE) << "Starting point dimension (" << physicalStartingPoint.getDimension() << ") does not match event dimension (" << dimension << ").";
   result_ = AnalyticalResult(event_.getImplementation()->getAntecedent()->getDistribution().getIsoProbabilisticTransformation().operator()(physicalStartingPoint_), event, true);
 }
