@@ -3,7 +3,7 @@
  *  @file  AnalyticalResult.cxx
  *  @brief Result computes the results of an analytical Algorithm
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -54,9 +54,8 @@ static Factory<AnalyticalResult> RegisteredFactory("AnalyticalResult");
  */
 AnalyticalResult::AnalyticalResult(const NumericalPoint & standardSpaceDesignPoint,
                                    const Event & limitStateVariable,
-                                   const Bool isStandardPointOriginInFailureSpace,
-                                   const String & name):
-  PersistentObject(name),
+                                   const Bool isStandardPointOriginInFailureSpace):
+  PersistentObject(),
   standardSpaceDesignPoint_(standardSpaceDesignPoint.getDimension()),
   physicalSpaceDesignPoint_(standardSpaceDesignPoint.getDimension()),
   limitStateVariable_(limitStateVariable),
@@ -67,6 +66,7 @@ AnalyticalResult::AnalyticalResult(const NumericalPoint & standardSpaceDesignPoi
   hasoferReliabilityIndexSensitivity_(0),
   isAlreadyComputedImportanceFactors_(false),
   isAlreadyComputedClassicalImportanceFactors_(false),
+  isAlreadyComputedPhysicalImportanceFactors_(false),
   isAlreadyComputedHasoferReliabilityIndexSensitivity_(false)
 {
   /* we use the attribute accessor in order to compute automatically all the other attributes */
@@ -89,6 +89,7 @@ AnalyticalResult::AnalyticalResult():
   hasoferReliabilityIndexSensitivity_(0),
   isAlreadyComputedImportanceFactors_(false),
   isAlreadyComputedClassicalImportanceFactors_(false),
+  isAlreadyComputedPhysicalImportanceFactors_(false),
   isAlreadyComputedHasoferReliabilityIndexSensitivity_(false)
 {
   // Nothing to do
@@ -160,7 +161,7 @@ void AnalyticalResult::setIsStandardPointOriginInFailureSpace(const Bool isStand
 /* ImportanceFactors evaluation */
 void AnalyticalResult::computeImportanceFactors() const
 {
-  const UnsignedLong dimension(standardSpaceDesignPoint_.getDimension());
+  const UnsignedInteger dimension(standardSpaceDesignPoint_.getDimension());
   importanceFactors_ = NumericalPoint(dimension, -1.0);
   /* First, check that the importance factors are well-defined */
   if (standardSpaceDesignPoint_.norm() > 0.0)
@@ -175,7 +176,7 @@ void AnalyticalResult::computeImportanceFactors() const
     /* if Generalised Nataf Transformation : Z = E1^(-1)o F_{Xi}(Xi*) */
     /* if Rosenblatt  Transformation : Z = Phi^(-1)o F_{Xi}(Xi*) */
     // for each marginals */
-    for (UnsignedLong marginalIndex = 0; marginalIndex < dimension; ++marginalIndex)
+    for (UnsignedInteger marginalIndex = 0; marginalIndex < dimension; ++marginalIndex)
     {
       const NumericalScalar y(inputDistribution.getMarginal(marginalIndex).computeCDF(NumericalPoint(1, physicalSpaceDesignPoint_[marginalIndex])));
       importanceFactors_[marginalIndex] = standardMarginalDistribution.computeQuantile(y)[0];
@@ -193,7 +194,7 @@ void AnalyticalResult::computeImportanceFactors() const
 /* Classical ImportanceFactors evaluation */
 void AnalyticalResult::computeClassicalImportanceFactors() const
 {
-  const UnsignedLong dimension(standardSpaceDesignPoint_.getDimension());
+  const UnsignedInteger dimension(standardSpaceDesignPoint_.getDimension());
   classicalImportanceFactors_ = NumericalPoint(dimension, -1.0);
   /* First, check that the importance factors are well-defined */
   const NumericalScalar beta2(standardSpaceDesignPoint_.normSquare());
@@ -207,6 +208,26 @@ void AnalyticalResult::computeClassicalImportanceFactors() const
   isAlreadyComputedClassicalImportanceFactors_ = true;
 }
 
+
+void AnalyticalResult::computePhysicalImportanceFactors() const
+{
+  const Event myEvent(getLimitStateVariable());
+  const StandardEvent mystandardEvent(myEvent);
+  const NumericalScalar sign = myEvent.getOperator().compare(0., 1.) ? 1.0 : -1.0;
+  const NumericalPoint currentStandardGradient(mystandardEvent.getImplementation()->getFunction().gradient(getStandardSpaceDesignPoint()) * NumericalPoint(1, 1.0));
+  const NumericalPoint alpha(sign / currentStandardGradient.norm() * currentStandardGradient);
+  const Distribution physicalDistribution(myEvent.getImplementation()->getAntecedent()->getDistribution());
+  const InverseIsoProbabilisticTransformation inverseIsoProbabilisticTransformation(physicalDistribution.getInverseIsoProbabilisticTransformation());
+  const Matrix isoGradient(inverseIsoProbabilisticTransformation.gradient(standardSpaceDesignPoint_));
+  physicalImportanceFactors_ = (isoGradient * alpha).normalizeSquare();
+  const NumericalPoint currentPhysicalGradient(limitStateVariable_.getImplementation()->getFunction().gradient(getPhysicalSpaceDesignPoint()) * NumericalPoint(1, 1.0));
+  physicalImportanceFactors_ = currentPhysicalGradient.normalizeSquare();
+  physicalImportanceFactors_.setName("Physical importance factors");
+  physicalImportanceFactors_.setDescription(myEvent.getImplementation()->getAntecedent()->getDescription());
+  isAlreadyComputedPhysicalImportanceFactors_ = true;
+}
+
+
 /*  Mean point conditioned to the standard event realization accessor */
 void AnalyticalResult::computeMeanPointInStandardEventDomain() const
 {
@@ -218,13 +239,13 @@ void AnalyticalResult::computeMeanPointInStandardEventDomain() const
   // Quadrature rule
   NumericalPoint weights;
   const NumericalPoint nodes(p_standardDistribution->getGaussNodesAndWeights(weights));
-  const UnsignedLong nodesSize(nodes.getSize());
+  const UnsignedInteger nodesSize(nodes.getSize());
   NumericalScalar sum(0.0);
   const NumericalScalar quantileEpsilon(ResourceMap::GetAsNumericalScalar( "DistributionImplementation-DefaultQuantileEpsilon" ));
   do
   {
     // Integrate over a unit length segment [a, a+1]
-    for (UnsignedLong k = 0; k < nodesSize; ++k) sum += weights[k] * p_standardDistribution->computeRadialDistributionCDF(a + 0.5 * (1.0 + nodes[k]), true);
+    for (UnsignedInteger k = 0; k < nodesSize; ++k) sum += weights[k] * p_standardDistribution->computeRadialDistributionCDF(a + 0.5 * (1.0 + nodes[k]), true);
     sum *= 0.5;
     scaling += sum;
     a += 1.0;
@@ -247,25 +268,29 @@ void AnalyticalResult::setMeanPointInStandardEventDomain(const NumericalPoint &
 }
 
 /* ImportanceFactors accessor */
-NumericalPointWithDescription AnalyticalResult::getImportanceFactors(const Bool classical) const
+NumericalPointWithDescription AnalyticalResult::getImportanceFactors(const ImportanceFactorType type) const
 {
-  if (classical)
+  switch(type)
   {
-    if (!isAlreadyComputedClassicalImportanceFactors_) computeClassicalImportanceFactors();
-    return classicalImportanceFactors_;
-  }
-  else
-  {
-    if (!isAlreadyComputedImportanceFactors_) computeImportanceFactors();
-    return importanceFactors_;
+    case ELLIPTICAL:
+      if (!isAlreadyComputedImportanceFactors_) computeImportanceFactors();
+      return importanceFactors_;
+    case CLASSICAL:
+      if (!isAlreadyComputedClassicalImportanceFactors_) computeClassicalImportanceFactors();
+      return classicalImportanceFactors_;
+    case PHYSICAL:
+      if (!isAlreadyComputedPhysicalImportanceFactors_) computePhysicalImportanceFactors();
+      return physicalImportanceFactors_;
+    default:
+      throw InvalidArgumentException(HERE) << "Invalid importance factor type (" << type << ")";
   }
 }
 
 /* ImportanceFactors graph */
-Graph AnalyticalResult::drawImportanceFactors(const Bool classical) const
+Graph AnalyticalResult::drawImportanceFactors(const ImportanceFactorType type) const
 {
   // To ensure that the importance factors are up to date
-  getImportanceFactors(classical);
+  getImportanceFactors(type);
   /* we build the graph with a title */
   OSS oss;
   oss << "Importance Factors from Design Point - " << limitStateVariable_.getName();
@@ -321,14 +346,14 @@ void AnalyticalResult::computeHasoferReliabilityIndexSensitivity() const
   if (setIso.getDimension() > 0) isoProbabilisticGradient = inverseIsoProbabilisticTransformation.parametersGradient(standardSpaceDesignPoint_) * (physicalGradientMatrix * NumericalPoint(1, 1.0));
   /* associate to each element of Set1 the gradient value */
   /* hasoferReliabilityIndexSensitivity is the collection Set1 + one other collection wich is Set2 */
-  const UnsignedLong set1Size(set1.getSize());
-  const UnsignedLong size(set1Size + (isSet2Empty ? 0 : 1));
+  const UnsignedInteger set1Size(set1.getSize());
+  const UnsignedInteger size(set1Size + (isSet2Empty ? 0 : 1));
   hasoferReliabilityIndexSensitivity_ = Sensitivity(size);
 
-  for (UnsignedLong sensitivityIndex = 0; sensitivityIndex < set1Size; ++sensitivityIndex)
+  for (UnsignedInteger sensitivityIndex = 0; sensitivityIndex < set1Size; ++sensitivityIndex)
   {
     const NumericalPointWithDescription currentParameters(set1[sensitivityIndex]);
-    const UnsignedLong currentDimension(currentParameters.getDimension());
+    const UnsignedInteger currentDimension(currentParameters.getDimension());
     NumericalPointWithDescription currentSensitivity(currentDimension);
     const Description currentDescription(currentParameters.getDescription());
     // the currentSensitivity gets the description and the name from set1
@@ -336,9 +361,9 @@ void AnalyticalResult::computeHasoferReliabilityIndexSensitivity() const
     const String currentName(currentParameters.getName());
     currentSensitivity.setName(currentName);
     const Description isoDescription(setIso.getDescription());
-    for (UnsignedLong currentIndex = 0; currentIndex < currentDimension; ++currentIndex)
+    for (UnsignedInteger currentIndex = 0; currentIndex < currentDimension; ++currentIndex)
     {
-      const UnsignedLong position(computePosition(currentName, currentDescription[currentIndex], isoDescription));
+      const UnsignedInteger position(computePosition(currentName, currentDescription[currentIndex], isoDescription));
       /* if currentParameters[currentIndex] is into setIso, then we get the sensitivity value in the corresponding isoProbabilisticGradient */
       if (position < setIso.getDimension()) currentSensitivity[currentIndex] = gradientToSensitivity * isoProbabilisticGradient[position];
       /* else the  sensitivity value is null */
@@ -357,11 +382,11 @@ void AnalyticalResult::computeHasoferReliabilityIndexSensitivity() const
 
 
 /* Returns the position of the given (value, name) into the NumericalPoint or the dimension of the NumericalPoint if failed */
-UnsignedLong AnalyticalResult::computePosition(const String & marginalName, const String & marginalParameterName, const Description & parameterSetNames) const
+UnsignedInteger AnalyticalResult::computePosition(const String & marginalName, const String & marginalParameterName, const Description & parameterSetNames) const
 {
-  const UnsignedLong dimension(parameterSetNames.getSize());
+  const UnsignedInteger dimension(parameterSetNames.getSize());
   const String fullName(OSS() << marginalName << "_" << marginalParameterName);
-  for (UnsignedLong index = 0; index < dimension; ++index) if ( parameterSetNames[index] == fullName ) return index;
+  for (UnsignedInteger index = 0; index < dimension; ++index) if ( parameterSetNames[index] == fullName ) return index;
   return dimension;
 }
 
@@ -372,12 +397,12 @@ AnalyticalResult::GraphCollection AnalyticalResult::drawHasoferReliabilityIndexS
   GraphCollection hasoferReliabilityIndexSensitivityGraphCollection(0);
   // To ensure that the hasoferReliabilityIndexSensitivity_ are up to date
   if (! isAlreadyComputedHasoferReliabilityIndexSensitivity_) computeHasoferReliabilityIndexSensitivity();
-  const UnsignedLong dimension(standardSpaceDesignPoint_.getDimension());
-  const UnsignedLong size(hasoferReliabilityIndexSensitivity_.getSize());
+  const UnsignedInteger dimension(standardSpaceDesignPoint_.getDimension());
+  const UnsignedInteger size(hasoferReliabilityIndexSensitivity_.getSize());
   // The first graph shows the sensitivities with respect to the marginal parameters if there exist
   // in the cas where the distribution or some marginals are defined by user, it may not have parameters : we create a empty sensitivity graph
   Sensitivity marginalSensitivity(dimension);
-  for(UnsignedLong i = 0; i < dimension; ++i) marginalSensitivity[i] = hasoferReliabilityIndexSensitivity_[i];
+  for(UnsignedInteger i = 0; i < dimension; ++i) marginalSensitivity[i] = hasoferReliabilityIndexSensitivity_[i];
   Graph hasoferReliabilityIndexSensitivityGraphMarginal(drawSensitivity(marginalSensitivity, width));
   OSS oss1;
   oss1 << "Hasofer Reliability Index Sensitivities - Marginal parameters - " << limitStateVariable_.getName();
@@ -387,7 +412,7 @@ AnalyticalResult::GraphCollection AnalyticalResult::drawHasoferReliabilityIndexS
   if (size > dimension)
   {
     Sensitivity otherSensitivity(size - dimension);
-    for(UnsignedLong i = dimension; i < size; ++i) otherSensitivity[i - dimension] = hasoferReliabilityIndexSensitivity_[i];
+    for(UnsignedInteger i = dimension; i < size; ++i) otherSensitivity[i - dimension] = hasoferReliabilityIndexSensitivity_[i];
     Graph hasoferReliabilityIndexSensitivityGraphOther(drawSensitivity(otherSensitivity, width));
     OSS oss2;
     oss2 << "Hasofer Reliability Index Sensitivities - Other parameters - " << limitStateVariable_.getName();
@@ -410,13 +435,13 @@ Graph AnalyticalResult::drawSensitivity(const Sensitivity & sensitivity,
   BarPlot sensitivityBarPlot(NumericalSample(0, 2), shift, "");
 
   // Create the barplots
-  const UnsignedLong sensitivitySize(sensitivity.getSize());
+  const UnsignedInteger sensitivitySize(sensitivity.getSize());
   const Description colors(BarPlot::BuildDefaultPalette(sensitivitySize));
-  for (UnsignedLong collectionIndex = 0; collectionIndex < sensitivitySize; ++collectionIndex)
+  for (UnsignedInteger collectionIndex = 0; collectionIndex < sensitivitySize; ++collectionIndex)
   {
     NumericalSample data(sensitivity[collectionIndex].getDimension(), 2);
-    const UnsignedLong dataSize(data.getSize());
-    for (UnsignedLong sensitivityIndex = 0; sensitivityIndex < dataSize; ++sensitivityIndex)
+    const UnsignedInteger dataSize(data.getSize());
+    for (UnsignedInteger sensitivityIndex = 0; sensitivityIndex < dataSize; ++sensitivityIndex)
     {
       data[sensitivityIndex][0] = width;
       data[sensitivityIndex][1] = sensitivity[collectionIndex][sensitivityIndex];
@@ -478,9 +503,11 @@ void AnalyticalResult::save(Advocate & adv) const
   adv.saveAttribute( "hasoferReliabilityIndex_", hasoferReliabilityIndex_ );
   adv.saveAttribute( "importanceFactors_", importanceFactors_ );
   adv.saveAttribute( "classicalImportanceFactors_", classicalImportanceFactors_ );
+  adv.saveAttribute( "physicalImportanceFactors_", physicalImportanceFactors_ );
   adv.saveAttribute( "hasoferReliabilityIndexSensitivity_", sensitivity );
   adv.saveAttribute( "isAlreadyComputedImportanceFactors_", isAlreadyComputedImportanceFactors_ );
   adv.saveAttribute( "isAlreadyComputedClassicalImportanceFactors_", isAlreadyComputedClassicalImportanceFactors_ );
+  adv.saveAttribute( "isAlreadyComputedPhysicalImportanceFactors_", isAlreadyComputedPhysicalImportanceFactors_ );
   adv.saveAttribute( "isAlreadyComputedHasoferReliabilityIndexSensitivity_", isAlreadyComputedHasoferReliabilityIndexSensitivity_ );
   adv.saveAttribute( "optimizationResult_", optimizationResult_ );
 }
