@@ -3,7 +3,7 @@
  *  @file  StrongMaximumTest.cxx
  *  @brief StrongMaxTest implements an algorithm to check if a given design point
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -32,6 +32,7 @@
 #include "ComparisonOperatorImplementation.hxx"
 #include "ResourceMap.hxx"
 #include "PersistentObjectFactory.hxx"
+#include "SpecFunc.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -95,7 +96,7 @@ StrongMaximumTest::StrongMaximumTest(const StandardEvent & event,
                                      const NumericalPoint & standardSpaceDesignPoint,
                                      const NumericalScalar importanceLevel,
                                      const NumericalScalar accuracyLevel,
-                                     const UnsignedLong pointNumber)
+                                     const UnsignedInteger pointNumber)
   : PersistentObject(),
     event_(event),
     standardSpaceDesignPoint_(standardSpaceDesignPoint),
@@ -155,7 +156,7 @@ NumericalScalar StrongMaximumTest::getImportanceLevel() const
 /* ImportanceLevel accessor */
 void StrongMaximumTest::setImportanceLevel(const NumericalScalar importanceLevel)
 {
-  if((importanceLevel >= 1.0) or (importanceLevel <= 0.0)) throw InvalidRangeException(HERE) << "importanceLevel is not within 0.0 and 1.0";
+  if((importanceLevel >= 1.0) || (importanceLevel <= 0.0)) throw InvalidRangeException(HERE) << "importanceLevel is not within 0.0 and 1.0";
   importanceLevel_ = importanceLevel ;
 }
 
@@ -181,7 +182,7 @@ NumericalScalar StrongMaximumTest::getConfidenceLevel() const
 /* ConfidenceLevel accessor */
 void StrongMaximumTest::setConfidenceLevel(const NumericalScalar confidenceLevel)
 {
-  if((confidenceLevel > 1.0) or (confidenceLevel < 0.0)) throw InvalidRangeException(HERE) << "confidenceLevel is not within 0.0 and 1.0";
+  if((confidenceLevel > 1.0) || (confidenceLevel < 0.0)) throw InvalidRangeException(HERE) << "confidenceLevel is not within 0.0 and 1.0";
   confidenceLevel_ = confidenceLevel ;
 }
 
@@ -194,18 +195,18 @@ NumericalScalar StrongMaximumTest::getDesignPointVicinity() const
 /* StrongMaxTestDesignPointVicinity accessor */
 void  StrongMaximumTest::setDesignPointVicinity(const NumericalScalar designPointVicinity)
 {
-  if((designPointVicinity >= 1.0) or (designPointVicinity <= 0.0)) throw InvalidRangeException(HERE) << "designPointVicinity is not within 0.0 and 1.0";
+  if((designPointVicinity >= 1.0) || (designPointVicinity <= 0.0)) throw InvalidRangeException(HERE) << "designPointVicinity is not within 0.0 and 1.0";
   designPointVicinity_ =  designPointVicinity;
 }
 
 /* StrongMaxTestPointNumber  accessor */
-UnsignedLong  StrongMaximumTest::getPointNumber() const
+UnsignedInteger  StrongMaximumTest::getPointNumber() const
 {
   return pointNumber_;
 }
 
 /* StrongMaxTestPointNumber accessor */
-void StrongMaximumTest::setPointNumber(const UnsignedLong pointNumber)
+void StrongMaximumTest::setPointNumber(const UnsignedInteger pointNumber)
 {
   if(pointNumber == 0) throw InvalidRangeException(HERE) << "pointNumber is equal to 0";
   pointNumber_ = pointNumber ;
@@ -337,10 +338,10 @@ void StrongMaximumTest::initializeParametersGivenConfidenceLevel()
   /* evaluate the HyperSphereSurfaceRatio (see documentation) */
   NumericalScalar p(computeHyperSphereSurfaceRatio());
   // put eps1 and eps2 instead of 1.0 and 0.0
-  if((p >= 1.0) or (p <= 0.0)) throw InvalidRangeException(HERE) << "hyperSphereSurfaceRatio is not strictly within 0.0 and 1.0";
+  if((p >= 1.0) || (p <= 0.0)) throw InvalidRangeException(HERE) << "hyperSphereSurfaceRatio is not strictly within 0.0 and 1.0";
 
   /* evaluate and affect the pointNumber_ */
-  setPointNumber(UnsignedLong(round(log1p(-confidenceLevel_) / log1p(-p))));
+  setPointNumber(static_cast<UnsignedInteger>(round(log1p(-confidenceLevel_) / log1p(-p))));
 
 
   /* evaluate and affect the designPointVicinity_ */
@@ -357,10 +358,10 @@ void StrongMaximumTest::initializeParametersGivenPointNumber()
   NumericalScalar p(computeHyperSphereSurfaceRatio());
 
   // put eps1 and eps2 instead of 1.0 and 0.0
-  if((p >= 1.0) or (p <= 0.0)) throw InvalidRangeException(HERE) << "hyperSphereSurfaceRatio is not strictly within 0.0 and 1.0";
+  if((p >= 1.0) || (p <= 0.0)) throw InvalidRangeException(HERE) << "hyperSphereSurfaceRatio is not strictly within 0.0 and 1.0";
 
   /* evaluate and affect the confidenceLevel */
-  setConfidenceLevel(1.0 - pow(1.0 - p, pointNumber_));
+  setConfidenceLevel(1.0 - pow(1.0 - p, static_cast<int>(pointNumber_)));
 
   /* evaluate and affect the designPointVicinity_ */
   setDesignPointVicinity(1.0 / (1.0 + accuracyLevel_ * deltaEpsilon_));
@@ -369,7 +370,7 @@ void StrongMaximumTest::initializeParametersGivenPointNumber()
 /*  the function that evaluates the HyperSphereSurfaceRatio (see documentation) */
 NumericalScalar StrongMaximumTest::computeHyperSphereSurfaceRatio()
 {
-  const UnsignedLong dimension(standardSpaceDesignPoint_.getDimension());
+  const UnsignedInteger dimension(standardSpaceDesignPoint_.getDimension());
   const NumericalScalar a( acos((1.0 + deltaEpsilon_) / ( 1.0 + accuracyLevel_ * deltaEpsilon_) ) );
   const NumericalScalar sinA(sin(a));
   const NumericalScalar squareSinA(sinA * sinA);
@@ -377,9 +378,9 @@ NumericalScalar StrongMaximumTest::computeHyperSphereSurfaceRatio()
   /* even dimension  */
   if (dimension % 2 == 0)
   {
-    const UnsignedLong indexMax(dimension / 2 - 1);
+    const UnsignedInteger indexMax(dimension / 2 - 1);
     NumericalScalar u(sinA);
-    for (UnsignedLong index = 0; index < indexMax; ++index)
+    for (UnsignedInteger index = 0; index < indexMax; ++index)
     {
       sum += u;
       u *= (1.0 - 1.0 / (2.0 * index + 3.0)) * squareSinA;
@@ -390,9 +391,9 @@ NumericalScalar StrongMaximumTest::computeHyperSphereSurfaceRatio()
   else
     /* odd dimension  */
   {
-    const UnsignedLong indexMax((dimension - 1) / 2);
+    const UnsignedInteger indexMax((dimension - 1) / 2);
     NumericalScalar u(1.0);
-    for (UnsignedLong index = 0; index < indexMax; ++index)
+    for (UnsignedInteger index = 0; index < indexMax; ++index)
     {
       sum += u;
       u *= (1.0 - 1.0 / (2.0 * index + 2.0)) * squareSinA;
@@ -482,12 +483,12 @@ void StrongMaximumTest::run()
   nearDesignPointVerifyingEventPoints_ = nearestPointCheckerResult.getVerifyingConstraintPoints();
   nearDesignPointVerifyingEventValues_ = nearestPointCheckerResult.getVerifyingConstraintValues();
 
-  UnsignedLong sampleSize(nearDesignPointVerifyingEventPoints_.getSize());
+  UnsignedInteger sampleSize(nearDesignPointVerifyingEventPoints_.getSize());
   /* If there is something to classify */
   if (sampleSize > 0)
   {
-    UnsignedLong leftCounter(0);
-    UnsignedLong rightCounter(sampleSize - 1);
+    UnsignedInteger leftCounter(0);
+    UnsignedInteger rightCounter(sampleSize - 1);
 
     /* we sort among the nearDesignPointVerifyingEventPoints_ (ie which realise the event) the ones which are in the vicinity of the design point */
     while (leftCounter < rightCounter)
@@ -530,8 +531,8 @@ void StrongMaximumTest::run()
   /* If there is something to classify */
   if (sampleSize > 0)
   {
-    UnsignedLong leftCounter(0);
-    UnsignedLong rightCounter(sampleSize - 1);
+    UnsignedInteger leftCounter(0);
+    UnsignedInteger rightCounter(sampleSize - 1);
 
     /* we sort among the nearDesignPointViolatingEventPoints_ (ie which realise the event) the ones which are in the vicinity of the design point */
     while (leftCounter < rightCounter)
@@ -570,14 +571,14 @@ void StrongMaximumTest::run()
 
 /* the function that samples the sphere (radius) with N points */
 NumericalSample StrongMaximumTest::sampleSphere(const NumericalScalar radius,
-    const UnsignedLong dimension,
-    const UnsignedLong pointNumber) const
+    const UnsignedInteger dimension,
+    const UnsignedInteger pointNumber) const
 {
   // First, generate a sample of a standard normal distribution of the proper size and dimension
   const Normal standardNormal(dimension);
   NumericalSample sample(standardNormal.getSample(pointNumber));
   // Then, normalize the points to have length radius
-  for (UnsignedLong i = 0; i < pointNumber; ++i)
+  for (UnsignedInteger i = 0; i < pointNumber; ++i)
   {
     NumericalScalar norm(static_cast<NumericalPoint>(sample[i]).norm());
     // If the point is the origin, we reject it
