@@ -3,7 +3,7 @@
  *  @file  FunctionalChaosAlgorithm.cxx
  *  @brief The class building chaos expansions
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -30,18 +30,31 @@
 #include "NumericalPoint.hxx"
 #include "NumericalMathFunctionImplementation.hxx"
 #include "DatabaseNumericalMathEvaluationImplementation.hxx"
-#include "OrthogonalProductPolynomialFactory.hxx"
 #include "RosenblattEvaluation.hxx"
 #include "InverseRosenblattEvaluation.hxx"
 #include "MarginalTransformationEvaluation.hxx"
 #include "MarginalTransformationGradient.hxx"
 #include "MarginalTransformationHessian.hxx"
 #include "FixedStrategy.hxx"
+#include "CleaningStrategy.hxx"
 #include "FixedExperiment.hxx"
-#include "UserDefined.hxx"
 #include "LeastSquaresStrategy.hxx"
 #include "Exception.hxx"
 #include "ResourceMap.hxx"
+#include "HyperbolicAnisotropicEnumerateFunction.hxx"
+#include "OrthogonalUniVariatePolynomialFamily.hxx"
+#include "OrthogonalProductPolynomialFactory.hxx"
+#include "KernelSmoothing.hxx"
+#include "NormalCopulaFactory.hxx"
+#include "UserDefined.hxx"
+#include "DistributionFactory.hxx"
+#include "ComposedDistribution.hxx"
+#include "StandardDistributionPolynomialFactory.hxx"
+#include "LeastSquaresMetaModelSelectionFactory.hxx"
+#include "LAR.hxx"
+#include "KFold.hxx"
+#include "CorrectedLeaveOneOut.hxx"
+#include "FittingTest.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -55,10 +68,10 @@ static Factory<FunctionalChaosAlgorithm> RegisteredFactory("FunctionalChaosAlgor
 
 /* Default constructor */
 FunctionalChaosAlgorithm::FunctionalChaosAlgorithm()
-  : MetaModelAlgorithm(),
-    adaptiveStrategy_(FixedStrategy(OrthogonalProductPolynomialFactory(), 0)),
-    projectionStrategy_(LeastSquaresStrategy()),
-    maximumResidual_(ResourceMap::GetAsNumericalScalar( "FunctionalChaosAlgorithm-DefaultMaximumResidual" ))
+  : MetaModelAlgorithm()
+  , adaptiveStrategy_(FixedStrategy(OrthogonalProductPolynomialFactory(), 0))
+  , projectionStrategy_(LeastSquaresStrategy())
+  , maximumResidual_(ResourceMap::GetAsNumericalScalar( "FunctionalChaosAlgorithm-DefaultMaximumResidual" ))
 {
   // Nothing to do
 }
@@ -69,10 +82,10 @@ FunctionalChaosAlgorithm::FunctionalChaosAlgorithm(const NumericalMathFunction &
     const Distribution & distribution,
     const AdaptiveStrategy & adaptiveStrategy,
     const ProjectionStrategy & projectionStrategy)
-  : MetaModelAlgorithm( distribution, model ),
-    adaptiveStrategy_(adaptiveStrategy),
-    projectionStrategy_(projectionStrategy),
-    maximumResidual_(ResourceMap::GetAsNumericalScalar( "FunctionalChaosAlgorithm-DefaultMaximumResidual" ))
+  : MetaModelAlgorithm( distribution, model )
+  , adaptiveStrategy_(adaptiveStrategy)
+  , projectionStrategy_(projectionStrategy)
+  , maximumResidual_(ResourceMap::GetAsNumericalScalar( "FunctionalChaosAlgorithm-DefaultMaximumResidual" ))
 {
   // Nothing to do
 }
@@ -83,10 +96,10 @@ FunctionalChaosAlgorithm::FunctionalChaosAlgorithm(const NumericalSample & input
     const Distribution & distribution,
     const AdaptiveStrategy & adaptiveStrategy,
     const ProjectionStrategy & projectionStrategy)
-  : MetaModelAlgorithm( distribution, NumericalMathFunction(NumericalMathFunctionImplementation(DatabaseNumericalMathEvaluationImplementation(inputSample, outputSample, false).clone())) ),
-    adaptiveStrategy_(adaptiveStrategy),
-    projectionStrategy_(projectionStrategy),
-    maximumResidual_(ResourceMap::GetAsNumericalScalar( "FunctionalChaosAlgorithm-DefaultMaximumResidual" ))
+  : MetaModelAlgorithm( distribution, NumericalMathFunction(NumericalMathFunctionImplementation(DatabaseNumericalMathEvaluationImplementation(inputSample, outputSample, false).clone())) )
+  , adaptiveStrategy_(adaptiveStrategy)
+  , projectionStrategy_(projectionStrategy)
+  , maximumResidual_(ResourceMap::GetAsNumericalScalar( "FunctionalChaosAlgorithm-DefaultMaximumResidual" ))
 {
   // Check sample size
   if (inputSample.getSize() != outputSample.getSize()) throw InvalidArgumentException(HERE) << "Error: the input sample and the output sample must have the same size.";
@@ -105,10 +118,10 @@ FunctionalChaosAlgorithm::FunctionalChaosAlgorithm(const NumericalSample & input
     const Distribution & distribution,
     const AdaptiveStrategy & adaptiveStrategy,
     const ProjectionStrategy & projectionStrategy)
-  : MetaModelAlgorithm( distribution, NumericalMathFunction(NumericalMathFunctionImplementation(DatabaseNumericalMathEvaluationImplementation(inputSample, outputSample, false).clone())) ),
-    adaptiveStrategy_(adaptiveStrategy),
-    projectionStrategy_(projectionStrategy),
-    maximumResidual_(ResourceMap::GetAsNumericalScalar( "FunctionalChaosAlgorithm-DefaultMaximumResidual" ))
+  : MetaModelAlgorithm( distribution, NumericalMathFunction(NumericalMathFunctionImplementation(DatabaseNumericalMathEvaluationImplementation(inputSample, outputSample, false).clone())) )
+  , adaptiveStrategy_(adaptiveStrategy)
+  , projectionStrategy_(projectionStrategy)
+  , maximumResidual_(ResourceMap::GetAsNumericalScalar( "FunctionalChaosAlgorithm-DefaultMaximumResidual" ))
 {
   // Check sample size
   if (inputSample.getSize() != outputSample.getSize()) throw InvalidArgumentException(HERE) << "Error: the input sample and the output sample must have the same size.";
@@ -124,10 +137,10 @@ FunctionalChaosAlgorithm::FunctionalChaosAlgorithm(const NumericalSample & input
 FunctionalChaosAlgorithm::FunctionalChaosAlgorithm(const NumericalMathFunction & model,
     const Distribution & distribution,
     const AdaptiveStrategy & adaptiveStrategy)
-  : MetaModelAlgorithm( distribution, model ),
-    adaptiveStrategy_(adaptiveStrategy),
-    projectionStrategy_(LeastSquaresStrategy()),
-    maximumResidual_(ResourceMap::GetAsNumericalScalar( "FunctionalChaosAlgorithm-DefaultMaximumResidual" ))
+  : MetaModelAlgorithm( distribution, model )
+  , adaptiveStrategy_(adaptiveStrategy)
+  , projectionStrategy_(LeastSquaresStrategy())
+  , maximumResidual_(ResourceMap::GetAsNumericalScalar( "FunctionalChaosAlgorithm-DefaultMaximumResidual" ))
 {
   // Nothing to do
 }
@@ -137,25 +150,87 @@ FunctionalChaosAlgorithm::FunctionalChaosAlgorithm(const NumericalSample & input
     const NumericalSample & outputSample,
     const Distribution & distribution,
     const AdaptiveStrategy & adaptiveStrategy)
-  : MetaModelAlgorithm( distribution, NumericalMathFunction(NumericalMathFunctionImplementation(DatabaseNumericalMathEvaluationImplementation(inputSample, outputSample, false).clone())) ),
-    adaptiveStrategy_(adaptiveStrategy),
-    projectionStrategy_(LeastSquaresStrategy(inputSample, outputSample)),
-    maximumResidual_(ResourceMap::GetAsNumericalScalar( "FunctionalChaosAlgorithm-DefaultMaximumResidual" ))
+  : MetaModelAlgorithm( distribution, NumericalMathFunction(NumericalMathFunctionImplementation(DatabaseNumericalMathEvaluationImplementation(inputSample, outputSample, false).clone())) )
+  , adaptiveStrategy_(adaptiveStrategy)
+  , projectionStrategy_(LeastSquaresStrategy(inputSample, outputSample))
+  , maximumResidual_(ResourceMap::GetAsNumericalScalar( "FunctionalChaosAlgorithm-DefaultMaximumResidual" ))
 {
   // Check sample size
   if (inputSample.getSize() != outputSample.getSize()) throw InvalidArgumentException(HERE) << "Error: the input sample and the output sample must have the same size.";
 }
 
+/* Constructor */
+FunctionalChaosAlgorithm::FunctionalChaosAlgorithm(const NumericalSample & inputSample,
+    const NumericalSample & outputSample)
+  : MetaModelAlgorithm( Distribution(), NumericalMathFunction(NumericalMathFunctionImplementation(DatabaseNumericalMathEvaluationImplementation(inputSample, outputSample, false).clone())) )
+  , adaptiveStrategy_()
+  , projectionStrategy_()
+  , maximumResidual_(ResourceMap::GetAsNumericalScalar( "FunctionalChaosAlgorithm-DefaultMaximumResidual" ))
+{
+  // Check sample size
+  if (inputSample.getSize() != outputSample.getSize()) throw InvalidArgumentException(HERE) << "Error: the input sample and the output sample must have the same size.";
+  // Recover the distribution, taking into account that we look for performance
+  const UnsignedInteger inputDimension(inputSample.getDimension());
+  Collection< Distribution > marginals(inputDimension);
+  Collection< OrthogonalUniVariatePolynomialFamily > polynomials(inputDimension);
+  // The strategy is to test first a Uniform distribution, then a Normal distribution, then a kernel smoothing for the marginals
+  KernelSmoothing ks;
+  Collection< DistributionFactory > factories(DistributionFactory::GetContinuousUniVariateFactories());
+  LOGINFO("In FunctionalChaosAlgorithm, identify marginal distributions");
+  const Description inputDescription(inputSample.getDescription());
+  for (UnsignedInteger i = 0; i < inputDimension; ++i)
+  {
+    TestResult bestResult;
+    const Distribution candidate(FittingTest::BestModelKolmogorov(inputSample.getMarginal(i), factories, bestResult));
+    if (bestResult.getPValue() > 1e-3) marginals[i] = candidate;
+    else marginals[i] = ks.build(inputSample.getMarginal(i));
+    marginals[i].setDescription(Description(1, inputDescription[i]));
+    LOGINFO(OSS() << "In FunctionalChaosAlgorithm constructor, selected distribution for marginal " << i << "=" << marginals[i]);
+    polynomials[i] = StandardDistributionPolynomialFactory(marginals[i]);
+  }
+  // For the dependence structure, we test first the independent copula, then the normal copula, but not a non-parametric copula as the penalty on the meta-model evaluation speed is most of the time prohibitive
+  setDistribution(ComposedDistribution(marginals, NormalCopulaFactory().build(inputSample)));
+  const HyperbolicAnisotropicEnumerateFunction enumerate(inputDimension, ResourceMap::GetAsNumericalScalar( "FunctionalChaosAlgorithm-QNorm" ));
+  OrthogonalProductPolynomialFactory basis(polynomials, enumerate);
+  const UnsignedInteger maximumTotalDegree(ResourceMap::GetAsUnsignedInteger( "FunctionalChaosAlgorithm-MaximumTotalDegree" ));
+  // For small sample size, use sparse regression
+  LOGINFO("In FunctionalChaosAlgorithm, select adaptive strategy");
+  if (inputSample.getSize() < ResourceMap::GetAsUnsignedInteger( "FunctionalChaosAlgorithm-SmallSampleSize" ))
+  {
+    projectionStrategy_ = LeastSquaresStrategy(inputSample, outputSample, LeastSquaresMetaModelSelectionFactory(LAR(), KFold()));
+    // projectionStrategy_ = LeastSquaresStrategy(inputSample, outputSample, LeastSquaresMetaModelSelectionFactory(LAR(), CorrectedLeaveOneOut()));
+    adaptiveStrategy_ = FixedStrategy(basis, enumerate.getStrataCumulatedCardinal(maximumTotalDegree));
+    LOGINFO(OSS() << "In FunctionalChaosAlgorithm, selected a sparse chaos expansion based on LAR and KFold for a total degree of " << maximumTotalDegree);
+  } // Small sample
+  else if (inputSample.getSize() < ResourceMap::GetAsUnsignedInteger( "FunctionalChaosAlgorithm-LargeSampleSize" ))
+  {
+    projectionStrategy_ = LeastSquaresStrategy(inputSample, outputSample);
+    const UnsignedInteger totalSize(enumerate.getStrataCumulatedCardinal(maximumTotalDegree));
+    const UnsignedInteger basisSize(std::min(totalSize, maximumTotalDegree * maximumTotalDegree * inputSample.getDimension()));
+    CleaningStrategy cleaning(basis, totalSize);
+    cleaning.setMaximumSize(basisSize);
+    adaptiveStrategy_ = cleaning;
+    LOGINFO(OSS() << "In FunctionalChaosAlgorithm, selected a constrained chaos expansion based on CleaningStrategy for a total degree of " << maximumTotalDegree << " and a maximum number of terms of " << basisSize);
+  } // Medium sample
+  else
+  {
+    projectionStrategy_ = LeastSquaresStrategy(inputSample, outputSample);
+    const UnsignedInteger totalSize(enumerate.getStrataCumulatedCardinal(maximumTotalDegree));
+    adaptiveStrategy_ = FixedStrategy(basis, totalSize);
+    LOGINFO(OSS() << "In FunctionalChaosAlgorithm, selected a chaos expansion based on FixedStrategy for a total degree of " << maximumTotalDegree);
+  } // Large sample
+}
+
 /* Constructor */
 FunctionalChaosAlgorithm::FunctionalChaosAlgorithm(const NumericalSample & inputSample,
     const NumericalPoint & weights,
     const NumericalSample & outputSample,
     const Distribution & distribution,
     const AdaptiveStrategy & adaptiveStrategy)
-  : MetaModelAlgorithm( distribution, NumericalMathFunction(NumericalMathFunctionImplementation(DatabaseNumericalMathEvaluationImplementation(inputSample, outputSample, false).clone())) ),
-    adaptiveStrategy_(adaptiveStrategy),
-    projectionStrategy_(LeastSquaresStrategy(inputSample, weights, outputSample)),
-    maximumResidual_(ResourceMap::GetAsNumericalScalar( "FunctionalChaosAlgorithm-DefaultMaximumResidual" ))
+  : MetaModelAlgorithm( distribution, NumericalMathFunction(NumericalMathFunctionImplementation(DatabaseNumericalMathEvaluationImplementation(inputSample, outputSample, false).clone())) )
+  , adaptiveStrategy_(adaptiveStrategy)
+  , projectionStrategy_(LeastSquaresStrategy(inputSample, weights, outputSample))
+  , maximumResidual_(ResourceMap::GetAsNumericalScalar( "FunctionalChaosAlgorithm-DefaultMaximumResidual" ))
 {
   // Check sample size
   if (inputSample.getSize() != outputSample.getSize()) throw InvalidArgumentException(HERE) << "Error: the input sample and the output sample must have the same size.";
@@ -201,7 +276,7 @@ ProjectionStrategy FunctionalChaosAlgorithm::getProjectionStrategy() const
 /* Computes the functional chaos */
 void FunctionalChaosAlgorithm::run()
 {
-  const UnsignedLong outputDimension(model_.getOutputDimension());
+  const UnsignedInteger outputDimension(model_.getOutputDimension());
   // First, compute all the parts that are independent of the marginal output
   // Create the isoprobabilistic transformation
   // If we call Z a random vector which probability distribution is measure and X a random vector which probability distribution is distribution_, and T the isoprobabilistic transformation, we have:
@@ -218,11 +293,11 @@ void FunctionalChaosAlgorithm::run()
   // Has the distribution an independent copula? Simply use marginal transformations
   if (distribution_.hasIndependentCopula())
   {
-    const UnsignedLong dimension(distribution_.getDimension());
+    const UnsignedInteger dimension(distribution_.getDimension());
     // We use empty collections to avoid the construction of default distributions
     DistributionCollection marginalX(0);
     DistributionCollection marginalZ(0);
-    for (UnsignedLong i = 0; i < dimension; ++i)
+    for (UnsignedInteger i = 0; i < dimension; ++i)
     {
       marginalX.add(distribution_.getMarginal(i));
       marginalZ.add(measure.getMarginal(i));
@@ -278,8 +353,8 @@ void FunctionalChaosAlgorithm::run()
   // missing, we have to take care of the different sparsity patterns
   NumericalPoint residuals(outputDimension);
   NumericalPoint relativeErrors(outputDimension);
-  std::map<UnsignedLong, NumericalPoint> coefficientsMap;
-  for (UnsignedLong outputIndex = 0; outputIndex < outputDimension; ++outputIndex)
+  std::map<UnsignedInteger, NumericalPoint> coefficientsMap;
+  for (UnsignedInteger outputIndex = 0; outputIndex < outputDimension; ++outputIndex)
   {
     Indices marginalIndices;
     NumericalPoint marginalAlpha_k;
@@ -289,14 +364,14 @@ void FunctionalChaosAlgorithm::run()
     runMarginal(outputIndex, marginalIndices, marginalAlpha_k, marginalResidual, marginalRelativeError);
     residuals[outputIndex] = marginalResidual;
     relativeErrors[outputIndex] = marginalRelativeError;
-    for (UnsignedLong j = 0; j < marginalIndices.getSize(); ++j)
+    for (UnsignedInteger j = 0; j < marginalIndices.getSize(); ++j)
     {
       // Deal only with non-zero coefficients
       const NumericalScalar marginalAlpha_kj(marginalAlpha_k[j]);
       if (marginalAlpha_kj != 0.0)
       {
         // Current index in the decomposition of the current marginal output
-        const UnsignedLong index(marginalIndices[j]);
+        const UnsignedInteger index(marginalIndices[j]);
         // If the current index is not in the map, create it
         if (coefficientsMap.find(index) == coefficientsMap.end()) coefficientsMap[index] = NumericalPoint(outputDimension, 0.0);
         // Add the current scalar coefficient to the corresponding component of the vectorial coefficient
@@ -305,7 +380,7 @@ void FunctionalChaosAlgorithm::run()
     } // Loop over the marginal indices
   } // Loop over the output dimension
   // At this point, the map contains all the associations (index, vector coefficient). It remains to present these data into the proper form and to build the associated partial basis
-  std::map<UnsignedLong, NumericalPoint>::iterator iter;
+  std::map<UnsignedInteger, NumericalPoint>::iterator iter;
   // Full set of indices
   Indices I_k(0);
   // Full set of vectorial coefficients
@@ -314,7 +389,7 @@ void FunctionalChaosAlgorithm::run()
   NumericalMathFunctionCollection Psi_k(0);
   for (iter = coefficientsMap.begin(); iter != coefficientsMap.end(); ++iter)
   {
-    const UnsignedLong i(iter->first);
+    const UnsignedInteger i(iter->first);
     const NumericalPoint currentcoefficient(iter->second);
     I_k.add(i);
     alpha_k.add(currentcoefficient);
@@ -330,7 +405,7 @@ void FunctionalChaosAlgorithm::run()
 }
 
 /* Marginal computation */
-void FunctionalChaosAlgorithm::runMarginal(const UnsignedLong marginalIndex,
+void FunctionalChaosAlgorithm::runMarginal(const UnsignedInteger marginalIndex,
     Indices & indices,
     NumericalPoint & coefficients,
     NumericalScalar & residual,
@@ -338,25 +413,10 @@ void FunctionalChaosAlgorithm::runMarginal(const UnsignedLong marginalIndex,
 {
   // Initialize the projection basis Phi_k_p_ and I_p_
   adaptiveStrategy_.computeInitialBasis();
-  // Compute the associated coefficients alpha_k_p_ and the residual residual_p_
-  projectionStrategy_.computeCoefficients(composedModel_, adaptiveStrategy_.getImplementation()->Psi_k_p_, adaptiveStrategy_.getImplementation()->I_p_, adaptiveStrategy_.getImplementation()->addedPsi_k_ranks_, adaptiveStrategy_.getImplementation()->conservedPsi_k_ranks_, adaptiveStrategy_.getImplementation()->removedPsi_k_ranks_, marginalIndex);
-  // The basis is adapted under the following conditions:
-  // + the current residual is small enough
-  // + the adaptive strategy has no more vector to propose
-  if (projectionStrategy_.getImplementation()->residual_p_ < maximumResidual_)
+
+  do
   {
-    indices = adaptiveStrategy_.getImplementation()->I_p_;
-    coefficients = projectionStrategy_.getImplementation()->alpha_k_p_;
-    residual = projectionStrategy_.getImplementation()->residual_p_;
-    relativeError = projectionStrategy_.getImplementation()->relativeError_p_;
-    return;
-  }
-  // Update the basis
-  adaptiveStrategy_.updateBasis(projectionStrategy_.getImplementation()->alpha_k_p_, projectionStrategy_.getImplementation()->residual_p_, projectionStrategy_.getImplementation()->relativeError_p_);
-  // Check if there is still something to do
-  while ((adaptiveStrategy_.getImplementation()->addedPsi_k_ranks_.getSize() > 0) || (adaptiveStrategy_.getImplementation()->removedPsi_k_ranks_.getSize() > 0))
-  {
-    projectionStrategy_.computeCoefficients(composedModel_, adaptiveStrategy_.getImplementation()->Psi_k_p_, adaptiveStrategy_.getImplementation()->I_p_, adaptiveStrategy_.getImplementation()->addedPsi_k_ranks_, adaptiveStrategy_.getImplementation()->conservedPsi_k_ranks_, adaptiveStrategy_.getImplementation()->removedPsi_k_ranks_, marginalIndex);
+    projectionStrategy_.computeCoefficients(composedModel_, *adaptiveStrategy_.getImplementation()->basis_.getImplementation(), adaptiveStrategy_.getImplementation()->I_p_, adaptiveStrategy_.getImplementation()->addedPsi_k_ranks_, adaptiveStrategy_.getImplementation()->conservedPsi_k_ranks_, adaptiveStrategy_.getImplementation()->removedPsi_k_ranks_, marginalIndex);
     // The basis is adapted under the following conditions:
     // + the current residual is small enough
     // + the adaptive strategy has no more vector to propose
@@ -370,6 +430,10 @@ void FunctionalChaosAlgorithm::runMarginal(const UnsignedLong marginalIndex,
     }
     adaptiveStrategy_.updateBasis(projectionStrategy_.getImplementation()->alpha_k_p_, projectionStrategy_.getImplementation()->residual_p_, projectionStrategy_.getImplementation()->relativeError_p_);
   }
+  // Check if there is still something to do
+  while ((adaptiveStrategy_.getImplementation()->addedPsi_k_ranks_.getSize() > 0) || (adaptiveStrategy_.getImplementation()->removedPsi_k_ranks_.getSize() > 0));
+
+
   indices = adaptiveStrategy_.getImplementation()->I_p_;
   coefficients = projectionStrategy_.getImplementation()->alpha_k_p_;
   residual = projectionStrategy_.getImplementation()->residual_p_;
