@@ -3,7 +3,7 @@
  *  @file  LeastSquaresStrategy.cxx
  *  @brief An implementation of projection strategy as a leastSquares
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -24,7 +24,6 @@
 #include "LeastSquaresStrategy.hxx"
 #include "OSS.hxx"
 #include "PersistentObjectFactory.hxx"
-#include "PenalizedLeastSquaresAlgorithmFactory.hxx"
 #include "Exception.hxx"
 #include "ApproximationAlgorithm.hxx"
 
@@ -39,8 +38,8 @@ static Factory<LeastSquaresStrategy> RegisteredFactory("LeastSquaresStrategy");
 
 /* Default constructor */
 LeastSquaresStrategy::LeastSquaresStrategy(const ApproximationAlgorithmImplementationFactory & factory)
-  : ProjectionStrategyImplementation(),
-    p_approximationAlgorithmImplementationFactory_( factory.clone() )
+  : ProjectionStrategyImplementation()
+  , p_approximationAlgorithmImplementationFactory_( factory.clone() )
 {
   // Nothing to do
 }
@@ -48,8 +47,8 @@ LeastSquaresStrategy::LeastSquaresStrategy(const ApproximationAlgorithmImplement
 /* Parameter constructor */
 LeastSquaresStrategy::LeastSquaresStrategy(const Distribution & measure,
     const ApproximationAlgorithmImplementationFactory & factory)
-  : ProjectionStrategyImplementation(measure),
-    p_approximationAlgorithmImplementationFactory_( factory.clone() )
+  : ProjectionStrategyImplementation(measure)
+  , p_approximationAlgorithmImplementationFactory_( factory.clone() )
 {
   // Nothing to do
 }
@@ -57,8 +56,8 @@ LeastSquaresStrategy::LeastSquaresStrategy(const Distribution & measure,
 /* Parameter constructor */
 LeastSquaresStrategy::LeastSquaresStrategy(const WeightedExperiment & weightedExperiment,
     const ApproximationAlgorithmImplementationFactory & factory)
-  : ProjectionStrategyImplementation(weightedExperiment),
-    p_approximationAlgorithmImplementationFactory_( factory.clone() )
+  : ProjectionStrategyImplementation(weightedExperiment)
+  , p_approximationAlgorithmImplementationFactory_( factory.clone() )
 {
   // Nothing to do
 }
@@ -67,8 +66,8 @@ LeastSquaresStrategy::LeastSquaresStrategy(const WeightedExperiment & weightedEx
 LeastSquaresStrategy::LeastSquaresStrategy(const Distribution & measure,
     const WeightedExperiment & weightedExperiment,
     const ApproximationAlgorithmImplementationFactory & factory)
-  : ProjectionStrategyImplementation(measure, weightedExperiment),
-    p_approximationAlgorithmImplementationFactory_( factory.clone() )
+  : ProjectionStrategyImplementation(measure, weightedExperiment)
+  , p_approximationAlgorithmImplementationFactory_( factory.clone() )
 {
   // Nothing to do
 }
@@ -78,8 +77,8 @@ LeastSquaresStrategy::LeastSquaresStrategy(const NumericalSample & inputSample,
     const NumericalPoint & weights,
     const NumericalSample & outputSample,
     const ApproximationAlgorithmImplementationFactory & factory)
-  : ProjectionStrategyImplementation(inputSample, weights, outputSample),
-    p_approximationAlgorithmImplementationFactory_( factory.clone() )
+  : ProjectionStrategyImplementation(inputSample, weights, outputSample)
+  , p_approximationAlgorithmImplementationFactory_( factory.clone() )
 {
   // Nothing to do
 }
@@ -88,8 +87,8 @@ LeastSquaresStrategy::LeastSquaresStrategy(const NumericalSample & inputSample,
 LeastSquaresStrategy::LeastSquaresStrategy(const NumericalSample & inputSample,
     const NumericalSample & outputSample,
     const ApproximationAlgorithmImplementationFactory & factory)
-  : ProjectionStrategyImplementation(inputSample, NumericalPoint(inputSample.getSize(), 1.0 / inputSample.getSize()), outputSample),
-    p_approximationAlgorithmImplementationFactory_( factory.clone() )
+  : ProjectionStrategyImplementation(inputSample, NumericalPoint(inputSample.getSize(), 1.0 / inputSample.getSize()), outputSample)
+  , p_approximationAlgorithmImplementationFactory_( factory.clone() )
 {
   // Nothing to do
 }
@@ -113,12 +112,12 @@ String LeastSquaresStrategy::__repr__() const
    the L2 integral by a finite sum: the same input sample is used for all the calls
    to this method */
 void LeastSquaresStrategy::computeCoefficients(const NumericalMathFunction & function,
-    const NumericalMathFunctionCollection & partialBasis,
+    const Basis & basis,
     const Indices & indices,
     const Indices & addedRanks,
     const Indices & conservedRanks,
     const Indices & removedRanks,
-    const UnsignedLong marginalIndex)
+    const UnsignedInteger marginalIndex)
 {
   // Check if the marginal index is not compatible with the function output dimension
   if (marginalIndex >= function.getOutputDimension()) throw InvalidArgumentException(HERE) << "Error: the marginal index is too large with respect to the function output dimension.";
@@ -127,12 +126,20 @@ void LeastSquaresStrategy::computeCoefficients(const NumericalMathFunction & fun
   // upon this sample
   if (inputSample_.getSize() == 0)
   {
-    inputSample_  = p_weightedExperiment_->generate(weights_);
+    inputSample_  = p_weightedExperiment_->generateWithWeights(weights_);
     outputSample_ = function(inputSample_);
   }
 
+  // check that the proxy is initialized
+  if (proxy_.getInputSample().getSize() == 0)
+  {
+    proxy_ = DesignProxy(inputSample_, basis);
+  }
+
   // Run the Approximation Algorithm
-  ApproximationAlgorithm approximationAlgorithm( p_approximationAlgorithmImplementationFactory_->build( inputSample_, outputSample_.getMarginal(marginalIndex), weights_, partialBasis ) );
+  ApproximationAlgorithm approximationAlgorithm(p_approximationAlgorithmImplementationFactory_->build(inputSample_, outputSample_.getMarginal(marginalIndex), weights_, basis, indices));
+//   approximationAlgorithm.run();
+  approximationAlgorithm.run(proxy_);
   alpha_k_p_ = approximationAlgorithm.getCoefficients();
   residual_p_ = approximationAlgorithm.getResidual();
   relativeError_p_ = approximationAlgorithm.getRelativeError();
