@@ -3,7 +3,7 @@
  *  @file  ProjectionStrategy.cxx
  *  @brief This is the interface class for projection strategies
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -91,17 +91,41 @@ NumericalSample ProjectionStrategy::getOutputSample() const
   return getImplementation()->getOutputSample();
 }
 
+/* Weights accessor */
+NumericalPoint ProjectionStrategy::getWeights() const
+{
+  return getImplementation()->getWeights();
+}
+
+/* Residual accessor */
+NumericalScalar ProjectionStrategy::getResidual() const
+{
+  return getImplementation()->getResidual();
+}
+
+/* Relative error accessor */
+NumericalScalar ProjectionStrategy::getRelativeError() const
+{
+  return getImplementation()->getRelativeError();
+}
+
+/* Relative error accessor */
+NumericalPoint ProjectionStrategy::getCoefficients() const
+{
+  return getImplementation()->getCoefficients();
+}
+
 
 /* Compute the components alpha_k_p_ by projecting the model on the partial L2 basis */
 void ProjectionStrategy::computeCoefficients(const NumericalMathFunction & function,
-    const NumericalMathFunctionCollection & partialBasis,
+    const Basis & basis,
     const Indices & indices,
     const Indices & addedRanks,
     const Indices & conservedRanks,
     const Indices & removedRanks,
-    const UnsignedLong marginalIndex)
+    const UnsignedInteger marginalIndex)
 {
-  getImplementation()->computeCoefficients(function, partialBasis, indices, addedRanks, conservedRanks, removedRanks, marginalIndex);
+  getImplementation()->computeCoefficients(function, basis, indices, addedRanks, conservedRanks, removedRanks, marginalIndex);
 }
 
 
