@@ -3,7 +3,7 @@
  *  @file  MetaModelAlgorithm.cxx
  *  @brief Implementation for metamodel algorithms
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -27,26 +27,25 @@
 
 BEGIN_NAMESPACE_OPENTURNS
 
-
-
 CLASSNAMEINIT(MetaModelAlgorithm);
 
 static Factory<MetaModelAlgorithm> RegisteredFactory("MetaModelAlgorithm");
 
 /* Default constructor */
-MetaModelAlgorithm::MetaModelAlgorithm(const String & name)
-  : PersistentObject( name )
+MetaModelAlgorithm::MetaModelAlgorithm()
+  : PersistentObject()
 {
+  // Nothing to do
 }
 
 /* Constructor with parameters */
 MetaModelAlgorithm::MetaModelAlgorithm(const Distribution & distribution,
-                                       const NumericalMathFunction & model,
-                                       const String & name)
-  : PersistentObject( name ),
-    distribution_(distribution),
-    model_(model)
+                                       const NumericalMathFunction & model)
+  : PersistentObject()
+  , distribution_(distribution)
+  , model_(model)
 {
+  // Nothing to do
 }
 
 /* Virtual constructor */
@@ -80,21 +79,19 @@ Distribution MetaModelAlgorithm::getDistribution() const
 /* Response surface computation */
 void MetaModelAlgorithm::run()
 {
-  throw NotYetImplementedException(HERE) << " in MetaModelAlgorithm::run()";
+  throw NotYetImplementedException(HERE) << "In MetaModelAlgorithm::run()";
 }
 
 
 NumericalSample MetaModelAlgorithm::getInputSample() const
 {
-  throw NotYetImplementedException(HERE);
-  return NumericalSample();
+  throw NotYetImplementedException(HERE) << "In MetaModelAlgorithm::getInputSample() const";
 }
 
 
 NumericalSample MetaModelAlgorithm::getOutputSample() const
 {
-  throw NotYetImplementedException(HERE);
-  return NumericalSample();
+  throw NotYetImplementedException(HERE) << "In MetaModelAlgorithm::getOutputSample() const";
 }
 
 
