@@ -3,7 +3,7 @@
  *  @file  CharlierFactory.cxx
  *  @brief Charlier polynomial factory
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -63,7 +63,7 @@ CharlierFactory * CharlierFactory::clone() const
 
 /* Calculate the coefficients of recurrence a0n, a1n, a2n such that
    Pn+1(x) = (a0n * x + a1n) * Pn(x) + a2n * Pn-1(x) */
-CharlierFactory::Coefficients CharlierFactory::getRecurrenceCoefficients(const UnsignedLong n) const
+CharlierFactory::Coefficients CharlierFactory::getRecurrenceCoefficients(const UnsignedInteger n) const
 {
   Coefficients recurrenceCoefficients(3, 0.0);
   if (n == 0)
