@@ -3,7 +3,7 @@
  *  @file  MeixnerFactory.cxx
  *  @brief Meixner polynomial factory
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -46,7 +46,7 @@ MeixnerFactory::MeixnerFactory()
 }
 
 
-/* Parameter constructor: lambda is the order of the generalized Meixner polynomial, associated with the Poisson(lambda) distribution */
+/* Parameter constructor: lambda is the order of the generalized Meixner polynomial, associated with the NegativeBinomial(r, p) distribution */
 MeixnerFactory::MeixnerFactory(const NumericalScalar r,
                                const NumericalScalar p)
   : OrthogonalUniVariatePolynomialFactory( NegativeBinomial(r, p) ),
@@ -67,7 +67,7 @@ MeixnerFactory * MeixnerFactory::clone() const
 
 /* Calculate the coefficients of recurrence a0n, a1n, a2n such that
    Pn+1(x) = (a0n * x + a1n) * Pn(x) + a2n * Pn-1(x) */
-MeixnerFactory::Coefficients MeixnerFactory::getRecurrenceCoefficients(const UnsignedLong n) const
+MeixnerFactory::Coefficients MeixnerFactory::getRecurrenceCoefficients(const UnsignedInteger n) const
 {
   Coefficients recurrenceCoefficients(3, 0.0);
   if (n == 0)
