@@ -3,7 +3,7 @@
  *  @file  OrthonormalizationAlgorithm.cxx
  *  @brief
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -64,7 +64,7 @@ OrthonormalizationAlgorithm::OrthonormalizationAlgorithm()
 
 /* Calculate the coefficients of recurrence a0, a1, a2 such that
    Pn+1(x) = (a0 * x + a1) * Pn(x) + a2 * Pn-1(x) */
-OrthonormalizationAlgorithm::Coefficients OrthonormalizationAlgorithm::getRecurrenceCoefficients(const UnsignedLong n) const
+OrthonormalizationAlgorithm::Coefficients OrthonormalizationAlgorithm::getRecurrenceCoefficients(const UnsignedInteger n) const
 {
   return getImplementation()->getRecurrenceCoefficients(n);
 }
