@@ -3,7 +3,7 @@
  *  @file  StandardDistributionPolynomialFactory.cxx
  *  @brief OrthogonalUniVariatePolynomialStandardDistribution polynomial factory
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -43,10 +43,10 @@ static Factory<StandardDistributionPolynomialFactory> RegisteredFactory("Standar
 
 /* Default constructor */
 StandardDistributionPolynomialFactory::StandardDistributionPolynomialFactory()
-  : OrthogonalUniVariatePolynomialFactory(Uniform()),
-    orthonormalizationAlgorithm_(GramSchmidtAlgorithm(Uniform())),
-    specificFamily_(),
-    hasSpecificFamily_(false)
+  : OrthogonalUniVariatePolynomialFactory(Uniform())
+  , orthonormalizationAlgorithm_(GramSchmidtAlgorithm(Uniform()))
+  , specificFamily_()
+  , hasSpecificFamily_(false)
 {
   // Initialize the coefficient cache
   initializeCache();
@@ -55,10 +55,10 @@ StandardDistributionPolynomialFactory::StandardDistributionPolynomialFactory()
 
 /* Parameter constructor */
 StandardDistributionPolynomialFactory::StandardDistributionPolynomialFactory(const Distribution & measure)
-  : OrthogonalUniVariatePolynomialFactory(measure.getStandardRepresentative()),
-    orthonormalizationAlgorithm_(GramSchmidtAlgorithm(measure.getStandardRepresentative())),
-    specificFamily_(),
-    hasSpecificFamily_(false)
+  : OrthogonalUniVariatePolynomialFactory(measure.getStandardRepresentative())
+  , orthonormalizationAlgorithm_(GramSchmidtAlgorithm(measure.getStandardRepresentative()))
+  , specificFamily_()
+  , hasSpecificFamily_(false)
 {
   checkSpecificFamily();
   initializeCache();
@@ -67,10 +67,10 @@ StandardDistributionPolynomialFactory::StandardDistributionPolynomialFactory(con
 
 /* Parameter constructor */
 StandardDistributionPolynomialFactory::StandardDistributionPolynomialFactory(const OrthonormalizationAlgorithm & orthonormalizationAlgorithm)
-  : OrthogonalUniVariatePolynomialFactory(orthonormalizationAlgorithm.getMeasure().getStandardRepresentative()),
-    orthonormalizationAlgorithm_(orthonormalizationAlgorithm),
-    specificFamily_(),
-    hasSpecificFamily_(false)
+  : OrthogonalUniVariatePolynomialFactory(orthonormalizationAlgorithm.getMeasure().getStandardRepresentative())
+  , orthonormalizationAlgorithm_(orthonormalizationAlgorithm)
+  , specificFamily_()
+  , hasSpecificFamily_(false)
 {
   checkSpecificFamily();
   initializeCache();
@@ -86,7 +86,7 @@ StandardDistributionPolynomialFactory * StandardDistributionPolynomialFactory::c
 
 /* Calculate the coefficients of recurrence a0n, a1n, a2n such that
    Pn+1(x) = (a0n * x + a1n) * Pn(x) + a2n * Pn-1(x) */
-StandardDistributionPolynomialFactory::Coefficients StandardDistributionPolynomialFactory::getRecurrenceCoefficients(const UnsignedLong n) const
+StandardDistributionPolynomialFactory::Coefficients StandardDistributionPolynomialFactory::getRecurrenceCoefficients(const UnsignedInteger n) const
 {
   if (hasSpecificFamily_) return specificFamily_.getRecurrenceCoefficients(n);
   return orthonormalizationAlgorithm_.getRecurrenceCoefficients(n);
@@ -140,7 +140,7 @@ void StandardDistributionPolynomialFactory::checkSpecificFamily()
   if (measureType == "Binomial")
   {
     const NumericalPoint parameters(measure_.getParametersCollection()[0]);
-    specificFamily_ = KrawtchoukFactory(static_cast<UnsignedLong>(parameters[0]), parameters[1]);
+    specificFamily_ = KrawtchoukFactory(static_cast<UnsignedInteger>(parameters[0]), parameters[1]);
     hasSpecificFamily_ = true;
     return;
   }
