@@ -3,7 +3,7 @@
  *  @file  PostAnalyticalControlledImportanceSampling.cxx
  *  @brief PostAnalyticalControlledImportanceSampling is an implementation of the controlled importance sampling Monte Carlo simulation method in standard space
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -52,7 +52,7 @@ PostAnalyticalControlledImportanceSampling * PostAnalyticalControlledImportanceS
 /* Compute the block sample */
 NumericalSample PostAnalyticalControlledImportanceSampling::computeBlockSample()
 {
-  const UnsignedLong blockSize(getBlockSize());
+  const UnsignedInteger blockSize(getBlockSize());
   const NumericalPoint standardSpaceDesignPoint(analyticalResult_.getStandardSpaceDesignPoint());
   const Bool originFailure(analyticalResult_.getIsStandardPointOriginInFailureSpace());
   // Get the threshold and the reliability index
@@ -64,11 +64,11 @@ NumericalSample PostAnalyticalControlledImportanceSampling::computeBlockSample()
   // First, compute a sample of the importance distribution. It is simply
   // the standard distribution translated to the design point
   NumericalSample inputSample(standardDistribution_.getSample(blockSize));
-  inputSample.translate(standardSpaceDesignPoint);
+  inputSample += standardSpaceDesignPoint;
   // Then, evaluate the function on this sample
   NumericalSample blockSample(getEvent().getImplementation()->getFunction()(inputSample));
   // Then, modify in place this sample to take into account the change in the input distribution
-  for (UnsignedLong i = 0; i < blockSize; ++i)
+  for (UnsignedInteger i = 0; i < blockSize; ++i)
   {
     const NumericalPoint realization(inputSample[i]);
     Bool failureControl(dot(realization, standardSpaceDesignPoint) > betaSquare);
