@@ -3,7 +3,7 @@
  *  @file  RandomDirection.cxx
  *  @brief
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -40,7 +40,7 @@ RandomDirection::RandomDirection():
 }
 
 /* Constructor with parameters */
-RandomDirection::RandomDirection(const UnsignedLong dimension):
+RandomDirection::RandomDirection(const UnsignedInteger dimension):
   SamplingStrategyImplementation(dimension)
 {
   // Nothing to do
