@@ -4,7 +4,7 @@
  *  @brief Simulation is a generic view of simulation methods for computing
  * probabilities and related quantities by sampling and estimation
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -39,16 +39,35 @@ CLASSNAMEINIT(Simulation);
 
 static Factory<Simulation> RegisteredFactory("Simulation");
 
+/** For save/load mechanism */
+Simulation::Simulation(const Bool verbose, const HistoryStrategy & convergenceStrategy)
+  : PersistentObject()
+  , convergenceStrategy_(convergenceStrategy)
+  , blockSize_(ResourceMap::GetAsUnsignedInteger( "Simulation-DefaultBlockSize" ))
+  , event_()
+  , result_()
+  , progressCallback_(std::make_pair<ProgressCallback, void *>(0, 0))
+  , stopCallback_(std::make_pair<StopCallback, void *>(0, 0))
+  , maximumOuterSampling_(ResourceMap::GetAsUnsignedInteger( "Simulation-DefaultMaximumOuterSampling" ))
+  , maximumCoefficientOfVariation_(ResourceMap::GetAsNumericalScalar( "Simulation-DefaultMaximumCoefficientOfVariation" ))
+  , maximumStandardDeviation_(ResourceMap::GetAsNumericalScalar( "Simulation-DefaultMaximumStandardDeviation" ))
+  , verbose_(verbose)
+{
+  // Nothing to do
+}
+
 /* Constructor with parameters */
 Simulation::Simulation(const Event & event,
                        const Bool verbose,
                        const HistoryStrategy & convergenceStrategy)
   : PersistentObject()
   , convergenceStrategy_(convergenceStrategy)
-  , blockSize_(ResourceMap::GetAsUnsignedLong( "Simulation-DefaultBlockSize" ))
+  , blockSize_(ResourceMap::GetAsUnsignedInteger( "Simulation-DefaultBlockSize" ))
   , event_(event)
   , result_()
-  , maximumOuterSampling_(ResourceMap::GetAsUnsignedLong( "Simulation-DefaultMaximumOuterSampling" ))
+  , progressCallback_(std::make_pair<ProgressCallback, void *>(0, 0))
+  , stopCallback_(std::make_pair<StopCallback, void *>(0, 0))
+  , maximumOuterSampling_(ResourceMap::GetAsUnsignedInteger( "Simulation-DefaultMaximumOuterSampling" ))
   , maximumCoefficientOfVariation_(ResourceMap::GetAsNumericalScalar( "Simulation-DefaultMaximumCoefficientOfVariation" ))
   , maximumStandardDeviation_(ResourceMap::GetAsNumericalScalar( "Simulation-DefaultMaximumStandardDeviation" ))
   , verbose_(verbose)
@@ -81,13 +100,13 @@ SimulationResult Simulation::getResult() const
 }
 
 /* Maximum sample size accessor */
-void Simulation::setMaximumOuterSampling(const UnsignedLong maximumOuterSampling)
+void Simulation::setMaximumOuterSampling(const UnsignedInteger maximumOuterSampling)
 {
   maximumOuterSampling_ = maximumOuterSampling;
 }
 
 /* Maximum sample size accessor */
-UnsignedLong Simulation::getMaximumOuterSampling() const
+UnsignedInteger Simulation::getMaximumOuterSampling() const
 {
   return maximumOuterSampling_;
 }
@@ -118,7 +137,7 @@ NumericalScalar Simulation::getMaximumStandardDeviation() const
 }
 
 /* Block size accessor */
-void Simulation::setBlockSize(const UnsignedLong blockSize)
+void Simulation::setBlockSize(const UnsignedInteger blockSize)
 {
   // Check if the given block size is >= 1
   if (blockSize < 1) throw InvalidArgumentException(HERE) << "The block size must be >= 1";
@@ -126,7 +145,7 @@ void Simulation::setBlockSize(const UnsignedLong blockSize)
 }
 
 /* Block size accessor */
-UnsignedLong Simulation::getBlockSize() const
+UnsignedInteger Simulation::getBlockSize() const
 {
   return blockSize_;
 }
@@ -168,12 +187,12 @@ void Simulation::run()
    */
   // First, reset the convergence history
   convergenceStrategy_.clear();
-  UnsignedLong outerSampling(0);
+  UnsignedInteger outerSampling(0);
   NumericalScalar coefficientOfVariation(-1.0);
   NumericalScalar standardDeviation(-1.0);
   NumericalScalar probabilityEstimate(0.0);
   NumericalScalar varianceEstimate(0.0);
-  const UnsignedLong blockSize(getBlockSize());
+  const UnsignedInteger blockSize(getBlockSize());
   // Initialize the result. We use the accessors in order to preserve the exact nature of the result (SimulationResult or QuasiMonteCarloResult)
   // First, the invariant part
   // For the event, we have to access to the implementation as the interface does not provide the setEvent() method ON PURPOSE!
@@ -183,8 +202,10 @@ void Simulation::run()
   result_.setProbabilityEstimate(probabilityEstimate);
   result_.setVarianceEstimate(varianceEstimate);
   result_.setOuterSampling(outerSampling);
+
+  Bool stop = false;
   // We loop if there remains some outer sampling and the coefficient of variation is greater than the limit or has not been computed yet.
-  while ((outerSampling < getMaximumOuterSampling()) && ((coefficientOfVariation == -1.0) || (coefficientOfVariation > getMaximumCoefficientOfVariation())) && ((standardDeviation == -1.0) || (standardDeviation > getMaximumStandardDeviation())))
+  while ((outerSampling < getMaximumOuterSampling()) && ((coefficientOfVariation == -1.0) || (coefficientOfVariation > getMaximumCoefficientOfVariation())) && ((standardDeviation == -1.0) || (standardDeviation > getMaximumStandardDeviation())) && !stop)
   {
     // Perform a block of simulation
     const NumericalSample blockSample(computeBlockSample());
@@ -229,13 +250,23 @@ void Simulation::run()
     else
       convergencePoint[1] = -1.0;
     convergenceStrategy_.store(convergencePoint);
+
+    // callbacks
+    if (progressCallback_.first)
+    {
+      progressCallback_.first((100. * outerSampling) / getMaximumOuterSampling(), progressCallback_.second);
+    }
+    if (stopCallback_.first)
+    {
+      stop = stopCallback_.first(stopCallback_.second);
+    }
   }
 }
 
 /* Compute the block sample and the points that realized the event */
 NumericalSample Simulation::computeBlockSample()
 {
-  throw NotYetImplementedException(HERE);
+  throw NotYetImplementedException(HERE) << "In Simulation::computeBlockSample()";
 }
 
 /* Convergence strategy accessor */
@@ -253,11 +284,11 @@ HistoryStrategy Simulation::getConvergenceStrategy() const
 Graph Simulation::drawProbabilityConvergence(const NumericalScalar level) const
 {
   const NumericalSample convergenceSample(convergenceStrategy_.getSample());
-  const UnsignedLong size(convergenceSample.getSize());
+  const UnsignedInteger size(convergenceSample.getSize());
   NumericalSample dataEstimate(size, 2);
   NumericalSample dataLowerBound(0, 2);
   NumericalSample dataUpperBound(0, 2);
-  for (UnsignedLong i = 0; i < size; i++)
+  for (UnsignedInteger i = 0; i < size; i++)
   {
     const NumericalScalar probabilityEstimate(convergenceSample[i][0]);
     const NumericalScalar varianceEstimate(convergenceSample[i][1]);
@@ -318,4 +349,16 @@ void Simulation::load(Advocate & adv)
 }
 
 
+void Simulation::setProgressCallback(ProgressCallback callBack, void * data)
+{
+  progressCallback_ = std::pair<ProgressCallback, void *>(callBack, data);
+}
+
+
+void Simulation::setStopCallback(StopCallback callBack, void * data)
+{
+  stopCallback_ = std::pair<StopCallback, void *>(callBack, data);
+}
+
+
 END_NAMESPACE_OPENTURNS
