@@ -4,7 +4,7 @@
  *  @file  NatafEllipticalCopulaEvaluation.cxx
  *  @brief Class for the Nataf transformation evaluation for elliptical
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -39,24 +39,24 @@ CLASSNAMEINIT(NatafEllipticalCopulaEvaluation);
 static Factory<NatafEllipticalCopulaEvaluation> RegisteredFactory("NatafEllipticalCopulaEvaluation");
 
 /* Default constructor */
-NatafEllipticalCopulaEvaluation::NatafEllipticalCopulaEvaluation():
-  NumericalMathEvaluationImplementation(),
-  standardDistribution_(),
-  inverseCholesky_()
+NatafEllipticalCopulaEvaluation::NatafEllipticalCopulaEvaluation()
+  : NumericalMathEvaluationImplementation()
+  , standardDistribution_()
+  , inverseCholesky_()
 {
   // Nothing to do
 }
 
 /* Parameter constructor */
 NatafEllipticalCopulaEvaluation::NatafEllipticalCopulaEvaluation(const Distribution & standardDistribution,
-    const SquareMatrix & inverseCholesky):
-  NumericalMathEvaluationImplementation(),
-  standardDistribution_(standardDistribution),
-  inverseCholesky_(inverseCholesky)
+    const TriangularMatrix & inverseCholesky)
+  : NumericalMathEvaluationImplementation()
+  , standardDistribution_(standardDistribution)
+  , inverseCholesky_(inverseCholesky)
 {
   Description description;
-  for (UnsignedLong i = 0; i < inverseCholesky_.getNbColumns(); ++i) description.add(OSS() << "x" << i);
-  for (UnsignedLong i = 0; i < inverseCholesky_.getNbRows(); ++i) description.add(OSS() << "y" << i);
+  for (UnsignedInteger i = 0; i < inverseCholesky_.getNbColumns(); ++i) description.add(OSS() << "x" << i);
+  for (UnsignedInteger i = 0; i < inverseCholesky_.getNbRows(); ++i) description.add(OSS() << "y" << i);
   setDescription(description);
 }
 
@@ -86,11 +86,11 @@ String NatafEllipticalCopulaEvaluation::__repr__() const
  */
 NumericalPoint NatafEllipticalCopulaEvaluation::operator () (const NumericalPoint & inP) const
 {
-  const UnsignedLong dimension(getOutputDimension());
+  const UnsignedInteger dimension(getOutputDimension());
   NumericalPoint result(dimension);
   const Distribution standardMarginal(standardDistribution_.getMarginal(0));
   // First, filter the commmon marginal distribution
-  for (UnsignedLong i = 0; i < dimension; ++i) result[i] = standardMarginal.computeQuantile(inP[i])[0];
+  for (UnsignedInteger i = 0; i < dimension; ++i) result[i] = standardMarginal.computeQuantile(inP[i])[0];
   // Second, decorrelate the components
   result = inverseCholesky_ * result;
   ++callsNumber_;
@@ -110,13 +110,13 @@ Matrix NatafEllipticalCopulaEvaluation::parametersGradient(const NumericalPoint
 }
 
 /* Accessor for input point dimension */
-UnsignedLong NatafEllipticalCopulaEvaluation::getInputDimension() const
+UnsignedInteger NatafEllipticalCopulaEvaluation::getInputDimension() const
 {
   return inverseCholesky_.getNbColumns();
 }
 
 /* Accessor for output point dimension */
-UnsignedLong NatafEllipticalCopulaEvaluation::getOutputDimension() const
+UnsignedInteger NatafEllipticalCopulaEvaluation::getOutputDimension() const
 {
   return inverseCholesky_.getNbRows();
 }
