@@ -3,7 +3,7 @@
  *  @file  NatafEllipticalCopulaHessian.cxx
  *  @brief Class for the Nataf transformation evaluation for elliptical
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -37,20 +37,20 @@ CLASSNAMEINIT(NatafEllipticalCopulaHessian);
 static Factory<NatafEllipticalCopulaHessian> RegisteredFactory("NatafEllipticalCopulaHessian");
 
 /* Default constructor */
-NatafEllipticalCopulaHessian::NatafEllipticalCopulaHessian():
-  NumericalMathHessianImplementation(),
-  standardDistribution_(),
-  inverseCholesky_()
+NatafEllipticalCopulaHessian::NatafEllipticalCopulaHessian()
+  : NumericalMathHessianImplementation()
+  , standardDistribution_()
+  , inverseCholesky_()
 {
   // Nothing to do
 }
 
 /* Parameter constructor */
 NatafEllipticalCopulaHessian::NatafEllipticalCopulaHessian(const Distribution & standardDistribution,
-    const SquareMatrix & inverseCholesky):
-  NumericalMathHessianImplementation(),
-  standardDistribution_(standardDistribution),
-  inverseCholesky_(inverseCholesky)
+    const TriangularMatrix & inverseCholesky)
+  : NumericalMathHessianImplementation()
+  , standardDistribution_(standardDistribution)
+  , inverseCholesky_(inverseCholesky)
 {
   // Nothing to do
 }
@@ -92,32 +92,28 @@ String NatafEllipticalCopulaHessian::__repr__() const
  */
 SymmetricTensor NatafEllipticalCopulaHessian::hessian(const NumericalPoint & inP) const
 {
-  UnsignedLong dimension(getInputDimension());
-  NumericalPoint quantileSecondDerivative(dimension);
+  UnsignedInteger dimension(getInputDimension());
   const Distribution standardMarginal(standardDistribution_.getMarginal(0));
   SymmetricTensor result(dimension, dimension);
-  for (UnsignedLong i = 0; i < dimension; ++i)
+  for (UnsignedInteger i = 0; i < dimension; ++i)
   {
     NumericalPoint q(standardMarginal.computeQuantile(inP[i]));
     NumericalScalar factor(1.0 / standardMarginal.computePDF(q));
     NumericalScalar quantileSecondDerivative(-standardMarginal.computeDDF(q)[0] * factor * factor * factor);
     // inverseCholesky_ is lower triangular
-    for (UnsignedLong j = i; j < dimension; ++j)
-    {
-      result(i, i, j) = inverseCholesky_(j, i) * quantileSecondDerivative;
-    }
-  }
+    for (UnsignedInteger j = i; j < dimension; ++j) result(i, i, j) = inverseCholesky_(j, i) * quantileSecondDerivative;
+  } // i
   return result;
 }
 
 /* Accessor for input point dimension */
-UnsignedLong NatafEllipticalCopulaHessian::getInputDimension() const
+UnsignedInteger NatafEllipticalCopulaHessian::getInputDimension() const
 {
   return inverseCholesky_.getNbColumns();
 }
 
 /* Accessor for output point dimension */
-UnsignedLong NatafEllipticalCopulaHessian::getOutputDimension() const
+UnsignedInteger NatafEllipticalCopulaHessian::getOutputDimension() const
 {
   return inverseCholesky_.getNbRows();
 }
