@@ -3,7 +3,7 @@
  *  @file  InverseNatafEllipticalDistributionHessian.cxx
  *  @brief Class for the InverseNataf transformation hessian for elliptical
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -46,7 +46,7 @@ InverseNatafEllipticalDistributionHessian::InverseNatafEllipticalDistributionHes
 }
 
 /* Parameter constructor */
-InverseNatafEllipticalDistributionHessian::InverseNatafEllipticalDistributionHessian(const UnsignedLong dimension):
+InverseNatafEllipticalDistributionHessian::InverseNatafEllipticalDistributionHessian(const UnsignedInteger dimension):
   ConstantNumericalMathHessianImplementation(SymmetricTensor(dimension, dimension))
 {
   // Nothing to do
