@@ -3,7 +3,7 @@
  *  @file  BoxCoxFactory.cxx
  *  @brief
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -47,9 +47,9 @@ static Factory<BoxCoxFactory> RegisteredFactory("BoxCoxFactory");
 
 /* Constructor with parameters */
 BoxCoxFactory::BoxCoxFactory()
-  : PersistentObject(),
-    sample_(),
-    sumLog_(0.0)
+  : PersistentObject()
+  , sample_()
+  , sumLog_(0.0)
 {
   // Nothing to do
 }
@@ -65,13 +65,13 @@ BoxCoxFactory * BoxCoxFactory::clone() const
  */
 NumericalScalar BoxCoxFactory::computeLogLikelihood(const NumericalScalar & lambda) const
 {
-  const UnsignedLong size(sample_.getSize());
+  const UnsignedInteger size(sample_.getSize());
   BoxCoxEvaluationImplementation myBoxFunction(NumericalPoint(1, lambda));
   // compute the mean of the sample using the Box-Cox function
   const NumericalSample outSample(myBoxFunction(sample_));
   const NumericalScalar ratio(1.0 - 1.0 / size);
-  const NumericalScalar sigma(outSample.computeStandardDeviationPerComponent()[0]);
-  NumericalScalar result(-0.5 * size * log(sigma * sigma * ratio));
+  const NumericalScalar sigma2(outSample.computeVariance()[0]);
+  NumericalScalar result(-0.5 * size * log(sigma2 * ratio));
 
   //result is translated
   result += (lambda - 1.0) * sumLog_;
@@ -90,7 +90,7 @@ int BoxCoxFactory::ComputeObjectiveAndConstraint(int n,
   const NumericalScalar lambda(x[0]);
 
   const BoxCoxFactory * factory = static_cast<BoxCoxFactory *>(state);
-  *f = - factory->computeLogLikelihood( lambda );
+  *f = -factory->computeLogLikelihood( lambda );
 
   return 0;
 }
@@ -131,11 +131,11 @@ BoxCoxTransform BoxCoxFactory::build(const NumericalSample & sample,
                                      Graph & graph) const
 {
   // Check the input size
-  const UnsignedLong size(sample.getSize());
+  const UnsignedInteger size(sample.getSize());
   if (size == 0) throw InvalidArgumentException(HERE) << "Error: cannot build a Box-Cox factory from an empty time series";
 
   // Check the input dimensions
-  const UnsignedLong dimension(sample.getDimension());
+  const UnsignedInteger dimension(sample.getDimension());
   if (shift.getDimension() != dimension) throw InvalidArgumentException(HERE) << "Error: the shift has a dimension=" << shift.getDimension() << " different from the sample dimension=" << dimension;
 
   // Shape parameters of the transformation
@@ -155,12 +155,12 @@ BoxCoxTransform BoxCoxFactory::build(const NumericalSample & sample,
   cobyla_message message( COBYLA_MSG_NONE );
   // Keep the shifted marginal samples
   Collection< NumericalSample > marginalSamples(dimension);
-  for (UnsignedLong d = 0; d < dimension; ++d)
+  for (UnsignedInteger d = 0; d < dimension; ++d)
   {
     // Extract the marginal sample
     sample_ = sample.getMarginal(d);
     // Apply the shift
-    sample_.translate(NumericalPoint(1, shift[d]));
+    sample_ += NumericalPoint(1, shift[d]);
     marginalSamples[d] = sample_;
     // number of optimized variables
     int n(1);
@@ -169,7 +169,7 @@ BoxCoxTransform BoxCoxFactory::build(const NumericalSample & sample,
     // starting point
     NumericalPoint x(n, 1.0);
     // Compute the sum of the log-data
-    for (UnsignedLong k = 0; k < size; ++k) sumLog[d] += log(sample_[k][0]);
+    for (UnsignedInteger k = 0; k < size; ++k) sumLog[d] += log(sample_[k][0]);
     // Use
     sumLog_ = sumLog[d];
     // call cobyla algo
@@ -184,15 +184,15 @@ BoxCoxTransform BoxCoxFactory::build(const NumericalSample & sample,
   const NumericalScalar lambdaMin(*std::max_element(lambda.begin(), lambda.end()));
   const NumericalScalar xMin(std::min(0.0, 0.002 * round(1000.0 * lambdaMin)));
   const NumericalScalar xMax(std::max(0.0, 0.002 * round(1000.0 * lambdaMax)));
-  const UnsignedLong npts = ResourceMap::GetAsUnsignedLong("BoxCoxFactory-DefaultPointNumber");
+  const UnsignedInteger npts(ResourceMap::GetAsUnsignedInteger("BoxCoxFactory-DefaultPointNumber"));
   NumericalSample lambdaValues(npts, 1);
-  for (UnsignedLong i = 0; i < npts; ++i) lambdaValues[i][0] = xMin + i * (xMax - xMin) / (npts - 1.0);
-  for (UnsignedLong d = 0; d < dimension; ++d)
+  for (UnsignedInteger i = 0; i < npts; ++i) lambdaValues[i][0] = xMin + i * (xMax - xMin) / (npts - 1.0);
+  for (UnsignedInteger d = 0; d < dimension; ++d)
   {
     NumericalSample logLikelihoodValues(npts, 1);
     sumLog_ = sumLog[d];
     sample_ = marginalSamples[d];
-    for (UnsignedLong i = 0; i < npts; ++i) logLikelihoodValues[i][0] = computeLogLikelihood(lambdaValues[i][0]);
+    for (UnsignedInteger i = 0; i < npts; ++i) logLikelihoodValues[i][0] = computeLogLikelihood(lambdaValues[i][0]);
     Curve curve(lambdaValues, logLikelihoodValues);
     curve.setColor(Curve::ConvertFromHSV((360.0 * d) / dimension, 1.0, 1.0));
     graph.add(curve);
@@ -209,7 +209,7 @@ BoxCoxTransform BoxCoxFactory::build(const NumericalSample & sample,
     graph.setBoundingBox(bb);
   }
   // return result ==> Box Cox transform
-  return BoxCoxTransform(lambda);
+  return BoxCoxTransform(lambda, shift);
 }
 
 /* String converter */
