@@ -3,7 +3,7 @@
  *  @file  BootstrapExperiment.cxx
  *  @brief Abstract top-level view of an bootstrapExperiment plane
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -32,16 +32,15 @@ CLASSNAMEINIT(BootstrapExperiment);
 
 
 /* Default constructor */
-BootstrapExperiment::BootstrapExperiment(const String & name):
-  WeightedExperiment(name)
+BootstrapExperiment::BootstrapExperiment():
+  WeightedExperiment()
 {
   // Nothing to do
 }
 
 /* Constructor with parameters */
-BootstrapExperiment::BootstrapExperiment(const NumericalSample & sample,
-    const String & name):
-  WeightedExperiment(UserDefined(sample), sample.getSize(), name)
+BootstrapExperiment::BootstrapExperiment(const NumericalSample & sample):
+  WeightedExperiment(UserDefined(sample), sample.getSize())
 {
   // Nothing to do
 }
