@@ -3,7 +3,7 @@
  *  @file  FixedExperiment.cxx
  *  @brief Abstract top-level view of an fixedExperiment plane
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -32,17 +32,16 @@ CLASSNAMEINIT(FixedExperiment);
 
 
 /* Default constructor */
-FixedExperiment::FixedExperiment(const String & name):
-  WeightedExperiment(name),
+FixedExperiment::FixedExperiment():
+  WeightedExperiment(),
   sample_(0, 0)
 {
   // Nothing to do
 }
 
 /* Constructor with parameters */
-FixedExperiment::FixedExperiment(const NumericalSample & sample,
-                                 const String & name):
-  WeightedExperiment(UserDefined(sample), sample.getSize(), name),
+FixedExperiment::FixedExperiment(const NumericalSample & sample):
+  WeightedExperiment(UserDefined(sample), sample.getSize()),
   sample_(sample)
 {
   // Nothing to do
@@ -50,9 +49,8 @@ FixedExperiment::FixedExperiment(const NumericalSample & sample,
 
 /* Constructor with parameters */
 FixedExperiment::FixedExperiment(const NumericalSample & sample,
-                                 const NumericalPoint & weights,
-                                 const String & name):
-  WeightedExperiment(UserDefined(sample, weights), sample.getSize(), name),
+                                 const NumericalPoint & weights):
+  WeightedExperiment(UserDefined(sample, weights), sample.getSize()),
   sample_(sample)
 {
   // Add the weights to the upper level class
