@@ -3,7 +3,7 @@
  *  @file  GaussProductExperiment.cxx
  *  @brief Abstract top-level view of an monteCarloExperiment plane
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -38,8 +38,8 @@ CLASSNAMEINIT(GaussProductExperiment);
 typedef Collection< NumericalPoint > NumericalPointCollection;
 
 /* Default constructor */
-GaussProductExperiment::GaussProductExperiment(const String & name):
-  WeightedExperiment(name),
+GaussProductExperiment::GaussProductExperiment():
+  WeightedExperiment(),
   collection_(0),
   marginalDegrees_(0),
   nodes_(0, 0)
@@ -48,9 +48,8 @@ GaussProductExperiment::GaussProductExperiment(const String & name):
 }
 
 /* Constructor with parameters */
-GaussProductExperiment::GaussProductExperiment(const Indices & marginalDegrees,
-    const String & name):
-  WeightedExperiment(name),
+GaussProductExperiment::GaussProductExperiment(const Indices & marginalDegrees):
+  WeightedExperiment(),
   collection_(0),
   marginalDegrees_(0),
   nodes_(0, 0)
@@ -59,23 +58,21 @@ GaussProductExperiment::GaussProductExperiment(const Indices & marginalDegrees,
 }
 
 /* Constructor with parameters */
-GaussProductExperiment::GaussProductExperiment(const Distribution & distribution,
-    const String & name):
-  WeightedExperiment(name),
+GaussProductExperiment::GaussProductExperiment(const Distribution & distribution):
+  WeightedExperiment(),
   collection_(0),
   marginalDegrees_(0),
   nodes_(0, 0)
 {
   // The distribution must be set BEFORE the marginal degrees
   setDistribution(distribution);
-  setMarginalDegrees(Indices(distribution.getDimension(), ResourceMap::GetAsUnsignedLong( "GaussProductExperiment-DefaultMarginalDegree" )));
+  setMarginalDegrees(Indices(distribution.getDimension(), ResourceMap::GetAsUnsignedInteger( "GaussProductExperiment-DefaultMarginalDegree" )));
 }
 
 /* Constructor with parameters */
 GaussProductExperiment::GaussProductExperiment(const Distribution & distribution,
-    const Indices & marginalDegrees,
-    const String & name):
-  WeightedExperiment(name),
+    const Indices & marginalDegrees):
+  WeightedExperiment(),
   collection_(0),
   marginalDegrees_(0),
   nodes_(0, 0)
@@ -106,7 +103,7 @@ String GaussProductExperiment::__repr__() const
 void GaussProductExperiment::setDistribution(const Distribution & distribution)
 {
   if (!distribution.hasIndependentCopula()) throw InvalidArgumentException(HERE) << "Error: the GaussProductExperiment can only be used with distributions having an independent copula.";
-  for (UnsignedLong i = 0; i < distribution.getDimension(); ++i) collection_.add(StandardDistributionPolynomialFactory(distribution.getMarginal(i)));
+  for (UnsignedInteger i = 0; i < distribution.getDimension(); ++i) collection_.add(StandardDistributionPolynomialFactory(distribution.getMarginal(i)));
   WeightedExperiment::setDistribution(distribution);
   isAlreadyComputedNodesAndWeights_ = false;
 }
@@ -121,7 +118,7 @@ NumericalSample GaussProductExperiment::generate()
 /** Marginal degrees accessor */
 void GaussProductExperiment::setMarginalDegrees(const Indices & marginalDegrees)
 {
-  const UnsignedLong dimension(distribution_.getDimension());
+  const UnsignedInteger dimension(distribution_.getDimension());
   if (marginalDegrees.getSize() != dimension) throw InvalidArgumentException(HERE) << "Error: the marginal degrees number must match the distribution dimension. Here, the degrees are " << marginalDegrees << " and the dimension is " << dimension;
   if (marginalDegrees != marginalDegrees_)
   {
@@ -138,36 +135,37 @@ Indices GaussProductExperiment::getMarginalDegrees() const
 /* Compute the tensor product nodes and weights */
 void GaussProductExperiment::computeNodesAndWeights()
 {
-  const UnsignedLong dimension(distribution_.getDimension());
+  const UnsignedInteger dimension(distribution_.getDimension());
   // Build the integration nodes and weights
   // First, get the marginal nodes and weights
   NumericalPointCollection marginalNodes(dimension);
   NumericalPointCollection marginalWeights(dimension);
   size_ = 1;
-  for (UnsignedLong i = 0; i < dimension; ++i)
+  for (UnsignedInteger i = 0; i < dimension; ++i)
   {
-    const UnsignedLong dI(marginalDegrees_[i]);
+    const UnsignedInteger dI(marginalDegrees_[i]);
     marginalNodes[i] = collection_[i].getNodesAndWeights(dI, marginalWeights[i]);
     size_ *= dI;
   }
   // Second, multiplex everything
   nodes_ = NumericalSample(size_, dimension);
+  nodes_.setDescription(distribution_.getDescription());
   weights_ = NumericalPoint(size_, 1.0);
   Indices indices(dimension, 0);
-  for (UnsignedLong linearIndex = 0; linearIndex < size_; ++linearIndex)
+  for (UnsignedInteger linearIndex = 0; linearIndex < size_; ++linearIndex)
   {
-    for (UnsignedLong j = 0; j < dimension; ++j)
+    for (UnsignedInteger j = 0; j < dimension; ++j)
     {
-      const UnsignedLong indiceJ(indices[j]);
+      const UnsignedInteger indiceJ(indices[j]);
       nodes_[linearIndex][j] = marginalNodes[j][indiceJ];
       weights_[linearIndex] *= marginalWeights[j][indiceJ];
     }
     /* Update the indices */
     ++indices[0];
     /* Propagate the remainders */
-    for (UnsignedLong j = 0; j < dimension - 1; ++j) indices[j + 1] += (indices[j] == marginalDegrees_[j]);
+    for (UnsignedInteger j = 0; j < dimension - 1; ++j) indices[j + 1] += (indices[j] == marginalDegrees_[j]);
     /* Correction of the indices. The last index cannot overflow. */
-    for (UnsignedLong j = 0; j < dimension - 1; ++j) indices[j] = indices[j] % marginalDegrees_[j];
+    for (UnsignedInteger j = 0; j < dimension - 1; ++j) indices[j] = indices[j] % marginalDegrees_[j];
   } // Loop over the n-D nodes
   isAlreadyComputedNodesAndWeights_ = true;
 }
