@@ -3,7 +3,7 @@
  *  @file  ImportanceSamplingExperiment.cxx
  *  @brief Abstract top-level view of an monteCarloExperiment plane
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -32,8 +32,8 @@ CLASSNAMEINIT(ImportanceSamplingExperiment);
 
 
 /* Default constructor */
-ImportanceSamplingExperiment::ImportanceSamplingExperiment(const String & name):
-  WeightedExperiment(name)
+ImportanceSamplingExperiment::ImportanceSamplingExperiment():
+  WeightedExperiment()
 {
   // Take the default distribution as the importance distribution
   importanceDistribution_ = distribution_;
@@ -41,9 +41,8 @@ ImportanceSamplingExperiment::ImportanceSamplingExperiment(const String & name):
 
 /* Constructor with parameters */
 ImportanceSamplingExperiment::ImportanceSamplingExperiment(const Distribution & importanceDistribution,
-    const UnsignedLong size,
-    const String & name):
-  WeightedExperiment(size, name),
+    const UnsignedInteger size):
+  WeightedExperiment(size),
   importanceDistribution_(importanceDistribution)
 {
   // Take the default distribution as the importance distribution
@@ -52,9 +51,8 @@ ImportanceSamplingExperiment::ImportanceSamplingExperiment(const Distribution &
 /* Constructor with parameters */
 ImportanceSamplingExperiment::ImportanceSamplingExperiment(const Distribution & distribution,
     const Distribution & importanceDistribution,
-    const UnsignedLong size,
-    const String & name):
-  WeightedExperiment(distribution, size, name),
+    const UnsignedInteger size):
+  WeightedExperiment(distribution, size),
   importanceDistribution_(importanceDistribution)
 {
   // Check if the distributions have compatible dimensions
@@ -89,8 +87,9 @@ String ImportanceSamplingExperiment::__repr__() const
 NumericalSample ImportanceSamplingExperiment::generate(NumericalPoint & weights)
 {
   NumericalSample result(size_, distribution_.getDimension());
+  result.setDescription(distribution_.getDescription());
   weights_ = NumericalPoint(size_);
-  for (UnsignedLong i = 0; i < size_; ++i)
+  for (UnsignedInteger i = 0; i < size_; ++i)
   {
     result[i] = importanceDistribution_.getRealization();
     weights_[i] = distribution_.computePDF(result[i]) / importanceDistribution_.computePDF(result[i]);
