@@ -3,7 +3,7 @@
  *  @file  LowDiscrepancyExperiment.cxx
  *  @brief Abstract top-level view of an monteCarloExperiment plane
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -33,8 +33,8 @@ CLASSNAMEINIT(LowDiscrepancyExperiment);
 
 
 /* Default constructor */
-LowDiscrepancyExperiment::LowDiscrepancyExperiment(const String & name):
-  WeightedExperiment(name),
+LowDiscrepancyExperiment::LowDiscrepancyExperiment():
+  WeightedExperiment(),
   marginals_(),
   sequence_(SobolSequence())
 {
@@ -42,9 +42,8 @@ LowDiscrepancyExperiment::LowDiscrepancyExperiment(const String & name):
 }
 
 /* Constructor with parameters */
-LowDiscrepancyExperiment::LowDiscrepancyExperiment(const UnsignedLong size,
-    const String & name):
-  WeightedExperiment(size, name),
+LowDiscrepancyExperiment::LowDiscrepancyExperiment(const UnsignedInteger size):
+  WeightedExperiment(size),
   marginals_(),
   sequence_(SobolSequence())
 {
@@ -54,9 +53,8 @@ LowDiscrepancyExperiment::LowDiscrepancyExperiment(const UnsignedLong size,
 /* Constructor with parameters */
 LowDiscrepancyExperiment::LowDiscrepancyExperiment(const LowDiscrepancySequence & sequence,
     const Distribution & distribution,
-    const UnsignedLong size,
-    const String & name):
-  WeightedExperiment(distribution, size, name),
+    const UnsignedInteger size):
+  WeightedExperiment(distribution, size),
   marginals_(0),
   sequence_(sequence)
 {
@@ -65,9 +63,8 @@ LowDiscrepancyExperiment::LowDiscrepancyExperiment(const LowDiscrepancySequence
 
 /* Constructor with parameters */
 LowDiscrepancyExperiment::LowDiscrepancyExperiment(const LowDiscrepancySequence & sequence,
-    const UnsignedLong size,
-    const String & name):
-  WeightedExperiment(size, name),
+    const UnsignedInteger size):
+  WeightedExperiment(size),
   marginals_(0),
   sequence_(sequence)
 {
@@ -96,10 +93,10 @@ String LowDiscrepancyExperiment::__repr__() const
 void LowDiscrepancyExperiment::setDistribution(const Distribution & distribution)
 {
   if (!distribution.hasIndependentCopula()) throw InvalidArgumentException(HERE) << "Error: the LowDiscrepancyExperiment can only be used with distributions having an independent copula.";
-  const UnsignedLong dimension(distribution.getDimension());
+  const UnsignedInteger dimension(distribution.getDimension());
   marginals_ = DistributionCollection(dimension);
   // Get the marginal distributions
-  for (UnsignedLong i = 0; i < dimension; ++i) marginals_[i] = distribution.getMarginal(i);
+  for (UnsignedInteger i = 0; i < dimension; ++i) marginals_[i] = distribution.getMarginal(i);
   // initialize the low-discrepancy sequence
   sequence_.initialize(dimension);
   WeightedExperiment::setDistribution(distribution);
@@ -116,9 +113,10 @@ NumericalSample LowDiscrepancyExperiment::generate()
 {
   // In-place transformation to reduce memory consumption
   NumericalSample sample(sequence_.generate(size_));
-  const UnsignedLong dimension(marginals_.getSize());
-  for (UnsignedLong i = 0; i < size_; ++i)
-    for (UnsignedLong j = 0; j < dimension; ++j) sample[i][j] = marginals_[j].computeQuantile(sample[i][j])[0];
+  sample.setDescription(distribution_.getDescription());
+  const UnsignedInteger dimension(marginals_.getSize());
+  for (UnsignedInteger i = 0; i < size_; ++i)
+    for (UnsignedInteger j = 0; j < dimension; ++j) sample[i][j] = marginals_[j].computeQuantile(sample[i][j])[0];
   return sample;
 }
 
