@@ -3,7 +3,7 @@
  *  @file  MonteCarloExperiment.cxx
  *  @brief Abstract top-level view of an monteCarloExperiment plane
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -30,25 +30,23 @@ BEGIN_NAMESPACE_OPENTURNS
 CLASSNAMEINIT(MonteCarloExperiment);
 
 /* Default constructor */
-MonteCarloExperiment::MonteCarloExperiment(const String & name):
-  WeightedExperiment(name)
+MonteCarloExperiment::MonteCarloExperiment():
+  WeightedExperiment()
 {
   // Nothing to do
 }
 
 /* Constructor with parameters */
-MonteCarloExperiment::MonteCarloExperiment(const UnsignedLong size,
-    const String & name):
-  WeightedExperiment(size, name)
+MonteCarloExperiment::MonteCarloExperiment(const UnsignedInteger size):
+  WeightedExperiment(size)
 {
   // Nothing to do
 }
 
 /* Constructor with parameters */
 MonteCarloExperiment::MonteCarloExperiment(const Distribution & distribution,
-    const UnsignedLong size,
-    const String & name):
-  WeightedExperiment(distribution, size, name)
+    const UnsignedInteger size):
+  WeightedExperiment(distribution, size)
 {
   // Nothing to do
 }
