@@ -3,7 +3,7 @@
  *  @file  WeightedExperiment.cxx
  *  @brief Abstract top-level view of an weightedExperiment plane
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -36,19 +36,18 @@ CLASSNAMEINIT(WeightedExperiment);
 
 
 /* Default constructor */
-WeightedExperiment::WeightedExperiment(const String & name):
-  ExperimentImplementation(name),
+WeightedExperiment::WeightedExperiment():
+  ExperimentImplementation(),
   distribution_(),
-  size_(ResourceMap::GetAsUnsignedLong( "WeightedExperiment-DefaultSize" )),
-  weights_(ResourceMap::GetAsUnsignedLong( "WeightedExperiment-DefaultSize" ), 1.0 / ResourceMap::GetAsUnsignedLong( "WeightedExperiment-DefaultSize" ))
+  size_(ResourceMap::GetAsUnsignedInteger( "WeightedExperiment-DefaultSize" )),
+  weights_(ResourceMap::GetAsUnsignedInteger( "WeightedExperiment-DefaultSize" ), 1.0 / ResourceMap::GetAsUnsignedInteger( "WeightedExperiment-DefaultSize" ))
 {
   // Nothing to do
 }
 
 /* Constructor with parameters */
-WeightedExperiment::WeightedExperiment(const UnsignedLong size,
-                                       const String & name):
-  ExperimentImplementation(name),
+WeightedExperiment::WeightedExperiment(const UnsignedInteger size):
+  ExperimentImplementation(),
   distribution_(),
   size_(0),
   weights_(0)
@@ -59,9 +58,8 @@ WeightedExperiment::WeightedExperiment(const UnsignedLong size,
 
 /* Constructor with parameters */
 WeightedExperiment::WeightedExperiment(const Distribution & distribution,
-                                       const UnsignedLong size,
-                                       const String & name):
-  ExperimentImplementation(name),
+                                       const UnsignedInteger size):
+  ExperimentImplementation(),
   distribution_(distribution),
   size_(0),
   weights_(0)
@@ -99,14 +97,14 @@ Distribution WeightedExperiment::getDistribution() const
 }
 
 /* Size accessor */
-void WeightedExperiment::setSize(const UnsignedLong size)
+void WeightedExperiment::setSize(const UnsignedInteger size)
 {
   if (size == 0) throw InvalidArgumentException(HERE) << "Error: the size must be > 0.";
   size_ = size;
   weights_ = NumericalPoint(size_, 1.0 / size_);
 }
 
-UnsignedLong WeightedExperiment::getSize() const
+UnsignedInteger WeightedExperiment::getSize() const
 {
   return size_;
 }
@@ -114,11 +112,11 @@ UnsignedLong WeightedExperiment::getSize() const
 /* Sample generation */
 NumericalSample WeightedExperiment::generate()
 {
-  throw NotYetImplementedException(HERE);
+  throw NotYetImplementedException(HERE) << "In WeightedExperiment::generate()";
 }
 
 /* Sample generation with weights */
-NumericalSample WeightedExperiment::generate(NumericalPoint & weights)
+NumericalSample WeightedExperiment::generateWithWeights(NumericalPoint & weights)
 {
   const NumericalSample sample(generate());
   weights = weights_;
