@@ -3,7 +3,7 @@
  *  @file  CalibrationStrategy.cxx
  *  @brief Abstract top-level class for all CalibrationStrategy
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -60,7 +60,7 @@ CalibrationStrategy::CalibrationStrategy(const Interval & range,
 CalibrationStrategy::CalibrationStrategy(const Interval & range,
     const NumericalScalar expansionFactor,
     const NumericalScalar shrinkFactor,
-    const UnsignedLong calibrationStep)
+    const UnsignedInteger calibrationStep)
   : TypedInterfaceObject<CalibrationStrategyImplementation>(new CalibrationStrategyImplementation(range,
       expansionFactor,
       shrinkFactor,
@@ -116,14 +116,14 @@ NumericalScalar CalibrationStrategy::getShrinkFactor() const
 }
 
 
-void CalibrationStrategy::setCalibrationStep(const UnsignedLong calibrationStep)
+void CalibrationStrategy::setCalibrationStep(const UnsignedInteger calibrationStep)
 {
   copyOnWrite();
   getImplementation()->setCalibrationStep(calibrationStep);
 }
 
 
-UnsignedLong CalibrationStrategy::getCalibrationStep() const
+UnsignedInteger CalibrationStrategy::getCalibrationStep() const
 {
   return getImplementation()->getCalibrationStep();
 }
