@@ -3,7 +3,7 @@
  *  @file  CalibrationStrategyImplementation.cxx
  *  @brief Default CalibrationStrategyImplementation
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -36,7 +36,7 @@ static Factory<CalibrationStrategyImplementation> RegisteredFactory("Calibration
 CalibrationStrategyImplementation::CalibrationStrategyImplementation(const Interval & range,
     const NumericalScalar expansionFactor,
     const NumericalScalar shrinkFactor,
-    const UnsignedLong calibrationStep)
+    const UnsignedInteger calibrationStep)
   : PersistentObject()
 {
   setRange(range);
@@ -107,14 +107,14 @@ NumericalScalar CalibrationStrategyImplementation::computeUpdateFactor(const Num
   return factor;
 }
 
-void CalibrationStrategyImplementation::setCalibrationStep(const UnsignedLong calibrationStep)
+void CalibrationStrategyImplementation::setCalibrationStep(const UnsignedInteger calibrationStep)
 {
   if (calibrationStep == 0) throw InvalidArgumentException(HERE) << "The calibration period must be positive.";
   calibrationStep_ = calibrationStep;
 }
 
 
-UnsignedLong CalibrationStrategyImplementation::getCalibrationStep() const
+UnsignedInteger CalibrationStrategyImplementation::getCalibrationStep() const
 {
   return calibrationStep_;
 }
