@@ -3,7 +3,7 @@
  *  @file  MCMC.cxx
  *  @brief MCMC updates the chain
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -28,13 +28,10 @@
 #include "SpecFunc.hxx"
 #include "PersistentObjectFactory.hxx"
 #include "IdentityMatrix.hxx"
-#include "LinearNumericalMathFunction.hxx"
-
+#include "Full.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
-
-
 CLASSNAMEINIT(MCMC);
 
 static Factory<MCMC> RegisteredFactory("MCMC");
@@ -45,6 +42,7 @@ MCMC::MCMC()
   , burnIn_(0)
   , thinning_(0)
 {
+  // Nothing to do
 }
 
 
@@ -56,18 +54,22 @@ MCMC::MCMC( const Distribution & prior,
   : SamplerImplementation()
   , initialState_(initialState)
   , currentState_(initialState)
+  , history_(Full())
   , conditional_(conditional)
 
   // when not provided, set the model to the identity
-  , model_(NumericalMathFunction::NumericalMathFunctionCollection(observations.getSize(), LinearNumericalMathFunction(NumericalPoint(initialState.getDimension()), NumericalPoint(initialState.getDimension()), IdentityMatrix(initialState.getDimension()))))
-
-  , burnIn_(ResourceMap::GetAsUnsignedLong("MCMC-DefaultBurnIn"))
-  , thinning_(ResourceMap::GetAsUnsignedLong("MCMC-DefaultThinning"))
+  , model_()
+  , burnIn_(ResourceMap::GetAsUnsignedInteger("MCMC-DefaultBurnIn"))
+  , thinning_(ResourceMap::GetAsUnsignedInteger("MCMC-DefaultThinning"))
 {
+  const NumericalMathFunction fullFunction(Description::BuildDefault(initialState.getDimension(), "x"), Description::BuildDefault(initialState.getDimension(), "x"));
+  const Indices indices(0);
+  model_ = NumericalMathFunction(fullFunction, indices);
   setPrior(prior);
   if (model_.getInputDimension() != prior.getDimension()) throw InvalidDimensionException(HERE) << "The model input dimension (" << model_.getInputDimension() << ") does not match the dimension of the prior (" << prior.getDimension() << ").";
+  setParameters(NumericalSample(observations.getSize(), 0));
   setObservations(observations);
-  if (conditional.getParametersNumber() * observations.getSize() != model_.getOutputDimension()) throw InvalidDimensionException(HERE) << "The number of observations per parameter (" << conditional.getParametersNumber() << "x" << observations.getSize() << ") does not match the output dimension of the model (" << model_.getOutputDimension() << ").";
+  if (conditional.getParametersNumber() != model_.getOutputDimension()) throw InvalidDimensionException(HERE) << "The parameter dimension" << conditional.getParametersNumber() << " does not match the output dimension of the model (" << model_.getOutputDimension() << ").";
   if (initialState.getDimension() != prior.getDimension()) throw InvalidDimensionException(HERE) << "The initialState state dimension (" << initialState.getDimension() << ") does not match the prior dimension (" << prior.getDimension() << ").";
 
 }
@@ -77,22 +79,24 @@ MCMC::MCMC( const Distribution & prior,
 MCMC::MCMC( const Distribution & prior,
             const Distribution & conditional,
             const NumericalMathFunction & model,
+            const NumericalSample & parameters,
             const NumericalSample & observations,
             const NumericalPoint & initialState)
   : SamplerImplementation()
   , initialState_(initialState)
   , currentState_(initialState)
+  , history_(Full())
   , conditional_(conditional)
   , model_(model)
-  , burnIn_(ResourceMap::GetAsUnsignedLong("MCMC-DefaultBurnIn"))
-  , thinning_(ResourceMap::GetAsUnsignedLong("MCMC-DefaultThinning"))
+  , burnIn_(ResourceMap::GetAsUnsignedInteger("MCMC-DefaultBurnIn"))
+  , thinning_(ResourceMap::GetAsUnsignedInteger("MCMC-DefaultThinning"))
 {
   setPrior(prior);
   if (model.getInputDimension() != prior.getDimension()) throw InvalidDimensionException(HERE) << "The model input dimension (" << model.getInputDimension() << ") does not match the dimension of the prior (" << prior.getDimension() << ").";
+  setParameters(parameters);
   setObservations(observations);
-  if (conditional.getParametersNumber() * observations.getSize() != model.getOutputDimension()) throw InvalidDimensionException(HERE) << "The number of observations per parameter (" << conditional.getParametersNumber() << "x" << observations.getSize() << ") does not match the output dimension of the model (" << model.getOutputDimension() << ").";
+  if (model_.getInputDimension() != prior.getDimension()) throw InvalidDimensionException(HERE) << "The model input dimension (" << model_.getInputDimension() << ") does not match the dimension of the prior (" << prior.getDimension() << ").";
   if (initialState.getDimension() != prior.getDimension()) throw InvalidDimensionException(HERE) << "The initialState state dimension (" << initialState.getDimension() << ") does not match the prior dimension (" << prior.getDimension() << ").";
-
 }
 
 
@@ -103,6 +107,7 @@ String MCMC::__repr__() const
          << " prior=" << prior_
          << " conditional=" << conditional_
          << " model=" << model_
+         << " parameters=" << parameters_
          << " observations=" << observations_
          << " burnIn=" << burnIn_
          << " thinning=" << thinning_;
@@ -115,7 +120,7 @@ MCMC* MCMC::clone() const
 }
 
 
-UnsignedLong MCMC::getDimension() const
+UnsignedInteger MCMC::getDimension() const
 {
   return prior_.getDimension();
 }
@@ -124,24 +129,18 @@ UnsignedLong MCMC::getDimension() const
 /* Compute the likelihood w.r.t. observartions */
 NumericalScalar MCMC::computeLogLikelihood(const NumericalPoint & xi) const
 {
-  NumericalScalar value = prior_.computeLogPDF(xi);
+  NumericalScalar value(prior_.computeLogPDF(xi));
   if ( value == -SpecFunc::MaxNumericalScalar ) return -SpecFunc::MaxNumericalScalar;
 
-  // retrieve model data if available
-  const NumericalPoint z( model_(xi) );
-
-  const UnsignedLong size = observations_.getSize();
-  const UnsignedLong p = conditional_.getParametersNumber();
-  for ( UnsignedLong i = 0; i < size; ++ i )
+  const UnsignedInteger size(observations_.getSize());
+  for ( UnsignedInteger i = 0; i < size; ++ i )
   {
-    NumericalPoint zi(p);
-    for ( UnsignedLong j = 0; j < p; ++ j )
-    {
-      zi[j] = z[i * p + j];
-    }
+    // retrieve model data if available
+    const NumericalPoint zi( model_(xi, parameters_[i]) );
+
     Distribution pI( conditional_ );
     pI.setParametersCollection( zi );
-    NumericalScalar logPdf = pI.computeLogPDF( observations_[i] );
+    NumericalScalar logPdf(pI.computeLogPDF( observations_[i] ));
     if ( logPdf == -SpecFunc::MaxNumericalScalar ) return -SpecFunc::MaxNumericalScalar;
     value += logPdf;
   }
@@ -175,7 +174,7 @@ NumericalMathFunction MCMC::getModel() const
 
 void MCMC::setObservations(const NumericalSample& observations)
 {
-  if (!(observations.getSize() > 0)) throw InvalidArgumentException(HERE) << "No observations provided.";
+  if (!(observations.getSize() > 0)) throw InvalidArgumentException(HERE) << "No observation provided.";
   observations_ = observations;
 }
 
@@ -186,30 +185,55 @@ NumericalSample MCMC::getObservations() const
 }
 
 
-void MCMC::setBurnIn(UnsignedLong burnIn)
+void MCMC::setParameters(const NumericalSample& parameters)
+{
+  if (!(parameters.getSize() > 0)) throw InvalidArgumentException(HERE) << "No parameter provided.";
+  parameters_ = parameters;
+}
+
+
+NumericalSample MCMC::getParameters() const
+{
+  return parameters_;
+}
+
+
+void MCMC::setBurnIn(UnsignedInteger burnIn)
 {
   burnIn_ = burnIn;
 }
 
 
-UnsignedLong MCMC::getBurnIn() const
+UnsignedInteger MCMC::getBurnIn() const
 {
   return burnIn_;
 }
 
 
-void MCMC::setThinning(UnsignedLong thinning)
+void MCMC::setThinning(UnsignedInteger thinning)
 {
   thinning_ = thinning;
 }
 
 
-UnsignedLong MCMC::getThinning() const
+UnsignedInteger MCMC::getThinning() const
 {
   return thinning_;
 }
 
 
+void MCMC::setHistory(const HistoryStrategy & history)
+{
+  history_ = history;
+}
+
+
+HistoryStrategy MCMC::getHistory() const
+{
+  return history_;
+}
+
+
 /* Method save() stores the object through the StorageManager */
 void MCMC::save(Advocate & adv) const
 {
@@ -219,6 +243,7 @@ void MCMC::save(Advocate & adv) const
   adv.saveAttribute("prior_", prior_);
   adv.saveAttribute("conditional_", conditional_);
   adv.saveAttribute("model_", model_);
+  adv.saveAttribute("parameters_", parameters_);
   adv.saveAttribute("observations_", observations_);
   adv.saveAttribute("burnIn_", burnIn_);
   adv.saveAttribute("thinning_", thinning_);
@@ -233,6 +258,7 @@ void MCMC::load(Advocate & adv)
   adv.loadAttribute("prior_", prior_);
   adv.loadAttribute("conditional_", conditional_);
   adv.loadAttribute("model_", model_);
+  adv.loadAttribute("parameters_", parameters_);
   adv.loadAttribute("observations_", observations_);
   adv.loadAttribute("burnIn_", burnIn_);
   adv.loadAttribute("thinning_", thinning_);
