@@ -3,7 +3,7 @@
  *  @file  PosteriorRandomVector.cxx
  *  @brief An implementation class for random vectors based on samplers
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -64,7 +64,7 @@ Sampler PosteriorRandomVector::getSampler() const
 }
 
 
-UnsignedLong PosteriorRandomVector::getDimension() const
+UnsignedInteger PosteriorRandomVector::getDimension() const
 {
   return sampler_.getDimension();
 }
@@ -76,7 +76,7 @@ NumericalPoint PosteriorRandomVector::getRealization() const
 }
 
 
-NumericalSample PosteriorRandomVector::getSample(const UnsignedLong size) const
+NumericalSample PosteriorRandomVector::getSample(const UnsignedInteger size) const
 {
   return sampler_.getSample(size);
 }
