@@ -3,7 +3,7 @@
  *  @file  RandomWalkMetropolisHastings.cxx
  *  @brief RandomWalkMetropolisHastings updates the chain
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -46,6 +46,7 @@ RandomWalkMetropolisHastings::RandomWalkMetropolisHastings()
   , samplesNumber_(0)
   , acceptedNumber_(0)
 {
+  // Nthing to do
 }
 
 
@@ -68,10 +69,11 @@ RandomWalkMetropolisHastings::RandomWalkMetropolisHastings( const Distribution &
 RandomWalkMetropolisHastings::RandomWalkMetropolisHastings( const Distribution & prior,
     const Distribution & conditional,
     const NumericalMathFunction & model,
+    const NumericalSample & parameters,
     const NumericalSample & observations,
     const NumericalPoint & initialState,
     const DistributionCollection & proposal)
-  : MCMC(prior, conditional, model, observations, initialState)
+  : MCMC(prior, conditional, model, parameters, observations, initialState)
   , calibrationStrategy_(proposal.getSize())
   , samplesNumber_(0)
   , acceptedNumber_(initialState.getDimension())
@@ -100,16 +102,16 @@ RandomWalkMetropolisHastings* RandomWalkMetropolisHastings::clone() const
 
 NumericalPoint RandomWalkMetropolisHastings::getRealization() const
 {
-  const UnsignedLong dimension = initialState_.getDimension();
+  const UnsignedInteger dimension(initialState_.getDimension());
 
   // update factor
-  NumericalPoint delta(dimension, 1.);
+  NumericalPoint delta(dimension, 1.0);
 
   // number of samples accepted until calibration step
   Indices accepted(dimension);
 
   // perform burning if necessary
-  const UnsignedLong size = getThinning() + (( samplesNumber_ < getBurnIn() ) ? getBurnIn() : 0);
+  const UnsignedInteger size = getThinning() + ((samplesNumber_ < getBurnIn()) ? getBurnIn() : 0);
 
   // compute the first likelihood
   NumericalScalar alphaLogSave = computeLogLikelihood(currentState_);
@@ -119,11 +121,12 @@ NumericalPoint RandomWalkMetropolisHastings::getRealization() const
   }
 
   // for each new sample
-  UnsignedLong acceptedSteps = 0;
-  for ( UnsignedLong i = 0; i < size; ++ i )
+  UnsignedInteger acceptedSteps = 0;
+  for ( UnsignedInteger i = 0; i < size; ++ i )
   {
     // copy ot current state to accept each component independently
     NumericalPoint newState(currentState_);
+    history_.store(currentState_);
 
     // reuse the likelihood if one or None candidate has been accepted
     NumericalScalar alphaLogPrev = acceptedSteps <= 1 ? alphaLogSave : computeLogLikelihood(currentState_);
@@ -131,7 +134,7 @@ NumericalPoint RandomWalkMetropolisHastings::getRealization() const
 
     // update each chain component
     acceptedSteps = 0;
-    for ( UnsignedLong j = 0; j < dimension; ++ j )
+    for ( UnsignedInteger j = 0; j < dimension; ++ j )
     {
       NumericalPoint nextState(newState);
 
@@ -144,7 +147,7 @@ NumericalPoint RandomWalkMetropolisHastings::getRealization() const
       const NumericalScalar alphaLog = alphaLogNext  - alphaLogPrev;
 
       // acceptance test
-      const NumericalScalar uLog = log( RandomGenerator::Generate() );
+      const NumericalScalar uLog = log(RandomGenerator::Generate());
       if ( uLog < alphaLog )
       {
         ++ acceptedSteps;
@@ -161,46 +164,49 @@ NumericalPoint RandomWalkMetropolisHastings::getRealization() const
     currentState_ = newState;
 
     // recalibrate for each component if necessary
-    NumericalPoint factor(dimension);
-    NumericalPoint partialRho(dimension);
-    for ( UnsignedLong j = 0; j < dimension; ++ j )
+    if (samplesNumber_ < getBurnIn())
     {
-      const UnsignedLong calibrationStep = calibrationStrategy_[j].getCalibrationStep();
-      if ( ( samplesNumber_ % calibrationStep ) == ( calibrationStep - 1 ) )
+      for ( UnsignedInteger j = 0; j < dimension; ++ j )
       {
-        // compute the current acceptation rate
-        NumericalScalar rho = static_cast<NumericalScalar>(accepted[j]) / calibrationStep;
-
-        // compute factor
-        NumericalScalar factor = calibrationStrategy_[j].computeUpdateFactor( rho );
-
-        // update delta
-        delta[j] *= factor;
-
-        // reset the counter
-        accepted[j] = 0;
-
-        if ( getVerbose() )
+        const UnsignedInteger calibrationStep = calibrationStrategy_[j].getCalibrationStep();
+        if ( ( samplesNumber_ % calibrationStep ) == ( calibrationStep - 1 ) )
         {
-          LOGINFO( OSS() << "rho=" << rho << " factor=" << factor << " delta=" << delta.getCollection() << " accept=" << getAcceptanceRate().getCollection() );
-        }
+          // compute the current acceptation rate
+          NumericalScalar rho = 1.0 * accepted[j] / (1.0 * calibrationStep);
 
-      }
-    }
+          // compute factor
+          NumericalScalar factor = calibrationStrategy_[j].computeUpdateFactor(rho);
+
+          // update delta
+          delta[j] *= factor;
+
+          // reset the counter
+          accepted[j] = 0;
+
+          if ( getVerbose() )
+          {
+            LOGINFO( OSS() << "rho=" << rho << " factor=" << factor << " delta=" << delta.getCollection() << " accept=" << getAcceptanceRate().getCollection() );
+          }
+
+        } // calibrationStep
+      } // j
+    } // burn-in
 
     ++ samplesNumber_;
 
   } // for i
 
+  // Save the last state
+  history_.store(currentState_);
   return currentState_;
 }
 
 
 NumericalPoint RandomWalkMetropolisHastings::getAcceptanceRate() const
 {
-  const UnsignedLong dimension = initialState_.getDimension();
+  const UnsignedInteger dimension = initialState_.getDimension();
   NumericalPoint acceptanceRate(dimension);
-  for ( UnsignedLong j = 0; j < dimension; ++ j )
+  for ( UnsignedInteger j = 0; j < dimension; ++ j )
   {
     acceptanceRate[j] = static_cast<NumericalScalar>(acceptedNumber_[j]) / samplesNumber_;
   }
@@ -210,7 +216,7 @@ NumericalPoint RandomWalkMetropolisHastings::getAcceptanceRate() const
 
 void RandomWalkMetropolisHastings::setCalibrationStrategy(const CalibrationStrategy& calibrationStrategy)
 {
-  for ( UnsignedLong i = 0; i < calibrationStrategy_.getSize(); ++ i )
+  for ( UnsignedInteger i = 0; i < calibrationStrategy_.getSize(); ++ i )
   {
     calibrationStrategy_[i] = calibrationStrategy;
   }
@@ -223,7 +229,7 @@ RandomWalkMetropolisHastings::CalibrationStrategyCollection RandomWalkMetropolis
 
 void RandomWalkMetropolisHastings::setCalibrationStrategyPerComponent(const CalibrationStrategyCollection& calibrationStrategy)
 {
-  const UnsignedLong dimension = proposal_.getSize();
+  const UnsignedInteger dimension = proposal_.getSize();
   if(dimension != calibrationStrategy.getSize()) throw InvalidDimensionException(HERE) << "The proposal dimension (" << dimension << ") does not match the size of calibration strategy (" << calibrationStrategy.getSize() << ").";
   calibrationStrategy_ = calibrationStrategy;
 }
@@ -231,10 +237,10 @@ void RandomWalkMetropolisHastings::setCalibrationStrategyPerComponent(const Cali
 
 void RandomWalkMetropolisHastings::setProposal(const RandomWalkMetropolisHastings::DistributionCollection& proposal)
 {
-  const UnsignedLong dimension = getPrior().getDimension();
+  const UnsignedInteger dimension = getPrior().getDimension();
   if (proposal.getSize() != dimension) throw InvalidDimensionException(HERE) << "The proposal dimension (" << proposal.getSize() << ") does not match the prior dimension (" << dimension << ").";
 
-  for ( UnsignedLong i = 0; i < dimension; ++ i )
+  for ( UnsignedInteger i = 0; i < dimension; ++ i )
   {
     Bool symmetric = proposal[i].isElliptical();
     symmetric = symmetric && (fabs(proposal[i].getMean()[0]) < ResourceMap::GetAsNumericalScalar("DistributionImplementation-DefaultQuantileEpsilon"));
