@@ -3,7 +3,7 @@
  *  @file  Sampler.cxx
  *  @brief Abstract top-level class for all Sampler
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -46,7 +46,7 @@ Sampler::Sampler(const SamplerImplementation & op)
 }
 
 
-UnsignedLong Sampler::getDimension() const
+UnsignedInteger Sampler::getDimension() const
 {
   return getImplementation()->getDimension();
 }
@@ -60,7 +60,7 @@ NumericalPoint Sampler::getRealization() const
 
 
 /* Returns several realizations */
-NumericalSample Sampler::getSample(const UnsignedLong size) const
+NumericalSample Sampler::getSample(const UnsignedInteger size) const
 {
   return getImplementation()->getSample(size);
 }
