@@ -3,7 +3,7 @@
  *  @file  SamplerImplementation.cxx
  *  @brief Abstract top-level class for all SamplerImplementation
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -68,26 +68,23 @@ Bool SamplerImplementation::getVerbose() const
 /* Here is the interface that all derived class must implement */
 
 
-UnsignedLong SamplerImplementation::getDimension() const
+UnsignedInteger SamplerImplementation::getDimension() const
 {
-  throw NotYetImplementedException(HERE);
+  throw NotYetImplementedException(HERE) << "In SamplerImplementation::getDimension() const";
 }
 
 
 NumericalPoint SamplerImplementation::getRealization() const
 {
-  throw NotYetImplementedException(HERE);
+  throw NotYetImplementedException(HERE) << "In SamplerImplementation::getRealization() const";
 }
 
 
-NumericalSample SamplerImplementation::getSample(const UnsignedLong size) const
+NumericalSample SamplerImplementation::getSample(const UnsignedInteger size) const
 {
   NumericalSample sample(size, getDimension());
-  for (UnsignedLong i = 0; i < size; ++ i)
-  {
-    NumericalPoint realization(getRealization());
-    sample[i] = realization;
-  }
+  for (UnsignedInteger i = 0; i < size; ++ i)
+    sample[i] = getRealization();
   return sample;
 }
 
