@@ -3,7 +3,7 @@
  *  @file  AliMikhailHaqCopula.cxx
  *  @brief The AliMikhailHaqCopula distribution
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -36,18 +36,20 @@ static Factory<AliMikhailHaqCopula> RegisteredFactory("AliMikhailHaqCopula");
 
 /* Default constructor */
 AliMikhailHaqCopula::AliMikhailHaqCopula()
-  : ArchimedeanCopula("AliMikhailHaqCopula")
-  , theta_(0.0)
+  : ArchimedeanCopula()
+  , theta_(1.0)
 {
+  setName( "AliMikhailHaqCopula" );
   setDimension( 2 );
   computeRange();
 }
 
 /* Parameters constructor */
 AliMikhailHaqCopula::AliMikhailHaqCopula(const NumericalScalar theta)
-  : ArchimedeanCopula("AliMikhailHaqCopula")
+  : ArchimedeanCopula()
   , theta_(0.0)
 {
+  setName( "AliMikhailHaqCopula" );
   // We set the dimension of the AliMikhailHaqCopula distribution
   setDimension( 2 );
   // Check the given theta
@@ -99,14 +101,14 @@ NumericalPoint AliMikhailHaqCopula::getRealization() const
   const NumericalScalar b(-theta_ * (2.0 * a * v + 1.0) + 2.0 * theta2 * a * a * v + 1.0);
   const NumericalScalar delta(4.0 * v * (a - 1.0));
   const NumericalScalar c(theta2 * (a * delta + 1.0) - theta_ * (delta + 2.0) + 1.0);
-  realization[1] = 2.0 * v * pow(a * theta_ - 1.0, 2) / (b + sqrt(c));
+  realization[1] = 2.0 * v * std::pow(a * theta_ - 1.0, 2) / (b + std::sqrt(c));
   return realization;
 }
 
 /* Get the DDF of the distribution */
 NumericalPoint AliMikhailHaqCopula::computeDDF(const NumericalPoint & point) const
 {
-  const UnsignedLong dimension(getDimension());
+  const UnsignedInteger dimension(getDimension());
   if (point.getDimension() != dimension) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=" << dimension << ", here dimension=" << point.getDimension();
 
   const NumericalScalar u(point[0]);
@@ -134,7 +136,7 @@ NumericalPoint AliMikhailHaqCopula::computeDDF(const NumericalPoint & point) con
 /* Get the PDF of the distribution */
 NumericalScalar AliMikhailHaqCopula::computePDF(const NumericalPoint & point) const
 {
-  const UnsignedLong dimension(getDimension());
+  const UnsignedInteger dimension(getDimension());
   if (point.getDimension() != dimension) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=" << dimension << ", here dimension=" << point.getDimension();
 
   const NumericalScalar u(point[0]);
@@ -145,13 +147,13 @@ NumericalScalar AliMikhailHaqCopula::computePDF(const NumericalPoint & point) co
     return 0.0;
   }
   const NumericalScalar prod(theta_ * (1.0 - u) * (1.0 - v));
-  return (1.0 + theta_ * ((1.0 + u) * (1.0 + v) - 3.0 + prod)) / pow(1.0 - prod, 3);
+  return (1.0 + theta_ * ((1.0 + u) * (1.0 + v) - 3.0 + prod)) / std::pow(1.0 - prod, 3);
 }
 
 /* Get the CDF of the distribution */
 NumericalScalar AliMikhailHaqCopula::computeCDF(const NumericalPoint & point) const
 {
-  const UnsignedLong dimension(getDimension());
+  const UnsignedInteger dimension(getDimension());
   if (point.getDimension() != dimension) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=" << dimension << ", here dimension=" << point.getDimension();
 
   const NumericalScalar u(point[0]);
@@ -168,66 +170,66 @@ NumericalScalar AliMikhailHaqCopula::computeCDF(const NumericalPoint & point) co
   return u * v / (1.0 - theta_ * (1.0 - u) * (1.0 - v));
 }
 
-/* Get the Spearman correlation of the distribution */
-CorrelationMatrix AliMikhailHaqCopula::getSpearmanCorrelation() const
+/* Compute the covariance of the distribution */
+void AliMikhailHaqCopula::computeCovariance() const
 {
-  CorrelationMatrix rho(2);
-  if (abs(theta_) < 0.005633787383) rho(0, 1) = (1.0 / 3.0 + (1.0 / 12.0 + (3.0 / 100.0 + (1.0 / 75.0 + (1.0 / 147.0 + (3.0 / 784.0 + theta_ / 432.0) / theta_) / theta_) / theta_) / theta_) / theta_) / theta_;
-  else rho(0, 1) = 12.0 * ((((1.0 + theta_) * SpecFunc::DiLog(theta_) - 2.0 * (1.0 - theta_) * log1p(-theta_)) / theta_) - 3.0) / theta_ - 3.0;
-  return rho;
+  covariance_ = CovarianceMatrix(2);
+  covariance_(0, 0) = 1.0 / 12.0;
+  covariance_(0, 1) = (std::abs(theta_) < 0.005633787383 ? (1.0 / 3.0 + (1.0 / 12.0 + (3.0 / 100.0 + (1.0 / 75.0 + (1.0 / 147.0 + (3.0 / 784.0 + theta_ / 432.0) / theta_) / theta_) / theta_) / theta_) / theta_) / (12.0 * theta_) : ((((1.0 + theta_) * SpecFunc::DiLog(theta_) - 2.0 * (1.0 - theta_) * log1p(-theta_)) / theta_) - 3.0) / theta_ - 0.25);
+  covariance_(1, 1) = 1.0 / 12.0;
+  isAlreadyComputedCovariance_ = true;
 }
 
 /* Get the Kendall concordance of the distribution */
 CorrelationMatrix AliMikhailHaqCopula::getKendallTau() const
 {
   CorrelationMatrix tau(2);
-  if (abs(theta_) < 0.005149755205) tau(0, 1) = (2.0 / 9.0 + (1.0 / 18.0 + (1.0 / 45.0 + (1.0 / 90.0 + (2.0 / 315.0 + (1.0 / 252.0 + theta_ / 378.0) * theta_) * theta_) * theta_) * theta_) * theta_) * theta_;
-  else tau(0, 1) = 1.0 - 2.0 / (3.0 * theta_) + log1p(-theta_) * (-2.0 / 3.0 + 4.0 / (3.0 * theta_) - 2.0 / (3.0 * theta_ * theta_));
+  tau(0, 1) = (std::abs(theta_) < 0.005149755205 ? (2.0 / 9.0 + (1.0 / 18.0 + (1.0 / 45.0 + (1.0 / 90.0 + (2.0 / 315.0 + (1.0 / 252.0 + theta_ / 378.0) * theta_) * theta_) * theta_) * theta_) * theta_) * theta_ : 1.0 - 2.0 / (3.0 * theta_) + log1p(-theta_) * (-2.0 / 3.0 + 4.0 / (3.0 * theta_) - 2.0 / (3.0 * theta_ * theta_)));
   return tau;
 }
 
 /* Get the PDFGradient of the distribution */
 NumericalPoint AliMikhailHaqCopula::computePDFGradient(const NumericalPoint & point) const
 {
-  const UnsignedLong dimension(getDimension());
+  const UnsignedInteger dimension(getDimension());
   if (point.getDimension() != dimension) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=" << dimension << ", here dimension=" << point.getDimension();
 
-  throw NotYetImplementedException(HERE);
+  throw NotYetImplementedException(HERE) << "In AliMikhailHaqCopula::computePDFGradient(const NumericalPoint & point) const";
 }
 
 /* Get the CDFGradient of the distribution */
 NumericalPoint AliMikhailHaqCopula::computeCDFGradient(const NumericalPoint & point) const
 {
-  const UnsignedLong dimension(getDimension());
+  const UnsignedInteger dimension(getDimension());
   if (point.getDimension() != dimension) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=" << dimension << ", here dimension=" << point.getDimension();
 
-  throw NotYetImplementedException(HERE);
+  throw NotYetImplementedException(HERE) << "In AliMikhailHaqCopula::computeCDFGradient(const NumericalPoint & point) const";
 }
 
 /* Get the quantile of the distribution */
 NumericalPoint AliMikhailHaqCopula::computeQuantile(const NumericalScalar prob,
     const Bool tail) const
 {
-  return NumericalPoint(2, (prob * theta_ + sqrt(prob * (1.0 - theta_ + prob * theta_))) / (1.0 + prob * theta_));
+  return NumericalPoint(2, (prob * theta_ + std::sqrt(prob * (1.0 - theta_ + prob * theta_))) / (1.0 + prob * theta_));
 }
 
 /* Compute the CDF of Xi | X1, ..., Xi-1. x = Xi, y = (X1,...,Xi-1) */
 NumericalScalar AliMikhailHaqCopula::computeConditionalCDF(const NumericalScalar x, const NumericalPoint & y) const
 {
-  const UnsignedLong conditioningDimension(y.getDimension());
+  const UnsignedInteger conditioningDimension(y.getDimension());
   if (conditioningDimension >= getDimension()) throw InvalidArgumentException(HERE) << "Error: cannot compute a conditional CDF with a conditioning point of dimension greater or equal to the distribution dimension.";
   // Special case for no conditioning or independent copula
   if ((conditioningDimension == 0) || (hasIndependentCopula())) return x;
   const NumericalScalar u(y[0]);
   const NumericalScalar v(x);
   // If we are in the support
-  return v * (1.0 - theta_ * (1.0 - v)) / pow(1.0 - theta_ * (1.0 - u) * (1.0 - v), 2);
+  return v * (1.0 - theta_ * (1.0 - v)) / std::pow(1.0 - theta_ * (1.0 - u) * (1.0 - v), 2);
 }
 
 /* Compute the quantile of Xi | X1, ..., Xi-1, i.e. x such that CDF(x|y) = q with x = Xi, y = (X1,...,Xi-1) */
 NumericalScalar AliMikhailHaqCopula::computeConditionalQuantile(const NumericalScalar q, const NumericalPoint & y) const
 {
-  const UnsignedLong conditioningDimension(y.getDimension());
+  const UnsignedInteger conditioningDimension(y.getDimension());
   if (conditioningDimension >= getDimension()) throw InvalidArgumentException(HERE) << "Error: cannot compute a conditional quantile with a conditioning point of dimension greater or equal to the distribution dimension.";
   if ((q < 0.0) || (q > 1.0)) throw InvalidArgumentException(HERE) << "Error: cannot compute a conditional quantile for a probability level outside of [0, 1]";
   if (q == 0.0) return 0.0;
@@ -245,7 +247,7 @@ NumericalScalar AliMikhailHaqCopula::computeConditionalQuantile(const NumericalS
   const NumericalScalar qThetaU(qTheta * u);
   const NumericalScalar tmp1(2.0 * qThetaU);
   const NumericalScalar tmp2(4.0 * qTheta2 * u);
-  const NumericalScalar tmp3(sqrt(1.0 + theta2 + 4.0 * qThetaU - tmp2 + 4.0 * qTheta2U2 - 2.0 * theta_));
+  const NumericalScalar tmp3(std::sqrt(1.0 + theta2 + 4.0 * qThetaU - tmp2 + 4.0 * qTheta2U2 - 2.0 * theta_));
   return -0.5 * (theta_ + 2.0 * qTheta - 2.0 * qTheta2 - 2.0 * qTheta2U2 - tmp1 - 1.0 + tmp2 + tmp3) / (theta_ * (-1.0 + qTheta - tmp1 + qTheta * u2));
 }
 
@@ -262,21 +264,21 @@ NumericalScalar AliMikhailHaqCopula::computeArchimedeanGenerator(const Numerical
 NumericalScalar AliMikhailHaqCopula::computeInverseArchimedeanGenerator(const NumericalScalar t) const
 {
   const NumericalScalar y(t * (theta_ - 1.0) / theta_);
-  return (y - SpecFunc::LambertW(-t * exp(y) / theta_)) / t;
+  return (y - SpecFunc::LambertW(-t * std::exp(y) / theta_)) / t;
 }
 
 /* Compute the derivative of the density generator */
 NumericalScalar AliMikhailHaqCopula::computeArchimedeanGeneratorDerivative(const NumericalScalar t) const
 {
   const NumericalScalar u(1.0 - theta_ * (1.0 - t));
-  return (theta_ / u - log(u) / t) / t;
+  return (theta_ / u - std::log(u) / t) / t;
 }
 
 /* Compute the seconde derivative of the density generator */
 NumericalScalar AliMikhailHaqCopula::computeArchimedeanGeneratorSecondDerivative(const NumericalScalar t) const
 {
   const NumericalScalar u(1.0 - theta_ * (1.0 - t));
-  return (-theta_ * theta_ / (u * u) - 2.0 * theta_ / (t * u) + 2.0 * log(u) / (t * t)) / t;
+  return (-theta_ * theta_ / (u * u) - 2.0 * theta_ / (t * u) + 2.0 * std::log(u) / (t * t)) / t;
 }
 
 /* Parameters value and description accessor */
@@ -295,7 +297,9 @@ AliMikhailHaqCopula::NumericalPointWithDescriptionCollection AliMikhailHaqCopula
 
 void AliMikhailHaqCopula::setParametersCollection(const NumericalPointCollection & parametersCollection)
 {
+  const NumericalScalar w(getWeight());
   *this = AliMikhailHaqCopula(parametersCollection[0][0]);
+  setWeight(w);
 }
 
 /* Tell if the distribution has independent copula */
