@@ -3,7 +3,7 @@
  *  @file  Bernoulli.cxx
  *  @brief The Bernoulli distribution
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -26,6 +26,7 @@
 #include "RandomGenerator.hxx"
 #include "PersistentObjectFactory.hxx"
 #include "Exception.hxx"
+#include "SpecFunc.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -35,9 +36,10 @@ static Factory<Bernoulli> RegisteredFactory("Bernoulli");
 
 /* Default constructor */
 Bernoulli::Bernoulli()
-  : DiscreteDistribution("Bernoulli"),
+  : DiscreteDistribution(),
     p_(0.5)
 {
+  setName( "Bernoulli" );
   // We set the dimension of the Bernoulli distribution
   setDimension( 1 );
   computeRange();
@@ -45,9 +47,10 @@ Bernoulli::Bernoulli()
 
 /* Parameters constructor */
 Bernoulli::Bernoulli(const NumericalScalar p)
-  : DiscreteDistribution("Bernoulli"),
+  : DiscreteDistribution(),
     p_(-1.0)
 {
+  setName( "Bernoulli" );
   // This call sets also the range
   setP(p);
   // We set the dimension of the Bernoulli distribution
@@ -98,8 +101,8 @@ NumericalScalar Bernoulli::computePDF(const NumericalPoint & point) const
   if (point.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=1, here dimension=" << point.getDimension();
 
   const NumericalScalar k(point[0]);
-  if (fabs(k) < supportEpsilon_) return 1.0 - p_;
-  if (fabs(k - 1.0) < supportEpsilon_) return p_;
+  if (std::abs(k) < supportEpsilon_) return 1.0 - p_;
+  if (std::abs(k - 1.0) < supportEpsilon_) return p_;
   return 0.0;
 }
 
@@ -125,8 +128,8 @@ NumericalPoint Bernoulli::computePDFGradient(const NumericalPoint & point) const
 
   const NumericalScalar k(point[0]);
   NumericalPoint pdfGradient(1, 0.0);
-  if ((k < -supportEpsilon_) || (fabs(k - round(k)) > supportEpsilon_)) return pdfGradient;
-  throw NotYetImplementedException(HERE);
+  if ((k < -supportEpsilon_) || (std::abs(k - round(k)) > supportEpsilon_)) return pdfGradient;
+  throw NotYetImplementedException(HERE) << "In Bernoulli::computePDFGradient(const NumericalPoint & point) const";
 }
 
 
@@ -137,7 +140,7 @@ NumericalPoint Bernoulli::computeCDFGradient(const NumericalPoint & point) const
 
   const NumericalScalar k(point[0]);
   if (k < -supportEpsilon_) return NumericalPoint(1, 0.0);
-  throw NotYetImplementedException(HERE);
+  throw NotYetImplementedException(HERE) << "In Bernoulli::computeCDFGradient(const NumericalPoint & point) const";
 }
 
 /* Get the quantile of the distribution */
@@ -151,7 +154,7 @@ NumericalScalar Bernoulli::computeScalarQuantile(const NumericalScalar prob,
 /* Get the characteristic function of the distribution, i.e. phi(u) = E(exp(I*u*X)) */
 NumericalComplex Bernoulli::computeCharacteristicFunction(const NumericalScalar x) const
 {
-  const NumericalComplex value(1.0 - p_ + p_ * exp(NumericalComplex(0.0, x)));
+  const NumericalComplex value(1.0 - p_ + p_ * std::exp(NumericalComplex(0.0, x)));
   return value;
 }
 
@@ -172,14 +175,14 @@ void Bernoulli::computeMean() const
 /* Get the standard deviation of the distribution */
 NumericalPoint Bernoulli::getStandardDeviation() const
 {
-  return NumericalPoint(1, sqrt(p_ * (1.0 - p_)));
+  return NumericalPoint(1, std::sqrt(p_ * (1.0 - p_)));
 }
 
 /* Get the skewness of the distribution */
 NumericalPoint Bernoulli::getSkewness() const
 {
   if ((p_ == 0.0) || (p_ == 1.0)) throw NotDefinedException(HERE) << "Error: the skewness is not defined for the Bernoulli distribution when p is zero or one.";
-  return NumericalPoint(1, (1.0 - 2.0 * p_) / sqrt(p_ * (1.0 - p_)));
+  return NumericalPoint(1, (1.0 - 2.0 * p_) / std::sqrt(p_ * (1.0 - p_)));
 }
 
 /* Get the kurtosis of the distribution */
@@ -190,7 +193,7 @@ NumericalPoint Bernoulli::getKurtosis() const
 }
 
 /* Get the moments of the standardized distribution */
-NumericalPoint Bernoulli::getStandardMoment(const UnsignedLong n) const
+NumericalPoint Bernoulli::getStandardMoment(const UnsignedInteger n) const
 {
   if (n == 0) return NumericalPoint(1, 0.0);
   return NumericalPoint(1, p_);
@@ -208,10 +211,10 @@ void Bernoulli::computeCovariance() const
 NumericalSample Bernoulli::getSupport(const Interval & interval) const
 {
   if (interval.getDimension() != getDimension()) throw InvalidArgumentException(HERE) << "Error: the given interval has a dimension that does not match the distribution dimension.";
-  const UnsignedLong kMin(static_cast< UnsignedLong > (std::max(ceil(interval.getLowerBound()[0]), 0.0)));
-  const UnsignedLong kMax(static_cast< UnsignedLong > (std::min(floor(interval.getUpperBound()[0]), 1.0)));
+  const UnsignedInteger kMin(static_cast< UnsignedInteger > (std::max(ceil(interval.getLowerBound()[0]), 0.0)));
+  const UnsignedInteger kMax(static_cast< UnsignedInteger > (std::min(floor(interval.getUpperBound()[0]), 1.0)));
   NumericalSample result(0, 1);
-  for (UnsignedLong k = kMin; k <= kMax; ++k) result.add(NumericalPoint(1, k));
+  for (UnsignedInteger k = kMin; k <= kMax; ++k) result.add(NumericalPoint(1, k));
   return result;
 }
 
@@ -231,7 +234,9 @@ Bernoulli::NumericalPointWithDescriptionCollection Bernoulli::getParametersColle
 
 void Bernoulli::setParametersCollection(const NumericalPointCollection & parametersCollection)
 {
+  const NumericalScalar w(getWeight());
   *this = Bernoulli(parametersCollection[0][0]);
+  setWeight(w);
 }
 
 /* P accessor */
