@@ -3,7 +3,7 @@
  *  @file  ChiSquare.cxx
  *  @brief The ChiSquare distribution, ie the Gamma(nu/2,1/2) distribution
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -37,10 +37,11 @@ static Factory<ChiSquare> RegisteredFactory("ChiSquare");
 
 /* Default constructor */
 ChiSquare::ChiSquare()
-  : ContinuousDistribution("ChiSquare")
+  : ContinuousDistribution()
   , nu_(0.0)
   , normalizationFactor_(0.0)
 {
+  setName("ChiSquare");
   // This call also call update() and computeRange()
   setNu(1.0);
   setDimension(1);
@@ -49,10 +50,11 @@ ChiSquare::ChiSquare()
 
 /* Parameters constructor */
 ChiSquare::ChiSquare(const NumericalScalar nu)
-  : ContinuousDistribution("ChiSquare")
+  : ContinuousDistribution()
   , nu_(0.0)
   , normalizationFactor_(0.0)
 {
+  setName("ChiSquare");
   // This call set also call computeRange() and update().
   setNu(nu);
   setDimension(1);
@@ -147,7 +149,7 @@ NumericalScalar ChiSquare::computePDF(const NumericalPoint & point) const
 
   const NumericalScalar x(point[0]);
   if (x <= 0.0) return 0.0;
-  return exp(computeLogPDF(point));
+  return std::exp(computeLogPDF(point));
 }
 
 NumericalScalar ChiSquare::computeLogPDF(const NumericalPoint & point) const
@@ -156,7 +158,7 @@ NumericalScalar ChiSquare::computeLogPDF(const NumericalPoint & point) const
 
   const NumericalScalar x(point[0]);
   if (x <= 0.0) return -SpecFunc::MaxNumericalScalar;
-  return normalizationFactor_ + (0.5 * nu_ - 1) * log(x) - 0.5 * x;
+  return normalizationFactor_ + (0.5 * nu_ - 1) * std::log(x) - 0.5 * x;
 }
 
 /* Get the CDF of the distribution */
@@ -183,12 +185,12 @@ NumericalScalar ChiSquare::computeComplementaryCDF(const NumericalPoint & point)
 /* Get the characteristic function of the distribution, i.e. phi(u) = E(exp(I*u*X)) */
 NumericalComplex ChiSquare::computeCharacteristicFunction(const NumericalScalar x) const
 {
-  return pow(NumericalComplex(1.0, -2.0 * x), -0.5 * nu_);
+  return std::pow(NumericalComplex(1.0, -2.0 * x), -0.5 * nu_);
 }
 
 NumericalComplex ChiSquare::computeLogCharacteristicFunction(const NumericalScalar x) const
 {
-  return -0.5 * nu_ * log(NumericalComplex(1.0, -2.0 * x));
+  return -0.5 * nu_ * std::log(NumericalComplex(1.0, -2.0 * x));
 }
 
 /* Get the PDFGradient of the distribution */
@@ -200,7 +202,7 @@ NumericalPoint ChiSquare::computePDFGradient(const NumericalPoint & point) const
   const NumericalScalar x(point[0]);
   if (x <= 0.0) return pdfGradient;
   NumericalScalar pdf(computePDF(point));
-  pdfGradient[0] = 0.5 * (log(0.5 * x) - SpecFunc::Psi(0.5 * nu_)) * pdf;
+  pdfGradient[0] = 0.5 * (std::log(0.5 * x) - SpecFunc::Psi(0.5 * nu_)) * pdf;
   return pdfGradient;
 }
 
@@ -212,7 +214,7 @@ NumericalPoint ChiSquare::computeCDFGradient(const NumericalPoint & point) const
   NumericalPoint cdfGradient(1, 0.0);
   const NumericalScalar x(point[0]);
   if (x <= 0.0) return cdfGradient;
-  NumericalScalar eps(pow(cdfEpsilon_, 1.0 / 3.0));
+  NumericalScalar eps(std::pow(cdfEpsilon_, 1.0 / 3.0));
   cdfGradient[0] = (DistFunc::pGamma(0.5 * (nu_ + eps), 0.5 * x) - DistFunc::pGamma(0.5 * (nu_ - eps), 0.5 * x)) / (2.0 * eps);
   return cdfGradient;
 }
@@ -234,13 +236,13 @@ void ChiSquare::computeMean() const
 /* Get the standard deviation of the distribution */
 NumericalPoint ChiSquare::getStandardDeviation() const
 {
-  return NumericalPoint(1, sqrt(2.0 * nu_));
+  return NumericalPoint(1, std::sqrt(2.0 * nu_));
 }
 
 /* Get the skewness of the distribution */
 NumericalPoint ChiSquare::getSkewness() const
 {
-  return NumericalPoint(1, sqrt(8.0 / nu_));
+  return NumericalPoint(1, std::sqrt(8.0 / nu_));
 }
 
 /* Get the kurtosis of the distribution */
@@ -258,9 +260,9 @@ void ChiSquare::computeCovariance() const
 }
 
 /* Get the moments of the standardized distribution */
-NumericalPoint ChiSquare::getStandardMoment(const UnsignedLong n) const
+NumericalPoint ChiSquare::getStandardMoment(const UnsignedInteger n) const
 {
-  return NumericalPoint(1, exp(n * M_LN2 + SpecFunc::LnGamma(n + 0.5 * nu_) - SpecFunc::LnGamma(0.5 * nu_)));
+  return NumericalPoint(1, std::exp(n * M_LN2 + SpecFunc::LnGamma(n + 0.5 * nu_) - SpecFunc::LnGamma(0.5 * nu_)));
 }
 
 /* Parameters value and description accessor */
@@ -279,7 +281,9 @@ ChiSquare::NumericalPointWithDescriptionCollection ChiSquare::getParametersColle
 
 void ChiSquare::setParametersCollection(const NumericalPointCollection & parametersCollection)
 {
+  const NumericalScalar w(getWeight());
   *this = ChiSquare(parametersCollection[0][0]);
+  setWeight(w);
 }
 
 /* Method save() stores the object through the StorageManager */
