@@ -3,7 +3,7 @@
  *  @file  ComposedCopula.cxx
  *  @brief Abstract top-level class for all ComposedCopulas
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -27,8 +27,11 @@
 #include "PersistentObjectFactory.hxx"
 #include "IndependentCopula.hxx"
 #include "Exception.hxx"
+#include "RosenblattEvaluation.hxx"
+#include "InverseRosenblattEvaluation.hxx"
 #include "Log.hxx"
 #include "Normal.hxx"
+#include "NormalCopula.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -41,10 +44,11 @@ static Factory<ComposedCopula> RegisteredFactory("ComposedCopula");
 
 /* Default constructor */
 ComposedCopula::ComposedCopula()
-  : CopulaImplementation("ComposedCopula")
+  : CopulaImplementation()
   , copulaCollection_(0)
   , isIndependent_(false)
 {
+  setName("ComposedCopula");
   setDimension(1);
   CopulaCollection coll(1);
   coll[0] = IndependentCopula(1);
@@ -53,10 +57,11 @@ ComposedCopula::ComposedCopula()
 
 /* Default constructor */
 ComposedCopula::ComposedCopula(const CopulaCollection & coll)
-  : CopulaImplementation("ComposedCopula")
+  : CopulaImplementation()
   , copulaCollection_()
   , isIndependent_(false)
 {
+  setName("ComposedCopula");
   // We assign the copula collection through the accessor in order to compute the composed copula dimension
   setCopulaCollection(coll);
 }
@@ -75,7 +80,7 @@ String ComposedCopula::__repr__() const
   oss << "class=" << ComposedCopula::GetClassName()
       << " name=" << getName()
       << " dimension=" << getDimension();
-  for (UnsignedLong i = 0; i < copulaCollection_.getSize(); ++i)
+  for (UnsignedInteger i = 0; i < copulaCollection_.getSize(); ++i)
     oss << " copula[" << i << "]=" << copulaCollection_[i];
   return oss;
 }
@@ -85,7 +90,7 @@ String ComposedCopula::__str__(const String & offset) const
   OSS oss(false);
   oss << offset << getClassName() << "(";
   String separator("");
-  for (UnsignedLong i = 0; i < copulaCollection_.getSize(); ++i)
+  for (UnsignedInteger i = 0; i < copulaCollection_.getSize(); ++i)
   {
     oss << separator << copulaCollection_[i];
     separator = ", ";
@@ -94,25 +99,28 @@ String ComposedCopula::__str__(const String & offset) const
   return oss;
 }
 
-/* Distribution collection accessor */
+/* Copula collection accessor */
 void ComposedCopula::setCopulaCollection(const CopulaCollection & coll)
 {
   // Check if the collection is not empty
-  const UnsignedLong size(coll.getSize());
+  const UnsignedInteger size(coll.getSize());
   if (size == 0) throw InvalidArgumentException(HERE) << "Collection of distributions is empty";
   copulaCollection_ = coll;
   Description description(0);
-  UnsignedLong dimension(0);
+  UnsignedInteger dimension(0);
   // Compute the dimension, build the description and check the independence
   isIndependent_ = true;
-  for (UnsignedLong i = 0; i < size; ++i)
+  bool isParallel(true);
+  for (UnsignedInteger i = 0; i < size; ++i)
   {
-    const UnsignedLong copulaDimension(coll[i].getDimension());
+    const UnsignedInteger copulaDimension(coll[i].getDimension());
     dimension += copulaDimension;
     const Description copulaDescription(coll[i].getDescription());
-    for (UnsignedLong j = 0; j < copulaDimension; ++j) description.add(copulaDescription[j]);
+    for (UnsignedInteger j = 0; j < copulaDimension; ++j) description.add(copulaDescription[j]);
     isIndependent_ = isIndependent_ && copulaCollection_[i].hasIndependentCopula();
+    isParallel = isParallel && coll[i].getImplementation()->isParallel();
   }
+  setParallel(isParallel);
   isAlreadyComputedCovariance_ = false;
   // One MUST set the dimension BEFORE the description, else an error occurs
   setDimension(dimension);
@@ -136,15 +144,15 @@ ComposedCopula * ComposedCopula::clone() const
 /* Get one realization of the ComposedCopula */
 NumericalPoint ComposedCopula::getRealization() const
 {
-  const UnsignedLong dimension(getDimension());
-  const UnsignedLong size(copulaCollection_.getSize());
+  const UnsignedInteger dimension(getDimension());
+  const UnsignedInteger size(copulaCollection_.getSize());
   NumericalPoint result(dimension);
-  UnsignedLong index(0);
-  for (UnsignedLong i = 0; i < size; ++i)
+  UnsignedInteger index(0);
+  for (UnsignedInteger i = 0; i < size; ++i)
   {
     const NumericalPoint realization(copulaCollection_[i].getRealization());
-    const UnsignedLong copulaDimension(copulaCollection_[i].getDimension());
-    for (UnsignedLong j = 0; j < copulaDimension; ++j)
+    const UnsignedInteger copulaDimension(copulaCollection_[i].getDimension());
+    for (UnsignedInteger j = 0; j < copulaDimension; ++j)
     {
       result[index] = realization[j];
       ++index;
@@ -156,24 +164,24 @@ NumericalPoint ComposedCopula::getRealization() const
 /* Get the DDF of the ComposedCopula */
 NumericalPoint ComposedCopula::computeDDF(const NumericalPoint & point) const
 {
-  const UnsignedLong dimension(getDimension());
+  const UnsignedInteger dimension(getDimension());
   if (point.getDimension() != dimension) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=" << dimension << ", here dimension=" << point.getDimension();
 
   NumericalPoint DDF(getDimension());
-  const UnsignedLong size(copulaCollection_.getSize());
+  const UnsignedInteger size(copulaCollection_.getSize());
   NumericalPoint copulaPDF(size);
   NumericalPointCollection copulaDDF(size);
   NumericalScalar productPDF(1.0);
-  UnsignedLong index(0);
+  UnsignedInteger index(0);
   // First, compute the several elements
-  for (UnsignedLong i = 0; i < size; ++i)
+  for (UnsignedInteger i = 0; i < size; ++i)
   {
     // If one component is outside of the support, the PDF is null
     if ((point[i] <= 0.0) || (point[i] >= 1.0)) return NumericalPoint(dimension);
     const Copula copula(copulaCollection_[i]);
-    const UnsignedLong copulaDimension(copula.getDimension());
+    const UnsignedInteger copulaDimension(copula.getDimension());
     NumericalPoint component(copulaDimension);
-    for (UnsignedLong j = 0; j < copulaDimension; ++j)
+    for (UnsignedInteger j = 0; j < copulaDimension; ++j)
     {
       component[j] = point[index];
       ++index;
@@ -184,11 +192,11 @@ NumericalPoint ComposedCopula::computeDDF(const NumericalPoint & point) const
   }
   // Then, compute the DDF
   index = 0;
-  for (UnsignedLong i = 0; i < size; ++i)
+  for (UnsignedInteger i = 0; i < size; ++i)
   {
     const NumericalPoint currentDDF(copulaDDF[i] * (productPDF / copulaPDF[i]));
-    const UnsignedLong currentDimension(currentDDF.getDimension());
-    for (UnsignedLong j = 0; j < currentDimension; ++j)
+    const UnsignedInteger currentDimension(currentDDF.getDimension());
+    for (UnsignedInteger j = 0; j < currentDimension; ++j)
     {
       DDF[index] = currentDDF[j];
       ++index;
@@ -201,19 +209,19 @@ NumericalPoint ComposedCopula::computeDDF(const NumericalPoint & point) const
 NumericalScalar ComposedCopula::computePDF(const NumericalPoint & point) const
 {
   /* PDF = PDF_copula1x...xPDF_copula_n */
-  const UnsignedLong dimension(getDimension());
+  const UnsignedInteger dimension(getDimension());
+  if (isIndependent_) return IndependentCopula(dimension).computePDF(point);
   if (point.getDimension() != dimension) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=" << dimension << ", here dimension=" << point.getDimension();
-
-  const UnsignedLong size(copulaCollection_.getSize());
+  const UnsignedInteger size(copulaCollection_.getSize());
   NumericalScalar productPDF(1.0);
-  UnsignedLong index(0);
-  for (UnsignedLong i = 0; i < size; ++i)
+  UnsignedInteger index(0);
+  for (UnsignedInteger i = 0; i < size; ++i)
   {
     // If one component is outside of the support, the PDF is null
     if ((point[i] <= 0.0) || (point[i] >= 1.0)) return 0.0;
-    const UnsignedLong copulaDimension(copulaCollection_[i].getDimension());
+    const UnsignedInteger copulaDimension(copulaCollection_[i].getDimension());
     NumericalPoint component(copulaDimension);
-    for (UnsignedLong j = 0; j < copulaDimension; ++j)
+    for (UnsignedInteger j = 0; j < copulaDimension; ++j)
     {
       component[j] = point[index];
       ++index;
@@ -227,22 +235,23 @@ NumericalScalar ComposedCopula::computePDF(const NumericalPoint & point) const
 NumericalScalar ComposedCopula::computeCDF(const NumericalPoint & point) const
 {
   /* CDF = CDF_copula1x...xCDF_copula_n */
-  const UnsignedLong dimension(getDimension());
+  const UnsignedInteger dimension(getDimension());
+  if (isIndependent_) return IndependentCopula(dimension).computeCDF(point);
   if (point.getDimension() != dimension) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=" << dimension << ", here dimension=" << point.getDimension();
 
-  const UnsignedLong size(copulaCollection_.getSize());
+  const UnsignedInteger size(copulaCollection_.getSize());
   NumericalScalar productCDF(1.0);
-  UnsignedLong index(0);
-  for (UnsignedLong i = 0; i < size; ++i)
+  UnsignedInteger index(0);
+  for (UnsignedInteger i = 0; i < size; ++i)
   {
     // If one component is at the left of the support of its matginal distribution, the CDF is null
     if (point[i] <= 0.0) return 0.0;
     // If the component is inside of the support, update the CDF value
     if (point[i] < 1.0)
     {
-      const UnsignedLong copulaDimension(copulaCollection_[i].getDimension());
+      const UnsignedInteger copulaDimension(copulaCollection_[i].getDimension());
       NumericalPoint component(copulaDimension);
-      for (UnsignedLong j = 0; j < copulaDimension; ++j)
+      for (UnsignedInteger j = 0; j < copulaDimension; ++j)
       {
         component[j] = point[index];
         ++index;
@@ -257,7 +266,8 @@ NumericalScalar ComposedCopula::computeCDF(const NumericalPoint & point) const
 /* Compute the probability content of an interval */
 NumericalScalar ComposedCopula::computeProbability(const Interval & interval) const
 {
-  const UnsignedLong dimension(getDimension());
+  const UnsignedInteger dimension(getDimension());
+  if (isIndependent_) return IndependentCopula(dimension).computeProbability(interval);
   if (interval.getDimension() != dimension) throw InvalidArgumentException(HERE) << "Error: the given interval must have dimension=" << dimension << ", here dimension=" << interval.getDimension();
 
   // Reduce the given interval to the support of the distribution, which is the nD unit cube
@@ -266,15 +276,15 @@ NumericalScalar ComposedCopula::computeProbability(const Interval & interval) co
   if (intersect.isNumericallyEmpty()) return 0.0;
   const NumericalPoint lowerIntersect(intersect.getLowerBound());
   const NumericalPoint upperIntersect(intersect.getUpperBound());
-  const UnsignedLong size(copulaCollection_.getSize());
+  const UnsignedInteger size(copulaCollection_.getSize());
   NumericalScalar value(1.0);
-  for (UnsignedLong i = 0; i < size; ++i)
+  for (UnsignedInteger i = 0; i < size; ++i)
   {
     const Copula copula(copulaCollection_[i]);
-    const UnsignedLong copulaDimension(copula.getDimension());
+    const UnsignedInteger copulaDimension(copula.getDimension());
     NumericalPoint lower(copulaDimension);
     NumericalPoint upper(copulaDimension);
-    for (UnsignedLong j = 0; j < copulaDimension; ++j)
+    for (UnsignedInteger j = 0; j < copulaDimension; ++j)
     {
       lower[j] = lowerIntersect[j];
       upper[j] = upperIntersect[j];
@@ -284,110 +294,114 @@ NumericalScalar ComposedCopula::computeProbability(const Interval & interval) co
   return value;
 }
 
-/* Get the Spearman correlation of the distribution */
-CorrelationMatrix ComposedCopula::getSpearmanCorrelation() const
-{
-  const UnsignedLong dimension(getDimension());
-  CorrelationMatrix rho(dimension);
-  const UnsignedLong size(copulaCollection_.getSize());
-  UnsignedLong globalIndex(0);
-  for (UnsignedLong n = 0; n < size; ++n)
-  {
-    const CorrelationMatrix localRho(copulaCollection_[n].getSpearmanCorrelation());
-    const UnsignedLong localSize(localRho.getDimension());
-    for (UnsignedLong i = 0; i < localSize; ++i)
-      for (UnsignedLong j = 0; j < i; ++j)
-        rho(globalIndex + i, globalIndex + j) = localRho(i, j);
-    globalIndex += localSize;
-  }
-  return rho;
-}
-
 /* Get the Kendall concordance of the distribution */
 CorrelationMatrix ComposedCopula::getKendallTau() const
 {
-  const UnsignedLong dimension(getDimension());
+  const UnsignedInteger dimension(getDimension());
   CorrelationMatrix tau(dimension);
-  const UnsignedLong size(copulaCollection_.getSize());
-  UnsignedLong globalIndex(0);
-  for (UnsignedLong n = 0; n < size; ++n)
+  if (isIndependent_) return tau;
+  const UnsignedInteger size(copulaCollection_.getSize());
+  UnsignedInteger globalIndex(0);
+  for (UnsignedInteger n = 0; n < size; ++n)
   {
     const CorrelationMatrix localTau(copulaCollection_[n].getKendallTau());
-    const UnsignedLong localSize(localTau.getDimension());
-    for (UnsignedLong i = 0; i < localSize; ++i)
-      for (UnsignedLong j = 0; j < i; ++j)
+    const UnsignedInteger localSize(localTau.getDimension());
+    for (UnsignedInteger i = 0; i < localSize; ++i)
+      for (UnsignedInteger j = 0; j < i; ++j)
         tau(globalIndex + i, globalIndex + j) = localTau(i, j);
     globalIndex += localSize;
   }
   return tau;
 }
 
+/* Get the shape matrix of the distribution, ie the correlation matrix
+   of its copula if it is elliptical */
+CorrelationMatrix ComposedCopula::getShapeMatrix() const
+{
+  if (!hasEllipticalCopula()) throw NotDefinedException(HERE) << "Error: the shape matrix is defined only for elliptical copulas.";
+  const UnsignedInteger size(copulaCollection_.getSize());
+  if (size == 1) return copulaCollection_[0].getShapeMatrix();
+  const UnsignedInteger dimension(getDimension());
+  CorrelationMatrix shapeMatrix(dimension);
+  UnsignedInteger shift(0);
+  for (UnsignedInteger i = 0; i < size; ++i)
+  {
+    const CorrelationMatrix localShapeMatrix(copulaCollection_[i].getShapeMatrix());
+    const UnsignedInteger localDimension(localShapeMatrix.getDimension());
+    for (UnsignedInteger j = 0; j < localDimension; ++j)
+      for (UnsignedInteger k = 0; k <= j; ++k)
+        shapeMatrix(shift + j, shift + k) = localShapeMatrix(j, k);
+    shift += localDimension;
+  } // i
+  return shapeMatrix;
+}
+
 /* Get the PDF gradient of the distribution */
 NumericalPoint ComposedCopula::computePDFGradient(const NumericalPoint & point) const
 {
-  const UnsignedLong dimension(getDimension());
+  const UnsignedInteger dimension(getDimension());
   if (point.getDimension() != dimension) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=" << dimension << ", here dimension=" << point.getDimension();
 
-  throw NotYetImplementedException(HERE);
+  throw NotYetImplementedException(HERE) << "In ComposedCopula::computePDFGradient(const NumericalPoint & point) const";
 }
 
 /* Get the CDF gradient of the distribution */
 NumericalPoint ComposedCopula::computeCDFGradient(const NumericalPoint & point) const
 {
-  const UnsignedLong dimension(getDimension());
+  const UnsignedInteger dimension(getDimension());
   if (point.getDimension() != dimension) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=" << dimension << ", here dimension=" << point.getDimension();
 
-  throw NotYetImplementedException(HERE);
+  throw NotYetImplementedException(HERE) << "In ComposedCopula::computeCDFGradient(const NumericalPoint & point) const";
 }
 
 /* Compute the PDF of Xi | X1, ..., Xi-1. x = Xi, y = (X1,...,Xi-1) */
 NumericalScalar ComposedCopula::computeConditionalPDF(const NumericalScalar x, const NumericalPoint & y) const
 {
-  const UnsignedLong conditioningDimension(y.getDimension());
+  const UnsignedInteger conditioningDimension(y.getDimension());
   if (conditioningDimension >= getDimension()) throw InvalidArgumentException(HERE) << "Error: cannot compute a conditional PDF with a conditioning point of dimension greater or equal to the distribution dimension.";
   // Special case for no conditioning or independent copula
   if ((conditioningDimension == 0) || (hasIndependentCopula())) return (x < 0.0 ? 0.0 : x > 1.0 ? 0.0 : 1);
   // General case
-  UnsignedLong copulaIndex(0);
-  UnsignedLong partialDimension(copulaCollection_[copulaIndex].getDimension());
+  UnsignedInteger copulaIndex(0);
+  UnsignedInteger partialDimension(copulaCollection_[copulaIndex].getDimension());
   while (partialDimension < conditioningDimension)
   {
     ++copulaIndex;
     partialDimension += copulaCollection_[copulaIndex].getDimension();
   }
   // Extract the relevant part of the conditioning
-  const UnsignedLong conditioningSize(partialDimension - conditioningDimension);
+  const UnsignedInteger conditioningSize(partialDimension - conditioningDimension);
   NumericalPoint conditioningVector(conditioningSize);
-  for (UnsignedLong i = 0; i < conditioningSize; ++i) conditioningVector[i] = y[conditioningDimension - conditioningSize + i];
+  for (UnsignedInteger i = 0; i < conditioningSize; ++i) conditioningVector[i] = y[conditioningDimension - conditioningSize + i];
   return copulaCollection_[copulaIndex].computeConditionalPDF(x, conditioningVector);
 }
 
 /* Compute the CDF of Xi | X1, ..., Xi-1. x = Xi, y = (X1,...,Xi-1) */
 NumericalScalar ComposedCopula::computeConditionalCDF(const NumericalScalar x, const NumericalPoint & y) const
 {
-  const UnsignedLong conditioningDimension(y.getDimension());
+  const UnsignedInteger conditioningDimension(y.getDimension());
   if (conditioningDimension >= getDimension()) throw InvalidArgumentException(HERE) << "Error: cannot compute a conditional PDF with a conditioning point of dimension greater or equal to the distribution dimension.";
   // Special case for no conditioning or independent copula
   if ((conditioningDimension == 0) || (hasIndependentCopula())) return std::min(1.0, std::max(0.0, x));
   // General case
-  UnsignedLong copulaIndex(0);
-  UnsignedLong partialDimension(copulaCollection_[copulaIndex].getDimension());
+  UnsignedInteger copulaIndex(0);
+  UnsignedInteger partialDimension(copulaCollection_[copulaIndex].getDimension());
   while (partialDimension < conditioningDimension)
   {
     ++copulaIndex;
     partialDimension += copulaCollection_[copulaIndex].getDimension();
   }
   // Extract the relevant part of the conditioning
-  const UnsignedLong conditioningSize(partialDimension - conditioningDimension);
+  const UnsignedInteger conditioningSize(partialDimension - conditioningDimension);
   NumericalPoint conditioningVector(conditioningSize);
-  for (UnsignedLong i = 0; i < conditioningSize; ++i) conditioningVector[i] = y[conditioningDimension - conditioningSize + i];
+  for (UnsignedInteger i = 0; i < conditioningSize; ++i) conditioningVector[i] = y[conditioningDimension - conditioningSize + i];
   return copulaCollection_[copulaIndex].computeConditionalCDF(x, conditioningVector);
 }
 
 /* Compute the quantile of Xi | X1, ..., Xi-1, i.e. x such that CDF(x|y) = q with x = Xi, y = (X1,...,Xi-1) */
 NumericalScalar ComposedCopula::computeConditionalQuantile(const NumericalScalar q, const NumericalPoint & y) const
 {
-  const UnsignedLong conditioningDimension(y.getDimension());
+  const UnsignedInteger conditioningDimension(y.getDimension());
   if (conditioningDimension == 0) return q;
   if (conditioningDimension >= getDimension()) throw InvalidArgumentException(HERE) << "Error: cannot compute a conditional quantile with a conditioning point of dimension greater or equal to the distribution dimension.";
   if (conditioningDimension == 0) return q;
@@ -395,17 +409,17 @@ NumericalScalar ComposedCopula::computeConditionalQuantile(const NumericalScalar
   if (q == 0.0) return 0.0;
   if (q == 1.0) return 1.0;
   // General case
-  UnsignedLong copulaIndex(0);
-  UnsignedLong partialDimension(copulaCollection_[copulaIndex].getDimension());
+  UnsignedInteger copulaIndex(0);
+  UnsignedInteger partialDimension(copulaCollection_[copulaIndex].getDimension());
   while (partialDimension < conditioningDimension)
   {
     ++copulaIndex;
     partialDimension += copulaCollection_[copulaIndex].getDimension();
   }
   // Extract the relevant part of the conditioning
-  const UnsignedLong conditioningSize(partialDimension - conditioningDimension);
+  const UnsignedInteger conditioningSize(partialDimension - conditioningDimension);
   NumericalPoint conditioningVector(conditioningSize);
-  for (UnsignedLong i = 0; i < conditioningSize; ++i)
+  for (UnsignedInteger i = 0; i < conditioningSize; ++i)
   {
     conditioningVector[i] = y[conditioningDimension - conditioningSize + i];
   }
@@ -423,19 +437,19 @@ NumericalScalar ComposedCopula::computeConditionalQuantile(const NumericalScalar
 */
 ComposedCopula::Implementation ComposedCopula::getMarginal(const Indices & indices) const
 {
-  const UnsignedLong dimension(getDimension());
+  const UnsignedInteger dimension(getDimension());
   if (!indices.check(dimension - 1)) throw InvalidArgumentException(HERE) << "Error: the indices of a marginal distribution must be in the range [0, dim-1] and  must be different";
   CopulaCollection marginalCopulas;
-  const UnsignedLong indicesSize(indices.getSize());
-  const UnsignedLong size(copulaCollection_.getSize());
+  const UnsignedInteger indicesSize(indices.getSize());
+  const UnsignedInteger size(copulaCollection_.getSize());
   // For each copula, see if there is something to extract
-  UnsignedLong currentPosition(0);
-  UnsignedLong currentIndex(indices[currentPosition]);
+  UnsignedInteger currentPosition(0);
+  UnsignedInteger currentIndex(indices[currentPosition]);
   // Lower bound of indices related to the current copula
-  UnsignedLong lowerIndex(0);
+  UnsignedInteger lowerIndex(0);
   // Upper bound of indices related to the current copula plus 1
-  UnsignedLong upperIndex(0);
-  for (UnsignedLong i = 0; i < size; ++i)
+  UnsignedInteger upperIndex(0);
+  for (UnsignedInteger i = 0; i < size; ++i)
   {
     const Copula copula(copulaCollection_[i]);
     // Update index range for the current copula
@@ -469,16 +483,16 @@ ComposedCopula::NumericalPointWithDescriptionCollection ComposedCopula::getParam
   // Put the dependence parameters
   NumericalPointWithDescription point(0);
   Description description(0);
-  const UnsignedLong size(copulaCollection_.getSize());
-  for (UnsignedLong i = 0; i < size; ++i)
+  const UnsignedInteger size(copulaCollection_.getSize());
+  for (UnsignedInteger i = 0; i < size; ++i)
   {
     // All distributions, including copulas, must output a collection of NumericalPoint of size at least 1,
     // even if the NumericalPoint are empty
     const NumericalPointWithDescription copulaParameters(copulaCollection_[i].getParametersCollection()[0]);
     const Description parametersDescription(copulaParameters.getDescription());
     const String copulaName(copulaCollection_[i].getName());
-    const UnsignedLong parameterDimension(copulaParameters.getDimension());
-    for (UnsignedLong j = 0; j < parameterDimension; ++j)
+    const UnsignedInteger parameterDimension(copulaParameters.getDimension());
+    for (UnsignedInteger j = 0; j < parameterDimension; ++j)
     {
       point.add(copulaParameters[j]);
       description.add(OSS() << "copula_" << i << "_" << parametersDescription[j]);
@@ -496,18 +510,18 @@ void ComposedCopula::setParametersCollection(const NumericalPointCollection & pa
   if (parametersCollection.getSize() != 1) throw InvalidArgumentException(HERE) << "Error: the given collection has a size=" << parametersCollection.getSize() << " but should be of size=1";
   // Dependence parameters
   const NumericalPoint parameters(parametersCollection[0]);
-  const UnsignedLong parametersDimension(parameters.getDimension());
+  const UnsignedInteger parametersDimension(parameters.getDimension());
   // Index within the given parametersCollection
-  UnsignedLong globalIndex(0);
-  const UnsignedLong size(copulaCollection_.getSize());
-  for (UnsignedLong i = 0; i < size; ++i)
+  UnsignedInteger globalIndex(0);
+  const UnsignedInteger size(copulaCollection_.getSize());
+  for (UnsignedInteger i = 0; i < size; ++i)
   {
     // All distributions, including copulas, must output a collection of NumericalPoint of size at least 1,
     // even if the NumericalPoint are empty
-    const UnsignedLong atomParametersDimension(copulaCollection_[i].getParametersCollection()[0].getDimension());
+    const UnsignedInteger atomParametersDimension(copulaCollection_[i].getParametersCollection()[0].getDimension());
     // ith copula parameters
     NumericalPoint point(atomParametersDimension);
-    for (UnsignedLong j = 0; j < atomParametersDimension; ++j)
+    for (UnsignedInteger j = 0; j < atomParametersDimension; ++j)
     {
       if (globalIndex >= parametersDimension) throw InvalidArgumentException(HERE) << "Error: there are too few dependence parameters";
       point[j] = parameters[globalIndex];
@@ -521,7 +535,15 @@ void ComposedCopula::setParametersCollection(const NumericalPointCollection & pa
 /* Tell if the distribution has elliptical copula */
 Bool ComposedCopula::hasEllipticalCopula() const
 {
-  return isIndependent_;
+  // The copula is elliptical either because it is based on a unique elliptical copula or it is composed of normal copulas
+  const UnsignedInteger size(copulaCollection_.getSize());
+  // If there is only one copula in the collection, check if it has an elliptical copula
+  if (size == 1) return copulaCollection_[0].hasEllipticalCopula();
+  // Else, check if all the copulas are normal copulas. We cannot check it in the most general case (eg a SklarCopula built upon a normal distribution).
+  const String normalCopulaName(NormalCopula::GetClassName());
+  for (UnsignedInteger i = 0; i < size; ++i)
+    if (copulaCollection_[i].getImplementation()->getClassName() != normalCopulaName) return false;
+  return true;
 }
 
 /* Tell if the distribution has independent copula */
@@ -530,11 +552,84 @@ Bool ComposedCopula::hasIndependentCopula() const
   return isIndependent_;
 }
 
+/* Get the isoprobabilist transformation */
+ComposedCopula::IsoProbabilisticTransformation ComposedCopula::getIsoProbabilisticTransformation() const
+{
+  // First special case: the copula is independent
+  const UnsignedInteger dimension(getDimension());
+  if (isIndependent_) return IndependentCopula(dimension).getIsoProbabilisticTransformation();
+  const UnsignedInteger size(copulaCollection_.getSize());
+  // Second special case: only one copula in the collection
+  if (size == 1) return copulaCollection_[0].getIsoProbabilisticTransformation();
+  // General case: return the transformation as an aggregated function of pre/post processed isoprobabilistic transformations built using the elementary copulas. These transformations are the isoprobabilistic transformations of the elementary copulas if they lead to the standard Normal space, else a Rosenblatt transformation is substituted
+  const Description allVariables(Description::BuildDefault(dimension, "x"));
+  UnsignedInteger shift(0);
+  Collection< NumericalMathFunction > atomTransformations(size);
+  for (UnsignedInteger i = 0; i < size; ++i)
+  {
+    // First, build the mapping between the full components and the components of the current copula
+    const UnsignedInteger atomDimension(copulaCollection_[i].getDimension());
+    Description atomVariables(atomDimension);
+    for (UnsignedInteger j = 0; j < atomDimension; ++j) atomVariables[j] = allVariables[shift + j];
+    const NumericalMathFunction projection(allVariables, atomVariables);
+    // Second, check if the isoprobabilistic transformation associated with the current copula maps to a Normal standard distribution
+    if (copulaCollection_[i].getStandardDistribution().hasIndependentCopula()) atomTransformations[i] = NumericalMathFunction(copulaCollection_[i].getIsoProbabilisticTransformation(), projection);
+    else atomTransformations[i] = NumericalMathFunction(RosenblattEvaluation(copulaCollection_[i]), projection);
+  }
+  return NumericalMathFunction(atomTransformations);
+}
+
+/* Get the inverse isoprobabilist transformation */
+ComposedCopula::InverseIsoProbabilisticTransformation ComposedCopula::getInverseIsoProbabilisticTransformation() const
+{
+  // First special case: the copula is independent
+  const UnsignedInteger dimension(getDimension());
+  if (isIndependent_) return IndependentCopula(dimension).getInverseIsoProbabilisticTransformation();
+  const UnsignedInteger size(copulaCollection_.getSize());
+  // Special case: only one copula in the collection
+  if (size == 1) return copulaCollection_[0].getInverseIsoProbabilisticTransformation();
+  // General case: return the transformation as an aggregated function of pre/post processed isoprobabilistic transformations built using the elementary copulas. These transformations are the isoprobabilistic transformations of the elementary copulas if they lead to the standard Normal space, else a Rosenblatt transformation is substituted
+  const Description allVariables(Description::BuildDefault(dimension, "x"));
+  UnsignedInteger shift(0);
+  Collection< NumericalMathFunction > atomTransformations(size);
+  for (UnsignedInteger i = 0; i < size; ++i)
+  {
+    // First, build the mapping between the full components and the components of the current copula
+    const UnsignedInteger atomDimension(copulaCollection_[i].getDimension());
+    Description atomVariables(atomDimension);
+    for (UnsignedInteger j = 0; j < atomDimension; ++j) atomVariables[j] = allVariables[shift + j];
+    const NumericalMathFunction projection(allVariables, atomVariables);
+    // Second, check if the isoprobabilistic transformation associated with the current copula maps to a Normal standard distribution
+    if (copulaCollection_[i].getStandardDistribution().hasIndependentCopula()) atomTransformations[i] = NumericalMathFunction(copulaCollection_[i].getInverseIsoProbabilisticTransformation(), projection);
+    else atomTransformations[i] = NumericalMathFunction(InverseRosenblattEvaluation(copulaCollection_[i]), projection);
+  }
+  return NumericalMathFunction(atomTransformations);
+}
+
+/* Compute the covariance of the distribution */
+void ComposedCopula::computeCovariance() const
+{
+  const UnsignedInteger dimension(getDimension());
+  covariance_ = CovarianceMatrix(dimension);
+  UnsignedInteger shift(0);
+  for (UnsignedInteger i = 0; i < copulaCollection_.getSize(); ++i)
+  {
+    const CovarianceMatrix localCovariance(copulaCollection_[i].getCovariance());
+    const UnsignedInteger localDimension(localCovariance.getDimension());
+    for (UnsignedInteger j = 0; j < localDimension; ++j)
+      for (UnsignedInteger k = 0; k <= j; ++k)
+        covariance_(shift + j, shift + k) = localCovariance(j, k);
+    shift += localDimension;
+  } // i
+  isAlreadyComputedCovariance_ = true;
+}
+
 /* Method save() stores the object through the StorageManager */
 void ComposedCopula::save(Advocate & adv) const
 {
   CopulaImplementation::save(adv);
   adv.saveAttribute( "copulaCollection_", copulaCollection_ );
+  adv.saveAttribute( "isIndependent_", isIndependent_ );
 }
 
 /* Method load() reloads the object from the StorageManager */
@@ -542,6 +637,7 @@ void ComposedCopula::load(Advocate & adv)
 {
   CopulaImplementation::load(adv);
   adv.loadAttribute( "copulaCollection_", copulaCollection_ );
+  adv.loadAttribute( "isIndependent_", isIndependent_ );
   computeRange();
 }
 
