@@ -3,7 +3,7 @@
  *  @file  Dirac.cxx
  *  @brief The Dirac distribution
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -35,9 +35,10 @@ static Factory<Dirac> RegisteredFactory("Dirac");
 
 /* Default constructor */
 Dirac::Dirac()
-  : DiscreteDistribution("Dirac"),
-    point_(1, 0.0)
+  : DiscreteDistribution()
+  , point_(1, 0.0)
 {
+  setName( "Dirac" );
   // We set the dimension of the Dirac distribution
   setDimension( 1 );
   computeRange();
@@ -45,9 +46,10 @@ Dirac::Dirac()
 
 /* Parameters constructor */
 Dirac::Dirac(const NumericalScalar p)
-  : DiscreteDistribution("Dirac"),
-    point_(1, p)
+  : DiscreteDistribution()
+  , point_(1, p)
 {
+  setName( "Dirac" );
   // We set the dimension of the Dirac distribution
   setDimension( 1 );
   computeRange();
@@ -55,9 +57,10 @@ Dirac::Dirac(const NumericalScalar p)
 
 /* Parameters constructor */
 Dirac::Dirac(const NumericalPoint & point)
-  : DiscreteDistribution("Dirac"),
-    point_(point)
+  : DiscreteDistribution()
+  , point_(point)
 {
+  setName( "Dirac" );
   // We set the dimension of the Dirac distribution
   setDimension( point.getDimension() );
   computeRange();
@@ -84,7 +87,7 @@ String Dirac::__repr__() const
 String Dirac::__str__(const String & offset) const
 {
   OSS oss;
-  oss << offset << getClassName() << "(point = " << point_ << ")";
+  oss << offset << getClassName() << "(point = " << point_.__str__() << ")";
   return oss;
 }
 
@@ -100,11 +103,16 @@ NumericalPoint Dirac::getRealization() const
   return point_;
 }
 
+/* Get a sample of the distribution */
+NumericalSample Dirac::getSample(const UnsignedInteger size) const
+{
+  return NumericalSample(size, point_);
+}
 
 /* Get the PDF of the distribution */
 NumericalScalar Dirac::computePDF(const NumericalPoint & point) const
 {
-  const UnsignedLong dimension(getDimension());
+  const UnsignedInteger dimension(getDimension());
   if (point.getDimension() != dimension) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=" << dimension << ", here dimension=" << point.getDimension();
 
   if ((point - point_).norm() <= supportEpsilon_) return 1.0;
@@ -115,11 +123,11 @@ NumericalScalar Dirac::computePDF(const NumericalPoint & point) const
 /* Get the CDF of the distribution */
 NumericalScalar Dirac::computeCDF(const NumericalPoint & point) const
 {
-  const UnsignedLong dimension(getDimension());
+  const UnsignedInteger dimension(getDimension());
   if (point.getDimension() != dimension) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=" << dimension << ", here dimension=" << point.getDimension();
 
   // If at least one component is too small
-  for (UnsignedLong i = 0; i < dimension; ++i) if (point_[i] > point[i]) return 0.0;
+  for (UnsignedInteger i = 0; i < dimension; ++i) if (point_[i] > point[i]) return 0.0;
   return 1.0;
 }
 
@@ -133,20 +141,20 @@ NumericalPoint Dirac::computeQuantile(const NumericalScalar prob,
 /* Get the PDF gradient of the distribution */
 NumericalPoint Dirac::computePDFGradient(const NumericalPoint & point) const
 {
-  const UnsignedLong dimension(getDimension());
+  const UnsignedInteger dimension(getDimension());
   if (point.getDimension() != dimension) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=" << dimension << ", here dimension=" << point.getDimension();
 
-  throw NotYetImplementedException(HERE);
+  throw NotYetImplementedException(HERE) << "In Dirac::computePDFGradient(const NumericalPoint & point) const";
 }
 
 
 /* Get the CDF gradient of the distribution */
 NumericalPoint Dirac::computeCDFGradient(const NumericalPoint & point) const
 {
-  const UnsignedLong dimension(getDimension());
+  const UnsignedInteger dimension(getDimension());
   if (point.getDimension() != dimension) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=" << dimension << ", here dimension=" << point.getDimension();
 
-  throw NotYetImplementedException(HERE);
+  throw NotYetImplementedException(HERE) << "In Dirac::computeCDFGradient(const NumericalPoint & point) const";
 }
 
 /* Get the quantile of the distribution */
@@ -159,12 +167,12 @@ NumericalScalar Dirac::computeScalarQuantile(const NumericalScalar prob,
 /* Get the characteristic function of the distribution, i.e. phi(u) = E(exp(I*u*X)) */
 NumericalComplex Dirac::computeCharacteristicFunction(const NumericalScalar u) const
 {
-  return exp(computeLogCharacteristicFunction(u));
+  return std::exp(computeLogCharacteristicFunction(u));
 }
 
 NumericalComplex Dirac::computeLogCharacteristicFunction(const NumericalScalar u) const
 {
-  if (getDimension() != 1) throw NotYetImplementedException(HERE) << "Error: the computeCharacteristicFunction() method is implemented for 1D distributions only.";
+  if (getDimension() != 1) throw NotYetImplementedException(HERE) << "In Dirac::computeLogCharacteristicFunction(const NumericalScalar u) const: the computeCharacteristicFunction() method is implemented for 1D distributions only.";
   const NumericalComplex value(0.0, u * point_[0]);
   return value;
 }
@@ -172,13 +180,13 @@ NumericalComplex Dirac::computeLogCharacteristicFunction(const NumericalScalar u
 /* Get the generating function of the distribution, i.e. psi(z) = E(z^X) */
 NumericalComplex Dirac::computeGeneratingFunction(const NumericalComplex & z) const
 {
-  return exp(computeLogGeneratingFunction(z));
+  return std::exp(computeLogGeneratingFunction(z));
 }
 
 NumericalComplex Dirac::computeLogGeneratingFunction(const NumericalComplex & z) const
 {
-  if (getDimension() != 1) throw NotYetImplementedException(HERE) << "Error: the computeGeneratingFunction() method is implemented for 1D distributions only.";
-  return point_[0] * log(z);
+  if (getDimension() != 1) throw NotYetImplementedException(HERE) << "In Dirac::computeLogGeneratingFunction(const NumericalComplex & z) const: the computeGeneratingFunction() method is implemented for 1D distributions only.";
+  return point_[0] * std::log(z);
 }
 
 /* Compute the mean of the distribution */
@@ -207,11 +215,11 @@ NumericalPoint Dirac::getKurtosis() const
 }
 
 /* Get the moments of the standardized distribution */
-NumericalPoint Dirac::getStandardMoment(const UnsignedLong n) const
+NumericalPoint Dirac::getStandardMoment(const UnsignedInteger n) const
 {
-  const UnsignedLong dimension(getDimension());
+  const UnsignedInteger dimension(getDimension());
   NumericalPoint result(dimension);
-  for (UnsignedLong i = 0; i < dimension; ++i) result[i] = pow(point_[i], n);
+  for (UnsignedInteger i = 0; i < dimension; ++i) result[i] = std::pow(point_[i], static_cast<int>(n));
   return result;
 }
 
@@ -233,9 +241,9 @@ NumericalSample Dirac::getSupport(const Interval & interval) const
 /* Parameters value and description accessor */
 Dirac::NumericalPointWithDescriptionCollection Dirac::getParametersCollection() const
 {
-  const UnsignedLong dimension(getDimension());
+  const UnsignedInteger dimension(getDimension());
   NumericalPointWithDescriptionCollection parameters(dimension);
-  for (UnsignedLong i = 0; i < dimension; ++i)
+  for (UnsignedInteger i = 0; i < dimension; ++i)
   {
     NumericalPointWithDescription point(1);
     Description description(point.getDimension());
@@ -250,13 +258,15 @@ Dirac::NumericalPointWithDescriptionCollection Dirac::getParametersCollection()
 
 void Dirac::setParametersCollection(const NumericalPointCollection & parametersCollection)
 {
-  const UnsignedLong dimension(parametersCollection.getSize());
+  const NumericalScalar w(getWeight());
+  const UnsignedInteger dimension(parametersCollection.getSize());
   NumericalPoint point(dimension);
   // The ith component of the point is supposed to be the first component of the point
   // at position i in the parameters collection
-  for (UnsignedLong i = 0; i < dimension; ++i)
+  for (UnsignedInteger i = 0; i < dimension; ++i)
     point[i] = parametersCollection[i][0];
   *this = Dirac(point);
+  setWeight(w);
 }
 
 /* Point accessor */
@@ -282,9 +292,9 @@ void Dirac::computeRange()
 }
 
 /* Get the i-th marginal distribution */
-Dirac::Implementation Dirac::getMarginal(const UnsignedLong i) const
+Dirac::Implementation Dirac::getMarginal(const UnsignedInteger i) const
 {
-  const UnsignedLong dimension(getDimension());
+  const UnsignedInteger dimension(getDimension());
   if (i >= dimension) throw InvalidArgumentException(HERE) << "The index of a marginal distribution must be in the range [0, dim-1]";
   if (dimension == 1) return clone();
   return new Dirac(point_[i]);
@@ -293,12 +303,12 @@ Dirac::Implementation Dirac::getMarginal(const UnsignedLong i) const
 /* Get the distribution of the marginal distribution corresponding to indices dimensions */
 Dirac::Implementation Dirac::getMarginal(const Indices & indices) const
 {
-  const UnsignedLong dimension(getDimension());
+  const UnsignedInteger dimension(getDimension());
   if (!indices.check(dimension - 1)) throw InvalidArgumentException(HERE) << "The indices of a marginal distribution must be in the range [0, dim-1] and  must be different";
   if (dimension == 1) return clone();
-  const UnsignedLong outputDimension(indices.getSize());
+  const UnsignedInteger outputDimension(indices.getSize());
   NumericalPoint pointMarginal(outputDimension);
-  for (UnsignedLong i = 0; i < outputDimension; ++i) pointMarginal[i] = point_[indices[i]];
+  for (UnsignedInteger i = 0; i < outputDimension; ++i) pointMarginal[i] = point_[indices[i]];
   return new Dirac(pointMarginal);
 } // getMarginal(Indices)
 
