@@ -3,7 +3,7 @@
  *  @file  Exponential.cxx
  *  @brief The Exponential distribution
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -35,10 +35,11 @@ static Factory<Exponential> RegisteredFactory("Exponential");
 
 /* Default constructor */
 Exponential::Exponential()
-  : ContinuousDistribution("Exponential"),
-    lambda_(1.0),
-    gamma_(0.0)
+  : ContinuousDistribution()
+  , lambda_(1.0)
+  , gamma_(0.0)
 {
+  setName( "Exponential" );
   setDimension( 1 );
   computeRange();
 }
@@ -46,10 +47,11 @@ Exponential::Exponential()
 /* Parameters constructor */
 Exponential::Exponential(const NumericalScalar lambda,
                          const NumericalScalar gamma)
-  : ContinuousDistribution("Exponential"),
-    lambda_(0.0),
-    gamma_(gamma)
+  : ContinuousDistribution()
+  , lambda_(0.0)
+  , gamma_(gamma)
 {
+  setName( "Exponential" );
   // We set the dimension of the Exponential distribution
   setDimension( 1 );
   // This call check lambda and set also the range.
@@ -91,7 +93,7 @@ Exponential * Exponential::clone() const
 /* Get one realization of the distribution */
 NumericalPoint Exponential::getRealization() const
 {
-  return NumericalPoint(1, gamma_ - log(RandomGenerator::Generate()) / lambda_);
+  return NumericalPoint(1, gamma_ - std::log(RandomGenerator::Generate()) / lambda_);
 }
 
 
@@ -112,7 +114,7 @@ NumericalScalar Exponential::computePDF(const NumericalPoint & point) const
 
   const NumericalScalar x(point[0] - gamma_);
   if (x < 0.0) return 0.0;
-  return lambda_ * exp(-lambda_ * x);
+  return lambda_ * std::exp(-lambda_ * x);
 }
 
 NumericalScalar Exponential::computeLogPDF(const NumericalPoint & point) const
@@ -121,7 +123,7 @@ NumericalScalar Exponential::computeLogPDF(const NumericalPoint & point) const
 
   const NumericalScalar x(point[0] - gamma_);
   if (x < 0.0) return -SpecFunc::MaxNumericalScalar;
-  return log(lambda_) - lambda_ * x;
+  return std::log(lambda_) - lambda_ * x;
 }
 
 /* Get the CDF of the distribution */
@@ -141,18 +143,18 @@ NumericalScalar Exponential::computeComplementaryCDF(const NumericalPoint & poin
 
   const NumericalScalar x(point[0] - gamma_);
   if (x < 0.0) return 1.0;
-  return exp(-lambda_ * x);
+  return std::exp(-lambda_ * x);
 }
 
 /* Get the characteristic function of the distribution, i.e. phi(u) = E(exp(I*u*X)) */
 NumericalComplex Exponential::computeCharacteristicFunction(const NumericalScalar x) const
 {
-  return exp(NumericalComplex(0.0, x * gamma_)) / NumericalComplex(1.0, -x / lambda_);
+  return std::exp(NumericalComplex(0.0, x * gamma_)) / NumericalComplex(1.0, -x / lambda_);
 }
 
 NumericalComplex Exponential::computeLogCharacteristicFunction(const NumericalScalar x) const
 {
-  return NumericalComplex(0.0, x * gamma_) - log(NumericalComplex(1.0, - x / lambda_));
+  return NumericalComplex(0.0, x * gamma_) - std::log(NumericalComplex(1.0, - x / lambda_));
 }
 
 /* Get the PDFGradient of the distribution */
@@ -163,7 +165,7 @@ NumericalPoint Exponential::computePDFGradient(const NumericalPoint & point) con
   const NumericalScalar x(point[0] - gamma_);
   NumericalPoint pdfGradient(2, 0.0);
   if (x < 0.0) return pdfGradient;
-  const NumericalScalar expX(exp(-lambda_ * x));
+  const NumericalScalar expX(std::exp(-lambda_ * x));
   pdfGradient[0] = (1.0 - lambda_ * x) * expX;
   pdfGradient[1] = lambda_ * lambda_ * expX;
   return pdfGradient;
@@ -177,7 +179,7 @@ NumericalPoint Exponential::computeCDFGradient(const NumericalPoint & point) con
   const NumericalScalar x(point[0] - gamma_);
   NumericalPoint cdfGradient(2, 0.0);
   if (x < 0.0) return cdfGradient;
-  const NumericalScalar expX(exp(-lambda_ * x));
+  const NumericalScalar expX(std::exp(-lambda_ * x));
   cdfGradient[0] = x * expX;
   cdfGradient[1] = -lambda_ * expX;
   return cdfGradient;
@@ -187,7 +189,7 @@ NumericalPoint Exponential::computeCDFGradient(const NumericalPoint & point) con
 NumericalScalar Exponential::computeScalarQuantile(const NumericalScalar prob,
     const Bool tail) const
 {
-  if (tail) return gamma_ - log(prob) / lambda_;
+  if (tail) return gamma_ - std::log(prob) / lambda_;
   return gamma_ - log1p(-prob) / lambda_;
 }
 
@@ -225,7 +227,7 @@ void Exponential::computeCovariance() const
 }
 
 /* Get the moments of the standardized distribution */
-NumericalPoint Exponential::getStandardMoment(const UnsignedLong n) const
+NumericalPoint Exponential::getStandardMoment(const UnsignedInteger n) const
 {
   return NumericalPoint(1, SpecFunc::Gamma(n + 1));
 }
@@ -254,7 +256,9 @@ Exponential::NumericalPointWithDescriptionCollection Exponential::getParametersC
 
 void Exponential::setParametersCollection(const NumericalPointCollection & parametersCollection)
 {
+  const NumericalScalar w(getWeight());
   *this = Exponential(parametersCollection[0][0], parametersCollection[0][1]);
+  setWeight(w);
 }
 
 /* Lambda accessor */
