@@ -3,7 +3,7 @@
  *  @file  FarlieGumbelMorgensternCopula.cxx
  *  @brief The FarlieGumbelMorgensternCopula distribution
  *
- *  (C) Copyright 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -35,18 +35,20 @@ static Factory<FarlieGumbelMorgensternCopula> RegisteredFactory("FarlieGumbelMor
 
 /* Default constructor */
 FarlieGumbelMorgensternCopula::FarlieGumbelMorgensternCopula()
-  : CopulaImplementation("FarlieGumbelMorgensternCopula"),
-    theta_(0.0)
+  : CopulaImplementation()
+  , theta_(1.0)
 {
+  setName( "FarlieGumbelMorgensternCopula" );
   setDimension( 2 );
   computeRange();
 }
 
 /* Parameters constructor */
 FarlieGumbelMorgensternCopula::FarlieGumbelMorgensternCopula(const NumericalScalar theta)
-  : CopulaImplementation("FarlieGumbelMorgensternCopula"),
-    theta_(0.0)
+  : CopulaImplementation()
+  , theta_(0.0)
 {
+  setName( "FarlieGumbelMorgensternCopula" );
   // Check the value of theta
   setTheta(theta);
   // We set the dimension of the FarlieGumbelMorgensternCopula distribution
@@ -94,7 +96,7 @@ NumericalPoint FarlieGumbelMorgensternCopula::getRealization() const
 /* Get the DDF of the distribution */
 NumericalPoint FarlieGumbelMorgensternCopula::computeDDF(const NumericalPoint & point) const
 {
-  const UnsignedLong dimension(getDimension());
+  const UnsignedInteger dimension(getDimension());
   if (point.getDimension() != dimension) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=" << dimension << ", here dimension=" << point.getDimension();
 
   const NumericalScalar u(point[0]);
@@ -113,7 +115,7 @@ NumericalPoint FarlieGumbelMorgensternCopula::computeDDF(const NumericalPoint &
 /* Get the PDF of the distribution */
 NumericalScalar FarlieGumbelMorgensternCopula::computePDF(const NumericalPoint & point) const
 {
-  const UnsignedLong dimension(getDimension());
+  const UnsignedInteger dimension(getDimension());
   if (point.getDimension() != dimension) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=" << dimension << ", here dimension=" << point.getDimension();
 
   const NumericalScalar u(point[0]);
@@ -129,7 +131,7 @@ NumericalScalar FarlieGumbelMorgensternCopula::computePDF(const NumericalPoint &
 /* Get the CDF of the distribution */
 NumericalScalar FarlieGumbelMorgensternCopula::computeCDF(const NumericalPoint & point) const
 {
-  const UnsignedLong dimension(getDimension());
+  const UnsignedInteger dimension(getDimension());
   if (point.getDimension() != dimension) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=" << dimension << ", here dimension=" << point.getDimension();
 
   const NumericalScalar u(point[0]);
@@ -146,12 +148,14 @@ NumericalScalar FarlieGumbelMorgensternCopula::computeCDF(const NumericalPoint &
   return u * v * (1.0 + theta_ * (1.0 - u) * (1.0 - v));
 }
 
-/* Get the Spearman correlation of the distribution */
-CorrelationMatrix FarlieGumbelMorgensternCopula::getSpearmanCorrelation() const
+/* Compute the covariance of the distribution */
+void FarlieGumbelMorgensternCopula::computeCovariance() const
 {
-  CorrelationMatrix rho(2);
-  rho(0, 1) = theta_ / 3.0;
-  return rho;
+  covariance_ = CovarianceMatrix(2);
+  covariance_(0, 0) = 1.0 / 12.0;
+  covariance_(0, 1) = theta_ / 36.0;
+  covariance_(1, 1) = 1.0 / 12.0;
+  isAlreadyComputedCovariance_ = true;
 }
 
 /* Get the Kendall concordance of the distribution */
@@ -165,7 +169,7 @@ CorrelationMatrix FarlieGumbelMorgensternCopula::getKendallTau() const
 /* Get the PDFGradient of the distribution */
 NumericalPoint FarlieGumbelMorgensternCopula::computePDFGradient(const NumericalPoint & point) const
 {
-  const UnsignedLong dimension(getDimension());
+  const UnsignedInteger dimension(getDimension());
   if (point.getDimension() != dimension) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=" << dimension << ", here dimension=" << point.getDimension();
 
   const NumericalScalar u(point[0]);
@@ -181,7 +185,7 @@ NumericalPoint FarlieGumbelMorgensternCopula::computePDFGradient(const Numerical
 /* Get the CDFGradient of the distribution */
 NumericalPoint FarlieGumbelMorgensternCopula::computeCDFGradient(const NumericalPoint & point) const
 {
-  const UnsignedLong dimension(getDimension());
+  const UnsignedInteger dimension(getDimension());
   if (point.getDimension() != dimension) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=" << dimension << ", here dimension=" << point.getDimension();
 
   const NumericalScalar u(point[0]);
@@ -197,7 +201,7 @@ NumericalPoint FarlieGumbelMorgensternCopula::computeCDFGradient(const Numerical
 NumericalScalar FarlieGumbelMorgensternCopula::computeConditionalCDF(const NumericalScalar x,
     const NumericalPoint & y) const
 {
-  const UnsignedLong conditioningDimension(y.getDimension());
+  const UnsignedInteger conditioningDimension(y.getDimension());
   if (conditioningDimension >= getDimension()) throw InvalidArgumentException(HERE) << "Error: cannot compute a conditional CDF with a conditioning point of dimension greater or equal to the distribution dimension.";
   // Special case for no conditioning or independent copula
   if ((conditioningDimension == 0) || (hasIndependentCopula())) return x;
@@ -211,7 +215,7 @@ NumericalScalar FarlieGumbelMorgensternCopula::computeConditionalCDF(const Numer
 NumericalScalar FarlieGumbelMorgensternCopula::computeConditionalQuantile(const NumericalScalar q,
     const NumericalPoint & y) const
 {
-  const UnsignedLong conditioningDimension(y.getDimension());
+  const UnsignedInteger conditioningDimension(y.getDimension());
   if (conditioningDimension >= getDimension()) throw InvalidArgumentException(HERE) << "Error: cannot compute a conditional quantile with a conditioning point of dimension greater or equal to the distribution dimension.";
   if ((q < 0.0) || (q > 1.0)) throw InvalidArgumentException(HERE) << "Error: cannot compute a conditional quantile for a probability level outside of [0, 1]";
   // Special case for no conditioning or independent copula
@@ -221,7 +225,7 @@ NumericalScalar FarlieGumbelMorgensternCopula::computeConditionalQuantile(const
   if ((conditioningDimension == 0) || hasIndependentCopula()) return q;
   const NumericalScalar alpha(theta_ * (1.0 - 2.0 * y[0]));
   const NumericalScalar alpha1(1.0 + alpha);
-  return 2.0 * q / (alpha1 + sqrt(alpha1 * alpha1 - 4.0 * q * alpha));
+  return 2.0 * q / (alpha1 + std::sqrt(alpha1 * alpha1 - 4.0 * q * alpha));
 }
 
 /* Tell if the distribution has an elliptical copula */
@@ -252,13 +256,15 @@ FarlieGumbelMorgensternCopula::NumericalPointWithDescriptionCollection FarlieGum
 
 void FarlieGumbelMorgensternCopula::setParametersCollection(const NumericalPointCollection & parametersCollection)
 {
+  const NumericalScalar w(getWeight());
   *this = FarlieGumbelMorgensternCopula(parametersCollection[0][0]);
+  setWeight(w);
 }
 
 /* Theta accessor */
 void FarlieGumbelMorgensternCopula::setTheta(const NumericalScalar theta)
 {
-  if (fabs(theta) > 1.0) throw InvalidArgumentException(HERE) << "Theta MUST be in [-1, 1]";
+  if (std::abs(theta) > 1.0) throw InvalidArgumentException(HERE) << "Theta MUST be in [-1, 1]";
   theta_ = theta;
 }
 
@@ -273,7 +279,7 @@ FarlieGumbelMorgensternCopula::Implementation FarlieGumbelMorgensternCopula::get
 {
   if (!indices.check(1)) throw InvalidArgumentException(HERE) << "The indices of an archimedean copula  must be in the range [0, 1] and  must be different";
   // General case
-  const UnsignedLong outputDimension(indices.getSize());
+  const UnsignedInteger outputDimension(indices.getSize());
   // Only one indice is needed, call the specialized method
   if (outputDimension == 1) return getMarginal(indices[0]);
   // The indices correspond to all the components, with a possible transposition of the two components.
