@@ -3,7 +3,7 @@
  *  @file  FisherSnedecorFactory.cxx
  *  @brief Factory for FisherSnedecor distribution
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -22,6 +22,10 @@
  *  @date   2012-07-16 10:12:54 +0200 (Mon, 16 Jul 2012)
  */
 #include "FisherSnedecorFactory.hxx"
+#include "MethodBoundNumericalMathEvaluationImplementation.hxx"
+#include "CenteredFiniteDifferenceGradient.hxx"
+#include "SpecFunc.hxx"
+#include "TNC.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -57,19 +61,56 @@ FisherSnedecorFactory::Implementation FisherSnedecorFactory::build() const
   return buildAsFisherSnedecor().clone();
 }
 
+struct FisherSnedecorFactoryLogLikelihood
+{
+  /** Constructor from a sample */
+  FisherSnedecorFactoryLogLikelihood(const NumericalSample & sample)
+    : sample_(sample)
+  {
+    // Nothing to do
+  };
+
+  NumericalPoint computeLogLikelihood(const NumericalPoint & parameters) const
+  {
+    try
+    {
+      const FisherSnedecor distribution(parameters[0], parameters[1]);
+      const NumericalScalar logLikelihood(-distribution.computeLogPDF(sample_).computeMean()[0]);
+      if (SpecFunc::IsNormal(logLikelihood)) return NumericalPoint(1, logLikelihood);
+      return NumericalPoint(1, SpecFunc::MaxNumericalScalar);
+    }
+    catch (...)
+    {
+      return NumericalPoint(1, SpecFunc::MaxNumericalScalar);
+    }
+  }
+
+  const NumericalSample & sample_;
+};
+
 FisherSnedecor FisherSnedecorFactory::buildAsFisherSnedecor(const NumericalSample & sample) const
 {
-  const UnsignedLong size(sample.getSize());
+  const UnsignedInteger size(sample.getSize());
   if (size == 0) throw InvalidArgumentException(HERE) << "Error: cannot build a FisherSnedecor distribution from an empty sample";
   if (sample.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: can build an FisherSnedecor distribution only from a sample of dimension 1, here dimension=" << sample.getDimension();
-  const NumericalScalar mean(sample.computeMean()[0]);
-  const NumericalScalar var(sample.computeCovariance()(0, 0));
-  if (mean <= 1.0) throw InvalidArgumentException(HERE) << "Error: can build a FisherSnedecor distribution only from a sample with mean > 1, here mean=" << mean;
-  const NumericalScalar d1(-2.0 / (mean - 1.0 + var * (1.0 - 2.0 / mean) / mean));
-  const NumericalScalar d2(2.0 * mean / (mean - 1.0));
-  FisherSnedecor result(d1, d2);
-  result.setDescription(sample.getDescription());
-  return result;
+  FisherSnedecorFactoryLogLikelihood logLikelihoodWrapper(sample);
+  NumericalMathFunction logLikelihood(bindMethod<FisherSnedecorFactoryLogLikelihood, NumericalPoint, NumericalPoint>(logLikelihoodWrapper, &FisherSnedecorFactoryLogLikelihood::computeLogLikelihood, 2, 1));
+  CenteredFiniteDifferenceGradient gradient(1.0e-5, logLikelihood.getEvaluation());
+  logLikelihood.setGradient(gradient);
+  // Solver
+  TNC optimizationAlgorithm(logLikelihood);
+  optimizationAlgorithm.setMaximumEvaluationsNumber(ResourceMap::GetAsUnsignedInteger( "FisherSnedecorFactory-MaximumEvaluationNumber"));
+  optimizationAlgorithm.setMaximumAbsoluteError(ResourceMap::GetAsNumericalScalar( "FisherSnedecorFactory-MaximumAbsoluteError"));
+  optimizationAlgorithm.setMaximumRelativeError(ResourceMap::GetAsNumericalScalar( "FisherSnedecorFactory-MaximumRelativeError"));
+  optimizationAlgorithm.setMaximumObjectiveError(ResourceMap::GetAsNumericalScalar( "FisherSnedecorFactory-MaximumObjectiveError"));
+  optimizationAlgorithm.setMaximumConstraintError(ResourceMap::GetAsNumericalScalar( "FisherSnedecorFactory-MaximumConstraintError"));
+  NumericalPoint parametersLowerBound(0);
+  parametersLowerBound.add(ResourceMap::GetAsNumericalScalar( "FisherSnedecorFactory-D1LowerBound"));
+  parametersLowerBound.add(ResourceMap::GetAsNumericalScalar( "FisherSnedecorFactory-D2LowerBound"));
+  optimizationAlgorithm.setBoundConstraints(Interval(parametersLowerBound, NumericalPoint(2, SpecFunc::MaxNumericalScalar), Interval::BoolCollection(2, true), Interval::BoolCollection(2, false)));
+  optimizationAlgorithm.run();
+  const NumericalPoint parameters(optimizationAlgorithm.getResult().getOptimizer());
+  return FisherSnedecor(parameters[0], parameters[1]);
 }
 
 FisherSnedecor FisherSnedecorFactory::buildAsFisherSnedecor(const NumericalPointWithDescriptionCollection & parameters) const
