@@ -3,7 +3,7 @@
  *  @file  Gamma.cxx
  *  @brief The Gamma distribution
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -36,12 +36,13 @@ static Factory<Gamma> RegisteredFactory("Gamma");
 
 /* Default constructor */
 Gamma::Gamma()
-  : ContinuousDistribution("Gamma")
+  : ContinuousDistribution()
   , k_(1.0)
   , lambda_(1.0)
   , gamma_(0.0)
   , normalizationFactor_(0.0)
 {
+  setName("Gamma");
   setDimension(1);
   computeRange();
 }
@@ -51,12 +52,13 @@ Gamma::Gamma(const NumericalScalar arg1,
              const NumericalScalar arg2,
              const NumericalScalar gamma,
              const ParameterSet set)
-  : ContinuousDistribution("Gamma")
+  : ContinuousDistribution()
   , k_(0.0)
   , lambda_(0.0)
   , gamma_(gamma)
   , normalizationFactor_(0.0)
 {
+  setName("Gamma");
   switch (set)
   {
     case KLAMBDA:
@@ -169,7 +171,7 @@ NumericalScalar Gamma::getMu() const
 
 NumericalScalar Gamma::getSigma() const
 {
-  return sqrt(k_) / lambda_;
+  return std::sqrt(k_) / lambda_;
 }
 
 
@@ -209,15 +211,19 @@ void Gamma::computeRange()
 /** Update the derivative attributes */
 void Gamma::update()
 {
-  // For large k define an alternative normalization factor and use an asymptotic expansion to avoid cancellation
+  // For large k we use the following normalization factor:
+  // normalizationFactor = log(lambda*k^{k-1}/Gamma(k))
+  // which is expanded wrt k
   if (k_ >= 6.9707081224932495879)
   {
     static const NumericalScalar alpha[10] = {0.91893853320467274177, 0.83333333333333333333e-1, -0.27777777777777777778e-2, 0.79365079365079365079e-3, -0.59523809523809523810e-3, 0.84175084175084175084e-3, -0.19175269175269175269e-2, 0.64102564102564102564e-2, -0.29550653594771241830e-1, 0.17964437236883057316};
     const NumericalScalar ik(1.0 / k_);
     const NumericalScalar ik2(ik * ik);
-    normalizationFactor_ = log(lambda_) + k_ - 0.5 * log(k_) - (alpha[0] + ik * (alpha[1] + ik2 * (alpha[2] + ik2 * (alpha[3] + ik2 * (alpha[4] + ik2 * (alpha[5] + ik2 * (alpha[6] + ik2 * (alpha[7] + ik2 * (alpha[8] + ik2 * alpha[9])))))))));
+    normalizationFactor_ = std::log(lambda_) + k_ - 0.5 * std::log(k_) - (alpha[0] + ik * (alpha[1] + ik2 * (alpha[2] + ik2 * (alpha[3] + ik2 * (alpha[4] + ik2 * (alpha[5] + ik2 * (alpha[6] + ik2 * (alpha[7] + ik2 * (alpha[8] + ik2 * alpha[9])))))))));
   }
-  else normalizationFactor_ = log(lambda_) - SpecFunc::LnGamma(k_);
+  // For small k, the normalization factor is:
+  // normalizationFactor = log(lambda/Gamma(k))
+  else normalizationFactor_ = std::log(lambda_) - SpecFunc::LnGamma(k_);
   isAlreadyComputedMean_ = false;
   isAlreadyComputedCovariance_ = false;
 }
@@ -248,18 +254,20 @@ NumericalScalar Gamma::computePDF(const NumericalPoint & point) const
 
   const NumericalScalar x(point[0] - gamma_);
   if (x <= 0.0) return 0.0;
-  return exp(computeLogPDF(point));
+  return std::exp(computeLogPDF(point));
 }
 
 NumericalScalar Gamma::computeLogPDF(const NumericalPoint & point) const
 {
   if (point.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=1, here dimension=" << point.getDimension();
 
+  // From textbook, we have log(PDF(x)) =  - lambda * (x - gamma) + (k - 1) * log(x - gamma) + k * log(lambda) - log(Gamma(k))
   const NumericalScalar u(lambda_ * (point[0] - gamma_));
   if (u <= 0.0) return -SpecFunc::MaxNumericalScalar;
   // Use asymptotic expansion for large k
-  if (k_ >= 6.9707081224932495879) return normalizationFactor_ - u + (k_ - 1.0) * log(u / k_);
-  return normalizationFactor_ + (k_ - 1) * log(u) - u;
+  // Here log(PDF(x)) = L - lambda * (x - gamma) + (k - 1) * log(lambda * (x - gamma) / k)
+  if (k_ >= 6.9707081224932495879) return normalizationFactor_ - u + (k_ - 1.0) * std::log(u / k_);
+  return normalizationFactor_ + (k_ - 1) * std::log(u) - u;
 }
 
 /* Get the CDF of the distribution */
@@ -286,12 +294,12 @@ NumericalScalar Gamma::computeComplementaryCDF(const NumericalPoint & point) con
 /* Get the characteristic function of the distribution, i.e. phi(u) = E(exp(I*u*X)) */
 NumericalComplex Gamma::computeCharacteristicFunction(const NumericalScalar x) const
 {
-  return exp(NumericalComplex(0.0, x * gamma_)) * pow(NumericalComplex(1.0, -x / lambda_), -k_);
+  return std::exp(NumericalComplex(0.0, x * gamma_)) * std::pow(NumericalComplex(1.0, -x / lambda_), -k_);
 }
 
 NumericalComplex Gamma::computeLogCharacteristicFunction(const NumericalScalar x) const
 {
-  return NumericalComplex(0.0, x * gamma_) - k_ * log(NumericalComplex(1.0, -x / lambda_));
+  return NumericalComplex(0.0, x * gamma_) - k_ * std::log(NumericalComplex(1.0, -x / lambda_));
 }
 
 /* Get the PDFGradient of the distribution */
@@ -303,7 +311,7 @@ NumericalPoint Gamma::computePDFGradient(const NumericalPoint & point) const
   const NumericalScalar x(point[0] - gamma_);
   if (x <= 0.0) return pdfGradient;
   const NumericalScalar pdf(computePDF(point));
-  pdfGradient[0] = (log(x) + log(lambda_) - SpecFunc::Psi(k_)) * pdf;
+  pdfGradient[0] = (std::log(x) + std::log(lambda_) - SpecFunc::Psi(k_)) * pdf;
   pdfGradient[1] = (k_ / lambda_ - x) * pdf;
   pdfGradient[2] = ((1.0 - k_) / x + lambda_) * pdf;
   return pdfGradient;
@@ -318,8 +326,8 @@ NumericalPoint Gamma::computeCDFGradient(const NumericalPoint & point) const
   const NumericalScalar x(point[0] - gamma_);
   if (x <= 0.0) return cdfGradient;
   const NumericalScalar lambdaX(lambda_ * x);
-  const NumericalScalar factor(exp(k_ * log(lambdaX) - SpecFunc::LnGamma(k_) - lambdaX));
-  const NumericalScalar eps(pow(cdfEpsilon_, 1.0 / 3.0));
+  const NumericalScalar factor(std::exp(k_ * std::log(lambdaX) - SpecFunc::LnGamma(k_) - lambdaX));
+  const NumericalScalar eps(std::pow(cdfEpsilon_, 1.0 / 3.0));
   cdfGradient[0] = (DistFunc::pGamma(k_ + eps, lambda_ * x) - DistFunc::pGamma(k_ - eps, lambda_ * x)) / (2.0 * eps);
   cdfGradient[1] = factor / lambda_;
   cdfGradient[2] = -factor / x;
@@ -349,7 +357,7 @@ NumericalPoint Gamma::getStandardDeviation() const
 /* Get the skewness of the distribution */
 NumericalPoint Gamma::getSkewness() const
 {
-  return NumericalPoint(1, 2.0 / sqrt(k_));
+  return NumericalPoint(1, 2.0 / std::sqrt(k_));
 }
 
 /* Get the kurtosis of the distribution */
@@ -359,9 +367,9 @@ NumericalPoint Gamma::getKurtosis() const
 }
 
 /* Get the moments of the standardized distribution */
-NumericalPoint Gamma::getStandardMoment(const UnsignedLong n) const
+NumericalPoint Gamma::getStandardMoment(const UnsignedInteger n) const
 {
-  return NumericalPoint(1, exp(SpecFunc::LogGamma(n + k_) - SpecFunc::LogGamma(k_)));
+  return NumericalPoint(1, std::exp(SpecFunc::LogGamma(n + k_) - SpecFunc::LogGamma(k_)));
 }
 
 /* Get the standard representative in the parametric family, associated with the standard moments */
@@ -398,7 +406,9 @@ Gamma::NumericalPointWithDescriptionCollection Gamma::getParametersCollection()
 
 void Gamma::setParametersCollection(const NumericalPointCollection & parametersCollection)
 {
+  const NumericalScalar w(getWeight());
   *this = Gamma(parametersCollection[0][0], parametersCollection[0][1], parametersCollection[0][2]);
+  setWeight(w);
 }
 
 /* Method save() stores the object through the StorageManager */
