@@ -3,7 +3,7 @@
  *  @file  GeneralizedParetoFactory.cxx
  *  @brief Factory for GeneralizedPareto distribution
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -64,11 +64,11 @@ GeneralizedParetoFactory::Implementation GeneralizedParetoFactory::build() const
 GeneralizedPareto GeneralizedParetoFactory::buildAsGeneralizedPareto(const NumericalSample & sample) const
 {
   if (sample.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: can build a GeneralizedPareto distribution only from a sample of dimension 1, here dimension=" << sample.getDimension();
-  const UnsignedLong size(sample.getSize());
+  const UnsignedInteger size(sample.getSize());
   if (size == 0) throw InvalidArgumentException(HERE) << "Error: cannot build a GeneralizedPareto distribution from an empty sample";
   NumericalScalar xMin(sample.getMin()[0]);
   if (xMin <= 0.0) throw InvalidArgumentException(HERE) << "Error: cannot build a GeneralizedPareto distribution based on a sample with nonpositive values.";
-  NumericalScalar smallSize(ResourceMap::GetAsUnsignedLong( "GeneralizedParetoFactory-SmallSize" ));
+  NumericalScalar smallSize(ResourceMap::GetAsUnsignedInteger( "GeneralizedParetoFactory-SmallSize" ));
   // The strategy is to use the probability weighted moment method for small size and to switch to the maximum likelihood if the estimator is not defined. For large size, we only use the ML estimator.
   if (size <= smallSize)
   {
@@ -76,7 +76,7 @@ GeneralizedPareto GeneralizedParetoFactory::buildAsGeneralizedPareto(const Numer
     {
       return buildMethodOfProbabilityWeightedMoments(sample);
     }
-    catch (InternalException & ex)
+    catch (InvalidArgumentException & ex)
     {
       return buildMethodOfExponentialRegression(sample);
     }
@@ -114,10 +114,10 @@ GeneralizedPareto GeneralizedParetoFactory::buildMethodOfMoments(const Numerical
 {
   const NumericalScalar mean(sample.computeMean()[0]);
   const NumericalScalar std(sample.computeStandardDeviationPerComponent()[0]);
-  const NumericalScalar xi(0.5 * (pow(mean / std, 2) - 1.0));
+  const NumericalScalar xi(0.5 * (std::pow(mean / std, 2) - 1.0));
   // The moment estimator is valid only if the estimated xi parameter is greater than -1/4
-  if (xi <= -0.25) throw InternalException(HERE) << "Error: cannot estimate a GeneralizedPareto distribution with the method of moments when the estimated xi parameter=" << xi << " is less than -0.25";
-  const NumericalScalar sigma(0.5 * mean * (pow(mean / std, 2) + 1.0));
+  if (xi <= -0.25) throw InvalidArgumentException(HERE) << "Error: cannot estimate a GeneralizedPareto distribution with the method of moments when the estimated xi parameter=" << xi << " is less than -0.25";
+  const NumericalScalar sigma(0.5 * mean * (std::pow(mean / std, 2) + 1.0));
   GeneralizedPareto result(sigma, xi);
   result.setDescription(sample.getDescription());
   return result;
@@ -132,38 +132,38 @@ struct GeneralizedParetoFactoryParameterConstraint
   {
     const NumericalSample sortedSample(sample.sort());
     sampleY_ = NumericalSample(size_ - 2, 1);
-    for (UnsignedLong j = 0; j < size_ - 2; ++j)
-      sampleY_[j][0] = (j + 1.0) * log((sortedSample[size_ - 1 - j][0] - sortedSample[0][0]) / (sortedSample[size_ - 2 - j][0] - sortedSample[0][0]));
+    for (UnsignedInteger j = 0; j < size_ - 2; ++j)
+      sampleY_[j][0] = (j + 1.0) * std::log((sortedSample[size_ - 1 - j][0] - sortedSample[0][0]) / (sortedSample[size_ - 2 - j][0] - sortedSample[0][0]));
   };
 
   NumericalPoint computeConstraint(const NumericalPoint & parameter) const
   {
     const NumericalScalar gamma(parameter[0]);
     // Separate the small gamma case for stability purpose
-    if (fabs(gamma) < 1.0e-4)
+    if (std::abs(gamma) < 1.0e-4)
     {
       NumericalScalar exponentialRegressionLogLikelihood(0.0);
-      for (UnsignedLong j = 0; j < size_ - 2; ++j)
+      for (UnsignedInteger j = 0; j < size_ - 2; ++j)
       {
-        const NumericalScalar logAlphaJ(log((j + 1.0) / size_));
+        const NumericalScalar logAlphaJ(std::log((j + 1.0) / size_));
         const NumericalScalar gammaLogAlphaJ(gamma * logAlphaJ);
         const NumericalScalar yLogAlphaJ(sampleY_[j][0] * logAlphaJ);
-        exponentialRegressionLogLikelihood += log(-logAlphaJ) + yLogAlphaJ + 0.5 * gammaLogAlphaJ * (1.0 + yLogAlphaJ + gammaLogAlphaJ * (1.0 / 12.0 + yLogAlphaJ / 3.0 + gammaLogAlphaJ * yLogAlphaJ / 12.0));
+        exponentialRegressionLogLikelihood += std::log(-logAlphaJ) + yLogAlphaJ + 0.5 * gammaLogAlphaJ * (1.0 + yLogAlphaJ + gammaLogAlphaJ * (1.0 / 12.0 + yLogAlphaJ / 3.0 + gammaLogAlphaJ * yLogAlphaJ / 12.0));
       }
       return NumericalPoint(1, -exponentialRegressionLogLikelihood);
     }
     // Large gamma case
     NumericalScalar exponentialRegressionLogLikelihood(0.0);
-    for (UnsignedLong j = 0; j < size_ - 2; ++j)
+    for (UnsignedInteger j = 0; j < size_ - 2; ++j)
     {
-      const NumericalScalar alphaJ((1.0 - pow((j + 1.0) / size_, gamma)) / gamma);
-      exponentialRegressionLogLikelihood += log(alphaJ) - alphaJ * sampleY_[j][0];
+      const NumericalScalar alphaJ((1.0 - std::pow((j + 1.0) / size_, gamma)) / gamma);
+      exponentialRegressionLogLikelihood += std::log(alphaJ) - alphaJ * sampleY_[j][0];
     }
     return NumericalPoint(1, -exponentialRegressionLogLikelihood);
   }
 
   NumericalSample sampleY_;
-  UnsignedLong size_;
+  UnsignedInteger size_;
 };
 
 /* Algorithm associated with the method of exponential regression */
@@ -171,11 +171,11 @@ GeneralizedPareto GeneralizedParetoFactory::buildMethodOfExponentialRegression(c
 {
   GeneralizedParetoFactoryParameterConstraint constraint(sample);
   NumericalMathFunction f(bindMethod<GeneralizedParetoFactoryParameterConstraint, NumericalPoint, NumericalPoint>(constraint, &GeneralizedParetoFactoryParameterConstraint::computeConstraint, 1, 1));
-  CenteredFiniteDifferenceGradient gradient(1.0e-5, f.getEvaluationImplementation());
-  f.setGradientImplementation(gradient);
+  CenteredFiniteDifferenceGradient gradient(1.0e-5, f.getEvaluation());
+  f.setGradient(gradient);
   // Solver
   TNC optimizationAlgorithm(f);
-  optimizationAlgorithm.setMaximumEvaluationsNumber(ResourceMap::GetAsUnsignedLong( "GeneralizedParetoFactory-MaximumEvaluationNumber"));
+  optimizationAlgorithm.setMaximumEvaluationsNumber(ResourceMap::GetAsUnsignedInteger( "GeneralizedParetoFactory-MaximumEvaluationNumber"));
   optimizationAlgorithm.setMaximumAbsoluteError(ResourceMap::GetAsNumericalScalar( "GeneralizedParetoFactory-MaximumAbsoluteError"));
   optimizationAlgorithm.setMaximumRelativeError(ResourceMap::GetAsNumericalScalar( "GeneralizedParetoFactory-MaximumRelativeError"));
   optimizationAlgorithm.setMaximumObjectiveError(ResourceMap::GetAsNumericalScalar( "GeneralizedParetoFactory-MaximumObjectiveError"));
@@ -186,8 +186,8 @@ GeneralizedPareto GeneralizedParetoFactory::buildMethodOfExponentialRegression(c
   const NumericalSample sortedSample(sample.sort());
   // Compute the first probability weighted moment
   NumericalScalar m(0.0);
-  const UnsignedLong size(sample.getSize());
-  for (UnsignedLong i = 0; i < size; ++i) m += (size - (i + 0.65)) * sortedSample[i][0];
+  const UnsignedInteger size(sample.getSize());
+  for (UnsignedInteger i = 0; i < size; ++i) m += (size - (i + 0.65)) * sortedSample[i][0];
   m /= size * size;
   const NumericalScalar sigma(2.0 * mean * m / (mean - 2.0 * m));
   GeneralizedPareto result(sigma, xi);
@@ -202,11 +202,11 @@ GeneralizedPareto GeneralizedParetoFactory::buildMethodOfProbabilityWeightedMome
   const NumericalSample sortedSample(sample.sort());
   // Compute the first probability weighted moment
   NumericalScalar m(0.0);
-  const UnsignedLong size(sample.getSize());
-  for (UnsignedLong i = 0; i < size; ++i) m += (size - (i + 0.65)) * sortedSample[i][0];
+  const UnsignedInteger size(sample.getSize());
+  for (UnsignedInteger i = 0; i < size; ++i) m += (size - (i + 0.65)) * sortedSample[i][0];
   m /= size * size;
   const NumericalScalar xi(mean / (mean - 2.0 * m) - 2.0);
-  if (xi <= -0.5) throw InternalException(HERE) << "Error: cannot estimate a GeneralizedPareto distribution with the method of probability weighted moments when the estimated xi parameter=" << xi << " is less than -0.5";
+  if (xi <= -0.5) throw InvalidArgumentException(HERE) << "Error: cannot estimate a GeneralizedPareto distribution with the method of probability weighted moments when the estimated xi parameter=" << xi << " is less than -0.5";
   const NumericalScalar sigma(2.0 * mean * m / (mean - 2.0 * m));
   GeneralizedPareto result(sigma, xi);
   result.setDescription(sample.getDescription());
