@@ -3,7 +3,7 @@
  *  @file  Geometric.cxx
  *  @brief The Geometric distribution
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -35,18 +35,20 @@ static Factory<Geometric> RegisteredFactory("Geometric");
 
 /* Default constructor */
 Geometric::Geometric()
-  : DiscreteDistribution("Geometric")
+  : DiscreteDistribution()
   , p_(0.5)
 {
+  setName( "Geometric" );
   setDimension( 1 );
   computeRange();
 }
 
 /* Parameters constructor */
 Geometric::Geometric(const NumericalScalar p)
-  : DiscreteDistribution("Geometric")
+  : DiscreteDistribution()
   , p_(0.)
 {
+  setName( "Geometric" );
   // We set the dimension of the Geometric distribution
   setDimension( 1 );
   // Also sets the range
@@ -97,7 +99,7 @@ void Geometric::computeRange()
 /* Get one realization of the distribution */
 NumericalPoint Geometric::getRealization() const
 {
-  return NumericalPoint(1, ceil(log(RandomGenerator::Generate()) / log1p(-p_)));
+  return NumericalPoint(1, ceil(std::log(RandomGenerator::Generate()) / log1p(-p_)));
 }
 
 
@@ -107,8 +109,8 @@ NumericalScalar Geometric::computePDF(const NumericalPoint & point) const
   if (point.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=1, here dimension=" << point.getDimension();
 
   const NumericalScalar k(point[0]);
-  if ((k < 1.0 - supportEpsilon_) || (fabs(k - round(k)) > supportEpsilon_)) return 0.0;
-  return p_ * pow(1.0 - p_, k - 1.0);
+  if ((k < 1.0 - supportEpsilon_) || (std::abs(k - round(k)) > supportEpsilon_)) return 0.0;
+  return p_ * std::pow(1.0 - p_, k - 1.0);
 }
 
 
@@ -119,7 +121,7 @@ NumericalScalar Geometric::computeCDF(const NumericalPoint & point) const
 
   const NumericalScalar k(point[0]);
   if (k < 1.0) return 0.0;
-  return 1.0 - pow(1.0 - p_, floor(k));
+  return 1.0 - std::pow(1.0 - p_, floor(k));
 }
 
 NumericalScalar Geometric::computeComplementaryCDF(const NumericalPoint & point) const
@@ -128,7 +130,7 @@ NumericalScalar Geometric::computeComplementaryCDF(const NumericalPoint & point)
 
   const NumericalScalar k(point[0]);
   if (k < 1.0) return 1.0;
-  return pow(1.0 - p_, floor(k));
+  return std::pow(1.0 - p_, floor(k));
 }
 
 /* Get the PDFGradient of the distribution */
@@ -137,8 +139,8 @@ NumericalPoint Geometric::computePDFGradient(const NumericalPoint & point) const
   if (point.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=1, here dimension=" << point.getDimension();
 
   const NumericalScalar k(point[0]);
-  if ((k < 1.0 - supportEpsilon_) || (fabs(k - round(k)) > supportEpsilon_)) return NumericalPoint(1, 0.0);
-  return NumericalPoint(1, (1.0 - k * p_) * pow(1.0 - p_, k - 2.0));
+  if ((k < 1.0 - supportEpsilon_) || (std::abs(k - round(k)) > supportEpsilon_)) return NumericalPoint(1, 0.0);
+  return NumericalPoint(1, (1.0 - k * p_) * std::pow(1.0 - p_, k - 2.0));
 }
 
 /* Get the CDFGradient of the distribution */
@@ -148,21 +150,21 @@ NumericalPoint Geometric::computeCDFGradient(const NumericalPoint & point) const
 
   const NumericalScalar k(floor(point[0]));
   if ( k < 1.0 ) return NumericalPoint(1, 0.0);
-  return NumericalPoint(1, k * pow(1 - p_, k - 1.0));
+  return NumericalPoint(1, k * std::pow(1 - p_, k - 1.0));
 }
 
 /* Get the quantile of the distribution */
 NumericalScalar Geometric::computeScalarQuantile(const NumericalScalar prob,
     const Bool tail) const
 {
-  if (tail) return ceil(log(prob) / log1p(-p_));
+  if (tail) return ceil(std::log(prob) / log1p(-p_));
   return ceil(log1p(-prob) / log1p(-p_));
 }
 
 /* Get the characteristic function of the distribution, i.e. phi(u) = E(exp(I*u*X)) */
 NumericalComplex Geometric::computeCharacteristicFunction(const NumericalScalar x) const
 {
-  const NumericalComplex value(p_ / (exp(NumericalComplex(0.0, -x)) - (1.0 - p_)));
+  const NumericalComplex value(p_ / (std::exp(NumericalComplex(0.0, -x)) - (1.0 - p_)));
   return value;
 }
 
@@ -176,10 +178,10 @@ NumericalComplex Geometric::computeGeneratingFunction(const NumericalComplex & z
 NumericalSample Geometric::getSupport(const Interval & interval) const
 {
   if (interval.getDimension() != getDimension()) throw InvalidArgumentException(HERE) << "Error: the given interval has a dimension that does not match the distribution dimension.";
-  const UnsignedLong kMin(static_cast< UnsignedLong > (std::max(ceil(interval.getLowerBound()[0]), 0.0)));
-  const UnsignedLong kMax(static_cast< UnsignedLong > (floor(interval.getUpperBound()[0])));
+  const UnsignedInteger kMin(static_cast< UnsignedInteger > (std::max(ceil(interval.getLowerBound()[0]), 0.0)));
+  const UnsignedInteger kMax(static_cast< UnsignedInteger > (floor(interval.getUpperBound()[0])));
   NumericalSample result(0, 1);
-  for (UnsignedLong k = kMin; k <= kMax; ++k)
+  for (UnsignedInteger k = kMin; k <= kMax; ++k)
     result.add(NumericalPoint(1, k));
   return result;
 }
@@ -194,13 +196,13 @@ void Geometric::computeMean() const
 /* Get the standard deviation of the distribution */
 NumericalPoint Geometric::getStandardDeviation() const
 {
-  return NumericalPoint(1, sqrt(1.0 - p_) / p_);
+  return NumericalPoint(1, std::sqrt(1.0 - p_) / p_);
 }
 
 /* Get the skewness of the distribution */
 NumericalPoint Geometric::getSkewness() const
 {
-  return NumericalPoint(1, (2.0 - p_) / sqrt(1.0 - p_));
+  return NumericalPoint(1, (2.0 - p_) / std::sqrt(1.0 - p_));
 }
 
 /* Get the kurtosis of the distribution */
@@ -233,7 +235,9 @@ Geometric::NumericalPointWithDescriptionCollection Geometric::getParametersColle
 
 void Geometric::setParametersCollection(const NumericalPointCollection & parametersCollection)
 {
+  const NumericalScalar w(getWeight());
   *this = Geometric(parametersCollection[0][0]);
+  setWeight(w);
 }
 
 
