@@ -3,7 +3,7 @@
  *  @file  Histogram.cxx
  *  @brief The Histogram distribution
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -27,6 +27,7 @@
 #include "RandomGenerator.hxx"
 #include "PersistentObjectFactory.hxx"
 #include "Exception.hxx"
+#include "SpecFunc.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -39,11 +40,12 @@ static Factory<Histogram> RegisteredFactory_alt("Histogram");
 
 /* Default constructor */
 Histogram::Histogram()
-  : ContinuousDistribution("Histogram")
+  : ContinuousDistribution()
   , first_(0.0)
   , collection_(0)
   , cumulatedWidth_(0)
 {
+  setName( "Histogram" );
   // This call set also the range.
   setPairCollection(HistogramPairCollection(1, HistogramPair(1.0, 1.0)));
   setDimension( 1 );
@@ -52,11 +54,12 @@ Histogram::Histogram()
 /* Parameters constructor */
 Histogram::Histogram(const NumericalScalar first,
                      const HistogramPairCollection & collection)
-  : ContinuousDistribution("Histogram")
+  : ContinuousDistribution()
   , first_(first)
   , collection_(0)
   , cumulatedWidth_(0)
 {
+  setName( "Histogram" );
   // This call set also the range.
   setPairCollection(collection);
   setDimension( 1 );
@@ -65,17 +68,18 @@ Histogram::Histogram(const NumericalScalar first,
 Histogram::Histogram(const NumericalScalar first,
                      const NumericalPoint & width,
                      const NumericalPoint & height)
-  : ContinuousDistribution("Histogram")
+  : ContinuousDistribution()
   , first_(first)
   , collection_(0)
   , cumulatedWidth_(0)
 {
+  setName( "Histogram" );
   // Convert the width and height into an Histogram pairs collection
-  const UnsignedLong size(width.getSize());
+  const UnsignedInteger size(width.getSize());
   if (size == 0) throw InvalidArgumentException(HERE) << "Error: the given width has a size of 0.";
   if (size != height.getSize()) throw InvalidArgumentException(HERE) << "Error: the width and the height must have the same size.";
   HistogramPairCollection collection(size);
-  for (UnsignedLong i = 0; i < size; ++i) collection[i] = HistogramPair(width[i], height[i]);
+  for (UnsignedInteger i = 0; i < size; ++i) collection[i] = HistogramPair(width[i], height[i]);
   // This call set also the range.
   setPairCollection(collection);
   setDimension( 1 );
@@ -104,7 +108,7 @@ String Histogram::__str__(const String & offset) const
 {
   OSS oss(false);
   oss << offset << getClassName() << "(origin = " << first_;
-  for (UnsignedLong i = 0; i < collection_.getSize(); ++i) oss << ", {w" << i << " = " << collection_[i].getWidth() << ", h" << i << " = " << collection_[i].getHeight() << "}";
+  for (UnsignedInteger i = 0; i < collection_.getSize(); ++i) oss << ", {w" << i << " = " << collection_[i].getWidth() << ", h" << i << " = " << collection_[i].getHeight() << "}";
   oss << ")";
   return oss;
 }
@@ -118,7 +122,7 @@ Histogram * Histogram::clone() const
 /* Compute the numerical range of the distribution given the parameters values */
 void Histogram::computeRange()
 {
-  const UnsignedLong size(cumulatedWidth_.getSize());
+  const UnsignedInteger size(cumulatedWidth_.getSize());
   if (size == 0) return;
   setRange(Interval(first_, first_ + cumulatedWidth_[size - 1]));
 }
@@ -145,18 +149,18 @@ NumericalScalar Histogram::computePDF(const NumericalPoint & point) const
   if (point.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=1, here dimension=" << point.getDimension();
 
   NumericalScalar x(point[0] - first_);
-  const UnsignedLong size(collection_.getSize());
-  if ((x <= 0.0) || (x >= cumulatedWidth_[size - 1])) return 0.0;
-  NumericalScalar lower(0.0);
-  // We shift x bin by bin until x falls in the current bin.
-  for (UnsignedLong i = 0; i < size; ++i)
+  const UnsignedInteger size(collection_.getSize());
+  if ((x < 0.0) || (x >= cumulatedWidth_[size - 1])) return 0.0;
+  // Find the bin index by bisection
+  UnsignedInteger iMin(0);
+  UnsignedInteger iMax(size - 1);
+  while (iMax > iMin + 1)
   {
-    x -= lower;
-    lower = collection_[i].getWidth();
-    if (x < lower) return collection_[i].getHeight();
+    const UnsignedInteger i((iMin + iMax) / 2);
+    if (x < cumulatedWidth_[i]) iMax = i;
+    else iMin = i;
   }
-  // Should never go there
-  return 0.0;
+  return collection_[iMax].getHeight();
 }
 
 
@@ -166,41 +170,59 @@ NumericalScalar Histogram::computeCDF(const NumericalPoint & point) const
   if (point.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=1, here dimension=" << point.getDimension();
 
   NumericalScalar x(point[0] - first_);
-  const UnsignedLong size(collection_.getSize());
+  const UnsignedInteger size(collection_.getSize());
   if (x <= 0.0) return 0.0;
   if (x >= cumulatedWidth_[size - 1]) return 1.0;
-  NumericalScalar lower(0.0);
-  NumericalScalar cdf(0.0);
-  // We shift x bin by bin until x falls in the current bin. We aggregate the contribution of all the bins and make a proportional contribution for the last bin.
-  for (UnsignedLong i = 0; i < size; ++i)
+  // Find the bin index by bisection
+  // Must start at -1 as both cumulatedWidth_ and cumulatedSurface_ start with positive values
+  SignedInteger iMin(-1);
+  UnsignedInteger iMax(size - 1);
+  while (static_cast<SignedInteger>(iMax) > iMin + 1)
   {
-    x -= lower;
-    lower = collection_[i].getWidth();
-    cdf += collection_[i].getSurface();
-    if (x <= lower)
-    {
-      const NumericalScalar value(cdf + (x - lower) * collection_[i].getHeight());
-      return value;
-    }
+    const UnsignedInteger i((iMin + iMax) / 2);
+    if (x < cumulatedWidth_[i]) iMax = i;
+    else iMin = i;
   }
-  // Should never go there
-  return 1.0;
+  // Here, we use only iMax as iMin can be -1
+  return cumulatedSurface_[iMax] + (x - cumulatedWidth_[iMax]) * collection_[iMax].getHeight();
 }
 
-/** Get the PDFGradient of the distribution */
+/* Get the characteristic function of the distribution, i.e. phi(u) = E(exp(I*u*X)) */
+NumericalComplex Histogram::computeCharacteristicFunction(const NumericalScalar x) const
+{
+  if (x == 0.0) return 1.0;
+  NumericalComplex result(0.0);
+  const UnsignedInteger size(collection_.getSize());
+  if (std::abs(cumulatedWidth_[size - 1] * x) < 1e-10)
+  {
+    NumericalScalar term(collection_[0].getHeight() * cumulatedWidth_[0] * cumulatedWidth_[0]);
+    for (UnsignedInteger k = 1; k < size; ++k) term += collection_[k].getHeight() * (cumulatedWidth_[k - 1] + cumulatedWidth_[k]) * collection_[k].getWidth();
+    result = NumericalComplex(1.0, 0.5 * x * term);
+  }
+  else
+  {
+    result = collection_[0].getHeight() * SpecFunc::Expm1(NumericalComplex(0.0, cumulatedWidth_[0] * x));
+    for (UnsignedInteger k = 1; k < size; ++k) result += collection_[k].getHeight() * (std::exp(NumericalComplex(0.0, cumulatedWidth_[k] * x)) - std::exp(NumericalComplex(0.0, cumulatedWidth_[k - 1] * x)));
+    result /= NumericalComplex(0.0, x);
+  }
+  result *= std::exp(NumericalComplex(0.0, first_ * x));
+  return result;
+}
+
+/* Get the PDFGradient of the distribution */
 NumericalPoint Histogram::computePDFGradient(const NumericalPoint & point) const
 {
   if (point.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=1, here dimension=" << point.getDimension();
 
-  throw NotYetImplementedException(HERE);
+  throw NotYetImplementedException(HERE) << "In Histogram::computePDFGradient(const NumericalPoint & point) const";
 }
 
-/** Get the CDFGradient of the distribution */
+/* Get the CDFGradient of the distribution */
 NumericalPoint Histogram::computeCDFGradient(const NumericalPoint & point) const
 {
   if (point.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=1, here dimension=" << point.getDimension();
 
-  throw NotYetImplementedException(HERE);
+  throw NotYetImplementedException(HERE) << "In Histogram::computeCDFGradient(const NumericalPoint & point) const";
 }
 
 /* Get the quantile of the distribution */
@@ -208,11 +230,11 @@ NumericalScalar Histogram::computeScalarQuantile(const NumericalScalar prob,
     const Bool tail) const
 {
   const NumericalScalar p(tail ? 1.0 - prob : prob);
-  const UnsignedLong size(collection_.getSize());
-  // Research of the containing bin
-  UnsignedLong index(UnsignedLong(p * size));
+  const UnsignedInteger size(collection_.getSize());
+  // Search of the bin
+  UnsignedInteger  index(p * size);
   NumericalScalar currentProba(cumulatedSurface_[index]);
-  UnsignedLong currentIndex(index);
+  UnsignedInteger currentIndex(index);
   // Basic search: upper bound. The loop must end because cumulatedSurface_[size - 1] = 1.0 and prob < 1.0
   while (p >= currentProba)
   {
@@ -242,9 +264,9 @@ NumericalScalar Histogram::computeScalarQuantile(const NumericalScalar prob,
 void Histogram::computeMean() const
 {
   NumericalScalar mean(first_);
-  const UnsignedLong size(collection_.getSize());
+  const UnsignedInteger size(collection_.getSize());
   NumericalScalar lower(0.0);
-  for (UnsignedLong i = 0; i < size; ++i)
+  for (UnsignedInteger i = 0; i < size; ++i)
   {
     const NumericalScalar width(collection_[i].getWidth());
     NumericalScalar upper(lower + width);
@@ -259,11 +281,11 @@ void Histogram::computeMean() const
 void Histogram::computeCovariance() const
 {
   NumericalScalar value(0.0);
-  const UnsignedLong size(collection_.getSize());
+  const UnsignedInteger size(collection_.getSize());
   covariance_ = CovarianceMatrix(1);
   // Since variance is invariant by translation, we center the data for numerical stability
   NumericalScalar lower(first_ - getMean()[0]);
-  for (UnsignedLong i = 0; i < size; i++)
+  for (UnsignedInteger i = 0; i < size; i++)
   {
     const NumericalScalar width(collection_[i].getWidth());
     NumericalScalar upper(lower + width);
@@ -275,17 +297,17 @@ void Histogram::computeCovariance() const
 }
 
 /* Get the moments of the standardized distribution */
-NumericalPoint Histogram::getStandardMoment(const UnsignedLong n) const
+NumericalPoint Histogram::getStandardMoment(const UnsignedInteger n) const
 {
   if (n == 0) return NumericalPoint(1, 1.0);
   NumericalScalar value(0.0);
-  const UnsignedLong size(collection_.getSize());
+  const UnsignedInteger size(collection_.getSize());
   NumericalScalar xPrec(-1.0);
   const NumericalScalar factor(2.0 / cumulatedWidth_[size - 1]);
-  for (UnsignedLong i = 0; i < size; ++i)
+  for (UnsignedInteger i = 0; i < size; ++i)
   {
     const NumericalScalar x(xPrec + collection_[i].getWidth() * factor);
-    value += (pow(x, n + 1) - pow(xPrec, n + 1)) * collection_[i].getHeight();
+    value += (std::pow(x, static_cast<int>(n + 1)) - std::pow(xPrec, static_cast<int>(n + 1))) * collection_[i].getHeight();
     xPrec = x;
   }
   value /= (n + 1) * factor;
@@ -295,11 +317,11 @@ NumericalPoint Histogram::getStandardMoment(const UnsignedLong n) const
 /* Get the standard representative in the parametric family, associated with the standard moments */
 Histogram::Implementation Histogram::getStandardRepresentative() const
 {
-  const UnsignedLong size(collection_.getSize());
+  const UnsignedInteger size(collection_.getSize());
   HistogramPairCollection collection(size);
   const NumericalScalar first(-1.0);
   const NumericalScalar factor(2.0 / cumulatedWidth_[size - 1]);
-  for (UnsignedLong i = 0; i < size; ++i) collection[i] = HistogramPair(factor * collection_[i].getWidth(), collection_[i].getHeight() / factor);
+  for (UnsignedInteger i = 0; i < size; ++i) collection[i] = HistogramPair(factor * collection_[i].getWidth(), collection_[i].getHeight() / factor);
   return Histogram(first, collection).clone();
 }
 
@@ -307,12 +329,12 @@ Histogram::Implementation Histogram::getStandardRepresentative() const
 Histogram::NumericalPointWithDescriptionCollection Histogram::getParametersCollection() const
 {
   NumericalPointWithDescriptionCollection parameters(1);
-  const UnsignedLong size(collection_.getSize());
+  const UnsignedInteger size(collection_.getSize());
   NumericalPointWithDescription point(1 + 2 * size);
   Description description(1 + 2 * size);
   point[0] = first_;
   description[0] = "first";
-  for (UnsignedLong i = 0; i < size; ++i)
+  for (UnsignedInteger i = 0; i < size; ++i)
   {
     point[2 * i + 1] = collection_[i].getWidth();
     point[2 * i + 2] = collection_[i].getHeight();
@@ -360,11 +382,11 @@ NumericalScalar Histogram::getFirst() const
 void Histogram::setPairCollection(const HistogramPairCollection & collection)
 {
   NumericalScalar surface(0.0);
-  const UnsignedLong size(collection.getSize());
+  const UnsignedInteger size(collection.getSize());
   cumulatedWidth_ = NumericalPoint(size);
   cumulatedSurface_ = NumericalPoint(size);
   // first, check that all the heights and widths are >=0
-  for (UnsignedLong i = 0; i < size; ++i)
+  for (UnsignedInteger i = 0; i < size; ++i)
   {
     NumericalScalar height(collection[i].getHeight());
     if (height < 0.0) throw InvalidArgumentException(HERE) << "Error: all the heights must be >= 0, here values=" << collection;
@@ -379,7 +401,7 @@ void Histogram::setPairCollection(const HistogramPairCollection & collection)
   // Normalization
   collection_ = HistogramPairCollection(size);
   NumericalScalar normalizationFactor(1.0 / surface);
-  for (UnsignedLong i = 0; i < size; ++i)
+  for (UnsignedInteger i = 0; i < size; ++i)
   {
     collection_[i] = HistogramPair(collection[i].getWidth(), collection[i].getHeight() * normalizationFactor);
     cumulatedSurface_[i] *= normalizationFactor;
@@ -394,24 +416,24 @@ Histogram::HistogramPairCollection Histogram::getPairCollection() const
   return collection_;
 }
 
-/** Draw the PDF of the Histogram using a specific presentation */
+/* Draw the PDF of the Histogram using a specific presentation */
 Graph Histogram::drawPDF() const
 {
-  const UnsignedLong lastIndex(cumulatedWidth_.getSize() - 1);
+  const UnsignedInteger lastIndex(cumulatedWidth_.getSize() - 1);
   // Must prefix explicitely by the class name in order to avoid conflict with the methods in the upper class
   return Histogram::drawPDF(first_ - 0.5 * collection_[0].getWidth(), first_ + cumulatedWidth_[lastIndex] + 0.5 * collection_[lastIndex].getWidth());
 }
 
-/** Draw the PDF of the Histogram using a specific presentation */
+/* Draw the PDF of the Histogram using a specific presentation */
 Graph Histogram::drawPDF(const NumericalScalar xMin,
                          const NumericalScalar xMax,
-                         const UnsignedLong pointNumber) const
+                         const UnsignedInteger pointNumber) const
 {
   if (xMax <= xMin) throw InvalidArgumentException(HERE) << "Error: cannot draw a PDF with xMax >= xMin, here xmin=" << xMin << " and xmax=" << xMax;
   const String title(OSS() << getDescription()[0] << " PDF");
   const String xName(getDescription()[0]);
   Graph graphPDF(title, xName, "PDF", true, "topright");
-  const UnsignedLong size(collection_.getSize());
+  const UnsignedInteger size(collection_.getSize());
   // Check for the border cases
   // If the histogram is completely at the right or at the left of the plot range,
   // just draw an horizontal line
@@ -426,7 +448,7 @@ Graph Histogram::drawPDF(const NumericalScalar xMin,
     return graphPDF;
   }
   // Find the index of the left bar to draw
-  UnsignedLong indexLeft(0);
+  UnsignedInteger indexLeft(0);
   while (first_ + cumulatedWidth_[indexLeft] < xMin) ++indexLeft;
   // Another special case: the plot range covers only partially a unique bar
   if (first_ + cumulatedWidth_[indexLeft] >= xMax)
@@ -440,8 +462,8 @@ Graph Histogram::drawPDF(const NumericalScalar xMin,
     return graphPDF;
   }
   // Find the index of the right bar to draw
-  UnsignedLong indexRight(indexLeft);
-  UnsignedLong shiftFull(0);
+  UnsignedInteger indexRight(indexLeft);
+  UnsignedInteger shiftFull(0);
   NumericalSample dataFull(0, 2);
   while ((indexRight < size) && (first_ + cumulatedWidth_[indexRight] < xMax)) ++indexRight;
   // The graph is made of full bars for the class indices between indexLeft and indexRight
@@ -474,7 +496,7 @@ Graph Histogram::drawPDF(const NumericalScalar xMin,
   // Central part of the graph
   NumericalScalar startX(first_);
   if (indexLeft + shiftFull > 0) startX += cumulatedWidth_[indexLeft + shiftFull];
-  for (UnsignedLong i = indexLeft + shiftFull; i < indexRight; ++i)
+  for (UnsignedInteger i = indexLeft + shiftFull; i < indexRight; ++i)
   {
     NumericalSample data(4, 2);
     data[0][0] = startX;
