@@ -3,7 +3,7 @@
  *  @file  HistogramFactory.cxx
  *  @brief Factory for Histogram distribution
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -23,6 +23,7 @@
  */
 #include "HistogramFactory.hxx"
 #include "HistogramPair.hxx"
+#include "DistFunc.hxx"
 #include "Exception.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
@@ -57,30 +58,33 @@ HistogramFactory::Implementation HistogramFactory::build() const
 
 Histogram HistogramFactory::buildAsHistogram(const NumericalSample & sample) const
 {
-  if (sample.getDimension() != 1) throw InvalidDimensionException(HERE) << "Error: can build an Histogram only if dimension equals 1, here dimension=" << sample.getDimension();
+  if (sample.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: can build an Histogram only if dimension equals 1, here dimension=" << sample.getDimension();
   // Construct the histogram
   // It will extends from min to max.
   const NumericalScalar min(sample.getMin()[0]);
   const NumericalScalar max(sample.getMax()[0]);
   if (max == min) throw InvalidArgumentException(HERE) << "Error: cannot build an Histogram for a sample with constant realizations";
-  const UnsignedLong size(sample.getSize());
-  NumericalScalar hOpt(sample.computeStandardDeviationPerComponent()[0] * pow(24.0 * sqrt(M_PI) / size, 1.0 / 3.0));
-  const UnsignedLong barNumber(static_cast<UnsignedLong>(ceil((max - min) / hOpt + 0.5)));
+  const UnsignedInteger size(sample.getSize());
+  // First, try to use the robust estimation of dispersion based on inter-quartile
+  NumericalScalar hOpt((sample.computeQuantilePerComponent(0.75)[0] - sample.computeQuantilePerComponent(0.25)[0]) * std::pow(24.0 * std::sqrt(M_PI) / size, 1.0 / 3.0) / (2.0 * DistFunc::qNormal(0.75)));
+  // If we get a zero, try using standard deviation
+  if (hOpt == 0.0) hOpt = sample.computeStandardDeviationPerComponent()[0] * std::pow(24.0 * std::sqrt(M_PI) / size, 1.0 / 3.0);
+  const UnsignedInteger barNumber(static_cast<UnsignedInteger>(ceil((max - min) / hOpt + 0.5)));
   // Adjust the bin with in order to match the bin number. Add a small adjustment in order to have bins defined as [x_k, x_k+1[ intervals
   const NumericalScalar delta(ResourceMap::GetAsNumericalScalar("DistributionImplementation-DefaultQuantileEpsilon") * (max - min));
   hOpt = ((max - min) + delta) / barNumber;
   NumericalPoint heights(barNumber, 0.0);
   const NumericalScalar step(1.0 / hOpt);
   // Aggregate the realizations into the bins
-  for(UnsignedLong i = 0; i < size; ++i)
+  for(UnsignedInteger i = 0; i < size; ++i)
   {
     // The index takes values in [[0, barNumber-1]] because min <= sample[i][0] <= max and step < barNumber / (max - min)
-    const UnsignedLong index(static_cast<UnsignedLong>(floor((sample[i][0] - min) * step)));
+    const UnsignedInteger index(static_cast<UnsignedInteger>(floor((sample[i][0] - min) * step)));
     heights[index] += 1.0;
   }
   const NumericalScalar inverseArea(1.0 / (hOpt * size));
   Histogram::HistogramPairCollection collection(barNumber);
-  for(UnsignedLong i = 0; i < barNumber; ++i) collection[i] = HistogramPair(hOpt, heights[i] * inverseArea);
+  for(UnsignedInteger i = 0; i < barNumber; ++i) collection[i] = HistogramPair(hOpt, heights[i] * inverseArea);
   Histogram result(min, collection);
   result.setDescription(sample.getDescription());
   return result;
