@@ -3,7 +3,7 @@
  *  @file  MeixnerDistribution.cxx
  *  @brief The MeixnerDistribution distribution
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -40,13 +40,14 @@ static Factory<MeixnerDistribution> RegisteredFactory("MeixnerDistribution");
 
 /* Default constructor */
 MeixnerDistribution::MeixnerDistribution()
-  : ContinuousDistribution("MeixnerDistribution")
+  : ContinuousDistribution()
   , alpha_(0.0)
   , beta_(0.0)
   , delta_(0.0)
   , mu_(0.0)
   , logNormalizationFactor_(0.0)
 {
+  setName("MeixnerDistribution");
   setAlphaBetaDelta(1.0, 0.0, 1.0);
   setDimension(1);
 }
@@ -56,13 +57,14 @@ MeixnerDistribution::MeixnerDistribution(const NumericalScalar alpha,
     const NumericalScalar beta,
     const NumericalScalar delta,
     const NumericalScalar mu)
-  : ContinuousDistribution("MeixnerDistribution")
+  : ContinuousDistribution()
   , alpha_(0.0)
   , beta_(0.0)
   , delta_(0.0)
   , mu_(mu)
   , logNormalizationFactor_(0.0)
 {
+  setName("MeixnerDistribution");
   setAlphaBetaDelta(alpha, beta, delta);
   setDimension(1);
 }
@@ -119,7 +121,7 @@ NumericalScalar MeixnerDistribution::getAlpha() const
 /* Beta accessor */
 void MeixnerDistribution::setBeta(const NumericalScalar beta)
 {
-  if (fabs(beta) >= M_PI) throw InvalidArgumentException(HERE) << "Beta MUST be in (-pi, pi)";
+  if (std::abs(beta) >= M_PI) throw InvalidArgumentException(HERE) << "Beta MUST be in (-pi, pi)";
   if (beta != beta_)
   {
     beta_ = beta;
@@ -153,7 +155,7 @@ void MeixnerDistribution::setAlphaBetaDelta(const NumericalScalar alpha,
     const NumericalScalar delta)
 {
   if (alpha <= 0.0) throw InvalidArgumentException(HERE) << "Alpha MUST be positive";
-  if (fabs(beta) >= M_PI) throw InvalidArgumentException(HERE) << "Beta MUST be in (-pi, pi)";
+  if (std::abs(beta) >= M_PI) throw InvalidArgumentException(HERE) << "Beta MUST be in (-pi, pi)";
   if (delta <= 0.0) throw InvalidArgumentException(HERE) << "Delta MUST be positive";
   if ((alpha != alpha_) || (beta != beta_) || (delta != delta_))
   {
@@ -191,7 +193,7 @@ void MeixnerDistribution::computeRange()
   const NumericalPoint mu(getMean());
   const NumericalPoint sigma(getStandardDeviation());
   const NumericalScalar logPDF(computeLogPDF(mu));
-  const NumericalScalar logPDFEpsilon(log(getPDFEpsilon()));
+  const NumericalScalar logPDFEpsilon(std::log(getPDFEpsilon()));
   NumericalPoint lowerBound(mu);
   // Find the numerical lower bound based on the PDF value
   NumericalScalar logPDFLower(logPDF);
@@ -224,12 +226,12 @@ struct MeixnerBounds
 
   NumericalPoint computeObjectiveB(const NumericalPoint & point) const
   {
-    return NumericalPoint(1, sqrt(distribution_.computePDF(point)));
+    return NumericalPoint(1, std::sqrt(distribution_.computePDF(point)));
   }
 
   NumericalPoint computeObjectiveCD(const NumericalPoint & point) const
   {
-    return NumericalPoint(1, point[0] * sqrt(distribution_.computePDF(point)));
+    return NumericalPoint(1, point[0] * std::sqrt(distribution_.computePDF(point)));
   }
 
   const MeixnerDistribution & distribution_;
@@ -239,13 +241,13 @@ struct MeixnerBounds
 void MeixnerDistribution::update()
 {
   // First, the parameters of the distribution
-  logNormalizationFactor_ = 2.0 * delta_ * log(2.0 * cos(0.5 * beta_)) - log(2.0 * M_PI * alpha_) - SpecFunc::LogGamma(2.0 * delta_);
+  logNormalizationFactor_ = 2.0 * delta_ * std::log(2.0 * std::cos(0.5 * beta_)) - std::log(2.0 * M_PI * alpha_) - SpecFunc::LogGamma(2.0 * delta_);
   computeRange();
   // Second, the moments
   isAlreadyComputedMean_ = false;
   isAlreadyComputedCovariance_ = false;
   // Third, the CDF and complementary CDF
-  Collection<PiecewiseHermiteEvaluationImplementation> CDFCCDF(interpolateCDF(ResourceMap::GetAsUnsignedLong("MeixnerDistribution-CDFDiscretization")));
+  Collection<PiecewiseHermiteEvaluationImplementation> CDFCCDF(interpolateCDF(ResourceMap::GetAsUnsignedInteger("MeixnerDistribution-CDFDiscretization")));
   cdfApproximation_ = CDFCCDF[0];
   ccdfApproximation_ = CDFCCDF[1];
   // Fourth, the random generator
@@ -260,16 +262,16 @@ void MeixnerDistribution::update()
   algorithm.setBoundConstraints(getRange());
   NumericalMathFunction fB(bindMethod<MeixnerBounds, NumericalPoint, NumericalPoint>(boundsFunctions, &MeixnerBounds::computeObjectiveB, 1, 1));
   const NumericalPoint epsilon(1.0e-5 * getStandardDeviation());
-  const CenteredFiniteDifferenceGradient gradientB(epsilon, fB.getEvaluationImplementation());
-  fB.setGradientImplementation(gradientB.clone());
+  const CenteredFiniteDifferenceGradient gradientB(epsilon, fB.getEvaluation());
+  fB.setGradient(gradientB.clone());
   algorithm.setObjectiveFunction(fB);
   // Tell the algorithm we want to maximize the objective function
   algorithm.setOptimizationProblem(BoundConstrainedAlgorithmImplementationResult::MAXIMIZATION);
   algorithm.run();
   b_ = algorithm.getResult().getOptimalValue();
   NumericalMathFunction fCD(bindMethod<MeixnerBounds, NumericalPoint, NumericalPoint>(boundsFunctions, &MeixnerBounds::computeObjectiveCD, 1, 1));
-  const CenteredFiniteDifferenceGradient gradientCD(epsilon, fCD.getEvaluationImplementation());
-  fCD.setGradientImplementation(gradientCD.clone());
+  const CenteredFiniteDifferenceGradient gradientCD(epsilon, fCD.getEvaluation());
+  fCD.setGradient(gradientCD.clone());
   algorithm.setObjectiveFunction(fCD);
   // Tell the algorithm we want to minimize the objective function
   algorithm.setOptimizationProblem(BoundConstrainedAlgorithmImplementationResult::MINIMIZATION);
@@ -295,7 +297,7 @@ NumericalPoint MeixnerDistribution::getRealization() const
     if (u == 0.0) continue;
     const NumericalScalar v(c_ + dc_ * RandomGenerator::Generate());
     const NumericalScalar rho(v / u);
-    if (2.0 * log(u) <= computeLogPDF(rho)) return NumericalPoint(1, rho);
+    if (2.0 * std::log(u) <= computeLogPDF(rho)) return NumericalPoint(1, rho);
   }
 }
 
@@ -304,7 +306,7 @@ NumericalScalar MeixnerDistribution::computePDF(const NumericalPoint & point) co
 {
   if (point.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=1, here dimension=" << point.getDimension();
 
-  return exp(computeLogPDF(point));
+  return std::exp(computeLogPDF(point));
 }
 
 NumericalScalar MeixnerDistribution::computeLogPDF(const NumericalPoint & point) const
@@ -339,7 +341,7 @@ NumericalScalar MeixnerDistribution::computeScalarQuantile(const NumericalScalar
   const NumericalScalar b(getRange().getUpperBound()[0]);
   if (prob <= 0.0) return (tail ? b : a);
   if (prob >= 1.0) return (tail ? a : b);
-  const UnsignedLong n(cdfApproximation_.getLocations().getSize());
+  const UnsignedInteger n(cdfApproximation_.getLocations().getSize());
   if (tail)
   {
     // Here we have to solve ComplementaryCDF(x) = prob which is mathematically
@@ -360,37 +362,37 @@ NumericalScalar MeixnerDistribution::computeScalarQuantile(const NumericalScalar
 /* Get the characteristic function of the distribution, i.e. phi(u) = E(exp(I*u*X)) */
 NumericalComplex MeixnerDistribution::computeCharacteristicFunction(const NumericalScalar x) const
 {
-  return exp(computeLogCharacteristicFunction(x));
+  return std::exp(computeLogCharacteristicFunction(x));
 }
 
 NumericalComplex MeixnerDistribution::computeLogCharacteristicFunction(const NumericalScalar x) const
 {
-  return NumericalComplex(2.0 * delta_ * log(cos(0.5 * beta_)), mu_ * x) - 2.0 * delta_ * log(cosh(NumericalComplex(0.5 * alpha_ * x, -0.5 * mu_)));
+  return NumericalComplex(2.0 * delta_ * std::log(std::cos(0.5 * beta_)), mu_ * x) - 2.0 * delta_ * std::log(std::cosh(NumericalComplex(0.5 * alpha_ * x, -0.5 * mu_)));
 }
 
 /* Compute the mean of the distribution */
 void MeixnerDistribution::computeMean() const
 {
-  mean_ = NumericalPoint(1, alpha_ * delta_ * tan(0.5 * beta_) + mu_);
+  mean_ = NumericalPoint(1, alpha_ * delta_ * std::tan(0.5 * beta_) + mu_);
   isAlreadyComputedMean_ = true;
 }
 
 /* Get the standard deviation of the distribution */
 NumericalPoint MeixnerDistribution::getStandardDeviation() const
 {
-  return NumericalPoint(1, alpha_ * sqrt(delta_ / (1.0 + cos(beta_))));
+  return NumericalPoint(1, alpha_ * std::sqrt(delta_ / (1.0 + std::cos(beta_))));
 }
 
 /* Get the skewness of the distribution */
 NumericalPoint MeixnerDistribution::getSkewness() const
 {
-  return NumericalPoint(1, sin(0.5 * beta_) * sqrt(2.0 / delta_));
+  return NumericalPoint(1, std::sin(0.5 * beta_) * std::sqrt(2.0 / delta_));
 }
 
 /* Get the kurtosis of the distribution */
 NumericalPoint MeixnerDistribution::getKurtosis() const
 {
-  return NumericalPoint(1, 3.0 + (2.0 - cos(beta_)) / delta_);
+  return NumericalPoint(1, 3.0 + (2.0 - std::cos(beta_)) / delta_);
 }
 
 /* Get the standard representative in the parametric family, associated with the standard moments */
@@ -403,7 +405,7 @@ MeixnerDistribution::Implementation MeixnerDistribution::getStandardRepresentati
 void MeixnerDistribution::computeCovariance() const
 {
   covariance_ = CovarianceMatrix(1);
-  covariance_(0, 0) = alpha_ * alpha_ * delta_ / (1.0 + cos(beta_));
+  covariance_(0, 0) = alpha_ * alpha_ * delta_ / (1.0 + std::cos(beta_));
   isAlreadyComputedCovariance_ = true;
 }
 
@@ -429,7 +431,9 @@ MeixnerDistribution::NumericalPointWithDescriptionCollection MeixnerDistribution
 
 void MeixnerDistribution::setParametersCollection(const NumericalPointCollection & parametersCollection)
 {
+  const NumericalScalar w(getWeight());
   *this = MeixnerDistribution(parametersCollection[0][0], parametersCollection[0][1], parametersCollection[0][2], parametersCollection[0][3]);
+  setWeight(w);
 }
 
 /* Method save() stores the object through the StorageManager */
