@@ -3,7 +3,7 @@
  *  @file  MinCopula.cxx
  *  @brief A class that implements an independent copula
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -36,9 +36,10 @@ CLASSNAMEINIT(MinCopula);
 static Factory<MinCopula> RegisteredFactory("MinCopula");
 
 /* Default constructor */
-MinCopula::MinCopula(const UnsignedLong dim)
-  : CopulaImplementation("MinCopula")
+MinCopula::MinCopula(const UnsignedInteger dim)
+  : CopulaImplementation()
 {
+  setName("MinCopula");
   // The range is generic for all the copulas
   setDimension(dim);
   computeRange();
@@ -83,7 +84,7 @@ NumericalPoint MinCopula::getRealization() const
 /* Get the DDF of the distribution */
 NumericalPoint MinCopula::computeDDF(const NumericalPoint & point) const
 {
-  const UnsignedLong dimension(getDimension());
+  const UnsignedInteger dimension(getDimension());
   if (point.getDimension() != dimension) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=" << dimension << ", here dimension=" << point.getDimension();
 
   return NumericalPoint(dimension, 0.0);
@@ -92,24 +93,22 @@ NumericalPoint MinCopula::computeDDF(const NumericalPoint & point) const
 /* Get the PDF of the distribution */
 NumericalScalar MinCopula::computePDF(const NumericalPoint & point) const
 {
-  const UnsignedLong dimension(getDimension());
+  const UnsignedInteger dimension(getDimension());
   if (point.getDimension() != dimension) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=" << dimension << ", here dimension=" << point.getDimension();
 
   const NumericalScalar u(point[0]);
   if ((u <= 0.0) || (u > 1.0)) return 0.0;
-  for (UnsignedLong i = 1; i < dimension; ++i) if (u != point[i]) return 0.0;
+  for (UnsignedInteger i = 1; i < dimension; ++i) if (u != point[i]) return 0.0;
   return u;
 }
 
 /* Get the CDF of the distribution */
 NumericalScalar MinCopula::computeCDF(const NumericalPoint & point) const
 {
-  const UnsignedLong dimension(getDimension());
+  const UnsignedInteger dimension(getDimension());
   if (point.getDimension() != dimension) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=" << dimension << ", here dimension=" << point.getDimension();
 
-  NumericalScalar u(point[0]);
-  for (UnsignedLong i = 1; i < dimension; ++i) if (point[i] < u) u = point[i];
-  return std::max(0.0, std::min(1.0, u));
+  return std::max(0.0, std::min(1.0, *std::min_element(point.begin(), point.end())));
 } // computeCDF
 
 /* Compute the survival function */
@@ -132,32 +131,22 @@ NumericalPoint MinCopula::computeQuantile(const NumericalScalar prob,
 /* Compute the covariance of the distribution */
 void MinCopula::computeCovariance() const
 {
-  const UnsignedLong dimension(getDimension());
-  covariance_ = CovarianceMatrix(dimension);
-  for (UnsignedLong i = 0; i < dimension; ++i)
-    for (UnsignedLong j = 0; j <= i; ++j)
-      covariance_(i, j) = 1.0 / 12.0;
+  const UnsignedInteger dimension(getDimension());
+  covariance_ = CovarianceMatrix(dimension, Collection<NumericalScalar>(dimension * dimension, 1.0 / 12.0));
   isAlreadyComputedCovariance_ = true;
 }
 
-/* Get the Spearman correlation of the distribution */
-CorrelationMatrix MinCopula::getSpearmanCorrelation() const
-{
-  const UnsignedLong dimension(getDimension());
-  return CorrelationMatrix(dimension, Collection<NumericalScalar>(dimension * dimension, 1.0));
-}
-
 /* Get the Kendall concordance of the distribution */
 CorrelationMatrix MinCopula::getKendallTau() const
 {
-  const UnsignedLong dimension(getDimension());
+  const UnsignedInteger dimension(getDimension());
   return CorrelationMatrix(dimension, Collection<NumericalScalar>(dimension * dimension, 1.0));
 }
 
 /* Get the distribution of the marginal distribution corresponding to indices dimensions */
 MinCopula::Implementation MinCopula::getMarginal(const Indices & indices) const
 {
-  const UnsignedLong dimension(getDimension());
+  const UnsignedInteger dimension(getDimension());
   if (!indices.check(dimension - 1)) throw InvalidArgumentException(HERE) << "The indices of a marginal distribution must be in the range [0, dim-1] and  must be different";
   // Special case for dimension 1
   if (dimension == 1) return clone();
@@ -165,8 +154,8 @@ MinCopula::Implementation MinCopula::getMarginal(const Indices & indices) const
   return new MinCopula(indices.getSize());
 }
 
-/* Get the inverse isoprobabilist transformation */
-MinCopula::InverseIsoProbabilisticTransformation MinCopula::getIsoProbabilisticTransformation() const
+/* Get the isoprobabilist transformation */
+MinCopula::IsoProbabilisticTransformation MinCopula::getIsoProbabilisticTransformation() const
 {
   throw NotDefinedException(HERE) << "Error: no iso-probabilistic transformation can be defined for the Min copula.";
 }
@@ -192,7 +181,7 @@ Bool MinCopula::isContinuous() const
 /* Tell if the distribution has elliptical copula */
 Bool MinCopula::hasEllipticalCopula() const
 {
-  return false;
+  return hasIndependentCopula();
 }
 
 /* Tell if the distribution has independent copula */
