@@ -3,7 +3,7 @@
  *  @file  Multinomial.cxx
  *  @brief The Multinomial distribution
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -37,7 +37,7 @@
 
 BEGIN_NAMESPACE_OPENTURNS
 
-typedef Collection<UnsignedLong>     UnsignedLongCollection;
+typedef Collection<UnsignedInteger>     UnsignedIntegerCollection;
 
 CLASSNAMEINIT(Multinomial);
 
@@ -45,28 +45,30 @@ static Factory<Multinomial> RegisteredFactory("Multinomial");
 
 /* Default constructor */
 Multinomial::Multinomial()
-  : DiscreteDistribution("Multinomial")
+  : DiscreteDistribution()
   , n_(0)
   , p_(0)
   , sumP_(0.0)
   , smallA_(ResourceMap::GetAsNumericalScalar("Multinomial-smallA"))
   , eta_(ResourceMap::GetAsNumericalScalar("Multinomial-eta"))
 {
+  setName("Multinomial");
   // This method compute the range also
   setN(1);
   setP( NumericalPoint(1, 0.5) );
 }
 
 /* Parameters constructor */
-Multinomial::Multinomial(const UnsignedLong n,
+Multinomial::Multinomial(const UnsignedInteger n,
                          const NumericalPoint & p)
-  : DiscreteDistribution("Multinomial")
+  : DiscreteDistribution()
   , n_(0)
   , p_(0)
   , sumP_(0.0)
   , smallA_(ResourceMap::GetAsNumericalScalar("Multinomial-smallA"))
   , eta_(ResourceMap::GetAsNumericalScalar("Multinomial-eta"))
 {
+  setName("Multinomial");
   // This method compute the range also
   setN( n );
   setP( p );
@@ -108,7 +110,7 @@ Multinomial * Multinomial::clone() const
 /* Compute the numerical range of the distribution given the parameters values */
 void Multinomial::computeRange()
 {
-  const UnsignedLong dimension(getDimension());
+  const UnsignedInteger dimension(getDimension());
   const NumericalPoint lowerBound(dimension, 0.0);
   const NumericalPoint upperBound(dimension, n_);
   const Interval::BoolCollection finiteLowerBound(dimension, true);
@@ -119,16 +121,16 @@ void Multinomial::computeRange()
 /* Get one realization of the distribution */
 NumericalPoint Multinomial::getRealization() const
 {
-  const UnsignedLong dimension(getDimension());
+  const UnsignedInteger dimension(getDimension());
   NumericalPoint realization(dimension);
   /* We use an elementary algorithm based on the definition of the Multinomial distribution:
    * the i-th component is generated using a Binomial distribution */
-  UnsignedLong n(n_);
+  UnsignedInteger n(n_);
   NumericalScalar sum(1.0);
-  for (UnsignedLong i = 0; i < dimension; ++i)
+  for (UnsignedInteger i = 0; i < dimension; ++i)
   {
     /* The current component follow a binomial distribution with parameters p_[i] and N */
-    const UnsignedLong xI(DistFunc::rBinomial(n, p_[i] / sum));
+    const UnsignedInteger xI(DistFunc::rBinomial(n, p_[i] / sum));
     realization[i] = xI;
     n -= xI;
     sum -= p_[i];
@@ -139,29 +141,29 @@ NumericalPoint Multinomial::getRealization() const
 /* Get the PDF of the distribution */
 NumericalScalar Multinomial::computePDF(const NumericalPoint & point) const
 {
-  const UnsignedLong dimension(getDimension());
+  const UnsignedInteger dimension(getDimension());
   if (point.getDimension() != dimension) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=" << dimension << ", here dimension=" << point.getDimension();
 
   // First, check the validity of the input
   NumericalScalar sumX(0.0);
-  for (UnsignedLong i = 0; i < dimension; ++i)
+  for (UnsignedInteger i = 0; i < dimension; ++i)
   {
     const NumericalScalar k(point[i]);
     // Early exit if the given point is not in the support of the distribution
-    if ((fabs(k - round(k)) > supportEpsilon_) || (k < -supportEpsilon_) || (k > n_ + supportEpsilon_)) return 0.0;
+    if ((std::abs(k - round(k)) > supportEpsilon_) || (k < -supportEpsilon_) || (k > n_ + supportEpsilon_)) return 0.0;
     sumX += k;
   }
   if (sumX > n_ + supportEpsilon_) return 0.0;
   NumericalScalar logPDF(lgamma(n_ + 1.0) - lgamma(n_ - sumX + 1.0) + (n_ - sumX) * log1p(-sumP_));
-  for (UnsignedLong i = 0; i < dimension; ++i)
+  for (UnsignedInteger i = 0; i < dimension; ++i)
   {
     const NumericalScalar k(point[i]);
     // For p_[i] > 0, it is possible to obtain any value of k between 0 and n
-    if (p_[i] > 0.0) logPDF += k * log(p_[i]) - lgamma(k + 1.0);
+    if (p_[i] > 0.0) logPDF += k * std::log(p_[i]) - lgamma(k + 1.0);
     // Else only k == 0 is allowed, with a zero contribution to the log PDF
     else if (k > 0) return 0.0;
   }
-  return exp(logPDF);
+  return std::exp(logPDF);
 }
 
 /* Compute the generating function of a sum of truncated Poisson distributions as needed in the computeCDF() method */
@@ -169,12 +171,12 @@ NumericalComplex Multinomial::computeGlobalPhi(const NumericalComplex & z,
     const NumericalPoint & x) const
 {
   // Initialize with the non truncated term
-  NumericalComplex value(exp(-(1.0 - sumP_) * n_ * (1.0 - z)));
-  const UnsignedLong dimension(getDimension());
-  for (UnsignedLong i = 0; i < dimension; ++i)
+  NumericalComplex value(std::exp(-(1.0 - sumP_) * n_ * (1.0 - z)));
+  const UnsignedInteger dimension(getDimension());
+  for (UnsignedInteger i = 0; i < dimension; ++i)
   {
     value *= computeLocalPhi(z, n_ * p_[i], x[i]);
-    if (abs(value) == 0.0)
+    if (std::abs(value) == 0.0)
     {
       LOGWARN("Underflow in Multinomial::computePhi");
       return 0.0;
@@ -190,13 +192,13 @@ NumericalComplex Multinomial::computeLocalPhi(const NumericalComplex & z,
 {
   if (z == 0.0) return 1.0;
   const NumericalComplex u(lambda * z);
-  const UnsignedLong iMax(static_cast< UnsignedLong > (floor(a)));
+  const UnsignedInteger iMax(static_cast< UnsignedInteger > (floor(a)));
   // Small value of a, evaluate the generating function as a polynomial
   if (a <= smallA_)
   {
-    NumericalComplex value(exp(-lambda));
+    NumericalComplex value(std::exp(-lambda));
     NumericalComplex term(value);
-    for (UnsignedLong i = 1; i <= iMax; ++i)
+    for (UnsignedInteger i = 1; i <= iMax; ++i)
     {
       term *= u / NumericalComplex(i);
       value += term;
@@ -204,10 +206,10 @@ NumericalComplex Multinomial::computeLocalPhi(const NumericalComplex & z,
     return value;
   } // smallA_
   // Large a
-  NumericalComplex value(exp(-lambda + u));
-  UnsignedLong i(iMax + 1);
-  NumericalComplex term(exp(-lambda + NumericalComplex(i) * log(u) - lgamma(i + 1.0)));
-  while (abs(term) > SpecFunc::Precision * abs(value))
+  NumericalComplex value(std::exp(-lambda + u));
+  UnsignedInteger i(iMax + 1);
+  NumericalComplex term(std::exp(-lambda + NumericalComplex(i) * std::log(u) - lgamma(i + 1.0)));
+  while (std::abs(term) > SpecFunc::Precision * std::abs(value))
   {
     value -= term;
     ++i;
@@ -222,7 +224,7 @@ NumericalComplex Multinomial::computeLocalPhi(const NumericalComplex & z,
 */
 NumericalScalar Multinomial::computeCDF(const NumericalPoint & point) const
 {
-  const UnsignedLong dimension(getDimension());
+  const UnsignedInteger dimension(getDimension());
   if (point.getDimension() != dimension) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=" << dimension << ", here dimension=" << point.getDimension();
 
   // Early exit for 1D case
@@ -238,26 +240,26 @@ NumericalScalar Multinomial::computeCDF(const NumericalPoint & point) const
   Bool allZero(true);
   NumericalScalar sumX(0.0);
   // Trivial cases
-  for (UnsignedLong i = 0; i < dimension; ++i)
+  for (UnsignedInteger i = 0; i < dimension; ++i)
   {
     // If the given point does not cover any point of the support, return 0.0
     if (point[i] < -supportEpsilon_) return 0.0;
     if (point[i] < n_ - supportEpsilon_) indices.add(i);
-    allZero = allZero && (fabs(point[i]) < supportEpsilon_);
+    allZero = allZero && (std::abs(point[i]) < supportEpsilon_);
     sumX += point[i];
   }
   // If we are at the origin, CDF=PDF(0,...,0)
-  if (allZero) return pow(1.0 - sumP_, n_);
+  if (allZero) return std::pow(1.0 - sumP_, static_cast<int>(n_));
   // If the atoms with non zero probability sum to N
-  if ((fabs(sumP_ - 1.0) < supportEpsilon_) && (sumX == n_))
+  if ((std::abs(sumP_ - 1.0) < supportEpsilon_) && (sumX == n_))
   {
     NumericalScalar value(lgamma(n_ + 1));
-    for (UnsignedLong j = 0; j < dimension; ++j)
-      value += point[j] * log(p_[j]) - lgamma(point[j] + 1.0);
-    return exp(value);
+    for (UnsignedInteger j = 0; j < dimension; ++j)
+      value += point[j] * std::log(p_[j]) - lgamma(point[j] + 1.0);
+    return std::exp(value);
   }
   // If the point covers the whole support of the distribution, return 1.0
-  const UnsignedLong size(indices.getSize());
+  const UnsignedInteger size(indices.getSize());
   if (size == 0) return 1.0;
   // Now, check if there is a possible reduction of the dimension
   if (size < dimension)
@@ -265,7 +267,7 @@ NumericalScalar Multinomial::computeCDF(const NumericalPoint & point) const
     // reduce the dimension to the active indices
     NumericalPoint pReduced(size);
     NumericalPoint xReduced(size);
-    for (UnsignedLong i = 0; i < size; ++i)
+    for (UnsignedInteger i = 0; i < size; ++i)
     {
       pReduced[i] = p_[indices[i]];
       xReduced[i] = point[indices[i]];
@@ -274,11 +276,11 @@ NumericalScalar Multinomial::computeCDF(const NumericalPoint & point) const
   }
   // Evaluation of P(W=n) using Poisson's formula
   NumericalComplex phiK(computeGlobalPhi(r_, point));
-  const NumericalComplex zetaN(exp(NumericalComplex(0.0, M_PI / n_)));
+  const NumericalComplex zetaN(std::exp(NumericalComplex(0.0, M_PI / n_)));
   NumericalComplex phiKp1(computeGlobalPhi(r_ * zetaN, point));
   NumericalComplex delta(phiK - phiKp1);
   NumericalScalar value(delta.real());
-  const NumericalScalar dv0(abs(delta));
+  const NumericalScalar dv0(std::abs(delta));
   if (dv0 == 0.0)
   {
     LOGWARN("Underflow in Multinomial::computeCDF");
@@ -286,14 +288,14 @@ NumericalScalar Multinomial::computeCDF(const NumericalPoint & point) const
   }
   NumericalScalar sign(-1.0);
   NumericalComplex t(zetaN);
-  for (UnsignedLong k = 1; k < n_; ++k)
+  for (UnsignedInteger k = 1; k < n_; ++k)
   {
     phiK = phiKp1;
     t *= zetaN;
     phiKp1 = computeGlobalPhi(r_ * t, point);
     delta = phiK - phiKp1;
     value += sign * delta.real();
-    const NumericalScalar dv(abs(delta));
+    const NumericalScalar dv(std::abs(delta));
     if (dv < SpecFunc::Precision * dv0) break;
     sign = -sign;
   }
@@ -314,85 +316,85 @@ NumericalScalar Multinomial::computeScalarQuantile(const NumericalScalar prob,
 NumericalScalar Multinomial::computeConditionalPDF(const NumericalScalar x,
     const NumericalPoint & y) const
 {
-  const UnsignedLong conditioningDimension(y.getDimension());
+  const UnsignedInteger conditioningDimension(y.getDimension());
   if (conditioningDimension >= getDimension()) throw InvalidArgumentException(HERE) << "Error: cannot compute a conditional PDF with a conditioning point of dimension greater or equal to the distribution dimension.";
   // Special case for no conditioning or independent copula
   if (conditioningDimension == 0) return Binomial(n_, p_[0]).computePDF(x);
   // General case
   // Check that y is a valid conditioning vector
-  UnsignedLongCollection intY(conditioningDimension);
+  UnsignedIntegerCollection intY(conditioningDimension);
   NumericalScalar sumY(0.0);
   NumericalScalar sumP(0.0);
-  for (UnsignedLong i = 0; i < conditioningDimension; ++i)
+  for (UnsignedInteger i = 0; i < conditioningDimension; ++i)
   {
     const NumericalScalar yI(y[i]);
-    const UnsignedLong intYI(static_cast<UnsignedLong>(round(yI)));
-    if (fabs(yI - intYI) > supportEpsilon_) throw InvalidArgumentException(HERE) << "Error: the conditioning vector has non-integer values";
+    const UnsignedInteger intYI(static_cast<UnsignedInteger>(round(yI)));
+    if (std::abs(yI - intYI) > supportEpsilon_) throw InvalidArgumentException(HERE) << "Error: the conditioning vector has non-integer values";
     sumY += yI;
     intY[i] = intYI;
     sumP += p_[i];
   }
   if (sumY > n_) throw InvalidArgumentException(HERE) << "Error: the conditioning vector has a sum of components greater than the allowed range.";
-  return Binomial(static_cast<UnsignedLong>(n_ - sumY), p_[conditioningDimension] / sumP).computePDF(x);
+  return Binomial(static_cast<UnsignedInteger>(n_ - sumY), p_[conditioningDimension] / sumP).computePDF(x);
 }
 
 /* Compute the CDF of Xi | X1, ..., Xi-1. x = Xi, y = (X1,...,Xi-1) */
 NumericalScalar Multinomial::computeConditionalCDF(const NumericalScalar x,
     const NumericalPoint & y) const
 {
-  const UnsignedLong conditioningDimension(y.getDimension());
+  const UnsignedInteger conditioningDimension(y.getDimension());
   if (conditioningDimension >= getDimension()) throw InvalidArgumentException(HERE) << "Error: cannot compute a conditional CDF with a conditioning point of dimension greater or equal to the distribution dimension.";
   // Special case for no conditioning or independent copula
   if (conditioningDimension == 0) return Binomial(n_, p_[0]).computeCDF(x);
   // General case
   // Check that y is a valid conditioning vector
-  UnsignedLongCollection intY(conditioningDimension);
+  UnsignedIntegerCollection intY(conditioningDimension);
   NumericalScalar sumY(0.0);
   NumericalScalar sumP(0.0);
-  for (UnsignedLong i = 0; i < conditioningDimension; ++i)
+  for (UnsignedInteger i = 0; i < conditioningDimension; ++i)
   {
     const NumericalScalar yI(y[i]);
-    const UnsignedLong intYI(static_cast<UnsignedLong>(round(yI)));
-    if (fabs(yI - intYI) > supportEpsilon_) throw InvalidArgumentException(HERE) << "Error: the conditioning vector has non-integer values";
+    const UnsignedInteger intYI(static_cast<UnsignedInteger>(round(yI)));
+    if (std::abs(yI - intYI) > supportEpsilon_) throw InvalidArgumentException(HERE) << "Error: the conditioning vector has non-integer values";
     sumY += yI;
     intY[i] = intYI;
     sumP += p_[i];
   }
   if (sumY > n_) throw InvalidArgumentException(HERE) << "Error: the conditioning vector has a sum of components greater than the allowed range.";
-  return Binomial(static_cast<UnsignedLong>(n_ - sumY), p_[conditioningDimension] / sumP).computeCDF(x);
+  return Binomial(static_cast<UnsignedInteger>(n_ - sumY), p_[conditioningDimension] / sumP).computeCDF(x);
 }
 
 /* Compute the quantile of Xi | X1, ..., Xi-1, i.e. x such that CDF(x|y) = q with x = Xi, y = (X1,...,Xi-1) */
 NumericalScalar Multinomial::computeConditionalQuantile(const NumericalScalar q,
     const NumericalPoint & y) const
 {
-  const UnsignedLong conditioningDimension(y.getDimension());
+  const UnsignedInteger conditioningDimension(y.getDimension());
   if (conditioningDimension >= getDimension()) throw InvalidArgumentException(HERE) << "Error: cannot compute a conditional quantile with a conditioning point of dimension greater or equal to the distribution dimension.";
   if ((q < 0.0) || (q > 1.0)) throw InvalidArgumentException(HERE) << "Error: cannot compute a conditional quantile for a probability level outside of [0, 1]";
   // Special case when no contitioning or independent copula
   if (conditioningDimension == 0) return Binomial(n_, p_[0]).computeQuantile(q)[0];
   // General case
   // Check that y is a valid conditioning vector
-  UnsignedLongCollection intY(conditioningDimension);
+  UnsignedIntegerCollection intY(conditioningDimension);
   NumericalScalar sumY(0.0);
   NumericalScalar sumP(0.0);
-  for (UnsignedLong i = 0; i < conditioningDimension; ++i)
+  for (UnsignedInteger i = 0; i < conditioningDimension; ++i)
   {
     const NumericalScalar yI(y[i]);
-    const UnsignedLong intYI(static_cast<UnsignedLong>(round(yI)));
-    if (fabs(yI - intYI) > supportEpsilon_) throw InvalidArgumentException(HERE) << "Error: the conditioning vector has non-integer values";
+    const UnsignedInteger intYI(static_cast<UnsignedInteger>(round(yI)));
+    if (std::abs(yI - intYI) > supportEpsilon_) throw InvalidArgumentException(HERE) << "Error: the conditioning vector has non-integer values";
     sumY += yI;
     intY[i] = intYI;
     sumP += p_[i];
   }
   if (sumY > n_) throw InvalidArgumentException(HERE) << "Error: the conditioning vector has a sum of components greater than the allowed range.";
-  return Binomial(static_cast<UnsignedLong>(n_ - sumY), p_[conditioningDimension] / sumP).computeQuantile(q)[0];
+  return Binomial(static_cast<UnsignedInteger>(n_ - sumY), p_[conditioningDimension] / sumP).computeQuantile(q)[0];
 }
 
 /* Get the i-th marginal distribution */
-Multinomial::Implementation Multinomial::getMarginal(const UnsignedLong i) const
+Multinomial::Implementation Multinomial::getMarginal(const UnsignedInteger i) const
 {
-  const UnsignedLong dimension(getDimension());
+  const UnsignedInteger dimension(getDimension());
   if (i >= dimension) throw InvalidArgumentException(HERE) << "The index of a marginal distribution must be in the range [0, dim-1]";
   // Special case for dimension 1
   if (dimension == 1) return clone();
@@ -403,17 +405,17 @@ Multinomial::Implementation Multinomial::getMarginal(const UnsignedLong i) const
 /* Get the distribution of the marginal distribution corresponding to indices dimensions */
 Multinomial::Implementation Multinomial::getMarginal(const Indices & indices) const
 {
-  const UnsignedLong dimension(getDimension());
+  const UnsignedInteger dimension(getDimension());
   if (!indices.check(dimension - 1)) throw InvalidArgumentException(HERE) << "The indices of a marginal distribution must be in the range [0, dim-1] and  must be different";
   // Special case for dimension 1
   if (dimension == 1) return clone();
   // General case
-  const UnsignedLong outputDimension(indices.getSize());
+  const UnsignedInteger outputDimension(indices.getSize());
   NumericalPoint marginalP(outputDimension);
   // Extract the correlation matrix, the marginal standard deviations and means
-  for (UnsignedLong i = 0; i < outputDimension; ++i)
+  for (UnsignedInteger i = 0; i < outputDimension; ++i)
   {
-    const UnsignedLong index_i(indices[i]);
+    const UnsignedInteger index_i(indices[i]);
     marginalP[i] = p_[index_i];
   }
   return new Multinomial(n_, marginalP);
@@ -422,7 +424,7 @@ Multinomial::Implementation Multinomial::getMarginal(const Indices & indices) co
 /* Get the support of a discrete distribution that intersect a given interval */
 NumericalSample Multinomial::getSupport(const Interval & interval) const
 {
-  const UnsignedLong dimension(getDimension());
+  const UnsignedInteger dimension(getDimension());
   if (interval.getDimension() != dimension) throw InvalidArgumentException(HERE) << "Error: the given interval has a dimension that does not match the distribution dimension.";
   NumericalSample support(0, dimension);
   // Quick return if the lower bound of the interval is already outside of the support
@@ -430,7 +432,7 @@ NumericalSample Multinomial::getSupport(const Interval & interval) const
   const NumericalPoint upperBound(interval.getUpperBound());
   NumericalScalar sumLower(0.0);
   NumericalScalar sumUpper(0.0);
-  for (UnsignedLong i = 0; i < dimension; ++i)
+  for (UnsignedInteger i = 0; i < dimension; ++i)
   {
     // One of the components of the upper bound is negative, so the intersection with the positive quadrant is empty
     if (upperBound[i] < 0.0) return support;
@@ -445,7 +447,7 @@ NumericalSample Multinomial::getSupport(const Interval & interval) const
   if ((sumUpper >= n_) && (sumLower <= 0.0))
   {
     Bool allInside(true);
-    for (UnsignedLong i = 0; i < dimension; ++i)
+    for (UnsignedInteger i = 0; i < dimension; ++i)
     {
       allInside = allInside && (lowerBound[i] <= 0.0);
       if (!allInside) break;
@@ -453,8 +455,8 @@ NumericalSample Multinomial::getSupport(const Interval & interval) const
     if (allInside) return fullSupport;
   }
   // We have to remove some points
-  const UnsignedLong size(fullSupport.getSize());
-  for (UnsignedLong i = 0; i < size; ++i)
+  const UnsignedInteger size(fullSupport.getSize());
+  for (UnsignedInteger i = 0; i < size; ++i)
   {
     const NumericalPoint point(fullSupport[i]);
     const Bool isInside(interval.contains(point));
@@ -466,12 +468,15 @@ NumericalSample Multinomial::getSupport(const Interval & interval) const
 /* Get the support of a discrete distribution that intersect a given interval */
 NumericalSample Multinomial::getSupport() const
 {
-  const UnsignedLong dimension(getDimension());
+  const UnsignedInteger dimension(getDimension());
   LinearEnumerateFunction enumerate(dimension);
-  const UnsignedLong size(enumerate.getStrataCumulatedCardinal(n_));
+  const UnsignedInteger size(enumerate.getStrataCumulatedCardinal(n_));
   NumericalSample support(0, dimension);
-  for (UnsignedLong i = 0; i < size; ++i)
-    support.add(NumericalPoint(enumerate(i)));
+  for (UnsignedInteger i = 0; i < size; ++i)
+  {
+    Indices multi(enumerate(i));
+    support.add(Collection<NumericalScalar>(multi.begin(), multi.end()));
+  }
   return support;
 }
 
@@ -485,15 +490,15 @@ void Multinomial::computeMean() const
 /* Compute the covariance of the distribution */
 void Multinomial::computeCovariance() const
 {
-  const UnsignedLong dimension(getDimension());
+  const UnsignedInteger dimension(getDimension());
   // To insure a zero initialization
   covariance_ = CovarianceMatrix(dimension);
-  for (UnsignedLong i = 0; i < dimension; ++i)
+  for (UnsignedInteger i = 0; i < dimension; ++i)
   {
     const NumericalScalar pI(p_[i]);
     covariance_(i, i) = pI * (1.0 - pI) * n_;
-    // Be careful! in these computations, n_ cannot be at the begining of the formula else -n_ will underflow the UnsignedLong range!
-    for (UnsignedLong j = 0; j < i; ++j) covariance_(i, j) = -pI * p_[j] * n_;
+    // Be careful! in these computations, n_ cannot be at the begining of the formula else -n_ will underflow the UnsignedInteger range!
+    for (UnsignedInteger j = 0; j < i; ++j) covariance_(i, j) = -pI * p_[j] * n_;
   }
   isAlreadyComputedCovariance_ = true;
 }
@@ -501,9 +506,9 @@ void Multinomial::computeCovariance() const
 /* Parameters value and description accessor */
 Multinomial::NumericalPointWithDescriptionCollection Multinomial::getParametersCollection() const
 {
-  const UnsignedLong dimension(getDimension());
+  const UnsignedInteger dimension(getDimension());
   NumericalPointWithDescriptionCollection parameters((dimension == 1 ? 1 : dimension + 1));
-  for (UnsignedLong i = 0; i < dimension; ++i)
+  for (UnsignedInteger i = 0; i < dimension; ++i)
   {
     NumericalPointWithDescription point(2);
     point[0] = n_;
@@ -523,7 +528,7 @@ Multinomial::NumericalPointWithDescriptionCollection Multinomial::getParametersC
     Description description(dimension + 1);
     point[0] = n_;
     description[0] = "n";
-    for (UnsignedLong i = 0; i < dimension; ++i)
+    for (UnsignedInteger i = 0; i < dimension; ++i)
     {
       point[i + 1] = p_[i];
       OSS oss;
@@ -541,17 +546,26 @@ Multinomial::NumericalPointWithDescriptionCollection Multinomial::getParametersC
 void Multinomial::setP(const NumericalPoint & p)
 {
   // We check that the elements are all positive
-  const UnsignedLong dimension(p.getDimension());
+  const UnsignedInteger dimension(p.getDimension());
   if (dimension == 0) throw InvalidArgumentException(HERE) << "P must have a positive dimension.";
   NumericalScalar sum(0.0);
-  for(UnsignedLong i = 0; i < dimension; ++i)
+  for(UnsignedInteger i = 0; i < dimension; ++i)
   {
     NumericalScalar pI(p[i]);
     if (pI < 0.0) throw InvalidArgumentException(HERE) << "P elements MUST be nonnegative";
     sum += pI;
   }
-  p_ = p;
-  sumP_ = sum;
+  if (sum > 1.0)
+  {
+    LOGWARN(OSS() << "P elements have a sum=" << sum << " greater than 1. It has been renormalized to 1.0");
+    p_ = p / sum;
+    sumP_ = 1.0;
+  }
+  else
+  {
+    p_ = p;
+    sumP_ = sum;
+  }
   setDimension(dimension);
   isAlreadyComputedMean_ = false;
   isAlreadyComputedCovariance_ = false;
@@ -565,15 +579,15 @@ NumericalPoint Multinomial::getP() const
 }
 
 /* N accessor */
-void Multinomial::setN(const UnsignedLong n)
+void Multinomial::setN(const UnsignedInteger n)
 {
   if (n == 0) throw InvalidArgumentException(HERE) << "Error: n must be > 0.";
   if (n != n_)
   {
     n_ = n;
     // Best overall performance for Poisson's formula, see reference
-    r_ = pow(eta_, 1.0 / (2.0 * n));
-    normalizationCDF_ = exp(lgamma(n + 1.0) - n * log(n) + n - log(2.0 * n) - 0.5 * log(eta_));
+    r_ = std::pow(eta_, 1.0 / (2.0 * n));
+    normalizationCDF_ = std::exp(lgamma(n + 1.0) - n * std::log(1.0 * n) + n - std::log(2.0 * n) - 0.5 * std::log(eta_));
     isAlreadyComputedMean_ = false;
     isAlreadyComputedCovariance_ = false;
     isAlreadyCreatedGeneratingFunction_ = false;
@@ -581,7 +595,7 @@ void Multinomial::setN(const UnsignedLong n)
   }
 }
 
-UnsignedLong Multinomial::getN() const
+UnsignedInteger Multinomial::getN() const
 {
   return n_;
 }
