@@ -4,7 +4,7 @@
  *  @brief Efficient implementation of the CDF computation for a bi-dimensional
  *         Normal distribution
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -69,7 +69,7 @@ NumericalScalar Normal2DCDF(const NumericalScalar x1,
                             const NumericalScalar rho,
                             const Bool tail)
 {
-  NumericalScalar absRho(fabs(rho));
+  NumericalScalar absRho(std::abs(rho));
   if (absRho > 1.0) throw InvalidArgumentException(HERE) << "Error: the correlation coefficient must be in [-1,1], here rho=" << rho;
   // Use the relation Normal2DCDF(x1, x2, false) = Normal2DCDF(-x1, -x2, true)
   if (!tail) return Normal2DCDF(-x1, -x2, rho, true);
@@ -86,8 +86,8 @@ NumericalScalar Normal2DCDF(const NumericalScalar x1,
   // Nodes and weights for Legendre integration
   static NumericalScalar nodes[19] = {0.9324695142031522, 0.6612093864662647, 0.2386191860831970, 0.9815606342467191, 0.9041172563704750, 0.7699026741943050, 0.5873179542866171, 0.3678314989981802, 0.1252334085114692, 0.9931285991850949, 0.9639719272779138, 0.9122344282513259, 0.8391169718222188, 0.7463319064601508, 0.6360536807265150, 0.5108670019508271, 0.3737060887154196, 0.2277858511416451, 0.07652652113349733};
   static NumericalScalar weights[19] = {0.1713244923791705, 0.3607615730481384, 0.4679139345726904, 0.04717533638651177, 0.1069393259953183, 0.1600783285433464, 0.2031674267230659, 0.2334925365383547, 0.2491470458134029, 0.01761400713915212, 0.04060142980038694, 0.06267204833410906, 0.08327674157670475, 0.1019301198172404, 0.1181945319615184, 0.1316886384491766, 0.1420961093183821, 0.1491729864726037, 0.1527533871307259};
-  UnsignedLong shift(0);
-  UnsignedLong size(0);
+  UnsignedInteger shift(0);
+  UnsignedInteger size(0);
   if (absRho <= 0.3)
   {
     shift = 0;
@@ -111,12 +111,12 @@ NumericalScalar Normal2DCDF(const NumericalScalar x1,
   if (absRho <= 0.925)
   {
     const NumericalScalar halfSquare(0.5 * (u1 * u1 + u2 * u2));
-    const NumericalScalar arcSinRho(asin(rho));
-    for (UnsignedLong i = 0; i < size; ++i)
+    const NumericalScalar arcSinRho(std::asin(rho));
+    for (UnsignedInteger i = 0; i < size; ++i)
     {
-      const NumericalScalar sinValueMinus(sin(0.5 * arcSinRho * (1.0 - nodes[shift + i])));
-      const NumericalScalar sinValuePlus(sin(0.5 * arcSinRho * (1.0 + nodes[shift + i])));
-      cdf += weights[shift + i] * (exp((sinValueMinus * u1u2 - halfSquare) / (1.0 - sinValueMinus * sinValueMinus)) + exp((sinValuePlus * u1u2 - halfSquare) / (1.0 - sinValuePlus * sinValuePlus)));
+      const NumericalScalar sinValueMinus(std::sin(0.5 * arcSinRho * (1.0 - nodes[shift + i])));
+      const NumericalScalar sinValuePlus(std::sin(0.5 * arcSinRho * (1.0 + nodes[shift + i])));
+      cdf += weights[shift + i] * (std::exp((sinValueMinus * u1u2 - halfSquare) / (1.0 - sinValueMinus * sinValueMinus)) + std::exp((sinValuePlus * u1u2 - halfSquare) / (1.0 - sinValuePlus * sinValuePlus)));
     }
     cdf *= arcSinRho / (4.0 * M_PI);
     cdf += DistFunc::pNormal(-u1) * DistFunc::pNormal(-u2);
@@ -130,33 +130,33 @@ NumericalScalar Normal2DCDF(const NumericalScalar x1,
   if (absRho < 1.0)
   {
     const NumericalScalar aSquare((1.0 - rho) * (1.0 + rho));
-    NumericalScalar a(sqrt(aSquare));
-    const NumericalScalar b(fabs(u1 - u2));
+    NumericalScalar a(std::sqrt(aSquare));
+    const NumericalScalar b(std::abs(u1 - u2));
     const NumericalScalar bSquare(b * b);
     const NumericalScalar c(0.5 - 0.125 * u1u2);
     const NumericalScalar d(0.75 - 0.06125 * u1u2);
     const NumericalScalar aSquareReduced(-0.5 * (bSquare / aSquare + u1u2));
     const NumericalScalar firstTerm(c * (1.0 - 0.2 * d * bSquare) / 3.0);
-    if (aSquareReduced > NORMAL2DCDF_MIN_LOG) cdf = a * exp(aSquareReduced) * (1.0 - (bSquare - aSquare) * firstTerm + 0.2 * c * d * aSquare * aSquare);
+    if (aSquareReduced > NORMAL2DCDF_MIN_LOG) cdf = a * std::exp(aSquareReduced) * (1.0 - (bSquare - aSquare) * firstTerm + 0.2 * c * d * aSquare * aSquare);
     if (u1u2 < -2.0 * NORMAL2DCDF_MIN_LOG)
     {
-      const NumericalScalar sp(sqrt(2.0 * M_PI) * DistFunc::pNormal(-b / a));
-      cdf -= exp(-0.5 * u1u2) * sp * b * (1.0 - bSquare * firstTerm);
+      const NumericalScalar sp(std::sqrt(2.0 * M_PI) * DistFunc::pNormal(-b / a));
+      cdf -= std::exp(-0.5 * u1u2) * sp * b * (1.0 - bSquare * firstTerm);
     } // u1u2 < -2.0 * NORMAL2DCDF_MIN_LOG
     a *= 0.5;
-    for(UnsignedLong i = 0; i < size; ++i)
+    for(UnsignedInteger i = 0; i < size; ++i)
     {
-      for (UnsignedLong j = 0; j < 2; ++j)
+      for (UnsignedInteger j = 0; j < 2; ++j)
       {
         const NumericalScalar x(a * (1.0 + (-1.0 + 2.0 * j) * nodes[shift + i]));
         const NumericalScalar xSquare(x * x);
         const NumericalScalar asr(-0.5 * (bSquare / xSquare + u1u2));
         if (asr > NORMAL2DCDF_MIN_LOG)
         {
-          const NumericalScalar rs(sqrt(1.0 - xSquare));
+          const NumericalScalar rs(std::sqrt(1.0 - xSquare));
           const NumericalScalar sp(1.0 + c * xSquare * (1.0 + d * xSquare));
-          const NumericalScalar ep(exp(-u1u2 * (1.0 - rs) / (2.0 * (1.0 + rs))) / rs);
-          cdf += a * weights[shift + i] * exp(asr) * (ep - sp);
+          const NumericalScalar ep(std::exp(-u1u2 * (1.0 - rs) / (2.0 * (1.0 + rs))) / rs);
+          cdf += a * weights[shift + i] * std::exp(asr) * (ep - sp);
         } // asr > NORMAL2DCDF_MIN_LOG
       } // j
     } // i
