@@ -3,7 +3,7 @@
  *  @file  PosteriorDistribution.cxx
  *  @brief The PosteriorDistribution distribution
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -40,10 +40,11 @@ static Factory<PosteriorDistribution> RegisteredFactory("PosteriorDistribution")
 
 /* Default constructor */
 PosteriorDistribution::PosteriorDistribution()
-  : ContinuousDistribution("PosteriorDistribution"),
+  : ContinuousDistribution(),
     conditionalDistribution_(),
     observations_()
 {
+  setName("PosteriorDistribution");
   // First, set the observations
   observations_ = NumericalSample(1, conditionalDistribution_.getConditionedDistribution().getMean());
   // Then, set the conditional distribution. It also set the dimension.
@@ -54,10 +55,11 @@ PosteriorDistribution::PosteriorDistribution()
 /* Parameters constructor */
 PosteriorDistribution::PosteriorDistribution(const ConditionalDistribution & conditionalDistribution,
     const NumericalSample & observations)
-  : ContinuousDistribution("PosteriorDistribution"),
+  : ContinuousDistribution(),
     conditionalDistribution_(),
     observations_(observations)
 {
+  setName("PosteriorDistribution");
   if (observations.getSize() == 0) throw InvalidArgumentException(HERE) << "Error: cannot build a posterior distribution with no observation.";
   setConditionalDistribution(conditionalDistribution);
 }
@@ -101,8 +103,8 @@ NumericalPoint PosteriorDistribution::computeLikelihood(const NumericalPoint & t
   Distribution conditionedDistribution(conditionalDistribution_.getConditionedDistribution());
   conditionedDistribution.setParametersCollection(theta);
   NumericalScalar likelihood(1.0);
-  const UnsignedLong size(observations_.getSize());
-  for (UnsignedLong i = 0; i < size; ++i)
+  const UnsignedInteger size(observations_.getSize());
+  for (UnsignedInteger i = 0; i < size; ++i)
   {
     const NumericalScalar atomicValue(conditionedDistribution.computePDF(observations_[i]));
     likelihood *= atomicValue;
@@ -116,8 +118,8 @@ NumericalScalar PosteriorDistribution::computePDF(const NumericalPoint & point)
 {
   if (point.getDimension() != getDimension()) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=" << getDimension() << ", here dimension=" << point.getDimension();
 
-  const NumericalScalar value(log(conditionalDistribution_.getConditioningDistribution().computePDF(point)) - logNormalizationFactor_ + log(computeLikelihood(point)[0]));
-  return exp(value);
+  const NumericalScalar value(std::log(conditionalDistribution_.getConditioningDistribution().computePDF(point)) - logNormalizationFactor_ + std::log(computeLikelihood(point)[0]));
+  return std::exp(value);
 }
 
 
@@ -127,7 +129,7 @@ NumericalScalar PosteriorDistribution::computeCDF(const NumericalPoint & point)
   if (point.getDimension() != getDimension()) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=" << getDimension() << ", here dimension=" << point.getDimension();
 
   Description inputDescription(getDimension());
-  for (UnsignedLong i = 0; i < getDimension(); ++i) inputDescription[i] = String(OSS() << "x" << i);
+  for (UnsignedInteger i = 0; i < getDimension(); ++i) inputDescription[i] = String(OSS() << "x" << i);
   const NumericalMathFunction f(inputDescription, Description(1, "1"));
   const NumericalScalar cdf(conditionalDistribution_.computeExpectation(f, point)[0]);
   return cdf;
@@ -136,12 +138,12 @@ NumericalScalar PosteriorDistribution::computeCDF(const NumericalPoint & point)
 /* Parameters value and description accessor */
 PosteriorDistribution::NumericalPointWithDescriptionCollection PosteriorDistribution::getParametersCollection() const
 {
-  throw NotYetImplementedException(HERE);
+  throw NotYetImplementedException(HERE) << "In PosteriorDistribution::getParametersCollection() const";
 }
 
 void PosteriorDistribution::setParametersCollection(const NumericalPointCollection & parametersCollection)
 {
-  throw NotYetImplementedException(HERE);
+  throw NotYetImplementedException(HERE) << "In PosteriorDistribution::setParametersCollection(const NumericalPointCollection & parametersCollection)";
 }
 
 
@@ -152,9 +154,9 @@ void PosteriorDistribution::setConditionalDistribution(const ConditionalDistribu
   conditionalDistribution_ = conditionalDistribution;
   setDimension(conditionalDistribution.getConditioningDistribution().getDimension());
   logNormalizationFactor_ = 0.0;
-  const UnsignedLong size(observations_.getSize());
-  for (UnsignedLong i = 0; i < size; ++i)
-    logNormalizationFactor_ += log(conditionalDistribution_.computePDF(observations_[i]));
+  const UnsignedInteger size(observations_.getSize());
+  for (UnsignedInteger i = 0; i < size; ++i)
+    logNormalizationFactor_ += std::log(conditionalDistribution_.computePDF(observations_[i]));
   if (logNormalizationFactor_ == -SpecFunc::MaxNumericalScalar) throw InvalidArgumentException(HERE) << "Error: the normalization factor is null with the given conditional distribution and observations.";
   computeRange();
   isAlreadyComputedMean_ = false;
@@ -199,52 +201,52 @@ void PosteriorDistribution::computeMean() const
 {
   // std::cerr << "in PosteriorDistribution::computeMean()" << std::endl;
   Description inputDescription(getDimension());
-  for (UnsignedLong i = 0; i < getDimension(); ++i) inputDescription[i] = String(OSS() << "x" << i);
+  for (UnsignedInteger i = 0; i < getDimension(); ++i) inputDescription[i] = String(OSS() << "x" << i);
   const NumericalMathFunction meanFunction(inputDescription, inputDescription);
   // std::cerr << "meanFunction=" << meanFunction << std::endl;
   const NumericalMathFunction likelihood(bindMethod<PosteriorDistribution, NumericalPoint, NumericalPoint>(PosteriorDistribution(*this), &PosteriorDistribution::computeLikelihood, getDimension(), 1));
   // std::cerr << "likelihood=" << likelihood << std::endl;
-  mean_ = conditionalDistribution_.computeExpectation(likelihood * meanFunction, getRange().getUpperBound()) / exp(logNormalizationFactor_);
+  mean_ = conditionalDistribution_.computeExpectation(likelihood * meanFunction, getRange().getUpperBound()) / std::exp(logNormalizationFactor_);
   isAlreadyComputedMean_ = true;
 }
 
 /* Get the standard deviation of the distribution */
-NumericalPoint PosteriorDistribution::getStandardDeviation() const /*throw(NotDefinedException)*/
+NumericalPoint PosteriorDistribution::getStandardDeviation() const
 {
   // To insure that the covariance has been computed
   getCovariance();
   NumericalPoint sigma(getDimension());
-  for (UnsignedLong i = 0; i < getDimension(); ++i) sigma[i] = sqrt(covariance_(i, i));
+  for (UnsignedInteger i = 0; i < getDimension(); ++i) sigma[i] = std::sqrt(covariance_(i, i));
   return sigma;
 }
 
 /* Get the skewness of the distribution */
-NumericalPoint PosteriorDistribution::getSkewness() const /*throw(NotDefinedException)*/
+NumericalPoint PosteriorDistribution::getSkewness() const
 {
-  throw NotYetImplementedException(HERE);
+  throw NotYetImplementedException(HERE) << "In PosteriorDistribution::getSkewness() const";
 }
 
 /* Get the kurtosis of the distribution */
-NumericalPoint PosteriorDistribution::getKurtosis() const /*throw(NotDefinedException)*/
+NumericalPoint PosteriorDistribution::getKurtosis() const
 {
-  throw NotYetImplementedException(HERE);
+  throw NotYetImplementedException(HERE) << "In PosteriorDistribution::getKurtosis() const";
 }
 
 /* Compute the covariance of the distribution */
 void PosteriorDistribution::computeCovariance() const
 {
-  const UnsignedLong dimension(getDimension());
+  const UnsignedInteger dimension(getDimension());
   covariance_ = CovarianceMatrix(dimension);
   // To insure that the mean has been computed
   getMean();
   Description inputDescription(dimension);
-  for (UnsignedLong i = 0; i < dimension; ++i) inputDescription[i] = String(OSS() << "x" << i);
+  for (UnsignedInteger i = 0; i < dimension; ++i) inputDescription[i] = String(OSS() << "x" << i);
   Description formulas((dimension * (dimension + 1)) / 2);
-  UnsignedLong index(0);
-  for (UnsignedLong i = 0; i < dimension; ++i)
+  UnsignedInteger index(0);
+  for (UnsignedInteger i = 0; i < dimension; ++i)
   {
     const NumericalScalar muI(mean_[i]);
-    for (UnsignedLong j = 0; j <= i; ++j)
+    for (UnsignedInteger j = 0; j <= i; ++j)
     {
       const NumericalScalar muJ(mean_[j]);
       formulas[index] = String(OSS() << "(x" << i << "-" << muI << ")*(x" << j << "-" << muJ << ")");
@@ -253,10 +255,10 @@ void PosteriorDistribution::computeCovariance() const
   }
   const NumericalMathFunction covarianceFunction(inputDescription, formulas);
   const NumericalMathFunction likelihood(bindMethod<PosteriorDistribution, NumericalPoint, NumericalPoint>(PosteriorDistribution(*this), &PosteriorDistribution::computeLikelihood, getDimension(), 1));
-  const NumericalPoint result(conditionalDistribution_.computeExpectation(likelihood * covarianceFunction, getRange().getUpperBound()) / exp(logNormalizationFactor_));
+  const NumericalPoint result(conditionalDistribution_.computeExpectation(likelihood * covarianceFunction, getRange().getUpperBound()) / std::exp(logNormalizationFactor_));
   index = 0;
-  for (UnsignedLong i = 0; i < dimension; ++i)
-    for (UnsignedLong j = 0; j <= i; ++j)
+  for (UnsignedInteger i = 0; i < dimension; ++i)
+    for (UnsignedInteger j = 0; j <= i; ++j)
     {
       covariance_(i, j) = result[index];
       ++index;
