@@ -3,7 +3,7 @@
  *  @file  Rayleigh.cxx
  *  @brief The Rayleigh distribution
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -29,19 +29,17 @@
 
 BEGIN_NAMESPACE_OPENTURNS
 
-
-
-
 CLASSNAMEINIT(Rayleigh);
 
 static Factory<Rayleigh> RegisteredFactory("Rayleigh");
 
 /* Default constructor */
 Rayleigh::Rayleigh()
-  : ContinuousDistribution("Rayleigh"),
-    sigma_(1.0),
-    gamma_(0.0)
+  : ContinuousDistribution()
+  , sigma_(1.0)
+  , gamma_(0.0)
 {
+  setName("Rayleigh");
   setDimension(1);
   computeRange();
 }
@@ -49,9 +47,11 @@ Rayleigh::Rayleigh()
 /* Parameters constructor */
 Rayleigh::Rayleigh(const NumericalScalar sigma,
                    const NumericalScalar gamma)
-  : ContinuousDistribution("Rayleigh"),
-    sigma_(0.0), gamma_(gamma)
+  : ContinuousDistribution()
+  , sigma_(0.0)
+  , gamma_(gamma)
 {
+  setName("Rayleigh");
   // This call set also the range
   setSigma(sigma);
   setDimension(1);
@@ -103,7 +103,7 @@ void Rayleigh::computeRange()
 /* Get one realization of the distribution */
 NumericalPoint Rayleigh::getRealization() const
 {
-  return NumericalPoint(1, gamma_ + sigma_ * sqrt(-2.0 * log(RandomGenerator::Generate())));
+  return NumericalPoint(1, gamma_ + sigma_ * std::sqrt(-2.0 * std::log(RandomGenerator::Generate())));
 }
 
 
@@ -116,7 +116,7 @@ NumericalPoint Rayleigh::computeDDF(const NumericalPoint & point) const
   if (x <= 0.0) return NumericalPoint(1, 0.0);
   const NumericalScalar y(x / sigma_);
   const NumericalScalar sigma2(sigma_ * sigma_);
-  return NumericalPoint(1, -exp(-0.5 * y * y) * (x - sigma_) * (x + sigma_) / (sigma2 * sigma2));
+  return NumericalPoint(1, -std::exp(-0.5 * y * y) * (x - sigma_) * (x + sigma_) / (sigma2 * sigma2));
 }
 
 
@@ -128,7 +128,7 @@ NumericalScalar Rayleigh::computePDF(const NumericalPoint & point) const
   const NumericalScalar x(point[0] - gamma_);
   if (x <= 0.0) return 0.0;
   const NumericalScalar y(x / (sigma_ * sigma_));
-  return y * exp(-0.5 * x * y);
+  return y * std::exp(-0.5 * x * y);
 }
 
 NumericalScalar Rayleigh::computeLogPDF(const NumericalPoint & point) const
@@ -138,7 +138,7 @@ NumericalScalar Rayleigh::computeLogPDF(const NumericalPoint & point) const
   const NumericalScalar x(point[0] - gamma_);
   if (x <= 0.0) return -SpecFunc::MaxNumericalScalar;
   const NumericalScalar y(x / (sigma_ * sigma_));
-  return log(y) - 0.5 * x * y;
+  return std::log(y) - 0.5 * x * y;
 }
 
 
@@ -150,7 +150,7 @@ NumericalScalar Rayleigh::computeCDF(const NumericalPoint & point) const
   const NumericalScalar x(point[0] - gamma_);
   if (x <= 0.0) return 0.0;
   const NumericalScalar y(x / sigma_);
-  return 1.0 - exp(-0.5 * y * y);
+  return 1.0 - std::exp(-0.5 * y * y);
 }
 
 /* Get the characteristic function of the distribution, i.e. phi(u) = E(exp(I*u*X))
@@ -164,8 +164,8 @@ NumericalScalar Rayleigh::computeCDF(const NumericalPoint & point) const
 */
 NumericalComplex Rayleigh::computeCharacteristicFunction(const NumericalScalar x) const
 {
-  const NumericalScalar t(sigma_ * x / sqrt(2.0));
-  return NumericalComplex(1 - 2 * t * SpecFunc::Dawson(t), t * exp(-t * t) * sqrt(M_PI)) * exp(NumericalComplex(0.0, x * gamma_));
+  const NumericalScalar t(sigma_ * x / std::sqrt(2.0));
+  return NumericalComplex(1 - 2 * t * SpecFunc::Dawson(t), t * std::exp(-t * t) * std::sqrt(M_PI)) * std::exp(NumericalComplex(0.0, x * gamma_));
 }
 
 /* Get the PDFGradient of the distribution */
@@ -202,8 +202,8 @@ NumericalPoint Rayleigh::computeCDFGradient(const NumericalPoint & point) const
 NumericalScalar Rayleigh::computeScalarQuantile(const NumericalScalar prob,
     const Bool tail) const
 {
-  if (tail) return gamma_ + sigma_ * sqrt(-2.0 * log(prob));
-  return gamma_ + sigma_ * sqrt(-2.0 * log1p(-prob));
+  if (tail) return gamma_ + sigma_ * std::sqrt(-2.0 * std::log(prob));
+  return gamma_ + sigma_ * std::sqrt(-2.0 * log1p(-prob));
 }
 
 /* Compute the mean of the distribution */
@@ -236,9 +236,9 @@ NumericalPoint Rayleigh::getKurtosis() const
 }
 
 /* Get the moments of the distribution */
-NumericalPoint Rayleigh::getStandardMoment(const UnsignedLong n) const
+NumericalPoint Rayleigh::getStandardMoment(const UnsignedInteger n) const
 {
-  return NumericalPoint(1, exp(0.5 * n * M_LN2 + SpecFunc::LnGamma(1.0 + 0.5 * n)));
+  return NumericalPoint(1, std::exp(0.5 * n * M_LN2 + SpecFunc::LnGamma(1.0 + 0.5 * n)));
 }
 
 /* Get the standard representative in the parametric family, associated with the standard moments */
@@ -274,7 +274,9 @@ Rayleigh::NumericalPointWithDescriptionCollection Rayleigh::getParametersCollect
 
 void Rayleigh::setParametersCollection(const NumericalPointCollection & parametersCollection)
 {
+  const NumericalScalar w(getWeight());
   *this = Rayleigh(parametersCollection[0][0], parametersCollection[0][1]);
+  setWeight(w);
 }
 
 
