@@ -3,7 +3,7 @@
  *  @file  RiceFactory.cxx
  *  @brief Factory for Rice distribution
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -48,27 +48,28 @@ struct RiceFactoryParameterConstraint
 {
   /** Constructor from a sample and a derivative factor estimate */
   RiceFactoryParameterConstraint(const NumericalScalar r):
-    r2_(r * r)
+    r2p1_(1.0 + r * r)
   {
     // Nothing to do
   };
 
   NumericalPoint computeConstraint(const NumericalPoint & parameter) const
   {
+    // Here u = \theta^2 wrt reference
     const NumericalScalar u(parameter[0]);
-    const NumericalScalar relation(u - ((1.0 + r2_) * computeXi(u) - 2.0));
+    const NumericalScalar relation(u - (r2p1_ * computeXi(u) - 2.0));
     return NumericalPoint(1, relation);
   }
 
   NumericalScalar computeXi(const NumericalScalar u) const
   {
-    const NumericalScalar logI0(SpecFunc::LogBesselI0(0.25 * u));
-    const NumericalScalar logI1(SpecFunc::LogBesselI1(0.25 * fabs(u)));
-
-    return 2.0 + u - 0.125 * M_PI * exp(-0.5 * u + 2.0 * logI0) * pow(2.0 + u + fabs(u) * exp(logI1 - logI0), 2);
+    if (u <= 0.0) throw InvalidArgumentException(HERE) << "Error: the argument u=" << u << " in the constraint must be positive.";
+    const NumericalScalar up2(u + 2.0);
+    const NumericalScalar quarterU(0.25 * u);
+    return up2 - 0.125 * M_PI * std::exp(-0.5 * u + 2.0 * SpecFunc::LogBesselI0(quarterU)) * std::pow(up2 + u * std::exp(SpecFunc::DeltaLogBesselI10(quarterU)), 2.0);
   }
 
-  NumericalScalar r2_;
+  NumericalScalar r2p1_;
 };
 
 /* Here is the interface that all derived class must implement */
@@ -88,9 +89,12 @@ RiceFactory::Implementation RiceFactory::build() const
   return buildAsRice().clone();
 }
 
+/* Parameters estimation using the Koay inversion technique, see:
+   Koay, C. G. and Basser, P. J., "Analytically exact correction scheme for signal extraction from noisy magnitude MR signals", Journal of Magnetic Resonance, Vol. 179, 2, pp. 317-322 (2006)
+*/
 Rice RiceFactory::buildAsRice(const NumericalSample & sample) const
 {
-  const UnsignedLong size(sample.getSize());
+  const UnsignedInteger size(sample.getSize());
   if (size == 0) throw InvalidArgumentException(HERE) << "Error: cannot build a Rice distribution from an empty sample";
   if (sample.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: can build a Rice distribution only from a sample of dimension 1, here dimension=" << sample.getDimension();
   const NumericalScalar mu(sample.computeMean()[0]);
@@ -103,11 +107,11 @@ Rice RiceFactory::buildAsRice(const NumericalSample & sample) const
   NumericalScalar b(2.0);
   NumericalScalar fA(f(NumericalPoint(1, a))[0]);
   NumericalScalar fB(f(NumericalPoint(1, b))[0]);
-  const NumericalScalar largeValue(sqrt(SpecFunc::MaxNumericalScalar));
-  const UnsignedLong maximumIteration(ResourceMap::GetAsUnsignedLong( "RiceFactory-MaximumIteration" ));
-  UnsignedLong iteration(0);
+  const NumericalScalar largeValue(std::sqrt(SpecFunc::MaxNumericalScalar));
+  const UnsignedInteger maximumIteration(ResourceMap::GetAsUnsignedInteger( "RiceFactory-MaximumIteration" ));
+  UnsignedInteger iteration(0);
   // While f has the same sign at the two bounds, update the interval
-  while ((fA * fB > 0.0) && (fabs(fA) < largeValue) && (fabs(fB) < largeValue) && (b < largeValue) && (iteration < maximumIteration))
+  while ((fA * fB > 0.0) && (std::abs(fA) < largeValue) && (std::abs(fB) < largeValue) && (b < largeValue) && (iteration < maximumIteration))
   {
     a = 0.5 * a;
     fA = f(NumericalPoint(1, a))[0];
@@ -117,16 +121,16 @@ Rice RiceFactory::buildAsRice(const NumericalSample & sample) const
     LOGINFO(OSS() << "a=" << a << ", fa=" << fA << ", b=" << b << ", fb=" << fB);
     ++iteration;
   }
-  if ((fabs(fA) > largeValue) || (fabs(fB) > largeValue) || (fabs(b) > largeValue) || (iteration == maximumIteration)) throw InvalidArgumentException(HERE) << "Error: cannot estimate parameters of a Rice distribution from the given sample";
+  if ((std::abs(fA) > largeValue) || (std::abs(fB) > largeValue) || (std::abs(b) > largeValue) || (iteration == maximumIteration)) throw InvalidArgumentException(HERE) << "Error: cannot estimate parameters of a Rice distribution from the given sample";
   // Solve the constraint equation
   Brent solver(ResourceMap::GetAsNumericalScalar( "RiceFactory-AbsolutePrecision" ), ResourceMap::GetAsNumericalScalar( "RiceFactory-RelativePrecision" ), ResourceMap::GetAsNumericalScalar( "RiceFactory-ResidualPrecision" ), maximumIteration);
   // u estimate
   const NumericalScalar u(solver.solve(f, 0.0, a, b, fA, fB));
   const NumericalScalar xiU(constraint.computeXi(u));
   // Corresponding sigma estimate
-  const NumericalScalar sigma(std / sqrt(xiU));
+  const NumericalScalar sigma(std / std::sqrt(xiU));
   // Corresponding nu estimate
-  const NumericalScalar nu(sqrt(mu * mu + sigma * sigma * (xiU - 2.0)));
+  const NumericalScalar nu(std::sqrt(mu * mu + sigma * sigma * (xiU - 2.0)));
   try
   {
     Rice result(sigma, nu);
