@@ -3,7 +3,7 @@
  *  @file  Student.cxx
  *  @brief The Student distribution
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -32,8 +32,6 @@
 #include "DistFunc.hxx"
 #include "Log.hxx"
 #include "OSS.hxx"
-#include "Mvtdstpack.hxx"
-#include "Tvpack.hxx"
 #include "PersistentObjectFactory.hxx"
 #include "NumericalPoint.hxx"
 #include "Exception.hxx"
@@ -48,13 +46,14 @@ static Factory<Student> RegisteredFactory("Student");
 
 /* Default constructor */
 Student::Student(const NumericalScalar nu,
-                 const UnsignedLong dimension)
+                 const UnsignedInteger dimension)
   : EllipticalDistribution(NumericalPoint(dimension, 0.0),
                            NumericalPoint(dimension, 1.0),
-                           IdentityMatrix(dimension), -1.0, "Student")
+                           IdentityMatrix(dimension), -1.0)
   , nu_(0.0)
   , studentNormalizationFactor_(0.0)
 {
+  setName("Student");
   setDimension( dimension );
   // This call set also the range
   setNu(nu);
@@ -64,10 +63,11 @@ Student::Student(const NumericalScalar nu,
 Student::Student(const NumericalScalar nu,
                  const NumericalScalar mu,
                  const NumericalScalar sigma)
-  : EllipticalDistribution(NumericalPoint(1, mu), NumericalPoint(1, sigma), IdentityMatrix(1), -1.0, "Student")
+  : EllipticalDistribution(NumericalPoint(1, mu), NumericalPoint(1, sigma), IdentityMatrix(1), -1.0)
   , nu_(0.0)
   , studentNormalizationFactor_(0.0)
 {
+  setName("Student");
   setDimension(1);
   // Set nu with checks. This call set also the range.
   setNu(nu);
@@ -78,10 +78,11 @@ Student::Student(const NumericalScalar nu,
                  const NumericalPoint & mu,
                  const NumericalPoint & sigma,
                  const CorrelationMatrix & R)
-  : EllipticalDistribution(mu, sigma, R, -1.0, "Student")
+  : EllipticalDistribution(mu, sigma, R, -1.0)
   , nu_(0.0)
   , studentNormalizationFactor_(0.0)
 {
+  setName("Student");
   setDimension(mu.getDimension());
   // Set nu with checks. This call set also the range.
   setNu(nu);
@@ -122,23 +123,23 @@ String Student::__str__(const String & offset) const
  *  be written as p(x) = phi(t(x-mu)S^(-1)(x-mu))                      */
 NumericalScalar Student::computeDensityGenerator(const NumericalScalar betaSquare) const
 {
-  return exp(studentNormalizationFactor_ - 0.5 * (nu_ + getDimension()) * log1p(betaSquare / nu_));
+  return std::exp(studentNormalizationFactor_ - 0.5 * (nu_ + getDimension()) * log1p(betaSquare / nu_));
 }
 
 /* Compute the derivative of the density generator */
 NumericalScalar Student::computeDensityGeneratorDerivative(const NumericalScalar betaSquare) const
 {
   const NumericalScalar iNu(1.0 / nu_);
-  const UnsignedLong dimension(getDimension());
-  return -0.5 * exp(studentNormalizationFactor_ - (0.5 * (nu_ + dimension) + 1.0) * log1p(betaSquare * iNu)) * (1.0 + dimension * iNu);
+  const UnsignedInteger dimension(getDimension());
+  return -0.5 * std::exp(studentNormalizationFactor_ - (0.5 * (nu_ + dimension) + 1.0) * log1p(betaSquare * iNu)) * (1.0 + dimension * iNu);
 }
 
 /* Compute the second derivative of the density generator */
 NumericalScalar Student::computeDensityGeneratorSecondDerivative(const NumericalScalar betaSquare) const
 {
   const NumericalScalar iNu(1.0 / nu_);
-  const UnsignedLong dimension(getDimension());
-  return 0.25 * exp(studentNormalizationFactor_ - (0.5 * (nu_ + dimension) + 2.0) * log1p(betaSquare * iNu)) * (1.0 + dimension * iNu) * (1.0 + (dimension + 2.0) * iNu);
+  const UnsignedInteger dimension(getDimension());
+  return 0.25 * std::exp(studentNormalizationFactor_ - (0.5 * (nu_ + dimension) + 2.0) * log1p(betaSquare * iNu)) * (1.0 + dimension * iNu) * (1.0 + (dimension + 2.0) * iNu);
 }
 
 
@@ -151,107 +152,49 @@ Student * Student::clone() const
 /* Get one realization of the distribution */
 NumericalPoint Student::getRealization() const
 {
-  const UnsignedLong dimension(getDimension());
+  const UnsignedInteger dimension(getDimension());
   if (dimension == 1) return NumericalPoint(1, mean_[0] + sigma_[0] * DistFunc::rStudent(nu_));
   NumericalPoint value(dimension);
   // First, a realization of independant standard normal coordinates
-  for (UnsignedLong i = 0; i < dimension; ++i) value[i] = DistFunc::rNormal();
-  return sqrt(0.5 * nu_ / DistFunc::rGamma(0.5 * nu_)) * (cholesky_ * value) + mean_;
+  for (UnsignedInteger i = 0; i < dimension; ++i) value[i] = DistFunc::rNormal();
+  return std::sqrt(0.5 * nu_ / DistFunc::rGamma(0.5 * nu_)) * (cholesky_ * value) + mean_;
 }
 
 
 /* Get the CDF of the distribution */
 NumericalScalar Student::computeCDF(const NumericalPoint & point) const
 {
-  const UnsignedLong dimension(getDimension());
+  const UnsignedInteger dimension(getDimension());
   if (point.getDimension() != dimension) throw InvalidArgumentException(HERE) << "Error: the given point has a dimension incompatible with the distribution.";
   // Special case for dimension 1
   if (dimension == 1) return DistFunc::pStudent(nu_, (point[0] - mean_[0]) / sigma_[0]);
-  // Normalize the point to use the standard form of the multivariate student distribution
-  NumericalPoint u(normalize(point));
-  // For the bidimensional case, use specialized high precision routine for integral degrees of freedom
-  if ((dimension == 2) && (nu_ == round(nu_)))
-  {
-    int nu(static_cast<int>(round(nu_)));
-    double r(R_(0, 1));
-    return BVTL_F77(&nu, &(u[0]), &(u[1]), &r);
-  }
-  // For the tridimensional case, use specialized high precision routine for integral degrees of freedom
-  if ((dimension == 3) && (nu_ == round(nu_)))
-  {
-    int nu(static_cast<int>(round(nu_)));
-    double r[3];
-    r[0] = R_(1, 0);
-    r[1] = R_(2, 0);
-    r[2] = R_(2, 1);
-    double eps(ResourceMap::GetAsNumericalScalar( "Student-MaximumCDFEpsilon" ) * ResourceMap::GetAsNumericalScalar( "Student-MaximumCDFEpsilon" ));
-    cdfEpsilon_ = eps;
-    return TVTL_F77(&nu, &(u[0]), &r[0], &eps);
-  }
   // For moderate dimension, use a Gauss-Legendre integration
-  if (dimension <= ResourceMap::GetAsUnsignedLong("Student-SmallDimension"))
+  if (dimension <= ResourceMap::GetAsUnsignedInteger("Student-SmallDimension"))
   {
     // Reduce the default integration point number for CDF computation in the range 3 < dimension <= Student-SmallDimension
-    const UnsignedLong maximumNumber(static_cast< UnsignedLong > (round(pow(ResourceMap::GetAsUnsignedLong( "Student-MaximumNumberOfPoints" ), 1.0 / getDimension()))));
-    const UnsignedLong candidateNumber(ResourceMap::GetAsUnsignedLong( "Student-MarginalIntegrationNodesNumber" ));
+    const UnsignedInteger maximumNumber(static_cast< UnsignedInteger > (round(std::pow(ResourceMap::GetAsUnsignedInteger( "Student-MaximumNumberOfPoints" ), 1.0 / getDimension()))));
+    const UnsignedInteger candidateNumber(ResourceMap::GetAsUnsignedInteger( "Student-MarginalIntegrationNodesNumber" ));
     if (candidateNumber > maximumNumber) LOGWARN(OSS() << "Warning! The requested number of marginal integration nodes=" << candidateNumber << " would lead to an excessive number of PDF evaluations. It has been reduced to " << maximumNumber << ". You should increase the ResourceMap key \"Student-MaximumNumberOfPoints\"");
     setIntegrationNodesNumber(std::min(maximumNumber, candidateNumber));
     return ContinuousDistribution::computeCDF(point);
   }
-  // For larger dimension, use an adaptive integration
-  if ((dimension <= 500) && (nu_ == round(nu_)))
-  {
-    int nu(static_cast<int>(round(nu_)));
-    NumericalPoint lower(dimension, 0.0);
-    std::vector<int> infin(dimension, 0);
-    NumericalPoint correl(dimension * (dimension - 1) / 2, 0.0);
-    /* Copy the correlation matrix in the proper format for mvndst */
-    for (UnsignedLong i = 0; i < dimension; ++i)
-      for (UnsignedLong j = 0; j < i; ++j) correl[j + i * (i - 1) / 2] = R_(j, i);
-    // Non-centrality parameters
-    NumericalPoint delta(dimension, 0.0);
-    int maxpts(ResourceMap::GetAsUnsignedLong( "Student-MinimumNumberOfPoints" ));
-    // Use only relative precision
-    double abseps(0.0);
-    // Reduce the precision according to the dimension. It ranges from ResourceMap::GetAsNumericalScalar( "Student-MaximumCDFEpsilon" ) for dimension=4 to ResourceMap::GetAsNumericalScalar( "Student-MinimumCDFEpsilon" ) for dimension=500
-    double releps(ResourceMap::GetAsNumericalScalar( "Student-MaximumCDFEpsilon" ) * pow(ResourceMap::GetAsNumericalScalar( "Student-MinimumCDFEpsilon" ) / ResourceMap::GetAsNumericalScalar( "Student-MaximumCDFEpsilon" ), (4.0 + dimension) / 496.0));
-    double error;
-    double value;
-    int inform;
-    int dim(static_cast<UnsignedLong>( dimension ));
-    do
-    {
-      MVTDST_F77(&dim, &nu, &lower[0], &u[0], &infin[0], &correl[0], &delta[0], &maxpts, &abseps, &releps, &error, &value, &inform);
-      if (inform == 1)
-      {
-        LOGWARN(OSS() << "Warning, in Student::computeCDF(), the required precision has not been achieved with maxpts=" << NumericalScalar(maxpts) << ", we only got an absolute error of " << error << " and a relative error of " << error / value << ". We retry with maxpoint=" << 10 * maxpts);
-        maxpts *= 10;
-      }
-      else if (inform != 0) throw InternalException(HERE) << "MVTDST: error code=" << inform;
-    }
-    while ((static_cast<UnsignedLong>(maxpts) <= ResourceMap::GetAsUnsignedLong( "Student-MaximumNumberOfPoints" )) && (inform == 1));
-    if (inform == 1) LOGWARN(OSS() << "Warning, in Student::computeCDF(), the required precision has not been achieved with maxpts=" << NumericalScalar(maxpts) << ", we only got an absolute error of " << error << " and a relative error of " << error / value << ". No more retry.");
-    if ((value < 0.0) || (value > 1.0)) LOGWARN(OSS() << "Warning, in Student::computeCDF(), got a value outside of [0, 1], value=" << value << " your dependence structure might be too complex. The value will be truncated.");
-    cdfEpsilon_ = error;
-    return std::min(std::max(value, 0.0), 1.0);
-  }
   // For very large dimension, use a MonteCarlo algorithm
-  LOGWARN(OSS() << "Warning, in Student::computeCDF(), the dimension is very high. We will use a Monte Carlo method for the computation with a relative precision of 0.1% at 99% confidence level and a maximum of " << 10.0 * ResourceMap::GetAsUnsignedLong( "Student-MaximumNumberOfPoints" ) << " realizations. Expect a long running time and a poor accuracy for small values of the CDF...");
+  LOGWARN(OSS() << "Warning, in Student::computeCDF(), the dimension is very high. We will use a Monte Carlo method for the computation with a relative precision of 0.1% at 99% confidence level and a maximum of " << 10.0 * ResourceMap::GetAsUnsignedInteger( "Student-MaximumNumberOfPoints" ) << " realizations. Expect a long running time and a poor accuracy for small values of the CDF...");
   NumericalScalar value(0.0);
   NumericalScalar variance(0.0);
   NumericalScalar a99(DistFunc::qNormal(0.995));
-  UnsignedLong outerMax(10 * ResourceMap::GetAsUnsignedLong( "Student-MaximumNumberOfPoints" ) / ResourceMap::GetAsUnsignedLong( "Student-MinimumNumberOfPoints" ));
+  UnsignedInteger outerMax(10 * ResourceMap::GetAsUnsignedInteger( "Student-MaximumNumberOfPoints" ) / ResourceMap::GetAsUnsignedInteger( "Student-MinimumNumberOfPoints" ));
   NumericalScalar precision(0.0);
-  for (UnsignedLong indexOuter = 0; indexOuter < outerMax; ++indexOuter)
+  for (UnsignedInteger indexOuter = 0; indexOuter < outerMax; ++indexOuter)
   {
     NumericalScalar valueBlock(0.0);
     NumericalScalar varianceBlock(0.0);
-    for (UnsignedLong indexSample = 0; indexSample < ResourceMap::GetAsUnsignedLong( "Student-MinimumNumberOfPoints" ); ++indexSample)
+    for (UnsignedInteger indexSample = 0; indexSample < ResourceMap::GetAsUnsignedInteger( "Student-MinimumNumberOfPoints" ); ++indexSample)
     {
       Bool inside(true);
       NumericalPoint realization(getRealization());
       // Check if the realization is in the integration domain
-      for (UnsignedLong i = 0; i < dimension; ++i)
+      for (UnsignedInteger i = 0; i < dimension; ++i)
       {
         inside = realization[i] <= point[i];
         if (!inside) break;
@@ -268,7 +211,7 @@ NumericalScalar Student::computeCDF(const NumericalPoint & point) const
     // Quick return for value = 1
     const NumericalScalar quantileEpsilon(ResourceMap::GetAsNumericalScalar("DistributionImplementation-DefaultQuantileEpsilon"));
     if ((value >= 1.0 - quantileEpsilon) && (variance == 0.0)) return 1.0;
-    precision = a99 * sqrt(variance / (indexOuter + 1.0) / ResourceMap::GetAsUnsignedLong( "Student-MinimumNumberOfPoints" ));
+    precision = a99 * std::sqrt(variance / (indexOuter + 1.0) / ResourceMap::GetAsUnsignedInteger( "Student-MinimumNumberOfPoints" ));
     if (precision < ResourceMap::GetAsNumericalScalar( "Student-MinimumCDFEpsilon" ) * value) return value;
     // 0.1 * ((1000 * indexOuter) / outerMax) is to print percents with one figure after the decimal point
     LOGINFO(OSS() << 0.1 * ((1000 * indexOuter) / outerMax) << "% value=" << value << " absolute precision(99%)=" << precision << " relative precision(99%)=" << ((value > 0.0) ? precision / value : -1.0));
@@ -280,7 +223,7 @@ NumericalScalar Student::computeCDF(const NumericalPoint & point) const
 /* Compute the probability content of an interval */
 NumericalScalar Student::computeProbability(const Interval & interval) const
 {
-  const UnsignedLong dimension(getDimension());
+  const UnsignedInteger dimension(getDimension());
   if (interval.getDimension() != dimension) throw InvalidArgumentException(HERE) << "Error: the given interval must have dimension=" << dimension << ", here dimension=" << interval.getDimension();
 
   if (interval.isNumericallyEmpty()) return 0.0;
@@ -293,74 +236,29 @@ NumericalScalar Student::computeProbability(const Interval & interval) const
   const Interval::BoolCollection finiteUpper(interval.getFiniteUpperBound());
   /* General case */
   // For moderate dimension, use a Gauss-Legendre integration
-  if (dimension <= ResourceMap::GetAsUnsignedLong("Student-SmallDimension"))
+  if (dimension <= ResourceMap::GetAsUnsignedInteger("Student-SmallDimension"))
   {
     // Reduce the default integration point number for CDF computation in the range 3 < dimension <= Student-SmallDimension
-    const UnsignedLong maximumNumber(static_cast< UnsignedLong > (round(pow(ResourceMap::GetAsUnsignedLong( "Student-MaximumNumberOfPoints" ), 1.0 / getDimension()))));
-    const UnsignedLong candidateNumber(ResourceMap::GetAsUnsignedLong( "Student-MarginalIntegrationNodesNumber" ));
+    const UnsignedInteger maximumNumber(static_cast< UnsignedInteger > (round(std::pow(ResourceMap::GetAsUnsignedInteger( "Student-MaximumNumberOfPoints" ), 1.0 / getDimension()))));
+    const UnsignedInteger candidateNumber(ResourceMap::GetAsUnsignedInteger( "Student-MarginalIntegrationNodesNumber" ));
     if (candidateNumber > maximumNumber) LOGWARN(OSS() << "Warning! The requested number of marginal integration nodes=" << candidateNumber << " would lead to an excessive number of PDF evaluations. It has been reduced to " << maximumNumber << ". You should increase the ResourceMap key \"Student-MaximumNumberOfPoints\"");
     setIntegrationNodesNumber(std::min(maximumNumber, candidateNumber));
     return ContinuousDistribution::computeProbability(interval);
   }
-  // For large dimension, use an adaptive integration
-  if (dimension <= 500)
-  {
-    int nu(static_cast<UnsignedLong>(round(nu_)));
-    // Build finite/infinite flags according to MVNDST documentation
-    std::vector<int> infin(dimension, -1);
-    for (UnsignedLong i = 0; i < dimension; ++i)
-    {
-      // Infin[i] should be:
-      //  2 if finiteLower[i] && finiteUpper[i]
-      //  1 if finiteLower[i] && !finiteUpper[i]
-      //  0 if !finiteLower[i] && finiteUpper[i]
-      // -1 if !finiteLower[i] && !finiteUpper[i]
-      infin[i] += 2 * int(finiteLower[i]) + int(finiteUpper[i]);
-    }
-    NumericalPoint correl(dimension * (dimension - 1) / 2, 0.0);
-    /* Copy the correlation matrix in the proper format for mvndst */
-    for (UnsignedLong i = 0; i < UnsignedLong(dimension); ++i)
-      for (UnsignedLong j = 0; j < i; ++j) correl[j + i * (i - 1) / 2] = R_(j, i);
-    // Non-centrality parameter
-    NumericalPoint delta(dimension, 0.0);
-    int maxpts(ResourceMap::GetAsUnsignedLong( "Student-MinimumNumberOfPoints" ));
-    // Use only relative precision
-    double abseps(0.0);
-    // Reduce the precision according to the dimension. It ranges from ResourceMap::GetAsNumericalScalar( "Student-MaximumCDFEpsilon" ) for dimension=4 to ResourceMap::GetAsNumericalScalar( "Student-MinimumCDFEpsilon" ) for dimension=500
-    double releps(ResourceMap::GetAsNumericalScalar( "Student-MaximumCDFEpsilon" ) * pow(ResourceMap::GetAsNumericalScalar( "Student-MinimumCDFEpsilon" ) / ResourceMap::GetAsNumericalScalar( "Student-MaximumCDFEpsilon" ), (4.0 + dimension) / 496.0));
-    double error;
-    double value;
-    int inform;
-    int dim = static_cast<UnsignedLong>( dimension );
-    do
-    {
-      MVTDST_F77(&dim, &nu, &lower[0], &upper[0], &infin[0], &correl[0], &delta[0], &maxpts, &abseps, &releps, &error, &value, &inform);
-      if (inform == 1)
-      {
-        LOGWARN(OSS() << "Warning, in Student::computeProbability(), the required precision has not been achieved with maxpts=" << NumericalScalar(maxpts) << ", we only got an absolute error of " << error << " and a relative error of " << error / value << ". We retry with maxpoint=" << 10 * maxpts);
-        maxpts *= 10;
-      }
-      else if (inform != 0) throw InternalException(HERE) << "MVTDST: error code=" << inform;
-    }
-    while ((static_cast<UnsignedLong>(maxpts) <= ResourceMap::GetAsUnsignedLong( "Student-MaximumNumberOfPoints" )) && (inform == 1));
-    if (inform == 1) LOGWARN(OSS() << "Warning, in Student::computeProbability(), the required precision has not been achieved with maxpts=" << NumericalScalar(maxpts) << ", we only got an absolute error of " << error << " and a relative error of " << error / value << ". No more retry.");
-    if ((value < 0.0) || (value > 1.0)) LOGWARN(OSS() << "Warning, in Student::computeProbability(), got a value outside of [0, 1], value=" << value << " your dependence structure might be too complex. The value will be truncated.");
-    return std::min(std::max(value, 0.0), 1.0);
-  }
   // For very large dimension, use a MonteCarlo algorithm
-  LOGWARN(OSS() << "Warning, in Student::computeProbability(), the dimension is very high. We will use a Monte Carlo method for the computation with a relative precision of 0.1% at 99% confidence level and a maximum of " << 10.0 * ResourceMap::GetAsUnsignedLong( "Student-MaximumNumberOfPoints" ) << " realizations. Expect a long running time and a poor accuracy for low values of the CDF...");
+  LOGWARN(OSS() << "Warning, in Student::computeProbability(), the dimension is very high. We will use a Monte Carlo method for the computation with a relative precision of 0.1% at 99% confidence level and a maximum of " << 10.0 * ResourceMap::GetAsUnsignedInteger( "Student-MaximumNumberOfPoints" ) << " realizations. Expect a long running time and a poor accuracy for low values of the CDF...");
   RandomGeneratorState initialState(RandomGenerator::GetState());
-  RandomGenerator::SetSeed(ResourceMap::GetAsUnsignedLong( "Student-MinimumNumberOfPoints" ));
+  RandomGenerator::SetSeed(ResourceMap::GetAsUnsignedInteger( "Student-MinimumNumberOfPoints" ));
   NumericalScalar value(0.0);
   NumericalScalar variance(0.0);
   const NumericalScalar a99(DistFunc::qNormal(0.995));
-  UnsignedLong outerMax(10 * ResourceMap::GetAsUnsignedLong( "Student-MaximumNumberOfPoints" ) / ResourceMap::GetAsUnsignedLong( "Student-MinimumNumberOfPoints" ));
+  UnsignedInteger outerMax(10 * ResourceMap::GetAsUnsignedInteger( "Student-MaximumNumberOfPoints" ) / ResourceMap::GetAsUnsignedInteger( "Student-MinimumNumberOfPoints" ));
   NumericalScalar precision(0.0);
-  for (UnsignedLong indexOuter = 0; indexOuter < outerMax; ++indexOuter)
+  for (UnsignedInteger indexOuter = 0; indexOuter < outerMax; ++indexOuter)
   {
     NumericalScalar valueBlock(0.0);
     NumericalScalar varianceBlock(0.0);
-    for (UnsignedLong indexSample = 0; indexSample < ResourceMap::GetAsUnsignedLong( "Student-MinimumNumberOfPoints" ); ++indexSample)
+    for (UnsignedInteger indexSample = 0; indexSample < ResourceMap::GetAsUnsignedInteger( "Student-MinimumNumberOfPoints" ); ++indexSample)
     {
       // ind value is 1.0 if the realization is inside of the integration domain, 0.0 else.
       NumericalScalar ind(interval.numericallyContains(getRealization()));
@@ -374,7 +272,7 @@ NumericalScalar Student::computeProbability(const Interval & interval) const
     // Quick return for value = 1
     const NumericalScalar quantileEpsilon(ResourceMap::GetAsNumericalScalar("DistributionImplementation-DefaultQuantileEpsilon"));
     if ((value >= 1.0 - quantileEpsilon) && (variance == 0.0)) return 1.0;
-    precision = a99 * sqrt(variance / (indexOuter + 1.0) / ResourceMap::GetAsUnsignedLong( "Student-MinimumNumberOfPoints" ));
+    precision = a99 * std::sqrt(variance / (indexOuter + 1.0) / ResourceMap::GetAsUnsignedInteger( "Student-MinimumNumberOfPoints" ));
     if (precision < ResourceMap::GetAsNumericalScalar( "Student-MinimumCDFEpsilon" ) * value) return value;
     // 0.1 * ((1000 * indexOuter) / outerMax) is to print percents with one figure after the decimal point
     LOGINFO(OSS() << 0.1 * ((1000 * indexOuter) / outerMax) << "% value=" << value << " absolute precision(99%)=" << precision << " relative precision(99%)=" << ((value > 0.0) ? precision / value : -1.0));
@@ -386,7 +284,7 @@ NumericalScalar Student::computeProbability(const Interval & interval) const
 /* Get the PDFGradient of the distribution */
 NumericalPoint Student::computePDFGradient(const NumericalPoint & point) const
 {
-  const UnsignedLong dimension(getDimension());
+  const UnsignedInteger dimension(getDimension());
 
   if (point.getDimension() != dimension) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=" << dimension << ", here dimension=" << point.getDimension();
 
@@ -396,16 +294,16 @@ NumericalPoint Student::computePDFGradient(const NumericalPoint & point) const
     const NumericalPoint ellipticalPDFGradient(EllipticalDistribution::computePDFGradient(point));
     const NumericalScalar epsNu(1e-3);
     pdfGradient[0] = (Student(nu_ + epsNu, mean_, sigma_, R_).computePDF(point) - Student(nu_ - epsNu, mean_, sigma_, R_).computePDF(point)) / (2.0 * epsNu);
-    for (UnsignedLong i = 0; i < 2 * dimension; ++i) pdfGradient[i + 1] = ellipticalPDFGradient[i];
+    for (UnsignedInteger i = 0; i < 2 * dimension; ++i) pdfGradient[i + 1] = ellipticalPDFGradient[i];
     return pdfGradient;
   }
-  else throw NotYetImplementedException(HERE);
+  else throw NotYetImplementedException(HERE) << "In Student::computePDFGradient(const NumericalPoint & point) const";
 }
 
 /* Get the CDFGradient of the distribution */
 NumericalPoint Student::computeCDFGradient(const NumericalPoint & point) const
 {
-  const UnsignedLong dimension(getDimension());
+  const UnsignedInteger dimension(getDimension());
 
   if (point.getDimension() != dimension) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=" << dimension << ", here dimension=" << point.getDimension();
 
@@ -413,7 +311,7 @@ NumericalPoint Student::computeCDFGradient(const NumericalPoint & point) const
   {
     NumericalPoint cdfGradient(3, 0.0);
     const NumericalScalar x(point[0] - mean_[0]);
-    const NumericalScalar eps(pow(ResourceMap::GetAsNumericalScalar("DistFunc-Precision"), 1.0 / 3.0));
+    const NumericalScalar eps(std::pow(ResourceMap::GetAsNumericalScalar("DistFunc-Precision"), 1.0 / 3.0));
     const NumericalScalar i2Eps(0.5 / eps);
     cdfGradient[0] = (DistFunc::pStudent(nu_ + eps, x / sigma_[0]) - DistFunc::pStudent(nu_ - eps, x / sigma_[0])) * i2Eps;
     // Opposite sign for eps because x - eps = point[0] - (mu + eps)
@@ -421,7 +319,7 @@ NumericalPoint Student::computeCDFGradient(const NumericalPoint & point) const
     cdfGradient[2] = (DistFunc::pStudent(nu_, x / (sigma_[0] + eps)) - DistFunc::pStudent(nu_, x / (sigma_[0] - eps))) * i2Eps;
     return cdfGradient;
   }
-  else throw NotYetImplementedException(HERE);
+  else throw NotYetImplementedException(HERE) << "In Student::computeCDFGradient(const NumericalPoint & point) const";
 }
 
 /* Compute the PDF of Xi | X1, ..., Xi-1. x = Xi, y = (X1,...,Xi-1)
@@ -431,58 +329,58 @@ NumericalPoint Student::computeCDFGradient(const NumericalPoint & point) const
 NumericalScalar Student::computeConditionalPDF(const NumericalScalar x,
     const NumericalPoint & y) const
 {
-  const UnsignedLong conditioningDimension(y.getDimension());
+  const UnsignedInteger conditioningDimension(y.getDimension());
   if (conditioningDimension >= getDimension()) throw InvalidArgumentException(HERE) << "Error: cannot compute a conditional PDF with a conditioning point of dimension greater or equal to the distribution dimension.";
   // Special case for no conditioning
   if (conditioningDimension == 0) return Distribution(getMarginal(conditioningDimension)).computePDF(x);
   // General case
-  throw NotYetImplementedException(HERE);
-  NumericalScalar meanRos(0.0);
-  const NumericalScalar sigmaRos(1.0 / inverseCholesky_(conditioningDimension, conditioningDimension));
-  for (UnsignedLong i = 0; i < conditioningDimension; ++i) meanRos += inverseCholesky_(conditioningDimension, i) / sqrt(sigma_[i]) * (y[i] - mean_[i]);
-  meanRos = mean_[conditioningDimension] - sigmaRos * sqrt(sigma_[conditioningDimension]) * meanRos;
-  return exp(-0.5 * pow(x - meanRos, 2.0) / (sigmaRos * sigmaRos)) / (sigmaRos * sqrt(2.0 * M_PI));
+  throw NotYetImplementedException(HERE) << "In Student::computeConditionalPDF(const NumericalScalar x, const NumericalPoint & y) const";
+  //NumericalScalar meanRos(0.0);
+  //const NumericalScalar sigmaRos(1.0 / inverseCholesky_(conditioningDimension, conditioningDimension));
+  //for (UnsignedInteger i = 0; i < conditioningDimension; ++i) meanRos += inverseCholesky_(conditioningDimension, i) / std::sqrt(sigma_[i]) * (y[i] - mean_[i]);
+  //meanRos = mean_[conditioningDimension] - sigmaRos * std::sqrt(sigma_[conditioningDimension]) * meanRos;
+  //return std::exp(-0.5 * std::pow(x - meanRos, 2.0) / (sigmaRos * sigmaRos)) / (sigmaRos * std::sqrt(2.0 * M_PI));
 }
 
 /* Compute the CDF of Xi | X1, ..., Xi-1. x = Xi, y = (X1,...,Xi-1) */
 NumericalScalar Student::computeConditionalCDF(const NumericalScalar x,
     const NumericalPoint & y) const
 {
-  const UnsignedLong conditioningDimension(y.getDimension());
+  const UnsignedInteger conditioningDimension(y.getDimension());
   if (conditioningDimension >= getDimension()) throw InvalidArgumentException(HERE) << "Error: cannot compute a conditional CDF with a conditioning point of dimension greater or equal to the distribution dimension.";
   // Special case for no conditioning
   if (conditioningDimension == 0) return Distribution(getMarginal(conditioningDimension)).computeCDF(x);
   // General case
-  throw NotYetImplementedException(HERE);
-  NumericalScalar meanRos(0.0);
-  const NumericalScalar sigmaRos(1.0 / inverseCholesky_(conditioningDimension, conditioningDimension));
-  for (UnsignedLong i = 0; i < conditioningDimension; ++i) meanRos += inverseCholesky_(conditioningDimension, i) / sqrt(sigma_[i]) * (y[i] - mean_[i]);
-  meanRos = mean_[conditioningDimension] - sigmaRos * sqrt(sigma_[conditioningDimension]) * meanRos;
-  return DistFunc::pNormal((x - meanRos) / sigmaRos);
+  throw NotYetImplementedException(HERE) << "in NumericalScalar Student::computeConditionalCDF(const NumericalScalar x, const NumericalPoint & y) const";
+  //NumericalScalar meanRos(0.0);
+  //const NumericalScalar sigmaRos(1.0 / inverseCholesky_(conditioningDimension, conditioningDimension));
+  //for (UnsignedInteger i = 0; i < conditioningDimension; ++i) meanRos += inverseCholesky_(conditioningDimension, i) / std::sqrt(sigma_[i]) * (y[i] - mean_[i]);
+  //meanRos = mean_[conditioningDimension] - sigmaRos * std::sqrt(sigma_[conditioningDimension]) * meanRos;
+  //return DistFunc::pNormal((x - meanRos) / sigmaRos);
 }
 
 /* Compute the quantile of Xi | X1, ..., Xi-1, i.e. x such that CDF(x|y) = q with x = Xi, y = (X1,...,Xi-1) */
 NumericalScalar Student::computeConditionalQuantile(const NumericalScalar q,
     const NumericalPoint & y) const
 {
-  const UnsignedLong conditioningDimension(y.getDimension());
+  const UnsignedInteger conditioningDimension(y.getDimension());
   if (conditioningDimension >= getDimension()) throw InvalidArgumentException(HERE) << "Error: cannot compute a conditional quantile with a conditioning point of dimension greater or equal to the distribution dimension.";
   if ((q < 0.0) || (q > 1.0)) throw InvalidArgumentException(HERE) << "Error: cannot compute a conditional quantile for a probability level outside of [0, 1]";
   // Special case when no contitioning
   if (conditioningDimension == 0) return mean_[conditioningDimension] + sigma_[conditioningDimension] * DistFunc::qStudent(nu_, q);
   // General case
   throw NotYetImplementedException(HERE);
-  NumericalScalar meanRos(0.0);
-  const NumericalScalar sigmaRos(1.0 / inverseCholesky_(conditioningDimension, conditioningDimension));
-  for (UnsignedLong i = 0; i < conditioningDimension; ++i) meanRos += inverseCholesky_(conditioningDimension, i) / sqrt(sigma_[i]) * (y[i] - mean_[i]);
-  meanRos = mean_[conditioningDimension] - sigmaRos * sqrt(sigma_[conditioningDimension]) * meanRos;
-  if (q == 0.0) return meanRos - 0.5 * sigmaRos * sqrt(4.0 * (log(SpecFunc::ISQRT2PI / sigmaRos) - SpecFunc::LogMinNumericalScalar));
-  if (q == 1.0) return meanRos + 0.5 * sigmaRos * sqrt(4.0 * (log(SpecFunc::ISQRT2PI / sigmaRos) - SpecFunc::LogMinNumericalScalar));
-  return meanRos + sigmaRos * DistFunc::qNormal(q);
+  //NumericalScalar meanRos(0.0);
+  //const NumericalScalar sigmaRos(1.0 / inverseCholesky_(conditioningDimension, conditioningDimension));
+  //for (UnsignedInteger i = 0; i < conditioningDimension; ++i) meanRos += inverseCholesky_(conditioningDimension, i) / std::sqrt(sigma_[i]) * (y[i] - mean_[i]);
+  //meanRos = mean_[conditioningDimension] - sigmaRos * std::sqrt(sigma_[conditioningDimension]) * meanRos;
+  //if (q == 0.0) return meanRos - 0.5 * sigmaRos * std::sqrt(4.0 * (std::log(SpecFunc::ISQRT2PI / sigmaRos) - SpecFunc::LogMinNumericalScalar));
+  //if (q == 1.0) return meanRos + 0.5 * sigmaRos * std::sqrt(4.0 * (std::log(SpecFunc::ISQRT2PI / sigmaRos) - SpecFunc::LogMinNumericalScalar));
+  //return meanRos + sigmaRos * DistFunc::qNormal(q);
 }
 
 /* Get the i-th marginal distribution */
-Student::Implementation Student::getMarginal(const UnsignedLong i) const
+Student::Implementation Student::getMarginal(const UnsignedInteger i) const
 {
   if (i >= getDimension()) throw InvalidArgumentException(HERE) << "The index of a marginal distribution must be in the range [0, dim-1]";
   // Special case for dimension 1
@@ -497,22 +395,22 @@ Student::Implementation Student::getMarginal(const UnsignedLong i) const
 /* Get the distribution of the marginal distribution corresponding to indices dimensions */
 Student::Implementation Student::getMarginal(const Indices & indices) const
 {
-  UnsignedLong dimension(getDimension());
+  const UnsignedInteger dimension(getDimension());
   if (!indices.check(dimension - 1)) throw InvalidArgumentException(HERE) << "The indices of a marginal distribution must be in the range [0, dim-1] and  must be different";
   // Special case for dimension 1
   if (dimension == 1) return clone();
   // General case
-  const UnsignedLong outputDimension(indices.getSize());
+  const UnsignedInteger outputDimension(indices.getSize());
   CorrelationMatrix R(outputDimension);
   NumericalPoint sigma(outputDimension);
   NumericalPoint mean(outputDimension);
   // Extract the correlation matrix, the marginal standard deviations and means
-  for (UnsignedLong i = 0; i < outputDimension; ++i)
+  for (UnsignedInteger i = 0; i < outputDimension; ++i)
   {
-    const UnsignedLong index_i(indices[i]);
+    const UnsignedInteger index_i(indices[i]);
     sigma[i] = sigma_[index_i];
     mean[i] = mean_[index_i];
-    for (UnsignedLong j = 0; j <= i; ++j) R(i, j) = R_(index_i, indices[j]);
+    for (UnsignedInteger j = 0; j <= i; ++j) R(i, j) = R_(index_i, indices[j]);
   }
   return new Student(nu_, mean, sigma, R);
 } // getMarginal(Indices)
@@ -574,14 +472,14 @@ CovarianceMatrix Student::getCovariance() const
 }
 
 /* Get the moments of the standardized distribution */
-NumericalPoint Student::getStandardMoment(const UnsignedLong n) const
+NumericalPoint Student::getStandardMoment(const UnsignedInteger n) const
 {
   if (n >= nu_) throw NotDefinedException(HERE) << "Error: cannot compute a standard moment of order greater or equal to the number of degrees of freedom";
   if (n % 2 == 1) return NumericalPoint(1, 0.0);
   NumericalScalar moment(1.0);
-  for (UnsignedLong i = 0; i < n / 2; ++i) moment *= (nu_ * (2 * i + 1)) / (nu_ - 2 * (i + 1));
+  for (UnsignedInteger i = 0; i < n / 2; ++i) moment *= (nu_ * (2 * i + 1)) / (nu_ - 2 * (i + 1));
   // Alternate expression, not very useful as the raw moments overflow the double precision for n approximately equal to 300 (if nu is large enough), and for these values the loop is equivalent to the analytic expression both in terms of speed and
-  // const NumericalScalar moment(exp(0.5 * n * log(nu_) + SpecFunc::LogGamma(0.5 * (n + 1.0)) + SpecFunc::LogGamma(0.5 * (nu_ - n)) - SpecFunc::LogGamma(0.5 * nu_)) / sqrt(M_PI));
+  // const NumericalScalar moment(exp(0.5 * n * std::log(nu_) + SpecFunc::LogGamma(0.5 * (n + 1.0)) + SpecFunc::LogGamma(0.5 * (nu_ - n)) - SpecFunc::LogGamma(0.5 * nu_)) / sqrt(M_PI));
   return NumericalPoint(1, moment);
 }
 
@@ -597,17 +495,17 @@ Student::NumericalPointWithDescriptionCollection Student::getParametersCollectio
   // First, get the parameters of the underlying elliptical distribution, it means mu, sigma and R
   NumericalPointWithDescriptionCollection parameters(EllipticalDistribution::getParametersCollection());
   // We get a collection of NumericalPointWithDescription, we append the value of nu at the beginning of each NumericalPointWithDescription
-  const UnsignedLong size(parameters.getSize());
-  for (UnsignedLong i = 0; i < size; ++i)
+  const UnsignedInteger size(parameters.getSize());
+  for (UnsignedInteger i = 0; i < size; ++i)
   {
     const NumericalPointWithDescription ellipticalParameterI(parameters[i]);
     const Description ellipticalDescriptionI(ellipticalParameterI.getDescription());
-    const UnsignedLong ellipticalParameterIDimension(ellipticalParameterI.getDimension());
+    const UnsignedInteger ellipticalParameterIDimension(ellipticalParameterI.getDimension());
     NumericalPointWithDescription parameterI(ellipticalParameterIDimension + 1);
     Description descriptionI(ellipticalParameterIDimension + 1);
     parameterI[0] = nu_;
     descriptionI[0] = "nu";
-    for (UnsignedLong j = 0; j < ellipticalParameterIDimension; ++j)
+    for (UnsignedInteger j = 0; j < ellipticalParameterIDimension; ++j)
     {
       parameterI[j + 1] = ellipticalParameterI[j];
       descriptionI[j + 1] = ellipticalDescriptionI[j];
@@ -620,8 +518,9 @@ Student::NumericalPointWithDescriptionCollection Student::getParametersCollectio
 
 void Student::setParametersCollection(const NumericalPointCollection & parametersCollection)
 {
-  const UnsignedLong size(parametersCollection.getSize());
-  const UnsignedLong dimension(size > 1 ? size - 1 : size);
+  const NumericalScalar w(getWeight());
+  const UnsignedInteger size(parametersCollection.getSize());
+  const UnsignedInteger dimension(size > 1 ? size - 1 : size);
   if (dimension == 1) *this = Student(parametersCollection[0][0], parametersCollection[0][1], parametersCollection[0][2]);
   else
   {
@@ -629,15 +528,15 @@ void Student::setParametersCollection(const NumericalPointCollection & parameter
     NumericalPoint mean(dimension);
     NumericalPoint sigma(dimension);
     CorrelationMatrix R(dimension);
-    for (UnsignedLong i = 0; i < dimension; ++i)
+    for (UnsignedInteger i = 0; i < dimension; ++i)
     {
       mean[i] = parametersCollection[i][1];
       sigma[i] = parametersCollection[i][2];
     }
-    UnsignedLong parameterIndex(1);
-    for (UnsignedLong i = 0; i < dimension; ++i)
+    UnsignedInteger parameterIndex(1);
+    for (UnsignedInteger i = 0; i < dimension; ++i)
     {
-      for (UnsignedLong j = 0; j < i; ++j)
+      for (UnsignedInteger j = 0; j < i; ++j)
       {
         R(i, j) = parametersCollection[size - 1][parameterIndex];
         ++parameterIndex;
@@ -645,6 +544,7 @@ void Student::setParametersCollection(const NumericalPointCollection & parameter
     }
     *this = Student(nu, mean, sigma, R);
   }
+  setWeight(w);
 }
 
 
@@ -652,11 +552,11 @@ void Student::setParametersCollection(const NumericalPointCollection & parameter
 void Student::setNu(const NumericalScalar nu)
 {
   if (nu <= 2.0) LOGWARN(OSS() << "Warning! As nu <= 2, the covariance of the distribution will not be defined");
-  const UnsignedLong dimension(getDimension());
+  const UnsignedInteger dimension(getDimension());
   nu_ = nu;
   // Only set the covarianceScalingFactor if nu > 0, else its value is -1.0
   if (nu > 2.0) covarianceScalingFactor_ = nu_ / (nu_ - 2.0);
-  studentNormalizationFactor_ = SpecFunc::LnGamma(0.5 * (nu + dimension)) - SpecFunc::LnGamma(0.5 * nu) - 0.5 * dimension * log(nu * M_PI);
+  studentNormalizationFactor_ = SpecFunc::LnGamma(0.5 * (nu + dimension)) - SpecFunc::LnGamma(0.5 * nu) - 0.5 * dimension * std::log(nu * M_PI);
   computeRange();
 }
 
