@@ -3,7 +3,7 @@
  *  @file  TriangularFactory.cxx
  *  @brief Factory for Triangular distribution
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -61,13 +61,13 @@ TriangularFactory::Implementation TriangularFactory::build(const NumericalPointC
 Triangular TriangularFactory::buildAsTriangular(const NumericalSample & sample) const
 {
   const NumericalScalar size(sample.getSize());
-  if (size == 0) throw InvalidArgumentException(HERE) << "Error: cannot build a Triangular distribution from an empty sample";
+  if (size < 2) throw InvalidArgumentException(HERE) << "Error: cannot build a Triangular distribution from a sample of size < 2";
   if (sample.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: can build a Triangular distribution only from a sample of dimension 1, here dimension=" << sample.getDimension();
 
   const NumericalScalar xMin(sample.getMin()[0]);
-  const NumericalScalar a(xMin - fabs(xMin) / (size + 2));
+  const NumericalScalar a(xMin - std::abs(xMin) / (size + 2));
   const NumericalScalar xMax(sample.getMax()[0]);
-  const NumericalScalar b(xMax + fabs(xMax) / (size + 2));
+  const NumericalScalar b(xMax + std::abs(xMax) / (size + 2));
   const NumericalScalar m(3.0 * sample.computeMean()[0] - a - b);
   Triangular result(a, m, b);
   result.setDescription(sample.getDescription());
