@@ -3,7 +3,7 @@
  *  @file  TruncatedDistribution.cxx
  *  @brief The TruncatedDistribution distribution
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -39,7 +39,7 @@ static Factory<TruncatedDistribution> RegisteredFactory("TruncatedDistribution")
 
 /* Default constructor */
 TruncatedDistribution::TruncatedDistribution()
-  : DistributionImplementation("TruncatedDistribution")
+  : DistributionImplementation()
   , distribution_(Uniform(0.0, 1.0))
   , lowerBound_(0.0)
   , finiteLowerBound_(true)
@@ -52,6 +52,7 @@ TruncatedDistribution::TruncatedDistribution()
   , cdfUpperBound_(1.0)
   , normalizationFactor_(1.0)
 {
+  setName("TruncatedDistribution");
   setDimension(1);
   // Adjust the truncation interval and the distribution range
   computeRange();
@@ -62,15 +63,16 @@ TruncatedDistribution::TruncatedDistribution(const Distribution & distribution,
     const NumericalScalar lowerBound,
     const NumericalScalar upperBound,
     const NumericalScalar thresholdRealization)
-  : DistributionImplementation("TruncatedDistribution")
+  : DistributionImplementation()
 {
+  setName("TruncatedDistribution");
   setDistribution(distribution);
   setThresholdRealization(thresholdRealization);
   setDimension(1);
   if (upperBound <= lowerBound) throw InvalidArgumentException(HERE) << "Error: the upper bound must be greater than the lower bound, here lowerBound=" << lowerBound << " and upperBound=" << upperBound;
   cdfLowerBound_ = distribution.computeCDF(NumericalPoint(1, lowerBound));
   cdfUpperBound_ = distribution.computeCDF(NumericalPoint(1, upperBound));
-  if (cdfLowerBound_ == cdfUpperBound_) throw InvalidArgumentException(HERE) << "Error: the intervalle [lowerBound, upperBound] must contain a non-empty part of the support of the distribution, here CDf(lowerBound)=" << cdfLowerBound_ << " and CDF(upperBound)=" << cdfUpperBound_;
+  if (cdfLowerBound_ == cdfUpperBound_) throw InvalidArgumentException(HERE) << "Error: the interval [lowerBound, upperBound] must contain a non-empty part of the support of the distribution, here CDf(lowerBound)=" << cdfLowerBound_ << " and CDF(upperBound)=" << cdfUpperBound_;
   normalizationFactor_ = 1.0 / (cdfUpperBound_ - cdfLowerBound_);
   pdfLowerBound_ = distribution.computePDF(NumericalPoint(1, lowerBound));
   pdfUpperBound_ = distribution.computePDF(NumericalPoint(1, upperBound));
@@ -86,8 +88,9 @@ TruncatedDistribution::TruncatedDistribution(const Distribution & distribution,
     const NumericalScalar bound,
     const BoundSide side,
     const NumericalScalar thresholdRealization)
-  : DistributionImplementation("TruncatedDistribution")
+  : DistributionImplementation()
 {
+  setName("TruncatedDistribution");
   if (distribution.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: can truncate only distribution with dimension=1, here dimension=" << distribution.getDimension();
   distribution_ = distribution;
   setThresholdRealization(thresholdRealization);
@@ -134,8 +137,9 @@ TruncatedDistribution::TruncatedDistribution(const Distribution & distribution,
 TruncatedDistribution::TruncatedDistribution(const Distribution & distribution,
     const Interval & truncationInterval,
     const NumericalScalar thresholdRealization)
-  : DistributionImplementation("TruncatedDistribution")
+  : DistributionImplementation()
 {
+  setName("TruncatedDistribution");
   if (distribution.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: can truncate only distribution with dimension=1, here dimension=" << distribution.getDimension();
   distribution_ = distribution;
   setThresholdRealization(thresholdRealization);
@@ -348,6 +352,7 @@ void TruncatedDistribution::setDistribution(const Distribution & distribution)
   isAlreadyComputedMean_ = false;
   isAlreadyComputedCovariance_ = false;
   isAlreadyCreatedGeneratingFunction_ = false;
+  isParallel_ = distribution.getImplementation()->isParallel();
   computeRange();
 }
 
