@@ -3,7 +3,7 @@
  *  @file  Uniform.cxx
  *  @brief The Uniform distribution
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -34,10 +34,11 @@ static Factory<Uniform> RegisteredFactory("Uniform");
 
 /* Default constructor */
 Uniform::Uniform()
-  : ContinuousDistribution("Uniform")
+  : ContinuousDistribution()
   , a_(-1.0)
   , b_(1.0)
 {
+  setName( "Uniform" );
   setDimension( 1 );
   computeRange();
 }
@@ -45,10 +46,11 @@ Uniform::Uniform()
 /* Parameters constructor */
 Uniform::Uniform(const NumericalScalar a,
                  const NumericalScalar b)
-  : ContinuousDistribution("Uniform")
+  : ContinuousDistribution()
   , a_(a)
   , b_(b)
 {
+  setName( "Uniform" );
   setB(b);
   setDimension( 1 );
   computeRange();
@@ -100,12 +102,12 @@ NumericalPoint Uniform::getRealization() const
 }
 
 /* Get a sample of the distribution */
-NumericalSample Uniform::getSample(const UnsignedLong size) const
+NumericalSample Uniform::getSample(const UnsignedInteger size) const
 {
   NumericalSampleImplementation result(size, 1);
   result.setData(RandomGenerator::Generate(size));
-  result.scale(NumericalPoint(1, b_ - a_));
-  result.translate(NumericalPoint(1, a_));
+  result *= NumericalPoint(1, b_ - a_);
+  result += NumericalPoint(1, a_);
   result.setName(getName());
   result.setDescription(getDescription());
   return result;
@@ -158,11 +160,11 @@ NumericalComplex Uniform::computeCharacteristicFunction(const NumericalScalar x)
   NumericalComplex result;
   const NumericalScalar ax(a_ * x);
   const NumericalScalar bx(b_ * x);
-  if (fabs(x) <= 1.0e-10) result = NumericalComplex(1.0, 0.5 * (ax + bx));
+  if (std::abs(ax) + std::abs(bx) <= 1.0e-5) result = NumericalComplex(1.0 - (ax * ax + ax * bx + bx * bx) / 6.0, 0.5 * (ax + bx));
   else
   {
     const NumericalScalar idenom(1.0 / (bx - ax));
-    result = NumericalComplex(idenom * (sin(bx) - sin(ax)), idenom * (cos(ax) - cos(bx)));
+    result = NumericalComplex(idenom * (std::sin(bx) - std::sin(ax)), idenom * (std::cos(ax) - std::cos(bx)));
   }
   return result;
 }
@@ -174,7 +176,7 @@ NumericalPoint Uniform::computePDFGradient(const NumericalPoint & point) const
 
   const NumericalScalar x(point[0]);
   NumericalPoint pdfGradient(2, 0.0);
-  if ((x <= a_) || (x > b_)) return pdfGradient;
+  if ((x < a_) || (x > b_)) return pdfGradient;
   const NumericalScalar iAB(1.0 / (b_ - a_));
   const NumericalScalar iAB2(iAB * iAB);
   pdfGradient[0] = iAB2;
@@ -189,7 +191,7 @@ NumericalPoint Uniform::computeCDFGradient(const NumericalPoint & point) const
 
   const NumericalScalar x(point[0]);
   NumericalPoint cdfGradient(2, 0.0);
-  if ((x <= a_) || (x > b_)) return cdfGradient;
+  if ((x < a_) || (x > b_)) return cdfGradient;
   const NumericalScalar iAB(1.0 / (b_ - a_));
   const NumericalScalar iAB2(iAB * iAB);
   cdfGradient[0] = (x - b_) * iAB2;
@@ -221,7 +223,7 @@ void Uniform::computeMean() const
 /* Get the standard deviation of the distribution */
 NumericalPoint Uniform::getStandardDeviation() const
 {
-  return NumericalPoint(1, (b_ - a_) / sqrt(12.0));
+  return NumericalPoint(1, (b_ - a_) / std::sqrt(12.0));
 }
 
 /* Get the skewness of the distribution */
@@ -247,7 +249,7 @@ void Uniform::computeCovariance() const
 }
 
 /* Get the moments of the standardized distribution */
-NumericalPoint Uniform::getStandardMoment(const UnsignedLong n) const
+NumericalPoint Uniform::getStandardMoment(const UnsignedInteger n) const
 {
   if (n % 2 == 1) return NumericalPoint(1, 0.0);
   return NumericalPoint(1, 1.0 / (n + 1));
@@ -277,7 +279,9 @@ Uniform::NumericalPointWithDescriptionCollection Uniform::getParametersCollectio
 
 void Uniform::setParametersCollection(const NumericalPointCollection & parametersCollection)
 {
+  const NumericalScalar w(getWeight());
   *this = Uniform(parametersCollection[0][0], parametersCollection[0][1]);
+  setWeight(w);
 }
 
 /* Check if the distribution is elliptical */
@@ -291,7 +295,7 @@ Bool Uniform::isElliptical() const
 /* A accessor */
 void Uniform::setA(const NumericalScalar a)
 {
-  if (b_ <= a) throw InvalidArgumentException(HERE) << "Error the lower bound a of a Uniform distribution must be lesser than its upper bound b, here a=" << a << " b=" << b_;
+  if (b_ <= a) throw InvalidArgumentException(HERE) << "Error the lower bound a of a Uniform distribution must be less than its upper bound b, here a=" << a << " b=" << b_;
   if (a != a_)
   {
     a_ = a;
@@ -310,7 +314,7 @@ NumericalScalar Uniform::getA() const
 /* B accessor */
 void Uniform::setB(const NumericalScalar b)
 {
-  if (b <= a_) throw InvalidArgumentException(HERE) << "Error the lower bound a of a Uniform distribution must be lesser than its upper bound b, here a=" << a_ << " b=" << b;
+  if (b <= a_) throw InvalidArgumentException(HERE) << "Error the lower bound a of a Uniform distribution must be less than its upper bound b, here a=" << a_ << " b=" << b;
   if (b != b_)
   {
     b_ = b;
