@@ -3,7 +3,7 @@
  *  @file  Weibull.cxx
  *  @brief The Weibull distribution
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -36,11 +36,12 @@ static Factory<Weibull> RegisteredFactory("Weibull");
 
 /* Default constructor */
 Weibull::Weibull()
-  : ContinuousDistribution("Weibull")
+  : ContinuousDistribution()
   , alpha_(1.0)
   , beta_(1.0)
   , gamma_(0.0)
 {
+  setName("Weibull");
   setDimension(1);
   computeRange();
 }
@@ -50,11 +51,12 @@ Weibull::Weibull(const NumericalScalar arg1,
                  const NumericalScalar arg2,
                  const NumericalScalar gamma,
                  const ParameterSet set)
-  : ContinuousDistribution("Weibull")
+  : ContinuousDistribution()
   , alpha_(0.0)
   , beta_(0.0)
   , gamma_(gamma)
 {
+  setName("Weibull");
   switch (set)
   {
     case ALPHABETA:
@@ -122,7 +124,7 @@ void Weibull::computeRange()
 /* Get one realization of the distribution */
 NumericalPoint Weibull::getRealization() const
 {
-  return NumericalPoint(1, gamma_ + alpha_ * pow(-log(1.0 - RandomGenerator::Generate()), 1.0 / beta_));
+  return NumericalPoint(1, gamma_ + alpha_ * std::pow(-std::log(1.0 - RandomGenerator::Generate()), 1.0 / beta_));
 }
 
 
@@ -133,8 +135,8 @@ NumericalPoint Weibull::computeDDF(const NumericalPoint & point) const
 
   const NumericalScalar x(point[0] - gamma_);
   if (x <= 0.0) return NumericalPoint(1, 0.0);
-  const NumericalScalar powX(pow(x / alpha_, beta_));
-  return NumericalPoint(1, (beta_ * (1.0 - powX) - 1.0) / (x * x) * beta_ * powX * exp(-powX));
+  const NumericalScalar powX(std::pow(x / alpha_, beta_));
+  return NumericalPoint(1, (beta_ * (1.0 - powX) - 1.0) / (x * x) * beta_ * powX * std::exp(-powX));
 }
 
 
@@ -145,7 +147,7 @@ NumericalScalar Weibull::computePDF(const NumericalPoint & point) const
 
   const NumericalScalar x(point[0] - gamma_);
   if (x <= 0.0) return 0.0;
-  return exp(computeLogPDF(point));
+  return std::exp(computeLogPDF(point));
 }
 
 NumericalScalar Weibull::computeLogPDF(const NumericalPoint & point) const
@@ -155,7 +157,7 @@ NumericalScalar Weibull::computeLogPDF(const NumericalPoint & point) const
   const NumericalScalar x(point[0] - gamma_);
   if (x <= 0.0) return -SpecFunc::MaxNumericalScalar;
   const NumericalScalar y(x / alpha_);
-  return log(beta_) + (beta_ - 1.0) * log(y) - log(alpha_) - pow(y, beta_);
+  return std::log(beta_) + (beta_ - 1.0) * std::log(y) - std::log(alpha_) - std::pow(y, beta_);
 }
 
 
@@ -166,7 +168,59 @@ NumericalScalar Weibull::computeCDF(const NumericalPoint & point) const
 
   const NumericalScalar x(point[0] - gamma_);
   if (x <= 0.0) return 0.0;
-  return 1.0 - exp(-pow(x / alpha_, beta_));
+  return -expm1(-std::pow(x / alpha_, beta_));
+}
+
+NumericalScalar Weibull::computeComplementaryCDF(const NumericalPoint & point) const
+{
+  if (point.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=1, here dimension=" << point.getDimension();
+
+  const NumericalScalar x(point[0] - gamma_);
+  if (x <= 0.0) return 1.0;
+  return std::exp(-std::pow(x / alpha_, beta_));
+}
+
+/* Get the characteristic function of the distribution, i.e. phi(u) = E(exp(I*u*X)) */
+NumericalComplex Weibull::computeCharacteristicFunction(const NumericalScalar x) const
+{
+  /*
+  X=mu+sigma*Y;
+  phi_X(u)=E(exp(I*u*(mu+sigma*Y)))=exp(I*u*mu)*E(I*u*sigma*Y)=exp(I*u*mu)*phi_Y(sigma*u)
+  phi_Y(u)=1+(\sum_{r=1}^{\infty}(iu)^r\frac{\Gamma(r/\lambda)}{\Gamma(r)}
+  */
+  if (x == 0.0) return 1.0;
+  // Special case: beta == 1 -> exponential distribution
+  if (beta_ == 1.0) return 1.0 / NumericalComplex(1.0, -x / alpha_);
+  // If beta < 1.0, the series based on the Gamma function is divergente so use the generic implementation
+  if (beta_ < 1.0) return DistributionImplementation::computeCharacteristicFunction(x);
+  NumericalComplex value(1.0);
+  const NumericalScalar u(x * alpha_);
+  const NumericalScalar sign(x < 0.0 ? -1.0 : 1.0);
+  const NumericalScalar logAbsU(std::log(std::abs(u)));
+  NumericalScalar oldNorm(0.0);
+  NumericalScalar norm(oldNorm);
+  UnsignedInteger r(1);
+  Bool increasing(true);
+  while (increasing || (norm > std::abs(value) * SpecFunc::NumericalScalarEpsilon))
+  {
+    const NumericalScalar term1(std::exp(r * logAbsU - SpecFunc::LogGamma(r) + SpecFunc::LogGamma(r / beta_)));
+    ++r;
+    const NumericalScalar term2(std::exp(r * logAbsU - SpecFunc::LogGamma(r) + SpecFunc::LogGamma(r / beta_)));
+    ++r;
+    const NumericalScalar term3(std::exp(r * logAbsU - SpecFunc::LogGamma(r) + SpecFunc::LogGamma(r / beta_)));
+    ++r;
+    const NumericalScalar term4(std::exp(r * logAbsU - SpecFunc::LogGamma(r) + SpecFunc::LogGamma(r / beta_)));
+    ++r;
+    const NumericalComplex term((term4 - term2) / beta_, sign * (term1 - term3) / beta_);
+    oldNorm = norm;
+    norm = std::abs(term);
+    // If the term grows too much, the cancelation will be too large
+    if (norm > 1e3) return DistributionImplementation::computeCharacteristicFunction(x);
+    value += term;
+    increasing = norm > oldNorm;
+  }
+  value *= std::exp(NumericalComplex(0.0, x * gamma_));
+  return value;
 }
 
 /* Get the PDFGradient of the distribution */
@@ -177,10 +231,10 @@ NumericalPoint Weibull::computePDFGradient(const NumericalPoint & point) const
   const NumericalScalar x(point[0] - gamma_);
   NumericalPoint pdfGradient(3, 0.0);
   if (x <= 0.0) return pdfGradient;
-  const NumericalScalar powX(pow(x / alpha_, beta_));
-  const NumericalScalar factor(powX / x * exp(-powX));
+  const NumericalScalar powX(std::pow(x / alpha_, beta_));
+  const NumericalScalar factor(powX / x * std::exp(-powX));
   pdfGradient[0] = factor * (powX - 1.0) * beta_ * beta_ / alpha_;
-  pdfGradient[1] = factor * (1.0 + (1.0 - powX) * log(powX));
+  pdfGradient[1] = factor * (1.0 + (1.0 - powX) * std::log(powX));
   pdfGradient[2] = factor * (1.0 - beta_ + beta_ * powX) / x * beta_;
   return pdfGradient;
 }
@@ -193,10 +247,10 @@ NumericalPoint Weibull::computeCDFGradient(const NumericalPoint & point) const
   const NumericalScalar x(point[0] - gamma_);
   NumericalPoint cdfGradient(3, 0.0);
   if (x <= 0.0) return cdfGradient;
-  const NumericalScalar powX(pow(x / alpha_, beta_));
-  const NumericalScalar factor(powX * exp(-powX));
+  const NumericalScalar powX(std::pow(x / alpha_, beta_));
+  const NumericalScalar factor(powX * std::exp(-powX));
   cdfGradient[0] = -factor * beta_ / alpha_;
-  cdfGradient[1] = factor * log(x / alpha_);
+  cdfGradient[1] = factor * std::log(x / alpha_);
   cdfGradient[2] = -factor * beta_ / x;
   return cdfGradient;
 }
@@ -205,8 +259,8 @@ NumericalPoint Weibull::computeCDFGradient(const NumericalPoint & point) const
 NumericalScalar Weibull::computeScalarQuantile(const NumericalScalar prob,
     const Bool tail) const
 {
-  if (tail) return gamma_ + alpha_ * pow(-log(prob), 1.0 / beta_);
-  return gamma_ + alpha_ * pow(-log(1.0 - prob), 1.0 / beta_);
+  if (tail) return gamma_ + alpha_ * std::pow(-std::log(prob), 1.0 / beta_);
+  return gamma_ + alpha_ * std::pow(-std::log(1.0 - prob), 1.0 / beta_);
 }
 
 /* compute the mean of the distribution */
@@ -229,7 +283,7 @@ NumericalPoint Weibull::getSkewness() const
   const NumericalScalar gamma1_2(gamma1 * gamma1);
   const NumericalScalar gamma2(SpecFunc::Gamma(1.0 + 2.0 / beta_));
   const NumericalScalar gamma3(SpecFunc::Gamma(1.0 + 3.0 / beta_));
-  return NumericalPoint(1, (2.0 * gamma1_2 * gamma1 - 3.0 * gamma1 * gamma2 + gamma3) / pow((gamma2 - gamma1_2), 1.5));
+  return NumericalPoint(1, (2.0 * gamma1_2 * gamma1 - 3.0 * gamma1 * gamma2 + gamma3) / std::pow((gamma2 - gamma1_2), 1.5));
 }
 
 /* Get the kurtosis of the distribution */
@@ -240,19 +294,19 @@ NumericalPoint Weibull::getKurtosis() const
   const NumericalScalar gamma2(SpecFunc::Gamma(1.0 + 2.0 / beta_));
   const NumericalScalar gamma3(SpecFunc::Gamma(1.0 + 3.0 / beta_));
   const NumericalScalar gamma4(SpecFunc::Gamma(1.0 + 4.0 / beta_));
-  return NumericalPoint(1, (6.0 * gamma1_2 * gamma2 + gamma4 - 4.0 * gamma1 * gamma3 - 3.0 * gamma1_2 * gamma1_2) / pow(gamma2 - gamma1_2, 2.0));
+  return NumericalPoint(1, (6.0 * gamma1_2 * gamma2 + gamma4 - 4.0 * gamma1 * gamma3 - 3.0 * gamma1_2 * gamma1_2) / std::pow(gamma2 - gamma1_2, 2.0));
 }
 
 /* Compute the covariance of the distribution */
 void Weibull::computeCovariance() const
 {
   covariance_ = CovarianceMatrix(1);
-  covariance_(0, 0) = pow(getSigma(), 2.0);
+  covariance_(0, 0) = std::pow(getSigma(), 2.0);
   isAlreadyComputedCovariance_ = true;
 }
 
 /* Get the moments of the standardized distribution */
-NumericalPoint Weibull::getStandardMoment(const UnsignedLong n) const
+NumericalPoint Weibull::getStandardMoment(const UnsignedInteger n) const
 {
   return NumericalPoint(1, SpecFunc::Gamma(1.0 + n / beta_));
 }
@@ -283,7 +337,9 @@ Weibull::NumericalPointWithDescriptionCollection Weibull::getParametersCollectio
 
 void Weibull::setParametersCollection(const NumericalPointCollection & parametersCollection)
 {
+  const NumericalScalar w(getWeight());
   *this = Weibull(parametersCollection[0][0], parametersCollection[0][1], parametersCollection[0][2]);
+  setWeight(w);
 }
 
 
@@ -354,7 +410,7 @@ void Weibull::setMuSigma(const NumericalScalar mu,
 {
   if (mu <= gamma_) throw InvalidArgumentException(HERE) << "Mu MUST be > gamma, here mu=" << mu << " and gamma=" << gamma_;
   if (sigma <= 0.0) throw InvalidArgumentException(HERE) << "Sigma MUST be > 0.0, here sigma=" << sigma;
-  const NumericalScalar ratio(1.0 + pow(sigma / (mu - gamma_), 2.0));
+  const NumericalScalar ratio(1.0 + std::pow(sigma / (mu - gamma_), 2.0));
   NumericalScalar t;
   NumericalScalar betaMin(1.0);
   NumericalScalar betaMax(1.0);
@@ -367,7 +423,7 @@ void Weibull::setMuSigma(const NumericalScalar mu,
     {
       betaMin -= step;
       step *= 0.5;
-      t = exp(SpecFunc::LnGamma(1.0 + 2.0 / betaMin) - 2.0 * SpecFunc::LnGamma(1.0 + 1.0 / betaMin));
+      t = std::exp(SpecFunc::LnGamma(1.0 + 2.0 / betaMin) - 2.0 * SpecFunc::LnGamma(1.0 + 1.0 / betaMin));
     }
     while (t < ratio);
     // Here, we know that betaMin <= beta < betaMin + 2.0 * step
@@ -380,7 +436,7 @@ void Weibull::setMuSigma(const NumericalScalar mu,
     {
       betaMax += step;
       step *= 2.0;
-      t = exp(SpecFunc::LnGamma(1.0 + 2.0 / betaMax) - 2.0 * SpecFunc::LnGamma(1.0 + 1.0 / betaMax));
+      t = std::exp(SpecFunc::LnGamma(1.0 + 2.0 / betaMax) - 2.0 * SpecFunc::LnGamma(1.0 + 1.0 / betaMax));
     }
     while (t >= ratio);
     // Here, we know that betaMax - 0.5 * step <= beta < betaMax
@@ -392,14 +448,13 @@ void Weibull::setMuSigma(const NumericalScalar mu,
   {
     beta_ = 0.5 * (betaMin + betaMax);
     // Convergence
-    if (betaMax - betaMin <= epsilon * (1.0 + fabs(betaMax + betaMin)))
+    if (betaMax - betaMin <= epsilon * (1.0 + std::abs(betaMax + betaMin)))
     {
       alpha_ = (mu - gamma_) / SpecFunc::Gamma(1.0 + 1.0 / beta_);
-      computeRange();
-      return;
+      break;
     }
     // Non convergence, one step further
-    t = exp(SpecFunc::LnGamma(1.0 + 2.0 / beta_) - 2.0 * SpecFunc::LnGamma(1.0 + 1.0 / beta_));
+    t = std::exp(SpecFunc::LnGamma(1.0 + 2.0 / beta_) - 2.0 * SpecFunc::LnGamma(1.0 + 1.0 / beta_));
     if (t < ratio) betaMax = beta_;
     else betaMin = beta_;
   }
@@ -416,7 +471,7 @@ NumericalScalar Weibull::getMu() const
 
 NumericalScalar Weibull::getSigma() const
 {
-  return alpha_ * sqrt(SpecFunc::Gamma(1.0 + 2.0 / beta_) - pow(SpecFunc::Gamma(1.0 + 1.0 / beta_), 2.0));
+  return alpha_ * std::sqrt(SpecFunc::Gamma(1.0 + 2.0 / beta_) - std::pow(SpecFunc::Gamma(1.0 + 1.0 / beta_), 2.0));
 }
 
 
