@@ -3,7 +3,7 @@
  *  @file  ArchimedeanCopula.cxx
  *  @brief Abstract top-level class for archimedean copulas
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -33,8 +33,8 @@ CLASSNAMEINIT(ArchimedeanCopula);
 
 
 /* Default constructor */
-ArchimedeanCopula::ArchimedeanCopula(const String & name)
-  : CopulaImplementation(name)
+ArchimedeanCopula::ArchimedeanCopula()
+  : CopulaImplementation()
 {
   setDimension(2);
 }
@@ -89,7 +89,7 @@ NumericalScalar ArchimedeanCopula::computeCDF(const NumericalPoint & point) cons
 
 NumericalScalar ArchimedeanCopula::computeComplementaryCDF(const NumericalPoint & point) const
 {
-  throw NotYetImplementedException(HERE);
+  throw NotYetImplementedException(HERE) << "In ArchimedeanCopula::computeComplementaryCDF(const NumericalPoint & point) const";
 }
 
 /* Compute the probability content of an interval */
@@ -117,7 +117,7 @@ NumericalScalar ArchimedeanCopula::computeProbability(const Interval & interval)
 NumericalScalar ArchimedeanCopula::computeConditionalPDF(const NumericalScalar x,
     const NumericalPoint & y) const
 {
-  const UnsignedLong conditioningDimension(y.getDimension());
+  const UnsignedInteger conditioningDimension(y.getDimension());
   if (conditioningDimension >= getDimension()) throw InvalidArgumentException(HERE) << "Error: cannot compute a conditional PDF with a conditioning point of dimension greater or equal to the distribution dimension.";
   // If x is outside of the range of the marginal distribution
   if ((x <= 0.0) || (x >= 1.0)) return 0.0;
@@ -139,25 +139,25 @@ NumericalScalar ArchimedeanCopula::computeConditionalPDF(const NumericalScalar x
  */
 NumericalScalar ArchimedeanCopula::computeArchimedeanGenerator(const NumericalScalar t) const
 {
-  throw NotYetImplementedException(HERE);
+  throw NotYetImplementedException(HERE) << "In ArchimedeanCopula::computeArchimedeanGenerator(const NumericalScalar t) const";
 }
 
 /* Compute the inverse of the archimedean generator */
 NumericalScalar ArchimedeanCopula::computeInverseArchimedeanGenerator(const NumericalScalar t) const
 {
-  throw NotYetImplementedException(HERE);
+  throw NotYetImplementedException(HERE) << "In ArchimedeanCopula::computeInverseArchimedeanGenerator(const NumericalScalar t) const";
 }
 
 /* Compute the derivative of the density generator */
 NumericalScalar ArchimedeanCopula::computeArchimedeanGeneratorDerivative(const NumericalScalar t) const
 {
-  throw NotYetImplementedException(HERE);
+  throw NotYetImplementedException(HERE) << "In ArchimedeanCopula::computeArchimedeanGeneratorDerivative(const NumericalScalar t) const";
 }
 
 /* Compute the seconde derivative of the density generator */
 NumericalScalar ArchimedeanCopula::computeArchimedeanGeneratorSecondDerivative(const NumericalScalar t) const
 {
-  throw NotYetImplementedException(HERE);
+  throw NotYetImplementedException(HERE) << "In ArchimedeanCopula::computeArchimedeanGeneratorSecondDerivative(const NumericalScalar t) const";
 }
 
 /* Tell if the distribution has elliptical copula */
@@ -169,7 +169,7 @@ Bool ArchimedeanCopula::hasEllipticalCopula() const
 /* Tell if the distribution has independent copula */
 Bool ArchimedeanCopula::hasIndependentCopula() const
 {
-  throw NotYetImplementedException(HERE);
+  throw NotYetImplementedException(HERE) << "In ArchimedeanCopula::hasIndependentCopula() const";
 }
 
 /* Get the distribution of the marginal distribution corresponding to indices dimensions */
@@ -177,7 +177,7 @@ ArchimedeanCopula::Implementation ArchimedeanCopula::getMarginal(const Indices &
 {
   if (!indices.check(1)) throw InvalidArgumentException(HERE) << "The indices of an archimedean copula  must be in the range [0, 1] and  must be different";
   // General case
-  const UnsignedLong outputDimension(indices.getSize());
+  const UnsignedInteger outputDimension(indices.getSize());
   // Only one indice is needed, call the specialized method
   if (outputDimension == 1) return getMarginal(indices[0]);
   // The indices correspond to all the components, with a possible transposition of the two components.
