@@ -3,7 +3,7 @@
  *  @file  CompositeRandomVector.cxx
  *  @brief An implementation class for Composite random vectors
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -26,29 +26,25 @@
 
 BEGIN_NAMESPACE_OPENTURNS
 
-
-
-
 CLASSNAMEINIT(CompositeRandomVector);
 
 static Factory<CompositeRandomVector> RegisteredFactory("CompositeRandomVector");
 
 /* Standard constructor */
-CompositeRandomVector::CompositeRandomVector(const String & name)
-  : RandomVectorImplementation(name),
-    function_(),
-    p_antecedent_()
+CompositeRandomVector::CompositeRandomVector()
+  : RandomVectorImplementation()
+  , function_()
+  , p_antecedent_()
 {
   // Nothing to do
 }
 
 /* Standard constructor */
 CompositeRandomVector::CompositeRandomVector(const NumericalMathFunction & function,
-    const Antecedent & p_antecedent,
-    const String & name)
-  : RandomVectorImplementation(name),
-    function_(function),
-    p_antecedent_(p_antecedent)
+    const Antecedent & p_antecedent)
+  : RandomVectorImplementation()
+  , function_(function)
+  , p_antecedent_(p_antecedent)
 {
   if (function.getInputDimension() != p_antecedent->getDimension()) throw InvalidArgumentException(HERE) << "Error: trying to build a CompositeRandomVector from a RandomVector and a NumericalMathFunction with incompatible dimensions, here RandomVector dimension=" << p_antecedent->getDimension() << " and NumericalMathFunction input dimension=" << function.getInputDimension();
   // Get the description from the underlying function
@@ -57,11 +53,10 @@ CompositeRandomVector::CompositeRandomVector(const NumericalMathFunction & funct
 
 /* Standard constructor */
 CompositeRandomVector::CompositeRandomVector(const NumericalMathFunction & function,
-    const RandomVector & antecedent,
-    const String & name)
-  : RandomVectorImplementation(name),
-    function_(function),
-    p_antecedent_(antecedent.getImplementation())
+    const RandomVector & antecedent)
+  : RandomVectorImplementation()
+  , function_(function)
+  , p_antecedent_(antecedent.getImplementation())
 {
   if (function.getInputDimension() != p_antecedent_->getDimension()) throw InvalidArgumentException(HERE) << "Error: trying to build a CompositeRandomVector from a RandomVector and a NumericalMathFunction with incompatible dimensions, here RandomVector dimension=" << p_antecedent_->getDimension() << " and NumericalMathFunction input dimension=" << function.getInputDimension();
   // Get the description from the underlying function
@@ -80,7 +75,7 @@ String CompositeRandomVector::__repr__() const
   OSS oss;
   oss << "class=" << CompositeRandomVector::GetClassName()
       << " function=" << function_
-      << " antecedent=" << p_antecedent_->__repr__();
+      << " antecedent=" << (p_antecedent_ ? p_antecedent_->__repr__() : "");
   return oss;
 }
 
@@ -98,7 +93,7 @@ Bool CompositeRandomVector::isComposite() const
 
 
 /* Dimension accessor */
-UnsignedLong CompositeRandomVector::getDimension() const
+UnsignedInteger CompositeRandomVector::getDimension() const
 {
   return function_.getOutputDimension();
 }
@@ -110,9 +105,11 @@ NumericalPoint CompositeRandomVector::getRealization() const
 }
 
 /* Numerical sample accessor */
-NumericalSample CompositeRandomVector::getSample(const UnsignedLong size) const
+NumericalSample CompositeRandomVector::getSample(const UnsignedInteger size) const
 {
-  return function_(p_antecedent_->getSample(size));
+  NumericalSample sample(function_(p_antecedent_->getSample(size)));
+  sample.setDescription(getDescription());
+  return sample;
 }
 
 
@@ -121,7 +118,7 @@ NumericalPoint CompositeRandomVector::getMean() const
 {
   /* To be implemented by a suitable algorithm, given by the user.
      It could be the e.g. quadratic cumul algorithm */
-  throw NotYetImplementedException(HERE);
+  throw NotYetImplementedException(HERE) << "In CompositeRandomVector::getMean() const";
 }
 
 /* Covariance accessor */
@@ -129,11 +126,11 @@ CovarianceMatrix CompositeRandomVector::getCovariance() const
 {
   /* To be implemented by a suitable algorithm, given by the user.
      It could be the e.g. quadratic cumul algorithm */
-  throw NotYetImplementedException(HERE);
+  throw NotYetImplementedException(HERE) << "In CompositeRandomVector::getCovariance() const";
 }
 
 /* Get the random vector corresponding to the i-th marginal component */
-CompositeRandomVector::Implementation CompositeRandomVector::getMarginal(const UnsignedLong i) const
+CompositeRandomVector::Implementation CompositeRandomVector::getMarginal(const UnsignedInteger i) const
 {
   if (i >= getDimension()) throw InvalidArgumentException(HERE) << "The index of a marginal random vector must be in the range [0, dim-1]";
   return new CompositeRandomVector(function_.getMarginal(i), p_antecedent_);
@@ -161,7 +158,7 @@ NumericalMathFunction CompositeRandomVector::getFunction() const
 /* Distribution accessor */
 Distribution CompositeRandomVector::getDistribution() const
 {
-  throw NotYetImplementedException(HERE) << "CompositeRandomVector::Distribution CompositeRandomVector::getDistribution() const";
+  throw NotYetImplementedException(HERE) << "In CompositeRandomVector::getDistribution() const";
 }
 
 /* Method save() stores the object through the StorageManager */
