@@ -3,7 +3,7 @@
  *  @file  ContinuousDistribution.cxx
  *  @brief Abstract top-level class for Continuous distributions
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -36,8 +36,8 @@ BEGIN_NAMESPACE_OPENTURNS
 CLASSNAMEINIT(ContinuousDistribution);
 
 /* Default constructor */
-ContinuousDistribution::ContinuousDistribution(const String & name)
-  : DistributionImplementation(name)
+ContinuousDistribution::ContinuousDistribution()
+  : DistributionImplementation()
 {
   // Nothing to do
 }
@@ -65,11 +65,11 @@ String ContinuousDistribution::__repr__() const
 /* Get the DDF of the distributionImplementation */
 NumericalPoint ContinuousDistribution::computeDDF(const NumericalPoint & point) const
 {
-  const UnsignedLong dimension(getDimension());
+  const UnsignedInteger dimension(getDimension());
   NumericalPoint ddf(dimension);
-  const NumericalScalar h(pow(pdfEpsilon_, 1.0 / 3.0));
+  const NumericalScalar h(std::pow(pdfEpsilon_, 1.0 / 3.0));
   const NumericalScalar idenom(1.0 / (2.0 * h));
-  for (UnsignedLong i = 0; i < dimension; ++i)
+  for (UnsignedInteger i = 0; i < dimension; ++i)
   {
     NumericalPoint left(point);
     left[i] += h;
@@ -83,85 +83,71 @@ NumericalPoint ContinuousDistribution::computeDDF(const NumericalPoint & point)
 /* Get the PDF of the distribution */
 NumericalScalar ContinuousDistribution::computePDF(const NumericalPoint & point) const
 {
-  throw NotYetImplementedException(HERE);
+  throw NotYetImplementedException(HERE) << "In ContinuousDistribution::computePDF(const NumericalPoint & point) const";
 }
 
 /* Get the CDF of the distribution */
 NumericalScalar ContinuousDistribution::computeCDF(const NumericalPoint & point) const
 {
-  const UnsignedLong dimension(getDimension());
+  const UnsignedInteger dimension(getDimension());
   const NumericalPoint lowerBounds(getRange().getLowerBound());
   const NumericalPoint upperBounds(getRange().getUpperBound());
-  Bool allOutside(true);
-  for (UnsignedLong i = 0; i < dimension; ++i)
+  // Indices of the components to take into account in the computation
+  Indices toKeep(0);
+  NumericalPoint reducedPoint(0);
+  for (UnsignedInteger k = 0; k < dimension; ++ k)
   {
-    if (point[i] <= lowerBounds[i]) return 0.0;
-    allOutside &= (point[i] >= upperBounds[i]);
+    const NumericalScalar xK(point[k]);
+    // Early exit if one component is nonpositive
+    if (xK <= lowerBounds[k]) return 0.0;
+    // Keep only the indices for which xK is less than its corresponding range upper bound
+    // Marginalize the others
+    if (xK < upperBounds[k])
+    {
+      toKeep.add(k);
+      reducedPoint.add(xK);
+    }
+  } // k
+  // The point has all its components greater than the corresponding range upper bound
+  if (toKeep.getSize() == 0) return 1.0;
+  // The point has some components greater than the corresponding range upper bound
+  if (toKeep.getSize() != dimension)
+  {
+    // Try to reduce the dimension
+    try
+    {
+      return getMarginal(toKeep)->computeCDF(reducedPoint);
+    }
+    catch (...)
+    {
+      // Fallback on the default algorithm if the getMarginal() method is not implemented
+    }
   }
-  if (allOutside) return 1.0;
-  const NumericalScalar cdf(ContinuousDistribution::computeProbability(Interval(getRange().getLowerBound(), point)));
-  return cdf;
+  return computeProbabilityContinuous(Interval(getRange().getLowerBound(), point));
 }
 
 /* Get the survival function of the distribution */
 NumericalScalar ContinuousDistribution::computeSurvivalFunction(const NumericalPoint & point) const
 {
-  const UnsignedLong dimension(getDimension());
+  const UnsignedInteger dimension(getDimension());
   if (dimension == 1) return computeComplementaryCDF(point);
   const NumericalPoint lowerBounds(getRange().getLowerBound());
   const NumericalPoint upperBounds(getRange().getUpperBound());
   Bool allOutside(true);
-  for (UnsignedLong i = 0; i < dimension; ++i)
+  for (UnsignedInteger i = 0; i < dimension; ++i)
   {
     if (point[i] >= upperBounds[i]) return 0.0;
     allOutside &= (point[i] <= lowerBounds[i]);
   }
   if (allOutside) return 1.0;
-  const NumericalScalar survival(ContinuousDistribution::computeProbability(Interval(point, getRange().getUpperBound())));
+  const NumericalScalar survival(computeProbability(Interval(point, getRange().getUpperBound())));
   return survival;
 }
 
-/* Get the probability content of an interval */
-NumericalScalar ContinuousDistribution::computeProbability(const Interval & interval) const
-{
-  const Interval reducedInterval(interval.intersect(getRange()));
-  if (reducedInterval.isNumericallyEmpty()) return 0.0;
-  if (reducedInterval == getRange()) return 1.0;
-  const UnsignedLong dimension(getDimension());
-  const NumericalPoint lowerBounds(reducedInterval.getLowerBound());
-  const NumericalPoint upperBounds(reducedInterval.getUpperBound());
-  NumericalSample nodesAndWeights(getGaussNodesAndWeights());
-  // Perform the integration
-  const UnsignedLong marginalNodesNumber(getIntegrationNodesNumber());
-  const UnsignedLong size(static_cast< UnsignedLong >(round(pow(marginalNodesNumber, dimension))));
-  NumericalScalar probability(0.0);
-  Indices indices(dimension, 0);
-  for (UnsignedLong linearIndex = 0; linearIndex < size; ++linearIndex)
-  {
-    NumericalPoint node(dimension);
-    NumericalScalar weight(1.0);
-    for (UnsignedLong j = 0; j < dimension; ++j)
-    {
-      const UnsignedLong indiceJ(indices[j]);
-      const NumericalScalar delta(0.5 * (upperBounds[j] - lowerBounds[j]));
-      node[j] = lowerBounds[j] + delta * (1.0 + nodesAndWeights[0][indiceJ]);
-      weight *= delta * nodesAndWeights[1][indiceJ];
-    }
-    probability += weight * computePDF(node);
-    /* Update the indices */
-    ++indices[0];
-    /* Propagate the remainders */
-    for (UnsignedLong j = 0; j < dimension - 1; ++j) indices[j + 1] += (indices[j] == marginalNodesNumber);
-    /* Correction of the indices. The last index cannot overflow. */
-    for (UnsignedLong j = 0; j < dimension - 1; ++j) indices[j] = indices[j] % marginalNodesNumber;
-  } // Loop over the n-D nodes
-  return probability;
-}
-
 /* Build a C1 interpolation of the CDF function for 1D continuous distributions */
-Collection<PiecewiseHermiteEvaluationImplementation> ContinuousDistribution::interpolateCDF(const UnsignedLong n)
+Collection<PiecewiseHermiteEvaluationImplementation> ContinuousDistribution::interpolateCDF(const UnsignedInteger n)
 {
-  if (getDimension() != 1) throw NotYetImplementedException(HERE) << "Error: cannot interpolate CDF for multidimensional distributions.";
+  if (getDimension() != 1) throw NotYetImplementedException(HERE) << "In ContinuousDistribution::interpolateCDF(const UnsignedInteger n): cannot interpolate CDF for multidimensional distributions.";
   const PDFWrapper pdfWrapper(this);
   const NumericalMathFunction fPDF(bindMethod<PDFWrapper, NumericalPoint, NumericalPoint>(pdfWrapper, &PDFWrapper::computePDF, 1, 1));
   const NumericalScalar xMin(getRange().getLowerBound()[0]);
@@ -180,7 +166,7 @@ Collection<PiecewiseHermiteEvaluationImplementation> ContinuousDistribution::int
   GaussKronrod algo;
   const NumericalScalar stepCDF((mu - xMin) / (n - 1.0));
   const NumericalScalar stepCCDF((xMax - mu) / (n - 1.0));
-  for (UnsignedLong i = 1; i < n; ++i)
+  for (UnsignedInteger i = 1; i < n; ++i)
   {
     const NumericalScalar xCDF(xMin + i * stepCDF);
     const NumericalScalar xCCDF(xMax - i * stepCCDF);
@@ -188,11 +174,11 @@ Collection<PiecewiseHermiteEvaluationImplementation> ContinuousDistribution::int
     locationsCCDF[n - i - 1] = xCCDF;
     NumericalPoint ai;
     NumericalPoint bi;
-    NumericalPoint fi;
+    NumericalSample fi;
     NumericalPoint ei;
     NumericalScalar error;
-    valuesCDF[i] = valuesCDF[i - 1] + algo.integrate(fPDF, xCDFOld, xCDF, error, ai, bi, fi, ei);
-    valuesCCDF[n - i - 1] = valuesCCDF[n - i] + algo.integrate(fPDF, xCCDF, xCCDFOld, error, ai, bi, fi, ei);
+    valuesCDF[i] = valuesCDF[i - 1] + algo.integrate(fPDF, xCDFOld, xCDF, error, ai, bi, fi, ei)[0];
+    valuesCCDF[n - i - 1] = valuesCCDF[n - i] + algo.integrate(fPDF, xCCDF, xCCDFOld, error, ai, bi, fi, ei)[0];
     derivativesCDF[i] = computePDF(xCDF);
     derivativesCCDF[n - i - 1] = -computePDF(xCCDF);
     xCDFOld = xCDF;
