@@ -3,7 +3,7 @@
  *  @file  Distribution.cxx
  *  @brief Abstract top-level class for all distributions
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -38,16 +38,14 @@ Distribution::Distribution()
 }
 
 /* Default constructor */
-Distribution::Distribution(const DistributionImplementation & implementation,
-                           const String & name)
+Distribution::Distribution(const DistributionImplementation & implementation)
   : TypedInterfaceObject<DistributionImplementation>(implementation.clone())
 {
   // Nothing to do
 }
 
 /* Constructor from implementation */
-Distribution::Distribution(const Implementation & p_implementation,
-                           const String & name)
+Distribution::Distribution(const Implementation & p_implementation)
   : TypedInterfaceObject<DistributionImplementation>(p_implementation)
 {
   // Initialize any other class members here
@@ -56,8 +54,7 @@ Distribution::Distribution(const Implementation & p_implementation,
 
 
 /* Constructor from implementation pointer */
-Distribution::Distribution(DistributionImplementation * p_implementation,
-                           const String & name)
+Distribution::Distribution(DistributionImplementation * p_implementation)
   : TypedInterfaceObject<DistributionImplementation>(p_implementation)
 {
   // Initialize any other class members here
@@ -68,7 +65,169 @@ Distribution::Distribution(DistributionImplementation * p_implementation,
 /* Comparison operator */
 Bool Distribution::operator ==(const Distribution & other) const
 {
-  return (this == &other);
+  if (this == &other) return true;
+  return *getImplementation() == *other.getImplementation();
+}
+
+/* Comparison operator */
+Bool Distribution::operator !=(const Distribution & other) const
+{
+  return !operator==(other);
+}
+
+/* Addition operator */
+Distribution Distribution::operator + (const Distribution & other) const
+{
+  return getImplementation()->operator +(other.getImplementation());
+}
+
+Distribution Distribution::operator + (const NumericalScalar value) const
+{
+  return getImplementation()->operator +(value);
+}
+
+/* Substraction operator */
+Distribution Distribution::operator - (const Distribution & other) const
+{
+  return getImplementation()->operator -(other.getImplementation());
+}
+
+Distribution Distribution::operator - (const NumericalScalar value) const
+{
+  return getImplementation()->operator -(value);
+}
+
+/* Multiplication operator */
+Distribution Distribution::operator * (const Distribution & other) const
+{
+  return getImplementation()->operator *(other.getImplementation());
+}
+
+Distribution Distribution::operator * (const NumericalScalar value) const
+{
+  return getImplementation()->operator *(value);
+}
+
+/* Division operator */
+Distribution Distribution::operator / (const Distribution & other) const
+{
+  return getImplementation()->operator /(other.getImplementation());
+}
+
+Distribution Distribution::operator / (const NumericalScalar value) const
+{
+  return getImplementation()->operator /(value);
+}
+
+/* Transformation of distributions by usual functions */
+Distribution Distribution::cos() const
+{
+  return getImplementation()->cos();
+}
+
+Distribution Distribution::sin() const
+{
+  return getImplementation()->sin();
+}
+
+Distribution Distribution::tan() const
+{
+  return getImplementation()->tan();
+}
+
+Distribution Distribution::acos() const
+{
+  return getImplementation()->acos();
+}
+
+Distribution Distribution::asin() const
+{
+  return getImplementation()->asin();
+}
+
+Distribution Distribution::atan() const
+{
+  return getImplementation()->atan();
+}
+
+Distribution Distribution::cosh() const
+{
+  return getImplementation()->cosh();
+}
+
+Distribution Distribution::sinh() const
+{
+  return getImplementation()->sinh();
+}
+
+Distribution Distribution::tanh() const
+{
+  return getImplementation()->tanh();
+}
+
+Distribution Distribution::acosh() const
+{
+  return getImplementation()->acosh();
+}
+
+Distribution Distribution::asinh() const
+{
+  return getImplementation()->asinh();
+}
+
+Distribution Distribution::atanh() const
+{
+  return getImplementation()->atanh();
+}
+
+Distribution Distribution::exp() const
+{
+  return getImplementation()->exp();
+}
+
+Distribution Distribution::log() const
+{
+  return getImplementation()->log();
+}
+
+Distribution Distribution::ln() const
+{
+  return getImplementation()->ln();
+}
+
+Distribution Distribution::pow(const NumericalScalar & exponent) const
+{
+  return getImplementation()->pow(exponent);
+}
+
+Distribution Distribution::pow(const SignedInteger & exponent) const
+{
+  return getImplementation()->pow(exponent);
+}
+
+Distribution Distribution::sqr() const
+{
+  return getImplementation()->sqr();
+}
+
+Distribution Distribution::inverse() const
+{
+  return getImplementation()->inverse();
+}
+
+Distribution Distribution::sqrt() const
+{
+  return getImplementation()->sqrt();
+}
+
+Distribution Distribution::cbrt() const
+{
+  return getImplementation()->cbrt();
+}
+
+Distribution Distribution::abs() const
+{
+  return getImplementation()->abs();
 }
 
 /* String converter */
@@ -99,7 +258,7 @@ NumericalScalar Distribution::getWeight() const
 
 
 /* Dimension accessor */
-UnsignedLong Distribution::getDimension() const
+UnsignedInteger Distribution::getDimension() const
 {
   return getImplementation()->getDimension();
 }
@@ -135,19 +294,19 @@ NumericalPoint Distribution::getKurtosis() const
 }
 
 /* Get the raw moments of the standardized distribution */
-NumericalPoint Distribution::getStandardMoment(const UnsignedLong n) const
+NumericalPoint Distribution::getStandardMoment(const UnsignedInteger n) const
 {
   return getImplementation()->getStandardMoment(n);
 }
 
 /* Get the raw moments of the distribution */
-NumericalPoint Distribution::getMoment(const UnsignedLong n) const
+NumericalPoint Distribution::getMoment(const UnsignedInteger n) const
 {
   return getImplementation()->getMoment(n);
 }
 
 /* Get the centered moments about the mean of the distribution */
-NumericalPoint Distribution::getCenteredMoment(const UnsignedLong n) const
+NumericalPoint Distribution::getCenteredMoment(const UnsignedInteger n) const
 {
   return getImplementation()->getCenteredMoment(n);
 }
@@ -159,13 +318,13 @@ CovarianceMatrix Distribution::getCovariance() const
 }
 
 /* Cholesky factor of the covariance matrix accessor */
-SquareMatrix Distribution::getCholesky() const
+TriangularMatrix Distribution::getCholesky() const
 {
   return getImplementation()->getCholesky();
 }
 
 /* Inverse of the Cholesky factor of the covariance matrix accessor */
-SquareMatrix Distribution::getInverseCholesky() const
+TriangularMatrix Distribution::getInverseCholesky() const
 {
   return getImplementation()->getInverseCholesky();
 }
@@ -211,7 +370,7 @@ NumericalPoint Distribution::getRealization() const
 }
 
 /* Get a numerical sample whose elements follow the distribution */
-NumericalSample Distribution::getSample(const UnsignedLong size) const
+NumericalSample Distribution::getSample(const UnsignedInteger size) const
 {
   return getImplementation()->getSample(size);
 }
@@ -356,7 +515,7 @@ NumericalScalar Distribution::computeProbability(const Interval & interval) cons
 /*  Compute the PDF of 1D distributions over a regular grid */
 NumericalSample Distribution::computePDF(const NumericalScalar xMin,
     const NumericalScalar xMax,
-    const UnsignedLong pointNumber) const
+    const UnsignedInteger pointNumber) const
 {
   NumericalSample grid;
   return getImplementation()->computePDF(xMin, xMax, pointNumber, grid);
@@ -365,7 +524,7 @@ NumericalSample Distribution::computePDF(const NumericalScalar xMin,
 /*  Compute the CDF of 1D distributions over a regular grid */
 NumericalSample Distribution::computeCDF(const NumericalScalar xMin,
     const NumericalScalar xMax,
-    const UnsignedLong pointNumber) const
+    const UnsignedInteger pointNumber) const
 {
   NumericalSample grid;
   return getImplementation()->computeCDF(xMin, xMax, pointNumber, grid);
@@ -373,7 +532,7 @@ NumericalSample Distribution::computeCDF(const NumericalScalar xMin,
 
 NumericalSample Distribution::computeComplementaryCDF(const NumericalScalar xMin,
     const NumericalScalar xMax,
-    const UnsignedLong pointNumber) const
+    const UnsignedInteger pointNumber) const
 {
   NumericalSample grid;
   return getImplementation()->computeComplementaryCDF(xMin, xMax, pointNumber, grid);
@@ -385,13 +544,21 @@ NumericalPoint Distribution::computePDFGradient(const NumericalPoint & point) co
   return getImplementation()->computePDFGradient(point);
 }
 
+NumericalSample Distribution::computePDFGradient(const NumericalSample & sample) const
+{
+  return getImplementation()->computePDFGradient(sample);
+}
+
 /* Get the CDF gradient of the distribution */
 NumericalPoint Distribution::computeCDFGradient(const NumericalPoint & point) const
 {
   return getImplementation()->computeCDFGradient(point);
 }
 
-
+NumericalSample Distribution::computeCDFGradient(const NumericalSample & sample) const
+{
+  return getImplementation()->computeCDFGradient(sample);
+}
 
 /* Get the mathematical and numerical range of the distribution.
    Its mathematical range is the smallest closed interval outside
@@ -418,7 +585,7 @@ NumericalSample Distribution::computeQuantile(const NumericalPoint & prob,
 /* Compute the quantile over a regular grid */
 NumericalSample Distribution::computeQuantile(const NumericalScalar qMin,
     const NumericalScalar qMax,
-    const UnsignedLong pointNumber,
+    const UnsignedInteger pointNumber,
     const Bool tail) const
 {
   return getImplementation()->computeQuantile(qMin, qMax, pointNumber, tail);
@@ -484,8 +651,35 @@ NumericalSample Distribution::getSupport() const
   return getImplementation()->getSupport();
 }
 
+/* Compute the density generator of the elliptical generator, i.e.
+  *  the function phi such that the density of the distribution can
+  *  be written as p(x) = phi(t(x-mu)R(x-mu))                      */
+NumericalScalar Distribution::computeDensityGenerator(const NumericalScalar betaSquare) const
+{
+  return getImplementation()->computeDensityGenerator(betaSquare);
+}
+
+/* Compute the derivative of the density generator */
+NumericalScalar Distribution::computeDensityGeneratorDerivative(const NumericalScalar betaSquare) const
+{
+  return getImplementation()->computeDensityGeneratorDerivative(betaSquare);
+}
+
+/* Compute the seconde derivative of the density generator */
+NumericalScalar Distribution::computeDensityGeneratorSecondDerivative(const NumericalScalar betaSquare) const
+{
+  return getImplementation()->computeDensityGeneratorSecondDerivative(betaSquare);
+}
+
+/* Compute the radial distribution CDF */
+NumericalScalar Distribution::computeRadialDistributionCDF (const NumericalScalar radius,
+    const Bool tail) const
+{
+  return getImplementation()->computeRadialDistributionCDF(radius, tail);
+}
+
 /* Get the i-th marginal distribution */
-Distribution Distribution::getMarginal(const UnsignedLong i) const
+Distribution Distribution::getMarginal(const UnsignedInteger i) const
 {
   return *(getImplementation()->getMarginal(i));
 }
@@ -553,22 +747,22 @@ Distribution Distribution::getStandardRepresentative() const
 /* Draw the PDF of the distribution when its dimension is 1 */
 Graph Distribution::drawPDF(const NumericalScalar xMin,
                             const NumericalScalar xMax,
-                            const UnsignedLong pointNumber) const
+                            const UnsignedInteger pointNumber) const
 {
   return getImplementation()->drawPDF(xMin, xMax, pointNumber);
 }
 
 /* Draw the PDF of the distribution when its dimension is 1 */
-Graph Distribution::drawPDF(const UnsignedLong pointNumber) const
+Graph Distribution::drawPDF(const UnsignedInteger pointNumber) const
 {
   return getImplementation()->drawPDF(pointNumber);
 }
 
 /* Draw the PDF of a 1D marginal */
-Graph Distribution::drawMarginal1DPDF(const UnsignedLong marginalIndex,
+Graph Distribution::drawMarginal1DPDF(const UnsignedInteger marginalIndex,
                                       const NumericalScalar xMin,
                                       const NumericalScalar xMax,
-                                      const UnsignedLong pointNumber) const
+                                      const UnsignedInteger pointNumber) const
 {
   return getImplementation()->drawMarginal1DPDF(marginalIndex, xMin, xMax, pointNumber);
 }
@@ -595,8 +789,8 @@ Graph Distribution::drawPDF(const Indices & pointNumber) const
 }
 
 /* Draw the PDF of a 2D marginal */
-Graph Distribution::drawMarginal2DPDF(const UnsignedLong firstMarginal,
-                                      const UnsignedLong secondMarginal,
+Graph Distribution::drawMarginal2DPDF(const UnsignedInteger firstMarginal,
+                                      const UnsignedInteger secondMarginal,
                                       const NumericalPoint & xMin,
                                       const NumericalPoint & xMax,
                                       const Indices & pointNumber) const
@@ -613,22 +807,22 @@ Graph Distribution::drawPDF() const
 /* Draw the CDF of the distribution when its dimension is 1 */
 Graph Distribution::drawCDF(const NumericalScalar xMin,
                             const NumericalScalar xMax,
-                            const UnsignedLong pointNumber) const
+                            const UnsignedInteger pointNumber) const
 {
   return getImplementation()->drawCDF(xMin, xMax, pointNumber);
 }
 
 /* Draw the CDF of the distribution when its dimension is 1 */
-Graph Distribution::drawCDF(const UnsignedLong pointNumber) const
+Graph Distribution::drawCDF(const UnsignedInteger pointNumber) const
 {
   return getImplementation()->drawCDF(pointNumber);
 }
 
 /* Draw the CDF of a 1D marginal */
-Graph Distribution::drawMarginal1DCDF(const UnsignedLong marginalIndex,
+Graph Distribution::drawMarginal1DCDF(const UnsignedInteger marginalIndex,
                                       const NumericalScalar xMin,
                                       const NumericalScalar xMax,
-                                      const UnsignedLong pointNumber) const
+                                      const UnsignedInteger pointNumber) const
 {
   return getImplementation()->drawMarginal1DCDF(marginalIndex, xMin, xMax, pointNumber);
 }
@@ -655,8 +849,8 @@ Graph Distribution::drawCDF(const Indices & pointNumber) const
 }
 
 /* Draw the CDF of a 2D marginal */
-Graph Distribution::drawMarginal2DCDF(const UnsignedLong firstMarginal,
-                                      const UnsignedLong secondMarginal,
+Graph Distribution::drawMarginal2DCDF(const UnsignedInteger firstMarginal,
+                                      const UnsignedInteger secondMarginal,
                                       const NumericalPoint & xMin,
                                       const NumericalPoint & xMax,
                                       const Indices & pointNumber) const
@@ -671,14 +865,14 @@ Graph Distribution::drawCDF() const
 }
 
 /* Draw the quantile of the distribution when its dimension is 1 or 2 */
-Graph Distribution::drawQuantile(const UnsignedLong pointNumber) const
+Graph Distribution::drawQuantile(const UnsignedInteger pointNumber) const
 {
   return getImplementation()->drawQuantile(pointNumber);
 }
 
 Graph Distribution::drawQuantile(const NumericalScalar qMin,
                                  const NumericalScalar qMax,
-                                 const UnsignedLong pointNumber) const
+                                 const UnsignedInteger pointNumber) const
 {
   return getImplementation()->drawQuantile(qMin, qMax, pointNumber);
 }
@@ -708,7 +902,7 @@ void Distribution::setParametersCollection(const NumericalPoint & parameters)
 }
 
 /* Parameters number */
-UnsignedLong Distribution::getParametersNumber() const
+UnsignedInteger Distribution::getParametersNumber() const
 {
   return getImplementation()->getParametersNumber();
 }
