@@ -3,7 +3,7 @@
  *  @file  EllipticalDistribution.cxx
  *  @brief Abstract top-level class for elliptical distributions
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -43,8 +43,8 @@ CLASSNAMEINIT(EllipticalDistribution);
 static Factory<EllipticalDistribution> RegisteredFactory("EllipticalDistribution");
 
 /* Default constructor */
-EllipticalDistribution::EllipticalDistribution(const String & name)
-  : ContinuousDistribution(name)
+EllipticalDistribution::EllipticalDistribution()
+  : ContinuousDistribution()
 {
   // Nothing to do
 }
@@ -53,14 +53,13 @@ EllipticalDistribution::EllipticalDistribution(const String & name)
 EllipticalDistribution::EllipticalDistribution(const NumericalPoint & mean,
     const NumericalPoint & sigma,
     const CorrelationMatrix & R,
-    const NumericalScalar covarianceScalingFactor,
-    const String & name)
-  : ContinuousDistribution(name)
+    const NumericalScalar covarianceScalingFactor)
+  : ContinuousDistribution()
   , sigma_(sigma)
   , R_(R)
   , covarianceScalingFactor_(covarianceScalingFactor)
 {
-  const UnsignedLong dimension(R.getDimension());
+  const UnsignedInteger dimension(R.getDimension());
   // We check if the inputs have the same dimension. If not, we throw an exception
   if ( (dimension != mean.getDimension()) ||
        (dimension != sigma.getDimension()) )
@@ -71,14 +70,14 @@ EllipticalDistribution::EllipticalDistribution(const NumericalPoint & mean,
   // We check that the given correlation matrix is definite positive
   if ( !R_.isPositiveDefinite()) throw InvalidArgumentException(HERE) << "The correlation matrix must be definite positive R=" << R;
   // We check that the marginal standard deviations are > 0
-  for(UnsignedLong i = 0; i < dimension; ++i)
+  for(UnsignedInteger i = 0; i < dimension; ++i)
     if (sigma[i] <= 0.0) throw InvalidArgumentException(HERE) << "The marginal standard deviations must be > 0 sigma=" << sigma;
   // Then we set the dimension of the Elliptical distribution
   setDimension(dimension);
   // We initialize the description
   Description description(dimension);
   // Set default description
-  for (UnsignedLong i = 0; i < dimension; ++i) description[i] = OSS() << "marginal " << i + 1;
+  for (UnsignedInteger i = 0; i < dimension; ++i) description[i] = OSS() << "marginal " << i + 1;
   setDescription(description);
   // The mean attribute is stored at an upper level
   mean_ = mean;
@@ -101,7 +100,7 @@ Bool EllipticalDistribution::operator ==(const EllipticalDistribution & other) c
 NumericalPoint EllipticalDistribution::normalize(const NumericalPoint & x) const
 {
   NumericalPoint u(x - mean_);
-  for (UnsignedLong i = 0; i < getDimension(); ++i) u[i] /= sigma_[i];
+  for (UnsignedInteger i = 0; i < getDimension(); ++i) u[i] /= sigma_[i];
   return u;
 }
 
@@ -109,7 +108,7 @@ NumericalPoint EllipticalDistribution::normalize(const NumericalPoint & x) const
 NumericalPoint EllipticalDistribution::denormalize(const NumericalPoint & u) const
 {
   NumericalPoint x(mean_);
-  for (UnsignedLong i = 0; i < getDimension(); ++i) x[i] += sigma_[i] * u[i];
+  for (UnsignedInteger i = 0; i < getDimension(); ++i) x[i] += sigma_[i] * u[i];
   return x;
 }
 
@@ -140,21 +139,21 @@ Bool EllipticalDistribution::hasEllipticalCopula() const
  *  be written as p(x) = phi((x-mean_).C^{-1} * (x-mean_))                      */
 NumericalScalar EllipticalDistribution::computeDensityGenerator(const NumericalScalar betaSquare) const
 {
-  throw NotYetImplementedException(HERE);
+  throw NotYetImplementedException(HERE) << "In EllipticalDistribution::computeDensityGenerator(const NumericalScalar betaSquare) const";
 }
 
 NumericalScalar EllipticalDistribution::computeLogDensityGenerator(const NumericalScalar betaSquare) const
 {
   const NumericalScalar densityGenerator(computeDensityGenerator(betaSquare));
   if (densityGenerator == 0.0) return -SpecFunc::MaxNumericalScalar;
-  return log(densityGenerator);
+  return std::log(densityGenerator);
 }
 
 /* Compute the derivative of the density generator */
 NumericalScalar EllipticalDistribution::computeDensityGeneratorDerivative(const NumericalScalar betaSquare) const
 {
   // Use centered finite difference
-  const NumericalScalar epsilon(pow(ResourceMap::GetAsNumericalScalar("DistributionImplementation-DefaultPDFEpsilon"), 1.0 / 3.0));
+  const NumericalScalar epsilon(std::pow(ResourceMap::GetAsNumericalScalar("DistributionImplementation-DefaultPDFEpsilon"), 1.0 / 3.0));
   return (computeDensityGenerator(betaSquare + epsilon) - computeDensityGenerator(betaSquare - epsilon)) / epsilon;
 }
 
@@ -162,7 +161,7 @@ NumericalScalar EllipticalDistribution::computeDensityGeneratorDerivative(const
 NumericalScalar EllipticalDistribution::computeDensityGeneratorSecondDerivative(const NumericalScalar betaSquare) const
 {
   // Use centered finite difference
-  const NumericalScalar epsilon(pow(ResourceMap::GetAsNumericalScalar("DistributionImplementation-DefaultPDFEpsilon"), 0.25));
+  const NumericalScalar epsilon(std::pow(ResourceMap::GetAsNumericalScalar("DistributionImplementation-DefaultPDFEpsilon"), 0.25));
   return (computeDensityGenerator(betaSquare + epsilon) - 2.0 * computeDensityGenerator(betaSquare) + computeDensityGenerator(betaSquare - epsilon)) / (epsilon * epsilon);
 }
 
@@ -171,9 +170,79 @@ NumericalPoint EllipticalDistribution::computeDDF(const NumericalPoint & point)
 {
   if (point.getDimension() != getDimension()) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=1, here dimension=" << point.getDimension();
 
-  const NumericalPoint iLx(inverseCholesky_ * (point - mean_));
-  const NumericalScalar betaSquare(iLx.normSquare());
-  return 2.0 * normalizationFactor_ * computeDensityGeneratorDerivative(betaSquare) * inverseCholesky_.transpose() * iLx;
+  const UnsignedInteger dimension(getDimension());
+  switch(dimension)
+  {
+    case 1:
+    {
+      const NumericalScalar iLx((point[0] - mean_[0]) / sigma_[0]);
+      return NumericalPoint(1, 2.0 * normalizationFactor_ * computeDensityGeneratorDerivative(iLx * iLx) * inverseCholesky_(0, 0) * iLx);
+    }
+    break;
+    case 2:
+    {
+      const NumericalScalar deltaX(point[0] - mean_[0]);
+      const NumericalScalar deltaY(point[1] - mean_[1]);
+      NumericalScalar iLx, iLy;
+      NumericalPoint result(2);
+      if (inverseCholesky_.isLowerTriangular())
+      {
+        iLx = inverseCholesky_(0, 0) * deltaX;
+        iLy = inverseCholesky_(1, 0) * deltaX + inverseCholesky_(1, 1) * deltaY;
+        const NumericalScalar betaSquare(iLx * iLx + iLy * iLy);
+        const NumericalScalar factor(2.0 * normalizationFactor_ * computeDensityGeneratorDerivative(betaSquare));
+        result[0] = factor * (inverseCholesky_(0, 0) * iLx + inverseCholesky_(1, 0) * iLy);
+        result[1] = factor * (inverseCholesky_(1, 1) * iLy);
+      }
+      else
+      {
+        iLx = inverseCholesky_(0, 0) * deltaX + inverseCholesky_(0, 1) * deltaY;
+        iLy = inverseCholesky_(1, 1) * deltaY;
+        const NumericalScalar betaSquare(iLx * iLx + iLy * iLy);
+        const NumericalScalar factor(2.0 * normalizationFactor_ * computeDensityGeneratorDerivative(betaSquare));
+        result[0] = factor * (inverseCholesky_(0, 0) * iLx);
+        result[1] = factor * (inverseCholesky_(0, 1) * iLx + inverseCholesky_(1, 1) * iLy);
+      }
+      return result;
+    }
+    break;
+    case 3:
+    {
+      const NumericalScalar deltaX(point[0] - mean_[0]);
+      const NumericalScalar deltaY(point[1] - mean_[1]);
+      const NumericalScalar deltaZ(point[2] - mean_[2]);
+      NumericalScalar iLx, iLy, iLz;
+      NumericalPoint result(3);
+      if (inverseCholesky_.isLowerTriangular())
+      {
+        iLx = inverseCholesky_(0, 0) * deltaX;
+        iLy = inverseCholesky_(1, 0) * deltaX + inverseCholesky_(1, 1) * deltaY;
+        iLz = inverseCholesky_(2, 0) * deltaX + inverseCholesky_(2, 1) * deltaY + inverseCholesky_(2, 2) * deltaZ;
+        const NumericalScalar betaSquare(iLx * iLx + iLy * iLy + iLz * iLz);
+        const NumericalScalar factor(2.0 * normalizationFactor_ * computeDensityGeneratorDerivative(betaSquare));
+        result[0] = factor * (inverseCholesky_(0, 0) * iLx + inverseCholesky_(1, 0) * iLy + inverseCholesky_(2, 0) * iLz);
+        result[1] = factor * (inverseCholesky_(1, 1) * iLy + inverseCholesky_(2, 1) * iLz);
+        result[2] = factor * (inverseCholesky_(2, 2) * iLz);
+      }
+      else
+      {
+        iLx = inverseCholesky_(0, 0) * deltaX + inverseCholesky_(0, 1) * deltaY + inverseCholesky_(0, 2) * deltaZ;
+        iLy = inverseCholesky_(1, 1) * deltaY + inverseCholesky_(1, 2) * deltaZ;
+        iLz = inverseCholesky_(2, 2) * deltaZ;
+        const NumericalScalar betaSquare(iLx * iLx + iLy * iLy + iLz * iLz);
+        const NumericalScalar factor(2.0 * normalizationFactor_ * computeDensityGeneratorDerivative(betaSquare));
+        result[0] = factor * (inverseCholesky_(0, 0) * iLx);
+        result[1] = factor * (inverseCholesky_(0, 1) * iLx + inverseCholesky_(1, 1) * iLy);
+        result[2] = factor * (inverseCholesky_(0, 2) * iLx + inverseCholesky_(1, 2) * iLy + inverseCholesky_(2, 2) * iLz);
+      }
+      return result;
+    }
+    break;
+    default:
+      const NumericalPoint iLx(inverseCholesky_ * (point - mean_));
+      const NumericalScalar betaSquare(iLx.normSquare());
+      return 2.0 * normalizationFactor_ * computeDensityGeneratorDerivative(betaSquare) * inverseCholesky_.transpose() * iLx;
+  }
 }
 
 /* Get the PDF of the distribution */
@@ -181,17 +250,60 @@ NumericalScalar EllipticalDistribution::computePDF(const NumericalPoint & point)
 {
   if (point.getDimension() != getDimension()) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=1, here dimension=" << point.getDimension();
 
-  const UnsignedLong dimension(getDimension());
-  if (dimension == 1)
+  const UnsignedInteger dimension(getDimension());
+  switch(dimension)
   {
-    const NumericalScalar iLx((point[0] - mean_[0]) / sigma_[0]);
-    return normalizationFactor_ * computeDensityGenerator(iLx * iLx);
-  }
-  else
-  {
-    const NumericalPoint iLx(inverseCholesky_ * (point - mean_));
-    const NumericalScalar betaSquare(iLx.normSquare());
-    return normalizationFactor_ * computeDensityGenerator(betaSquare);
+    case 1:
+    {
+      const NumericalScalar iLx((point[0] - mean_[0]) / sigma_[0]);
+      return normalizationFactor_ * computeDensityGenerator(iLx * iLx);
+    }
+    break;
+    case 2:
+    {
+      const NumericalScalar deltaX(point[0] - mean_[0]);
+      const NumericalScalar deltaY(point[1] - mean_[1]);
+      NumericalScalar iLx, iLy;
+      if (inverseCholesky_.isLowerTriangular())
+      {
+        iLx = inverseCholesky_(0, 0) * deltaX;
+        iLy = inverseCholesky_(1, 0) * deltaX + inverseCholesky_(1, 1) * deltaY;
+      }
+      else
+      {
+        iLx = inverseCholesky_(0, 0) * deltaX + inverseCholesky_(0, 1) * deltaY;
+        iLy = inverseCholesky_(1, 1) * deltaY;
+      }
+      const NumericalScalar betaSquare(iLx * iLx + iLy * iLy);
+      return normalizationFactor_ * computeDensityGenerator(betaSquare);
+    }
+    break;
+    case 3:
+    {
+      const NumericalScalar deltaX(point[0] - mean_[0]);
+      const NumericalScalar deltaY(point[1] - mean_[1]);
+      const NumericalScalar deltaZ(point[2] - mean_[2]);
+      NumericalScalar iLx, iLy, iLz;
+      if (inverseCholesky_.isLowerTriangular())
+      {
+        iLx = inverseCholesky_(0, 0) * deltaX;
+        iLy = inverseCholesky_(1, 0) * deltaX + inverseCholesky_(1, 1) * deltaY;
+        iLz = inverseCholesky_(2, 0) * deltaX + inverseCholesky_(2, 1) * deltaY + inverseCholesky_(2, 2) * deltaZ;
+      }
+      else
+      {
+        iLx = inverseCholesky_(0, 0) * deltaX + inverseCholesky_(0, 1) * deltaY + inverseCholesky_(0, 2) * deltaZ;
+        iLy = inverseCholesky_(1, 1) * deltaY + inverseCholesky_(1, 2) * deltaZ;
+        iLz = inverseCholesky_(2, 2) * deltaZ;
+      }
+      const NumericalScalar betaSquare(iLx * iLx + iLy * iLy + iLz * iLz);
+      return normalizationFactor_ * computeDensityGenerator(betaSquare);
+    }
+    break;
+    default:
+      const NumericalPoint iLx(inverseCholesky_ * (point - mean_));
+      const NumericalScalar betaSquare(iLx.normSquare());
+      return normalizationFactor_ * computeDensityGenerator(betaSquare);
   }
 }
 
@@ -201,14 +313,14 @@ NumericalPoint EllipticalDistribution::computePDFGradient(const NumericalPoint &
   if (point.getDimension() != getDimension()) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=1, here dimension=" << point.getDimension();
 
   const NumericalPoint minusGardientMean(computeDDF(point));
-  const UnsignedLong dimension(getDimension());
+  const UnsignedInteger dimension(getDimension());
   const NumericalPoint u(normalize(point));
   const NumericalPoint iRu(inverseR_ * u);
   const NumericalScalar betaSquare(dot(u, iRu));
   const NumericalScalar phi(computeDensityGenerator(betaSquare));
   const NumericalScalar phiDerivative(computeDensityGeneratorDerivative(betaSquare));
   NumericalPoint pdfGradient(2 * dimension);
-  for (UnsignedLong i = 0; i < dimension; ++i)
+  for (UnsignedInteger i = 0; i < dimension; ++i)
   {
     NumericalScalar iSigma(1.0 / sigma_[i]);
     // dPDF / dmu_i
@@ -228,28 +340,28 @@ NumericalScalar EllipticalDistribution::computeSurvivalFunction(const NumericalP
 /* Update the derivative attributes */
 void EllipticalDistribution::update()
 {
-  const UnsignedLong dimension(getDimension());
+  const UnsignedInteger dimension(getDimension());
   if (dimension > 1)
   {
     // Build the shape matrix
     shape_ = R_;
-    for (UnsignedLong i = 0; i < dimension; ++i)
-      for (UnsignedLong j = 0; j <= i; ++j)
+    for (UnsignedInteger i = 0; i < dimension; ++i)
+      for (UnsignedInteger j = 0; j <= i; ++j)
         shape_(i, j) *= sigma_[i] * sigma_[j];
     // Compute its Cholesky factor
     cholesky_ = shape_.computeCholesky();
 
-    inverseCholesky_ = TriangularMatrix(cholesky_.getImplementation()).solveLinearSystem(IdentityMatrix(dimension)).getImplementation();
+    inverseCholesky_ = cholesky_.solveLinearSystem(IdentityMatrix(dimension)).getImplementation();
 
     // Inverse the correlation matrix R = D^(-1).L.L'.D^(-1)
     // R^(-1) = D.L^(-1).L^(-1)'.D
     inverseR_ = SymmetricMatrix(dimension);
     const SquareMatrix inverseShape(inverseCholesky_.transpose() * inverseCholesky_);
-    for (UnsignedLong i = 0; i < dimension; ++i)
-      for (UnsignedLong j = 0; j <= i; ++j)
+    for (UnsignedInteger i = 0; i < dimension; ++i)
+      for (UnsignedInteger j = 0; j <= i; ++j)
         inverseR_(i, j) = sigma_[i] * inverseShape(i, j) * sigma_[j];
     normalizationFactor_ = 1.0;
-    for (UnsignedLong i = 0; i < dimension; ++i) normalizationFactor_ /= cholesky_(i, i);
+    for (UnsignedInteger i = 0; i < dimension; ++i) normalizationFactor_ /= cholesky_(i, i);
   }
   else  // dimension 1
   {
@@ -257,8 +369,8 @@ void EllipticalDistribution::update()
     {
       shape_ = CovarianceMatrix(1);
       inverseR_ = IdentityMatrix(1);
-      cholesky_ = SquareMatrix(1);
-      inverseCholesky_ = SquareMatrix(1);
+      cholesky_ = TriangularMatrix(1);
+      inverseCholesky_ = TriangularMatrix(1);
     }
     shape_(0, 0) = sigma_[0] * sigma_[0];
     cholesky_(0, 0) = sigma_[0];
@@ -308,7 +420,7 @@ void EllipticalDistribution::setSigma(const NumericalPoint & sigma)
         << "). Unable to construct elliptical distribution object.";
 
   // We check that the marginal standard deviations are > 0
-  for(UnsignedLong i = 0; i < sigma.getDimension(); ++i)
+  for(UnsignedInteger i = 0; i < sigma.getDimension(); ++i)
     if (sigma[i] <= 0.0) throw InvalidArgumentException(HERE) << "The marginal standard deviations must be > 0 sigma=" << sigma;
   sigma_ = sigma;
   update();
@@ -328,7 +440,7 @@ NumericalPoint EllipticalDistribution::getSigma() const
    distribution with nu < 2 */
 NumericalPoint EllipticalDistribution::getStandardDeviation() const
 {
-  return sqrt(covarianceScalingFactor_) * sigma_;
+  return std::sqrt(covarianceScalingFactor_) * sigma_;
 }
 
 /* Correlation matrix accessor */
@@ -360,13 +472,13 @@ SquareMatrix EllipticalDistribution::getInverseCorrelation() const
 }
 
 /* Cholesky factor of the correlation matrix accessor */
-SquareMatrix EllipticalDistribution::getCholesky() const
+TriangularMatrix EllipticalDistribution::getCholesky() const
 {
   return cholesky_;
 }
 
 /* Inverse of the Cholesky factor of the correlation matrix accessor */
-SquareMatrix EllipticalDistribution::getInverseCholesky() const
+TriangularMatrix EllipticalDistribution::getInverseCholesky() const
 {
   return inverseCholesky_;
 }
@@ -381,19 +493,19 @@ EllipticalDistribution * EllipticalDistribution::clone() const
 EllipticalDistribution::IsoProbabilisticTransformation EllipticalDistribution::getIsoProbabilisticTransformation() const
 {
   IsoProbabilisticTransformation transform;
-  transform.setEvaluationImplementation(new NatafEllipticalDistributionEvaluation(mean_, inverseCholesky_));
-  transform.setGradientImplementation(new NatafEllipticalDistributionGradient(inverseCholesky_));
-  transform.setHessianImplementation(new NatafEllipticalDistributionHessian(getDimension()));
+  transform.setEvaluation(new NatafEllipticalDistributionEvaluation(mean_, inverseCholesky_));
+  transform.setGradient(new NatafEllipticalDistributionGradient(inverseCholesky_));
+  transform.setHessian(new NatafEllipticalDistributionHessian(getDimension()));
   // Set the parameters values and descriptions
   // The result of parametersGradient is given
   // in the following form:
   // (d/dmu, d/dsigma)
   // There is no gradient according to the dependence parameters yet (28/10/2006)
-  const UnsignedLong dimension(getDimension());
+  const UnsignedInteger dimension(getDimension());
   NumericalPointWithDescription parameters(2 * dimension);
   Description description(parameters.getDimension());
   NumericalPointWithDescriptionCollection parametersCollection(getParametersCollection());
-  for (UnsignedLong i = 0; i < dimension; ++i)
+  for (UnsignedInteger i = 0; i < dimension; ++i)
   {
     const Description parametersDescription(parametersCollection[i].getDescription());
     const String marginalName(parametersCollection[i].getName());
@@ -411,19 +523,19 @@ EllipticalDistribution::IsoProbabilisticTransformation EllipticalDistribution::g
 EllipticalDistribution::InverseIsoProbabilisticTransformation EllipticalDistribution::getInverseIsoProbabilisticTransformation() const
 {
   InverseIsoProbabilisticTransformation inverseTransform;
-  inverseTransform.setEvaluationImplementation(new InverseNatafEllipticalDistributionEvaluation(mean_, cholesky_));
-  inverseTransform.setGradientImplementation(new InverseNatafEllipticalDistributionGradient(cholesky_));
-  inverseTransform.setHessianImplementation(new InverseNatafEllipticalDistributionHessian(getDimension()));
+  inverseTransform.setEvaluation(new InverseNatafEllipticalDistributionEvaluation(mean_, cholesky_));
+  inverseTransform.setGradient(new InverseNatafEllipticalDistributionGradient(cholesky_));
+  inverseTransform.setHessian(new InverseNatafEllipticalDistributionHessian(getDimension()));
   // Set the parameters values and descriptions
   // The result of parametersGradient is given
   // in the following form:
   // (d/dmu, d/dsigma)
   // There is no gradient according to the dependence parameters yet (28/10/2006)
-  const UnsignedLong dimension(getDimension());
+  const UnsignedInteger dimension(getDimension());
   NumericalPointWithDescription parameters(2 * dimension);
   Description description(parameters.getDimension());
   NumericalPointWithDescriptionCollection parametersCollection(getParametersCollection());
-  for (UnsignedLong i = 0; i < dimension; ++i)
+  for (UnsignedInteger i = 0; i < dimension; ++i)
   {
     const Description parametersDescription(parametersCollection[i].getDescription());
     const String marginalName(parametersCollection[i].getName());
@@ -442,7 +554,7 @@ EllipticalDistribution::InverseIsoProbabilisticTransformation EllipticalDistribu
 EllipticalDistribution::Implementation EllipticalDistribution::getStandardDistribution() const
 {
   EllipticalDistribution * p_standardDistribution(clone());
-  const UnsignedLong dimension(getDimension());
+  const UnsignedInteger dimension(getDimension());
   p_standardDistribution->setMean(NumericalPoint(dimension, 0.0));
   p_standardDistribution->setSigma(NumericalPoint(dimension, 1.0));
   p_standardDistribution->setCorrelation(CorrelationMatrix(dimension));
@@ -452,11 +564,11 @@ EllipticalDistribution::Implementation EllipticalDistribution::getStandardDistri
 /* Parameters value and description accessor */
 EllipticalDistribution::NumericalPointWithDescriptionCollection EllipticalDistribution::getParametersCollection() const
 {
-  const UnsignedLong dimension(getDimension());
+  const UnsignedInteger dimension(getDimension());
   NumericalPointWithDescriptionCollection parameters(dimension + (dimension > 1 ? 1 : 0));
   // First put the marginal parameters
   const Description description(getDescription());
-  for (UnsignedLong marginalIndex = 0; marginalIndex < dimension; ++marginalIndex)
+  for (UnsignedInteger marginalIndex = 0; marginalIndex < dimension; ++marginalIndex)
   {
     NumericalPointWithDescription point(2);
     Description marginalDescription(point.getDimension());
@@ -474,10 +586,10 @@ EllipticalDistribution::NumericalPointWithDescriptionCollection EllipticalDistri
     NumericalPointWithDescription point(dimension * (dimension - 1) / 2);
     Description dependenceDescription(point.getDimension());
     point.setName("dependence");
-    UnsignedLong dependenceIndex(0);
-    for (UnsignedLong i = 0; i < dimension; ++i)
+    UnsignedInteger dependenceIndex(0);
+    for (UnsignedInteger i = 0; i < dimension; ++i)
     {
-      for (UnsignedLong j = 0; j < i; ++j)
+      for (UnsignedInteger j = 0; j < i; ++j)
       {
         point[dependenceIndex] = R_(i, j);
         dependenceDescription[dependenceIndex] = OSS() << "R_" << i << "_" << j;
@@ -492,8 +604,8 @@ EllipticalDistribution::NumericalPointWithDescriptionCollection EllipticalDistri
 
 void EllipticalDistribution::setParametersCollection(const NumericalPointCollection & parametersCollection)
 {
-  const UnsignedLong size(parametersCollection.getSize());
-  const UnsignedLong dimension(size > 1 ? size - 1 : size);
+  const UnsignedInteger size(parametersCollection.getSize());
+  const UnsignedInteger dimension(size > 1 ? size - 1 : size);
   setDimension(dimension);
   mean_ = NumericalPoint(dimension);
   sigma_ = NumericalPoint(dimension);
@@ -506,16 +618,16 @@ void EllipticalDistribution::setParametersCollection(const NumericalPointCollect
   }
   else
   {
-    for (UnsignedLong i = 0; i < dimension; ++i)
+    for (UnsignedInteger i = 0; i < dimension; ++i)
     {
       mean_[i] = parametersCollection[i][0];
       sigma_[i] = parametersCollection[i][1];
       if (sigma_[i] <= 0.0) throw InvalidArgumentException(HERE) << "The marginal standard deviations must be > 0 sigma=" << sigma_;
     }
-    UnsignedLong parameterIndex(0);
-    for (UnsignedLong i = 0; i < dimension; ++i)
+    UnsignedInteger parameterIndex(0);
+    for (UnsignedInteger i = 0; i < dimension; ++i)
     {
-      for (UnsignedLong j = 0; j < i; ++j)
+      for (UnsignedInteger j = 0; j < i; ++j)
       {
         R_(i, j) = parametersCollection[size - 1][parameterIndex];
         ++parameterIndex;
@@ -530,7 +642,7 @@ void EllipticalDistribution::setParametersCollection(const NumericalPointCollect
 
 void EllipticalDistribution::setParametersCollection(const NumericalPoint & flattenCollection)
 {
-  const UnsignedLong dimension(getDimension());
+  const UnsignedInteger dimension(getDimension());
   if (dimension == 1)
   {
     if (flattenCollection.getDimension() != 2) throw InvalidArgumentException(HERE) << "Error: the given parameters point has an invalid dimension (" << flattenCollection.getDimension() << "), it should be 2";
