@@ -3,7 +3,7 @@
  *  @file  Event.cxx
  *  @brief The class that implements all random vectors
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -42,18 +42,16 @@ Event::Event()
 /* Constructor from RandomVector */
 Event::Event(const RandomVector & antecedent,
              const ComparisonOperator & op,
-             const NumericalScalar threshold,
-             const String & name)
-  : RandomVector(antecedent, op, threshold, name)
+             const NumericalScalar threshold)
+  : RandomVector(antecedent, op, threshold)
 {
   // Nothing to do
 }
 
 /* Constructor from RandomVector */
 Event::Event(const RandomVector & antecedent,
-             const Domain & domain,
-             const String & name)
-  : RandomVector(antecedent, domain, name)
+             const Domain & domain)
+  : RandomVector(antecedent, domain)
 {
   // Nothing to do
 }
@@ -61,9 +59,8 @@ Event::Event(const RandomVector & antecedent,
 
 /* Constructor from RandomVector */
 Event::Event(const Process & process,
-             const Domain & domain,
-             const String & name)
-  : RandomVector(process, domain, name)
+             const Domain & domain)
+  : RandomVector(process, domain)
 {
   // Nothing to do
 }
