@@ -3,7 +3,7 @@
  *  @file  Process.cxx
  *  @brief The class that implements all random vectors
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -38,27 +38,24 @@ Process::Process()
 }
 
 /* Parameters constructor */
-Process::Process(const ProcessImplementation & implementation,
-                 const String & name)
+Process::Process(const ProcessImplementation & implementation)
   : TypedInterfaceObject<ProcessImplementation>(implementation.clone())
 {
-  getImplementation()->setName(name);
+  // Nothing to do
 }
 
 /* Constructor from implementation */
-Process::Process(const Implementation & p_implementation,
-                 const String & name)
+Process::Process(const Implementation & p_implementation)
   : TypedInterfaceObject<ProcessImplementation>(p_implementation)
 {
-  getImplementation()->setName(name);
+  // Nothing to do
 }
 
 /* Constructor from implementation pointer */
-Process::Process(ProcessImplementation * p_implementation,
-                 const String & name)
+Process::Process(ProcessImplementation * p_implementation)
   : TypedInterfaceObject<ProcessImplementation>(p_implementation)
 {
-  getImplementation()->setName(name);
+  // Nothing to do
 }
 
 /* String converter */
@@ -111,12 +108,12 @@ Bool Process::isComposite() const
 /* Here is the interface that all derived class may implement */
 
 /* Dimension accessor */
-UnsignedLong Process::getMeshDimension() const
+UnsignedInteger Process::getSpatialDimension() const
 {
-  return getImplementation()->getMeshDimension();
+  return getImplementation()->getSpatialDimension();
 }
 
-UnsignedLong Process::getDimension() const
+UnsignedInteger Process::getDimension() const
 {
   return getImplementation()->getDimension();
 }
@@ -159,31 +156,31 @@ void Process::setMesh(const Mesh & mesh)
   return getImplementation()->setMesh(mesh);
 }
 
-ProcessSample Process::getSample(const UnsignedLong size) const
+ProcessSample Process::getSample(const UnsignedInteger size) const
 {
   return getImplementation()->getSample(size);
 }
 
-TimeSeries Process::getFuture(const UnsignedLong stepNumber) const
+TimeSeries Process::getFuture(const UnsignedInteger stepNumber) const
 {
   return getImplementation()->getFuture(stepNumber);
 }
 
-ProcessSample Process::getFuture(const UnsignedLong stepNumber,
-                                 const UnsignedLong size) const
+ProcessSample Process::getFuture(const UnsignedInteger stepNumber,
+                                 const UnsignedInteger size) const
 {
   return getImplementation()->getFuture(stepNumber, size);
 }
 
 /* Get the process corresponding to the i-th marginal component */
-Process Process::getMarginalProcess(const UnsignedLong i) const
+Process Process::getMarginal(const UnsignedInteger i) const
 {
-  return *(getImplementation()->getMarginalProcess(i));
+  return *(getImplementation()->getMarginal(i));
 }
 
 /* Get the marginal random vector corresponding to indices components */
-Process Process::getMarginalProcess(const Indices & indices) const
+Process Process::getMarginal(const Indices & indices) const
 {
-  return *(getImplementation()->getMarginalProcess(indices));
+  return *(getImplementation()->getMarginal(indices));
 }
 END_NAMESPACE_OPENTURNS
