@@ -3,7 +3,7 @@
  *  @file  RandomVectorImplementation.cxx
  *  @brief An interface for all implementation class of random vectors
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -27,17 +27,14 @@
 
 BEGIN_NAMESPACE_OPENTURNS
 
-
-
 CLASSNAMEINIT(RandomVectorImplementation);
 
 static Factory<RandomVectorImplementation> RegisteredFactory("RandomVectorImplementation");
 
-
 /* Default constructor */
-RandomVectorImplementation::RandomVectorImplementation(const String & name)
-  : PersistentObject(name),
-    description_()
+RandomVectorImplementation::RandomVectorImplementation()
+  : PersistentObject()
+  , description_()
 {
   // Nothing to do
 }
@@ -61,6 +58,9 @@ String RandomVectorImplementation::__repr__() const
 /* Description accessor */
 void RandomVectorImplementation::setDescription(const Description & description)
 {
+  if (description.getSize() != getDimension())
+    throw InvalidDimensionException(HERE) << "Description's size must be equal to dimension."
+                                          << " Here, description's size=" << description.getSize() << " and dimension=" << getDimension();
   description_ = description;
 }
 
@@ -80,89 +80,90 @@ Bool RandomVectorImplementation::isComposite() const
 }
 
 /* Dimension accessor */
-UnsignedLong RandomVectorImplementation::getDimension() const
+UnsignedInteger RandomVectorImplementation::getDimension() const
 {
-  throw NotYetImplementedException(HERE);
+  throw NotYetImplementedException(HERE) << "In RandomVectorImplementation::getDimension() const";
 }
 
 /* Realization accessor */
 NumericalPoint RandomVectorImplementation::getRealization() const
 {
-  throw NotYetImplementedException(HERE);
+  throw NotYetImplementedException(HERE) << "In RandomVectorImplementation::getRealization() const";
 }
 
 /* Numerical sample accessor */
-NumericalSample RandomVectorImplementation::getSample(const UnsignedLong size) const
+NumericalSample RandomVectorImplementation::getSample(const UnsignedInteger size) const
 {
   NumericalSample result(size, getDimension());
-  for (UnsignedLong i = 0; i < size; ++i) result[i] = getRealization();
+  for (UnsignedInteger i = 0; i < size; ++i) result[i] = getRealization();
+  result.setDescription(getDescription());
   return result;
 }
 
 /* Mean accessor */
 NumericalPoint RandomVectorImplementation::getMean() const
 {
-  throw NotYetImplementedException(HERE);
+  throw NotYetImplementedException(HERE) << "In RandomVectorImplementation::getMean() const";
 }
 
 /* Covariance accessor */
 CovarianceMatrix RandomVectorImplementation::getCovariance() const
 {
-  throw NotYetImplementedException(HERE);
+  throw NotYetImplementedException(HERE) << "In RandomVectorImplementation::getCovariance() const";
 }
 
 /* Get the random vector corresponding to the i-th marginal component */
-RandomVectorImplementation::Implementation RandomVectorImplementation::getMarginal(const UnsignedLong i) const
+RandomVectorImplementation::Implementation RandomVectorImplementation::getMarginal(const UnsignedInteger i) const
 {
-  throw NotYetImplementedException(HERE);
+  throw NotYetImplementedException(HERE) << "In RandomVectorImplementation::getMarginal(const UnsignedInteger i) const";
 }
 
 /* Get the marginal random vector corresponding to indices components */
 RandomVectorImplementation::Implementation RandomVectorImplementation::getMarginal(const Indices & indices) const
 {
-  throw NotYetImplementedException(HERE);
+  throw NotYetImplementedException(HERE) << "In RandomVectorImplementation::getMarginal(const Indices & indices) const";
 }
 
 /* Fake method due to pbs with dynamic_cast and Pointer */
 RandomVectorImplementation::Antecedent RandomVectorImplementation::getAntecedent() const
 {
-  throw NotYetImplementedException(HERE);
+  throw NotYetImplementedException(HERE) << "In RandomVectorImplementation::getAntecedent() const";
 }
 
 /* Fake method due to pbs with dynamic_cast and Pointer */
 NumericalMathFunction RandomVectorImplementation::getFunction() const
 {
-  throw NotYetImplementedException(HERE);
+  throw NotYetImplementedException(HERE) << "In RandomVectorImplementation::getFunction() const";
 }
 
 /* Fake method due to pbs with dynamic_cast and Pointer */
 Distribution RandomVectorImplementation::getDistribution() const
 {
-  throw NotYetImplementedException(HERE);
+  throw NotYetImplementedException(HERE) << "In RandomVectorImplementation::getDistribution() const";
 }
 
 /* Fake method due to pbs with dynamic_cast and Pointer */
 ComparisonOperator RandomVectorImplementation::getOperator() const
 {
-  throw NotYetImplementedException(HERE);
+  throw NotYetImplementedException(HERE) << "In RandomVectorImplementation::getOperator() const";
 }
 
 /* Fake method due to pbs with dynamic_cast and Pointer */
 Process RandomVectorImplementation::getProcess() const
 {
-  throw NotYetImplementedException(HERE);
+  throw NotYetImplementedException(HERE) << "In RandomVectorImplementation::getProcess() const";
 }
 
 /* Fake method due to pbs with dynamic_cast and Pointer */
 Domain RandomVectorImplementation::getDomain() const
 {
-  throw NotYetImplementedException(HERE);
+  throw NotYetImplementedException(HERE) << "In RandomVectorImplementation::getDomain() const";
 }
 
 /* Fake method due to pbs with dynamic_cast and Pointer */
 NumericalScalar RandomVectorImplementation::getThreshold() const
 {
-  throw NotYetImplementedException(HERE);
+  throw NotYetImplementedException(HERE) << "In RandomVectorImplementation::getThreshold() const";
 }
 
 /* Method save() stores the object through the StorageManager */
