@@ -3,7 +3,7 @@
  *  @file  StandardEvent.cxx
  *  @brief The class that implements an event based on a composite random vector whose
  *  antecedent has a spherical distribution
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -48,24 +48,22 @@ StandardEvent::StandardEvent()
 /* Constructor from a RandomVector */
 StandardEvent::StandardEvent(const RandomVector & antecedent,
                              const ComparisonOperator & op,
-                             const NumericalScalar threshold,
-                             const String & name)
-  : Event(antecedent, op, threshold, name)
+                             const NumericalScalar threshold)
+  : Event(antecedent, op, threshold)
 {
   // StandardEvent can only be constructed from composite random vector whose antecedent has a spherical distribution. As we cannot check it, we just check that the distribution is elliptical
   if (!antecedent.getImplementation()->getAntecedent()->getDistribution().isElliptical()) throw InvalidArgumentException(HERE) << "Error: StandardEvent can only be constructed from composite random vectors whose antecedent is standard spherical, here the distribution is " << antecedent.getImplementation()->getAntecedent()->getDistribution().getImplementation()->__str__();
   CovarianceMatrix covariance(antecedent.getImplementation()->getAntecedent()->getDistribution().getCovariance());
-  const UnsignedLong dimension(antecedent.getImplementation()->getAntecedent()->getDistribution().getDimension());
-  for (UnsignedLong i = 0; i < dimension; ++i)
+  const UnsignedInteger dimension(antecedent.getImplementation()->getAntecedent()->getDistribution().getDimension());
+  for (UnsignedInteger i = 0; i < dimension; ++i)
   {
     if (covariance(i, i) != 1.0) throw InvalidArgumentException(HERE) << "Error: StandardEvent can only be constructed from composite random vectors whose antecedent is standard spherical, here the distribution is " << antecedent.getImplementation()->getAntecedent()->getDistribution().getImplementation()->__str__();
-    for (UnsignedLong j = 0; j < i; ++j) if (covariance(i, j) != 0.0) throw InvalidArgumentException(HERE) << "Error: StandardEvent can only be constructed from composite random vectors whose antecedent is standard spherical, here the distribution is " << antecedent.getImplementation()->getAntecedent()->getDistribution().getImplementation()->__str__();
+    for (UnsignedInteger j = 0; j < i; ++j) if (covariance(i, j) != 0.0) throw InvalidArgumentException(HERE) << "Error: StandardEvent can only be constructed from composite random vectors whose antecedent is standard spherical, here the distribution is " << antecedent.getImplementation()->getAntecedent()->getDistribution().getImplementation()->__str__();
   }
 }
 
 /* Constructor from an Event */
-StandardEvent::StandardEvent(const Event & event,
-                             const String & name)
+StandardEvent::StandardEvent(const Event & event)
   : Event(event)
 {
   // Get the isoprobabilistic inverse transformation from the antecedent distribution
@@ -80,7 +78,8 @@ StandardEvent::StandardEvent(const Event & event,
   const NumericalMathFunction composed(function, inverse);
   const RandomVector vect(composed, antecedent);
   // Set the random vector implementation
-  (*this) = StandardEvent(vect, event.getOperator(), event.getThreshold(), event.getName());
+  (*this) = StandardEvent(vect, event.getOperator(), event.getThreshold());
+  setName(event.getName());
 }
 
 END_NAMESPACE_OPENTURNS
