@@ -3,7 +3,7 @@
  *  @file  UsualRandomVector.cxx
  *  @brief An implementation class for distribution-based random vectors
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -31,9 +31,8 @@ CLASSNAMEINIT(UsualRandomVector);
 static Factory<UsualRandomVector> RegisteredFactory("UsualRandomVector");
 
 /* Default constructor */
-UsualRandomVector::UsualRandomVector(const Distribution & distribution,
-                                     const String & name)
-  : RandomVectorImplementation(name)
+UsualRandomVector::UsualRandomVector(const Distribution & distribution)
+  : RandomVectorImplementation()
   , distribution_(distribution)
 {
   // Get the description from the underlying distribution
@@ -59,7 +58,7 @@ String UsualRandomVector::__repr__() const
 
 
 /* Dimension accessor */
-UnsignedLong UsualRandomVector::getDimension() const
+UnsignedInteger UsualRandomVector::getDimension() const
 {
   return distribution_.getDimension();
 }
@@ -71,9 +70,11 @@ NumericalPoint UsualRandomVector::getRealization() const
 }
 
 /* Numerical sample accessor */
-NumericalSample UsualRandomVector::getSample(const UnsignedLong size) const
+NumericalSample UsualRandomVector::getSample(const UnsignedInteger size) const
 {
-  return distribution_.getSample(size);
+  NumericalSample sample(distribution_.getSample(size));
+  sample.setDescription(getDescription());
+  return sample;
 }
 
 /* Mean accessor */
@@ -89,7 +90,7 @@ CovarianceMatrix UsualRandomVector::getCovariance() const
 }
 
 /* Get the random vector corresponding to the i-th marginal component */
-UsualRandomVector::Implementation UsualRandomVector::getMarginal(const UnsignedLong i) const
+UsualRandomVector::Implementation UsualRandomVector::getMarginal(const UnsignedInteger i) const
 {
   if (i >= getDimension()) throw InvalidArgumentException(HERE) << "The index of a marginal random vector must be in the range [0, dim-1]";
   return new UsualRandomVector(distribution_.getMarginal(i));
