@@ -3,7 +3,7 @@
  *  @file  FunctionalBasisProcess.cxx
  *  @brief A class which implements the FunctionalBasisProcess process
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -37,21 +37,21 @@ CLASSNAMEINIT(FunctionalBasisProcess);
 static Factory<FunctionalBasisProcess> RegisteredFactory("FunctionalBasisProcess");
 
 /* Standard constructor */
-FunctionalBasisProcess::FunctionalBasisProcess(const String & name)
-  : ProcessImplementation(name)
+FunctionalBasisProcess::FunctionalBasisProcess()
+  : ProcessImplementation()
   , distribution_(Normal())
   , basis_(Collection<NumericalMathFunction>(1, NumericalMathFunction("t", "t")))
   , state_(1, 0.0)
 {
   // Set the dimension of the process
   setDimension(1);
+  setDescription(basis_[0].getOutputDescription());
 }
 
 /* Standard constructor */
 FunctionalBasisProcess::FunctionalBasisProcess(const Distribution & distribution,
-    const Basis & basis,
-    const String & name)
-  : ProcessImplementation(name)
+    const Basis & basis)
+  : ProcessImplementation()
   , distribution_(distribution)
   , basis_()
   , state_(distribution.getDimension(), 0.0)
@@ -64,9 +64,8 @@ FunctionalBasisProcess::FunctionalBasisProcess(const Distribution & distribution
 /* Standard constructor */
 FunctionalBasisProcess::FunctionalBasisProcess(const Distribution & distribution,
     const Basis & basis,
-    const Mesh & mesh,
-    const String & name)
-  : ProcessImplementation(name)
+    const Mesh & mesh)
+  : ProcessImplementation()
   , distribution_(distribution)
   , basis_()
   , state_(distribution.getDimension(), 0.0)
@@ -108,17 +107,18 @@ Bool FunctionalBasisProcess::isNormal() const
 Field FunctionalBasisProcess::getRealization() const
 {
   state_ = distribution_.getRealization();
-  const UnsignedLong timeGridSize(mesh_.getVerticesNumber());
-  const UnsignedLong basisSize(basis_.getSize());
+  const UnsignedInteger timeGridSize(mesh_.getVerticesNumber());
+  const UnsignedInteger basisSize(basis_.getSize());
   // Loop over the time stamps
   NumericalSample result(timeGridSize, NumericalPoint(dimension_, 0.0));
   // Loop over the basis
-  for (UnsignedLong j = 0; j < basisSize; ++j)
+  for (UnsignedInteger j = 0; j < basisSize; ++j)
   {
     NumericalSample currentBasisContribution(basis_[j](mesh_.getVertices()));
     currentBasisContribution *= NumericalPoint(dimension_, state_[j]);
     result += currentBasisContribution;
   }
+  result.setDescription(getDescription());
   return Field(mesh_, result);
 }
 
@@ -131,7 +131,7 @@ NumericalMathFunction FunctionalBasisProcess::getContinuousRealization() const
 }
 
 /* Compute the next steps of the process */
-TimeSeries FunctionalBasisProcess::getFuture(const UnsignedLong stepNumber) const
+TimeSeries FunctionalBasisProcess::getFuture(const UnsignedInteger stepNumber) const
 {
   /* TimeGrid of the process */
   RegularGrid timeGrid;
@@ -141,41 +141,41 @@ TimeSeries FunctionalBasisProcess::getFuture(const UnsignedLong stepNumber) cons
   }
   catch (...)
   {
-    throw InternalException(HERE) << "Error: can extend the realization of a process only if defined on a regular gris.";
+    throw InternalException(HERE) << "Error: can extend the realization of a process only if defined on a regular grid.";
   }
   if (stepNumber == 0) throw InvalidArgumentException(HERE) << "Error: the number of future steps must be positive.";
   /* TimeGrid associated with the possible future */
   const NumericalScalar timeStep(timeGrid.getStep());
   const RegularGrid futureTimeGrid(timeGrid.getEnd(), timeStep, stepNumber);
-  const UnsignedLong basisSize(basis_.getSize());
+  const UnsignedInteger basisSize(basis_.getSize());
   // Loop over the time stamps
   NumericalSample result(stepNumber, NumericalPoint(dimension_, 0.0));
-  for (UnsignedLong i = 0; i  < stepNumber; ++i)
+  for (UnsignedInteger i = 0; i  < stepNumber; ++i)
   {
     const NumericalPoint t(1, futureTimeGrid.getValue(i));
     // Loop over the basis using the previous state
-    for (UnsignedLong j = 0; j < basisSize; ++j) result[i] += basis_[j](t) * state_[j];
+    for (UnsignedInteger j = 0; j < basisSize; ++j) result[i] += basis_[j](t) * state_[j];
   }
   return TimeSeries(futureTimeGrid, result);
 }
 
 /* Get the marginal process corresponding to the i-th marginal component */
-FunctionalBasisProcess::Implementation FunctionalBasisProcess::getMarginalProcess(const UnsignedLong i) const
+FunctionalBasisProcess::Implementation FunctionalBasisProcess::getMarginal(const UnsignedInteger i) const
 {
   if (i >= getDimension()) throw InvalidArgumentException(HERE) << "The index of a marginal process must be in the range [0, dim-1]";
-  return getMarginalProcess(Indices(1, i));
+  return getMarginal(Indices(1, i));
 }
 
 /* Get the marginal random vector corresponding to indices components */
-FunctionalBasisProcess::Implementation FunctionalBasisProcess::getMarginalProcess(const Indices & indices) const
+FunctionalBasisProcess::Implementation FunctionalBasisProcess::getMarginal(const Indices & indices) const
 {
   if (!indices.check(getDimension() - 1)) throw InvalidArgumentException(HERE) << "The indices of a marginal process must be in the range [0, dim-1] and  must be different";
   // First the marginal distribution
   Distribution marginalDistribution(distribution_.getMarginal(indices));
   // Second the marginal basis
-  const UnsignedLong basisSize(basis_.getSize());
+  const UnsignedInteger basisSize(basis_.getSize());
   Basis marginalBasis(basisSize);
-  for (UnsignedLong i = 0; i < basisSize; ++i) marginalBasis[i] = basis_[i].getMarginal(indices);
+  for (UnsignedInteger i = 0; i < basisSize; ++i) marginalBasis[i] = basis_[i].getMarginal(indices);
   // Return the associated FunctionalBasisProcess
   return FunctionalBasisProcess(marginalDistribution, marginalBasis, mesh_).clone();
 }
@@ -203,7 +203,7 @@ Basis FunctionalBasisProcess::getBasis() const
 /* Basis accessor */
 void FunctionalBasisProcess::setBasis(const Basis & basis)
 {
-  const UnsignedLong size(basis.getSize());
+  const UnsignedInteger size(basis.getSize());
   // Check if the basis is not empty
   if (size == 0) throw InvalidArgumentException(HERE) << "Error: the given basis is empty.";
   // Check the basis against the distribution
@@ -211,7 +211,7 @@ void FunctionalBasisProcess::setBasis(const Basis & basis)
   // Check if the functions in the basis are from R to R^n for the same n
   dimension_ = basis[0].getOutputDimension();
   const UnsignedInteger inputDimension(mesh_.getDimension());
-  for (UnsignedLong i = 0; i < size; ++i)
+  for (UnsignedInteger i = 0; i < size; ++i)
   {
     // Check the input dimension
     if (basis[i].getInputDimension() != inputDimension) throw InvalidArgumentException(HERE) << "Error: the function at index=" << i << " has an input dimension=" << basis[i].getInputDimension() << " which is not equal to " << inputDimension << ".";
@@ -219,6 +219,7 @@ void FunctionalBasisProcess::setBasis(const Basis & basis)
     if (basis[i].getOutputDimension() != dimension_) throw InvalidArgumentException(HERE) << "Error: the function at index=" << i << " has an output dimension=" << basis[i].getOutputDimension() << " which is not equal to the process dimension=" << dimension_;
   }
   basis_ = basis;
+  setDescription(basis[0].getOutputDescription());
 }
 
 /* Method save() stores the object through the StorageManager */
