@@ -3,7 +3,7 @@
  *  @file  WhiteNoise.cxx
  *  @brief A class which implements the WhiteNoise process
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -35,18 +35,17 @@ CLASSNAMEINIT(WhiteNoise);
 static Factory<WhiteNoise> RegisteredFactory("WhiteNoise");
 
 /* Standard constructor */
-WhiteNoise::WhiteNoise(const String & name)
-  : ProcessImplementation(name)
-  , distribution_(Normal())
+WhiteNoise::WhiteNoise()
+  : ProcessImplementation()
+  , distribution_()
 {
-  // Nothing to do
+  setDistribution(Normal());
 }
 
 /* Standard constructor */
-WhiteNoise::WhiteNoise(const Distribution & distribution,
-                       const String & name)
+WhiteNoise::WhiteNoise(const Distribution & distribution)
 /* throw (InvalidArgumentException) */
-  : ProcessImplementation(name)
+  : ProcessImplementation()
   , distribution_()
 {
   // Check if the given distribution has a null mean
@@ -55,9 +54,8 @@ WhiteNoise::WhiteNoise(const Distribution & distribution,
 
 /* Standard constructor */
 WhiteNoise::WhiteNoise(const Distribution & distribution,
-                       const Mesh & mesh,
-                       const String & name)
-  : ProcessImplementation(name)
+                       const Mesh & mesh)
+  : ProcessImplementation()
   , distribution_()
 {
   // Set the dimension of the process
@@ -103,7 +101,9 @@ Bool WhiteNoise::isNormal() const
 /* Realization accessor */
 Field WhiteNoise::getRealization() const
 {
-  return Field(mesh_, distribution_.getSample(mesh_.getVerticesNumber()));
+  NumericalSample values(distribution_.getSample(mesh_.getVerticesNumber()));
+  values.setDescription(getDescription());
+  return Field(mesh_, values);
 }
 
 /* Continuous realization accessor */
@@ -113,7 +113,7 @@ NumericalMathFunction WhiteNoise::getContinuousRealization() const
 }
 
 /* Compute the next steps of a random walk */
-TimeSeries WhiteNoise::getFuture(const UnsignedLong stepNumber) const
+TimeSeries WhiteNoise::getFuture(const UnsignedInteger stepNumber) const
 {
   /* TimeGrid of the process */
   RegularGrid timeGrid;
@@ -123,7 +123,7 @@ TimeSeries WhiteNoise::getFuture(const UnsignedLong stepNumber) const
   }
   catch (...)
   {
-    throw InternalException(HERE) << "Error: can extend the realization of a process only if defined on a regular gris.";
+    throw InternalException(HERE) << "Error: can extend the realization of a process only if defined on a regular grid.";
   }
   if (stepNumber == 0) throw InvalidArgumentException(HERE) << "Error: the number of future steps must be positive.";
   /* TimeGrid associated with the possible future */
@@ -133,14 +133,14 @@ TimeSeries WhiteNoise::getFuture(const UnsignedLong stepNumber) const
 }
 
 /* Get the marginal process corresponding to the i-th marginal component */
-WhiteNoise::Implementation WhiteNoise::getMarginalProcess(const UnsignedLong i) const
+WhiteNoise::Implementation WhiteNoise::getMarginal(const UnsignedInteger i) const
 {
   if (i >= getDimension()) throw InvalidArgumentException(HERE) << "The index of a marginal process must be in the range [0, dim-1]";
   return WhiteNoise(distribution_.getMarginal(i), mesh_).clone();
 }
 
 /* Get the marginal random vector corresponding to indices components */
-WhiteNoise::Implementation WhiteNoise::getMarginalProcess(const Indices & indices) const
+WhiteNoise::Implementation WhiteNoise::getMarginal(const Indices & indices) const
 {
   if (!indices.check(getDimension() - 1)) throw InvalidArgumentException(HERE) << "The indices of a marginal process must be in the range [0, dim-1] and  must be different";
   return new WhiteNoise(distribution_.getMarginal(indices), mesh_);
@@ -160,6 +160,7 @@ void WhiteNoise::setDistribution(const Distribution & distribution)
   if (mean.norm() > ResourceMap::GetAsNumericalScalar( "WhiteNoise-MeanEpsilon" )) throw InvalidArgumentException(HERE) << "Error: the given distribution has a mean=" << mean.__str__() << " which is not null.";
   distribution_ = distribution;
   setDimension(distribution.getDimension());
+  setDescription(distribution.getDescription());
 }
 
 /* Method save() stores the object through the StorageManager */
