@@ -4,7 +4,7 @@
  *  @brief StatTest implements statistical tests
  *  This statistical test enables user to check if a time series is stationary
  *
- *  (C) Copyright 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -41,8 +41,8 @@ static Factory<DickeyFullerTest> RegisteredFactory("DickeyFullerTest");
 
 
 /* Default constructor */
-DickeyFullerTest::DickeyFullerTest(const String & name)
-  : PersistentObject(name)
+DickeyFullerTest::DickeyFullerTest()
+  : PersistentObject()
   , timeSeries_()
   , T_()
   , verbose_(false)
@@ -70,9 +70,8 @@ DickeyFullerTest::DickeyFullerTest(const String & name)
 
 /* Standard constructor */
 DickeyFullerTest::DickeyFullerTest(const TimeSeries & series,
-                                   const Bool verbose,
-                                   const String & name)
-  : PersistentObject(name)
+                                   const Bool verbose)
+  : PersistentObject()
   , timeSeries_()
   , T_()
   , verbose_(verbose)
@@ -98,7 +97,7 @@ DickeyFullerTest::DickeyFullerTest(const TimeSeries & series,
     throw InvalidDimensionException(HERE) << "Expected time series of dimension 1";
 
   // Build the estimation of parameters rho and \phi_i
-  const UnsignedLong size(series.getSize());
+  const UnsignedInteger size(series.getSize());
   if (size <= 1)
     throw InvalidArgumentException(HERE) << "The size of time series is " << size
                                          << "Impossible to run the test" ;
@@ -120,7 +119,7 @@ void DickeyFullerTest::computeNoConstantCharacteristics_()
   {
     // Computation of \sum_{t=1}^{N} y_{t} y{t-1} and
     // Computation of \sum_{t=1}^{N} y_{t-1} * y{t-1}
-    for (UnsignedLong t = 0; t < T_; ++t)
+    for (UnsignedInteger t = 0; t < T_; ++t)
     {
       const NumericalScalar y_t_minus_one(timeSeries_.getValueAtIndex(t)[0]);
       const NumericalScalar y_t(timeSeries_.getValueAtIndex(t + 1)[0]);
@@ -140,7 +139,7 @@ void DickeyFullerTest::computeDriftCharacteristics_()
   if (!isComputedDriftCharacteristics_)
   {
     NumericalScalar partialSum(0.0);
-    for (UnsignedLong t = 1; t < T_; ++t) partialSum += timeSeries_.getValueAtIndex(t)[0];
+    for (UnsignedInteger t = 1; t < T_; ++t) partialSum += timeSeries_.getValueAtIndex(t)[0];
     sum_yt_minus_one_ = partialSum + timeSeries_.getValueAtIndex(0)[0];
     sum_yt_ = partialSum + timeSeries_.getValueAtIndex(T_)[0];
     isComputedDriftCharacteristics_ = true;
@@ -162,7 +161,7 @@ void DickeyFullerTest::computeTrendCharacteristics_()
   {
     // Computation of \sum_{t=1}^{N} t * y{t-1}
     // and \sum_{t=1}^{N} t * y{t}
-    for (UnsignedLong t = 0; t < T_; ++t)
+    for (UnsignedInteger t = 0; t < T_; ++t)
     {
       const NumericalScalar y_t_minus_one(timeSeries_.getValueAtIndex(t)[0]);
       const NumericalScalar time(timeGrid.getValue(t + 1));
@@ -223,7 +222,7 @@ void DickeyFullerTest::estimateDriftAndLinearTrendModel()
     // Estimate the sum square of residual value
     NumericalScalar error = 0.0;
     const RegularGrid timeGrid_(timeSeries_.getTimeGrid());
-    for (UnsignedLong t = 0; t < T_; ++t)
+    for (UnsignedInteger t = 0; t < T_; ++t)
     {
       const NumericalScalar X(timeSeries_.getValueAtIndex(t)[0]);
       const NumericalScalar Y(timeSeries_.getValueAtIndex(t + 1)[0]);
@@ -276,7 +275,7 @@ void DickeyFullerTest::estimateDriftModel()
     // Estimate the sum square of residual value
     NumericalScalar error = 0.0;
     const RegularGrid timeGrid_(timeSeries_.getTimeGrid());
-    for (UnsignedLong t = 0; t < T_; ++t)
+    for (UnsignedInteger t = 0; t < T_; ++t)
     {
       const NumericalScalar X(timeSeries_.getValueAtIndex(t)[0]);
       const NumericalScalar Y(timeSeries_.getValueAtIndex(t + 1)[0]);
@@ -311,7 +310,7 @@ void DickeyFullerTest::estimateAR1Model()
 
     // Expected error residual
     NumericalScalar error(0.0);
-    for (UnsignedLong t = 0; t < T_; ++t)
+    for (UnsignedInteger t = 0; t < T_; ++t)
     {
       const NumericalScalar X(timeSeries_.getValueAtIndex(t)[0]);
       const NumericalScalar Y(timeSeries_.getValueAtIndex(t + 1)[0]);
@@ -507,7 +506,7 @@ TestResult DickeyFullerTest::testUnitRootAndNoLinearTrendInDriftAndLinearTrendMo
   NumericalScalar SCR3(0.0);
 
   const RegularGrid timeGrid_(timeSeries_.getTimeGrid());
-  for (UnsignedLong t = 0; t < T_; ++t)
+  for (UnsignedInteger t = 0; t < T_; ++t)
   {
     const NumericalScalar deltaX(timeSeries_[t + 1][1] - timeSeries_[t][1]);
     const NumericalScalar epsilon_t(deltaX - c);
@@ -551,7 +550,7 @@ TestResult DickeyFullerTest::testNoUnitRootAndNoLinearTrendInDriftAndLinearTrend
   // Care: check that the variance is the non biased estimator
   // Student quantile ==> T(n - p - 1) with n: size of sample and p: number of variables
   // p here is 3 (rho, drift and trend)
-  const NumericalScalar studentStatisticNullTrend(std::abs(trend_) / sigmaTrend_);
+  const NumericalScalar studentStatisticNullTrend(fabs(trend_) / sigmaTrend_);
   // Here, T_ = n - 1
   const NumericalScalar complementaryCDFNullTrend(DistFunc::pStudent(T_ - 3, studentStatisticNullTrend, true));
   // True pValue = 1 - F(s) with s the student statistic and F the Student cumulative function
@@ -586,7 +585,7 @@ TestResult DickeyFullerTest::testUnitRootAndNoDriftInDriftModel(const NumericalS
   NumericalScalar SCR2c(0.0);
   NumericalScalar SCR2(0.0);
 
-  for (UnsignedLong t = 0; t < T_; ++t)
+  for (UnsignedInteger t = 0; t < T_; ++t)
   {
     const NumericalScalar epsilon_t(timeSeries_[t + 1][1] - timeSeries_[t][1]);
     SCR2c += epsilon_t * epsilon_t;
@@ -626,7 +625,7 @@ TestResult DickeyFullerTest::testNoUnitRootAndNoDriftInDriftModel(const Numerica
   }
 
   // Perform the statistical test
-  const NumericalScalar studentStatisticNullDrift(std::abs(drift_) / sigmaDrift_);
+  const NumericalScalar studentStatisticNullDrift(fabs(drift_) / sigmaDrift_);
   // Student quantile ==> T(n - p - 1) with n: size of sample and p: number of variables
   const NumericalScalar complementaryCDFNullDrift(DistFunc::pStudent(T_ - 2, studentStatisticNullDrift));
 
