@@ -3,7 +3,7 @@
  *  @file  FittingTest.cxx
  *  @brief StatTest implements statistical tests
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -37,7 +37,6 @@
 
 BEGIN_NAMESPACE_OPENTURNS
 
-TestResult FittingTest::lastResult_ = TestResult();
 
 /* Default constructor */
 FittingTest::FittingTest()
@@ -49,23 +48,28 @@ FittingTest::FittingTest()
 Distribution FittingTest::BestModelBIC(const NumericalSample & sample,
                                        const DistributionFactoryCollection & factoryCollection)
 {
-  const UnsignedLong size(factoryCollection.getSize());
+  const UnsignedInteger size(factoryCollection.getSize());
   if (size == 0) throw InternalException(HERE) << "Error: no model given";
+  Bool builtAtLeastOne = false;
   Distribution bestDistribution;
   NumericalScalar bestConcordanceMeasure(SpecFunc::MaxNumericalScalar);
-  for (UnsignedLong i = 0; i < size; ++i)
+  Bool continuousCase(true);
+  for (UnsignedInteger i = 0; i < size; ++i)
   {
     const DistributionFactory factory(factoryCollection[i]);
     try
     {
       LOGINFO(OSS(false) << "Trying factory " << factory);
       const Distribution distribution(factory.build(sample));
+      if (i == 0) continuousCase = distribution.isContinuous();
+      else if (distribution.isContinuous() != continuousCase) throw InvalidArgumentException(HERE) << "Error: cannot merge continuous and non-continuous models for BIC selection.";
       const NumericalScalar concordanceMeasure(BIC(sample, distribution, distribution.getParametersNumber()));
       LOGINFO(OSS(false) << "Resulting distribution=" << distribution << ", BIC=" << concordanceMeasure);
       if (concordanceMeasure < bestConcordanceMeasure)
       {
         bestConcordanceMeasure = concordanceMeasure;
         bestDistribution = distribution;
+        builtAtLeastOne = true;
       }
     }
     catch (InvalidArgumentException & ex)
@@ -73,7 +77,8 @@ Distribution FittingTest::BestModelBIC(const NumericalSample & sample,
       LOGWARN(OSS(false) << "Warning! Impossible to use factory " << factory << ". Reason=" << ex);
     }
   }
-  if (bestConcordanceMeasure == SpecFunc::MaxNumericalScalar) LOGWARN(OSS(false) << "Be carefull, the best model has an infinite concordance measure. The output distribution must be severely wrong.");
+  if(!builtAtLeastOne) throw InvalidArgumentException(HERE) << "None of the factories could build a model.";
+  if (bestConcordanceMeasure == SpecFunc::MaxNumericalScalar) LOGWARN(OSS(false) << "Be careful, the best model has an infinite concordance measure. The output distribution must be severely wrong.");
   return bestDistribution;
 }
 
@@ -81,11 +86,11 @@ Distribution FittingTest::BestModelBIC(const NumericalSample & sample,
 Distribution FittingTest::BestModelBIC(const NumericalSample  & sample,
                                        const DistributionCollection & distributionCollection)
 {
-  const UnsignedLong size(distributionCollection.getSize());
+  const UnsignedInteger size(distributionCollection.getSize());
   if (size == 0) throw InternalException(HERE) << "Error: no model given";
   Distribution bestDistribution;
   NumericalScalar bestConcordanceMeasure(SpecFunc::MaxNumericalScalar);
-  for (UnsignedLong i = 0; i < size; ++i)
+  for (UnsignedInteger i = 0; i < size; ++i)
   {
     const Distribution distribution(distributionCollection[i]);
     LOGINFO(OSS(false) << "Testing distribution " << distribution);
@@ -97,7 +102,7 @@ Distribution FittingTest::BestModelBIC(const NumericalSample  & sample,
       bestDistribution = distribution;
     }
   }
-  if (bestConcordanceMeasure > SpecFunc::MaxNumericalScalar) LOGWARN(OSS(false) << "Be carefull, the best model has an infinite concordance measure. The output distribution must be severely wrong.");
+  if (bestConcordanceMeasure > SpecFunc::MaxNumericalScalar) LOGWARN(OSS(false) << "Be careful, the best model has an infinite concordance measure. The output distribution must be severely wrong.");
   return bestDistribution;
 }
 
@@ -106,15 +111,16 @@ Distribution FittingTest::BestModelBIC(const NumericalSample  & sample,
 
 /* Best model for a given numerical sample by Kolmogorov */
 Distribution FittingTest::BestModelKolmogorov(const NumericalSample & sample,
-    const DistributionFactoryCollection & factoryCollection)
+    const DistributionFactoryCollection & factoryCollection,
+    TestResult & bestResult)
 {
-  const UnsignedLong size(factoryCollection.getSize());
+  const UnsignedInteger size(factoryCollection.getSize());
   if (size == 0) throw InternalException(HERE) << "Error: no model given";
   const NumericalScalar fakeLevel(0.5);
+  Bool builtAtLeastOne = false;
   Distribution bestDistribution;
-  TestResult bestResult;
   NumericalScalar bestPValue(0.0);
-  for (UnsignedLong i = 0; i < size; ++i)
+  for (UnsignedInteger i = 0; i < size; ++i)
   {
     const DistributionFactory factory(factoryCollection[i]);
     try
@@ -128,6 +134,7 @@ Distribution FittingTest::BestModelKolmogorov(const NumericalSample & sample,
         bestPValue = result.getPValue();
         bestResult = result;
         bestDistribution = distribution;
+        builtAtLeastOne = true;
       }
     }
     catch (InvalidArgumentException & ex)
@@ -135,21 +142,21 @@ Distribution FittingTest::BestModelKolmogorov(const NumericalSample & sample,
       LOGWARN(OSS(false) << "Warning! Impossible to use factory " << factory << ". Reason=" << ex);
     }
   }
-  if ( bestPValue == 0.0) LOGWARN(OSS(false) << "Be carefull, the best model has a p-value of zero. The output distribution must be severely wrong.");
-  lastResult_ = bestResult;
+  if(!builtAtLeastOne) throw InvalidArgumentException(HERE) << "None of the factories could build a model.";
+  if ( bestPValue == 0.0) LOGWARN(OSS(false) << "Be careful, the best model has a p-value of zero. The output distribution must be severely wrong.");
   return bestDistribution;
 }
 
 /* Best model for a given numerical sample by Kolmogorov */
 Distribution FittingTest::BestModelKolmogorov(const NumericalSample & sample,
-    const DistributionCollection & distributionCollection)
+    const DistributionCollection & distributionCollection,
+    TestResult & bestResult)
 {
-  const UnsignedLong size(distributionCollection.getSize());
+  const UnsignedInteger size(distributionCollection.getSize());
   if (size == 0) throw InternalException(HERE) << "Error: no model given";
   Distribution bestDistribution;
-  TestResult bestResult;
   NumericalScalar bestPValue(0.0);
-  for (UnsignedLong i = 0; i < size; ++i)
+  for (UnsignedInteger i = 0; i < size; ++i)
   {
     const Distribution distribution(distributionCollection[i]);
     LOGINFO(OSS(false) << "Testing distribution " << distribution);
@@ -162,22 +169,22 @@ Distribution FittingTest::BestModelKolmogorov(const NumericalSample & sample,
       bestDistribution = distribution;
     }
   }
-  if ( bestPValue == 0.0) LOGWARN(OSS(false) << "Be carefull, the best model has a p-value of zero. The output distribution must be severely wrong.");
-  lastResult_ = bestResult;
+  if ( bestPValue == 0.0) LOGWARN(OSS(false) << "Be careful, the best model has a p-value of zero. The output distribution must be severely wrong.");
   return bestDistribution;
 }
 
 
 /* Best model for a given numerical sample by ChiSquared */
 Distribution FittingTest::BestModelChiSquared(const NumericalSample & sample,
-    const DistributionFactoryCollection & factoryCollection)
+    const DistributionFactoryCollection & factoryCollection,
+    TestResult & bestResult)
 {
-  const UnsignedLong size(factoryCollection.getSize());
+  const UnsignedInteger size(factoryCollection.getSize());
   if (size == 0) throw InternalException(HERE) << "Error: no model given";
   const NumericalScalar fakeLevel(0.5);
   Distribution bestDistribution(factoryCollection[0].build(sample));
-  TestResult bestResult(ChiSquared(sample, bestDistribution, fakeLevel, bestDistribution.getParametersNumber()));
-  for (UnsignedLong i = 1; i < size; ++i)
+  bestResult = ChiSquared(sample, bestDistribution, fakeLevel, bestDistribution.getParametersNumber());
+  for (UnsignedInteger i = 1; i < size; ++i)
   {
     const Distribution distribution(factoryCollection[i].build(sample));
     const TestResult result(ChiSquared(sample, distribution, fakeLevel, distribution.getParametersNumber()));
@@ -187,20 +194,20 @@ Distribution FittingTest::BestModelChiSquared(const NumericalSample & sample,
       bestDistribution = distribution;
     }
   }
-  if ( bestResult.getPValue() == 0.0) LOGWARN(OSS(false) << "Be carefull, the best model has a p-value of zero.");
-  lastResult_ = bestResult;
+  if ( bestResult.getPValue() == 0.0) LOGWARN(OSS(false) << "Be careful, the best model has a p-value of zero.");
   return bestDistribution;
 }
 
 /* Best model for a given numerical sample by ChiSquared */
 Distribution FittingTest::BestModelChiSquared(const NumericalSample & sample,
-    const DistributionCollection & distributionCollection)
+    const DistributionCollection & distributionCollection,
+    TestResult & bestResult)
 {
-  const UnsignedLong size(distributionCollection.getSize());
+  const UnsignedInteger size(distributionCollection.getSize());
   if (size == 0) throw InternalException(HERE) << "Error: no model given";
   Distribution bestDistribution(distributionCollection[0]);
-  TestResult bestResult(ChiSquared(sample, bestDistribution));
-  for (UnsignedLong i = 1; i < size; ++i)
+  bestResult = ChiSquared(sample, bestDistribution);
+  for (UnsignedInteger i = 1; i < size; ++i)
   {
     const Distribution distribution(distributionCollection[i]);
     const TestResult result(ChiSquared(sample, distribution));
@@ -210,30 +217,28 @@ Distribution FittingTest::BestModelChiSquared(const NumericalSample & sample,
       bestDistribution = distribution;
     }
   }
-  if ( bestResult.getPValue() == 0.0) LOGWARN(OSS(false) << "Be carefull, the best model has a p-value of zero.");
-  lastResult_ = bestResult;
+  if ( bestResult.getPValue() == 0.0) LOGWARN(OSS(false) << "Be careful, the best model has a p-value of zero.");
   return bestDistribution;
 }
 
 /* Bayesian Information Criterion computation */
 NumericalScalar FittingTest::BIC(const NumericalSample & sample,
                                  const Distribution & distribution,
-                                 const UnsignedLong estimatedParameters)
+                                 const UnsignedInteger estimatedParameters)
 {
   if (sample.getDimension() != distribution.getDimension()) throw InvalidArgumentException(HERE) << "Error: the sample dimension and the distribution dimension must be equal";
   if (sample.getSize() == 0) throw InvalidArgumentException(HERE) << "Error: the sample is empty";
-  const UnsignedLong size(sample.getSize());
-  const UnsignedLong parametersNumber(distribution.getParametersNumber());
+  const UnsignedInteger size(sample.getSize());
+  const UnsignedInteger parametersNumber(distribution.getParametersNumber());
   if (parametersNumber < estimatedParameters) throw InvalidArgumentException(HERE) << "Error: the number of estimated parameters cannot exceed the number of parameters of the distribution";
   NumericalScalar logLikelihood(0.0);
   const NumericalSample logPDF(distribution.computeLogPDF(sample));
-  lastResult_ = TestResult();
-  for (UnsignedLong i = 0; i < size; ++i)
+  for (UnsignedInteger i = 0; i < size; ++i)
   {
     if (logPDF[i][0] == -SpecFunc::MaxNumericalScalar) return SpecFunc::MaxNumericalScalar;
     logLikelihood += logPDF[i][0];
   }
-  return (-2.0 * logLikelihood + estimatedParameters * log(size)) / size;
+  return (-2.0 * logLikelihood + estimatedParameters * log(1.0 * size)) / size;
 }
 
 /* Bayesian Information Criterion computation */
@@ -263,7 +268,7 @@ TestResult FittingTest::Kolmogorov(const NumericalSample & sample,
 TestResult FittingTest::Kolmogorov(const NumericalSample & sample,
                                    const Distribution & distribution,
                                    const NumericalScalar level,
-                                   const UnsignedLong estimatedParameters)
+                                   const UnsignedInteger estimatedParameters)
 {
   if ((level <= 0.0) || (level >= 1.0)) throw InvalidArgumentException(HERE) << "Error: level must be in ]0, 1[, here level=" << level;
   if (sample.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: Kolmogorov test works only with 1D samples";
@@ -271,19 +276,19 @@ TestResult FittingTest::Kolmogorov(const NumericalSample & sample,
   if (!distribution.getImplementation()->isContinuous()) throw InvalidArgumentException(HERE) << "Error: Kolmogorov test can be applied only to a continuous distribution";
   if (distribution.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: Kolmogorov test works only with 1D distribution";
   if (estimatedParameters > 0) LOGINFO("Warning: using Kolmogorov test for a distribution with estimated parameters will result in an overestimated pValue");
-  const UnsignedLong size(sample.getSize());
+  const UnsignedInteger size(sample.getSize());
   NumericalScalar value(0.0);
   const NumericalSample cdfValues(distribution.computeCDF(sample.sort()));
-  for (UnsignedLong i = 0; i < size; ++i)
+  for (UnsignedInteger i = 0; i < size; ++i)
   {
     const NumericalScalar cdfValue(cdfValues[i][0]);
     value = std::max(value, std::max(fabs(NumericalScalar(i) / size - cdfValue), fabs(cdfValue - NumericalScalar(i + 1) / size)));
   }
   const NumericalScalar pValue(DistFunc::pKolmogorov(size, value, true));
-  lastResult_ = TestResult(OSS(false) << "Kolmogorov" << distribution.getClassName(), (pValue > 1.0 - level), pValue, 1.0 - level);
-  lastResult_.setDescription(Description(1, String(OSS() << distribution.__str__() << " vs sample " << sample.getName())));
-  LOGDEBUG(OSS() << lastResult_);
-  return lastResult_;
+  TestResult result(OSS(false) << "Kolmogorov" << distribution.getClassName(), (pValue > 1.0 - level), pValue, 1.0 - level);
+  result.setDescription(Description(1, String(OSS() << distribution.__str__() << " vs sample " << sample.getName())));
+  LOGDEBUG(OSS() << result);
+  return result;
 }
 
 /* Chi-squared test */
@@ -305,7 +310,7 @@ TestResult FittingTest::ChiSquared(const NumericalSample & sample,
 TestResult FittingTest::ChiSquared(const NumericalSample & sample,
                                    const Distribution & distribution,
                                    const NumericalScalar level,
-                                   const UnsignedLong estimatedParameters)
+                                   const UnsignedInteger estimatedParameters)
 {
   if ((level <= 0.0) || (level >= 1.0)) throw InvalidArgumentException(HERE) << "Error: level must be in ]0, 1[, here level=" << level;
   if (sample.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: ChiSquared test works only with 1D samples";
@@ -313,19 +318,19 @@ TestResult FittingTest::ChiSquared(const NumericalSample & sample,
 
 #if 0
   // First, bin the data such that the theoretical frequency in each bin is at least nMin
-  const UnsignedLong nMin(ResourceMap::GetAsUnsignedLong("FittingTest-ChiSquaredMinFrequency"));
-  const UnsignedLong size(sample.getSize());
+  const UnsignedInteger nMin(ResourceMap::GetAsUnsignedInteger("FittingTest-ChiSquaredMinFrequency"));
+  const UnsignedInteger size(sample.getSize());
   if (size < 2 * nMin) throw InvalidArgumentException(HERE) << "Error: ChiSquared test cannot be used with a sample size smaller than " << 2 * nMin << ". Reduce the value of \"FittingTest-ChiSquaredMinFrequency\" below " << size / 2 << " if you really want to do this test.";
   // The test statistics
   NumericalScalar xi(0.0);
   // Sort the data
   const NumericalSample sortedSample(sample.sort());
-  const UnsignedLong iMax(static_cast<UnsignedLong>(round(size / nMin)));
-  UnsignedLong dataIndex(0);
-  for (UnsignedLong i = 1; i <= iMax; ++i)
+  const UnsignedInteger iMax(static_cast<UnsignedInteger>(round(size / nMin)));
+  UnsignedInteger dataIndex(0);
+  for (UnsignedInteger i = 1; i <= iMax; ++i)
   {
     const NumericalScalar currentBound(distribution.computeQuantile(i / NumericalScalar(iMax))[0]);
-    UnsignedLong count(0);
+    UnsignedInteger count(0);
     while (sample[dataIndex][0] <= currentBound)
     {
       ++count;
@@ -340,7 +345,7 @@ TestResult FittingTest::ChiSquared(const NumericalSample & sample,
 TestResult FittingTest::RunRTest(const NumericalSample & sample,
                                  const Distribution & distribution,
                                  const NumericalScalar level,
-                                 const UnsignedLong estimatedParameters,
+                                 const UnsignedInteger estimatedParameters,
                                  const String & testName)
 {
   const String dataFileName(sample.storeToTemporaryFile());
@@ -351,12 +356,13 @@ TestResult FittingTest::RunRTest(const NumericalSample & sample,
   cmdFile << "library(rot)" << std::endl;
   cmdFile << "options(digits=17)" << std::endl;
   cmdFile << "options(warn=-1)" << std::endl;
+  cmdFile << "options(stringsAsFactors = F)" << std::endl;
   cmdFile << "sample <- data.matrix(read.table(\"" << dataFileName << "\"))" << std::endl;
   cmdFile << "res <- computeTest" << testName << distribution.getImplementation()->getClassName();
   cmdFile << "(sample, ";
   const NumericalPoint parameters(distribution.getParametersCollection()[0]);
-  const UnsignedLong parametersNumber(parameters.getDimension());
-  for (UnsignedLong i = 0; i < parametersNumber; ++i) cmdFile << parameters[i] << ", ";
+  const UnsignedInteger parametersNumber(parameters.getDimension());
+  for (UnsignedInteger i = 0; i < parametersNumber; ++i) cmdFile << parameters[i] << ", ";
   cmdFile << level << ", " << estimatedParameters << ")" << std::endl;
   cmdFile << "f <- file(\"" << resultFileName << "\",\"wt\")" << std::endl;
   cmdFile << "cat(res$test, res$testResult, res$threshold, res$pValue, sep=\"\\n\", file=f)" << std::endl;
@@ -365,7 +371,7 @@ TestResult FittingTest::RunRTest(const NumericalSample & sample,
   const String RExecutable(ResourceMap::Get("R-executable-command"));
   OSS systemCommand;
   if (RExecutable != "") systemCommand << RExecutable << " --no-save --silent < \"" << commandFileName << "\"" << Os::GetDeleteCommandOutput();
-  else throw NotYetImplementedException(HERE) << "FittingTest::RunRTest() needs R. Please install it and set the absolute path of the R executable in ResourceMap.";
+  else throw NotYetImplementedException(HERE) << "In FittingTest::RunRTest(const NumericalSample & sample, const Distribution & distribution, const NumericalScalar level, const UnsignedInteger estimatedParameters, const String & testName): needs R. Please install it and set the absolute path of the R executable in ResourceMap.";
   const int returnCode(Os::ExecuteCommand(systemCommand));
   if (returnCode != 0) throw InternalException(HERE) << "Error: unable to execute the system command " << String(systemCommand) << " returned code is " << returnCode;
   // Parse result file
@@ -380,18 +386,13 @@ TestResult FittingTest::RunRTest(const NumericalSample & sample,
   resultFile >> pValue;
 
   // Clean-up everything
-  if (remove(dataFileName.c_str()) == -1) LOGWARN(OSS(false) << "Warning: cannot remove file " << dataFileName);
-  if (remove(resultFileName.c_str()) == -1) LOGWARN(OSS(false) << "Warning: cannot remove file " << dataFileName);
-  if (remove(commandFileName.c_str()) == -1) LOGWARN(OSS(false) << "Warning: cannot remove file " << dataFileName);
+  Os::Remove(dataFileName);
+  Os::Remove(resultFileName);
+  Os::Remove(commandFileName);
 
-  lastResult_ = TestResult(testType, testResult, pValue, pThreshold);
-  return GetLastResult();
+  TestResult result(testType, testResult, pValue, pThreshold);
+  return result;
 }
 
-/* Get last fitting result */
-TestResult FittingTest::GetLastResult()
-{
-  return lastResult_;
-}
 
 END_NAMESPACE_OPENTURNS
