@@ -3,7 +3,7 @@
  *  @file  VisualTest.cxx
  *  @brief StatTest implements statistical tests
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -33,6 +33,9 @@
 #include "Description.hxx"
 #include "ResourceMap.hxx"
 #include "UserDefined.hxx"
+#include "SpecFunc.hxx"
+#include "Normal.hxx"
+#include "NormalFactory.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -51,9 +54,9 @@ Graph VisualTest::DrawEmpiricalCDF(const NumericalSample & sample,
 
 /* Draw the Histogram of the Sample when its dimension is 1 */
 Graph VisualTest::DrawHistogram(const NumericalSample & sample,
-                                const UnsignedLong binNumber)
+                                const UnsignedInteger binNumber)
 {
-  const UnsignedLong size(sample.getSize());
+  const UnsignedInteger size(sample.getSize());
   if (size == 0) throw InvalidArgumentException(HERE) << "Error: cannot draw an Histogram based on an empty sample.";
   if (sample.getDimension() != 1) throw InvalidDimensionException(HERE) << "Error: can draw an Histogram only if dimension equals 1, here dimension=" << sample.getDimension();
   if (binNumber == 0) throw InvalidArgumentException(HERE) << "Error: cannot draw an Histogram with 0 bar";
@@ -89,15 +92,15 @@ Graph VisualTest::DrawHistogram(const NumericalSample & sample,
     {
       h = (max - min) / (binNumber - 1);
       min -= 0.5 * h;
-      for (UnsignedLong i = 0; i < binNumber; ++i) data[i][0] = h;
-      for (UnsignedLong i = 0; i < size; ++i)
+      for (UnsignedInteger i = 0; i < binNumber; ++i) data[i][0] = h;
+      for (UnsignedInteger i = 0; i < size; ++i)
       {
-        const UnsignedLong index(static_cast< UnsignedLong >((sample[i][0] - min) / h));
+        const UnsignedInteger index(static_cast< UnsignedInteger >((sample[i][0] - min) / h));
         ++data[index][1];
       }
     }
     const NumericalScalar inverseArea(1.0 / (h * size));
-    for (UnsignedLong i = 0; i < binNumber; ++i) data[i][1] *= inverseArea;
+    for (UnsignedInteger i = 0; i < binNumber; ++i) data[i][1] *= inverseArea;
   }
   // Create an empty graph
   Graph graphHist("sample histogram", "realizations", "frequency", true, "topright");
@@ -116,7 +119,7 @@ Graph VisualTest::DrawHistogram(const NumericalSample & sample)
 {
   if (sample.getDimension() != 1) throw InvalidDimensionException(HERE) << "Error: can draw a Histogram only if dimension equals 1, here dimension=" << sample.getDimension();
   const NumericalScalar std(sample.computeStandardDeviationPerComponent()[0]);
-  UnsignedLong nBars(1);
+  UnsignedInteger nBars(1);
   if (std == 0.0)
   {
     LOGWARN("You are drawing an Histogram for a sample with constant realizations, which is questionable.");
@@ -124,7 +127,7 @@ Graph VisualTest::DrawHistogram(const NumericalSample & sample)
   else
   {
     const NumericalScalar hOpt(std * pow(24.0 * sqrt(M_PI) / sample.getSize(), 1.0 / 3.0));
-    nBars = (UnsignedLong)(ceil((sample.getMax()[0] - sample.getMin()[0]) / hOpt + 0.5));
+    nBars = (UnsignedInteger)(ceil((sample.getMax()[0] - sample.getMin()[0]) / hOpt + 0.5));
   }
   return DrawHistogram(sample, nBars);
 }
@@ -132,25 +135,23 @@ Graph VisualTest::DrawHistogram(const NumericalSample & sample)
 /* Draw the QQplot of the two Samples when its dimension is 1 */
 Graph VisualTest::DrawQQplot(const NumericalSample & sample1,
                              const NumericalSample & sample2,
-                             const UnsignedLong pointNumber)
+                             const UnsignedInteger pointNumber)
 {
   if (sample1.getDimension() != 1) throw InvalidDimensionException(HERE) << "Error: can draw a QQplot only if dimension equals 1, here dimension=" << sample1.getDimension();
   if (sample2.getDimension() != 1) throw InvalidDimensionException(HERE) << "Error: can draw a QQplot only if dimension equals 1, here dimension=" << sample2.getDimension();
   NumericalSample data(pointNumber, 2);
   const NumericalScalar step(1.0 / pointNumber);
-  for (UnsignedLong i = 0; i < pointNumber; ++i)
+  for (UnsignedInteger i = 0; i < pointNumber; ++i)
   {
     const NumericalScalar q((i + 0.5) * step);
     data[i][0] = sample1.computeQuantilePerComponent(q)[0];
     data[i][1] = sample2.computeQuantilePerComponent(q)[0];
   }
-  OSS oss;
-  oss << sample1.getName() << " qqplot";
-  Cloud cloudQQplot(data, oss);
+  Cloud cloudQQplot(data, "Data");
   if (pointNumber < 100) cloudQQplot.setPointStyle("fcircle");
   else if (pointNumber < 1000) cloudQQplot.setPointStyle("bullet");
   else cloudQQplot.setPointStyle("dot");
-  Graph graphQQplot("two sample QQplot", "sample1", "sample2", true, "topleft");
+  Graph graphQQplot("Two sample QQ-plot", sample1.getDescription()[0], sample2.getDescription()[0], true, "topleft");
   // First, the bisectrice
   NumericalSample diagonal(2, 2);
   NumericalPoint point(2);
@@ -158,7 +159,7 @@ Graph VisualTest::DrawQQplot(const NumericalSample & sample1,
   diagonal[0][1] = data[0][0];
   diagonal[1][0] = data[pointNumber - 1][0];
   diagonal[1][1] = data[pointNumber - 1][0];
-  Curve bisectrice(diagonal);
+  Curve bisectrice(diagonal, "Test line");
   bisectrice.setColor("red");
   bisectrice.setLineStyle("dashed");
   graphQQplot.add(bisectrice);
@@ -182,22 +183,20 @@ Graph VisualTest::DrawQQplot(const NumericalSample & sample,
 {
   if (sample.getDimension() != 1) throw InvalidDimensionException(HERE) << "Error: can draw a QQplot only if dimension equals 1, here dimension=" << sample.getDimension();
   if (dist.getDimension() != 1) throw InvalidDimensionException(HERE) << "Error: can draw a QQplot only if dimension equals 1, here dimension=" << dist.getDimension();
-  const UnsignedLong size(sample.getSize());
+  const UnsignedInteger size(sample.getSize());
   const NumericalSample sortedSample(sample.sort(0));
   NumericalSample data(size, 2);
   const NumericalScalar step(1.0 / size);
-  for (UnsignedLong i = 0; i < size; ++i)
+  for (UnsignedInteger i = 0; i < size; ++i)
   {
     data[i][0] = sortedSample[i][0];
     data[i][1] = dist.computeQuantile((i + 0.5) * step)[0];
   }
-  OSS oss;
-  oss << sample.getName() << " qqplot";
-  Cloud cloudQQplot(data, oss);
+  Cloud cloudQQplot(data, "Data");
   if (size < 100) cloudQQplot.setPointStyle("fcircle");
   else if (size < 1000) cloudQQplot.setPointStyle("bullet");
   else cloudQQplot.setPointStyle("dot");
-  Graph graphQQplot("sample versus model QQplot", "sample", "model", true, "topleft");
+  Graph graphQQplot("Sample versus model QQ-plot", sample.getDescription()[0], dist.__str__(), true, "topleft");
   // First, the bisectrice
   NumericalSample diagonal(2, 2);
   NumericalPoint point(2);
@@ -205,7 +204,7 @@ Graph VisualTest::DrawQQplot(const NumericalSample & sample,
   diagonal[0][1] = data[0][0];
   diagonal[1][0] = data[size - 1][0];
   diagonal[1][1] = data[size - 1][0];
-  Curve bisectrice(diagonal);
+  Curve bisectrice(diagonal, "Test line");
   bisectrice.setColor("red");
   bisectrice.setLineStyle("dashed");
   graphQQplot.add(bisectrice);
@@ -223,39 +222,49 @@ Graph VisualTest::DrawQQplot(const NumericalSample & sample,
   return graphQQplot;
 }
 
-
-/* Draw the Henry curve for one Sample when its dimension is 1 */
+/* Draw the Henry line for a sample when its dimension is 1 */
 Graph VisualTest::DrawHenryLine(const NumericalSample & sample)
 {
-  if (sample.getDimension() != 1) throw InvalidDimensionException(HERE) << "Error: can draw a Henry line only if dimension equals 1, here dimension=" << sample.getDimension();
+  if (sample.getDimension() != 1) throw InvalidDimensionException(HERE) << "Error: can draw a Henry line only if the sample dimension equals 1, here dimension=" << sample.getDimension();
+  return DrawHenryLine(sample, NormalFactory().buildAsNormal(sample));
+}
 
-  const UnsignedLong size(sample.getSize());
-  const Normal dist;
+/* Draw the Henry line for a sample and a given normal distribution when its dimension is 1 */
+Graph VisualTest::DrawHenryLine(const NumericalSample & sample, const Distribution & normal)
+{
+  if (sample.getDimension() != 1) throw InvalidDimensionException(HERE) << "Error: can draw a Henry plot only if the sample dimension equals 1, here dimension=" << sample.getDimension();
+  if (normal.getDimension() != 1) throw InvalidDimensionException(HERE) << "Error: can draw a Henry plot only if the normal distribution dimension equals 1, here dimension=" << normal.getDimension();
+  if (normal.getImplementation()->getClassName() != "Normal") throw InvalidArgumentException(HERE) << "Normal distribution expected";
 
+  Graph graphHenry("Henry plot", "Sample", "Standard normal quantiles", true, "topleft");
+  const UnsignedInteger size(sample.getSize());
   const NumericalSample sortedSample(sample.sort(0));
+
+  // First, the Henry line: y = (x - mu) / sigma
+  const NumericalScalar mu = normal.getMean()[0];
+  const NumericalScalar sigma = normal.getStandardDeviation()[0];
+  NumericalSample henryLinePoints(2, 2);
+  henryLinePoints[0][0] = sortedSample[0][0]; // sample.getMin()[0];
+  henryLinePoints[0][1] = (henryLinePoints[0][0] - mu) / sigma;
+  henryLinePoints[1][0] = sortedSample[size - 1][0]; // sample.getMax()[0];
+  henryLinePoints[1][1] = (henryLinePoints[1][0] - mu) / sigma;
+  Curve henryLine(henryLinePoints, "Henry line");
+  henryLine.setColor("red");
+  henryLine.setLineStyle("dashed");
+  graphHenry.add(henryLine);
+
+  // Then, the data
+  const Normal standard_normal(0.0, 1.0);
   NumericalSample data(size, 2);
   const NumericalScalar step(1.0 / size);
-  for (UnsignedLong i = 0; i < size; ++i)
+  for (UnsignedInteger i = 0; i < size; ++i)
   {
     data[i][0] = sortedSample[i][0];
-    data[i][1] = dist.computeQuantile((i + 0.5) * step)[0];
+    data[i][1] = standard_normal.computeQuantile((i + 0.5) * step)[0];
   }
-  OSS oss;
-  oss << sample.getName() << " Henry Curve";
-  Curve curveHenry(data, oss);
-  Graph graphHenry("Henry Curve", "sample", "model", true, "topleft");
-  // First, the diagonal
-  NumericalSample diagonal(2, 2);
-  diagonal[0][0] = data[0][0];
-  diagonal[0][1] = data[0][0];
-  diagonal[1][0] = data[size - 1][0];
-  diagonal[1][1] = data[size - 1][0];
-  Curve bisectrice(diagonal);
-  bisectrice.setColor("red");
-  bisectrice.setLineStyle("dashed");
-  graphHenry.add(bisectrice);
-  // Then, the Henry line
-  graphHenry.add(curveHenry);
+  Cloud dataCloud(data, "Data");
+  graphHenry.add(dataCloud);
+
   return graphHenry;
 }
 
@@ -316,9 +325,9 @@ Graph VisualTest::DrawLinearModel(const NumericalSample & sample1,
   const NumericalSample y(linearModel.getPredicted(sample1));
   OSS oss;
   oss << sample1.getName() << " LinearModel visualTest";
-  const UnsignedLong size(sample1.getSize());
+  const UnsignedInteger size(sample1.getSize());
   NumericalSample sample2D(size, 2);
-  for (UnsignedLong i = 0; i < size; ++i)
+  for (UnsignedInteger i = 0; i < size; ++i)
   {
     NumericalPoint point(2);
     point[0] = sample1[i][0];
@@ -348,9 +357,9 @@ Graph VisualTest::DrawLinearModelResidual(const NumericalSample & sample1,
   if (sample1.getSize() != sample2.getSize()) throw InvalidArgumentException(HERE) << "Error: can draw a LinearModel residual visual test only if sample 1 and sample 2 have the same size, here sample 1 size=" << sample1.getSize() << " and sample 2 size=" << sample2.getSize();
 
   const NumericalSample y(linearModel.getResidual(sample1, sample2));
-  const UnsignedLong size(sample1.getSize());
+  const UnsignedInteger size(sample1.getSize());
   NumericalSample data(size - 1, 2);
-  for (UnsignedLong i = 0; i < size - 1; ++i)
+  for (UnsignedInteger i = 0; i < size - 1; ++i)
   {
     data[i][0] = y[i][0];
     data[i][1] = y[i + 1][0];
@@ -373,43 +382,43 @@ Graph VisualTest::DrawCobWeb(const NumericalSample & inputSample,
                              const String & color,
                              const Bool quantileScale)
 {
-  const UnsignedLong size(inputSample.getSize());
+  const UnsignedInteger size(inputSample.getSize());
   if (size == 0) throw InvalidArgumentException(HERE) << "Error: the input sample is empty.";
   if (size != outputSample.getSize()) throw InvalidArgumentException(HERE) << "Error: the input sample and the output sample must have the same size.";
   if (outputSample.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: the output sample dimension must be 1.";
   if (minValue > maxValue) throw InvalidArgumentException(HERE) << "Error: minValue cannot be greater than maxValue.";
   // If based on quantiles, rank the values
-  UnsignedLong minRank;
-  UnsignedLong maxRank;
+  UnsignedInteger minRank;
+  UnsignedInteger maxRank;
   if (!quantileScale)
   {
     const NumericalScalar minCDF(outputSample.computeEmpiricalCDF(NumericalPoint(1, minValue)));
     const NumericalScalar maxCDF(outputSample.computeEmpiricalCDF(NumericalPoint(1, maxValue)));
-    minRank = static_cast<UnsignedLong>(round(size * minCDF));
-    maxRank = static_cast<UnsignedLong>(round(size * maxCDF));
+    minRank = static_cast<UnsignedInteger>(round(size * minCDF));
+    maxRank = static_cast<UnsignedInteger>(round(size * maxCDF));
   }
   else
   {
     if ((minValue < 0.0) || (maxValue > 1.0) || (minValue > maxValue))  throw InvalidArgumentException(HERE) << "Error: we must have 0 <= minValue <= maxValue <= 1 when using quantile scale.";
-    minRank = static_cast<UnsignedLong>(size * minValue);
-    maxRank = static_cast<UnsignedLong>(size * maxValue);
+    minRank = static_cast<UnsignedInteger>(size * minValue);
+    maxRank = static_cast<UnsignedInteger>(size * maxValue);
   }
-  const UnsignedLong inputDimension(inputSample.getDimension());
+  const UnsignedInteger inputDimension(inputSample.getDimension());
   const NumericalSample rankedInput(inputSample.rank());
   const NumericalSample rankedOutput(outputSample.rank());
   // Create the graph
   Graph cobWeb(String(OSS() << "Cobweb graph - " << outputSample.getDescription() << " vs " << inputSample.getDescription()), "", "", false, "topright");
   // First discriminate the filaments: draw the background filaments and memorize the selected ones
   Indices selectedFilaments(0);
-  for (UnsignedLong i = 0; i < size; ++i)
+  for (UnsignedInteger i = 0; i < size; ++i)
   {
-    const UnsignedLong currentRank(static_cast<UnsignedLong>(rankedOutput[i][0]));
+    const UnsignedInteger currentRank(static_cast<UnsignedInteger>(rankedOutput[i][0]));
     if ((currentRank >= minRank) && (currentRank <= maxRank))
       selectedFilaments.add(i);
     else
     {
       NumericalSample data(inputDimension + 1, 1);
-      for (UnsignedLong j = 0; j < inputDimension; ++j) data[j][0] = rankedInput[i][j];
+      for (UnsignedInteger j = 0; j < inputDimension; ++j) data[j][0] = rankedInput[i][j];
       data[inputDimension][0] = rankedOutput[i][0];
       Curve filament(data);
       filament.setColor("grey");
@@ -417,11 +426,11 @@ Graph VisualTest::DrawCobWeb(const NumericalSample & inputSample,
     }
   }
   // Draw the selected filaments
-  const UnsignedLong selectedSize(selectedFilaments.getSize());
-  for (UnsignedLong i = 0; i < selectedSize; ++i)
+  const UnsignedInteger selectedSize(selectedFilaments.getSize());
+  for (UnsignedInteger i = 0; i < selectedSize; ++i)
   {
     NumericalSample data(inputDimension + 1, 1);
-    for (UnsignedLong j = 0; j < inputDimension; ++j) data[j][0] = rankedInput[selectedFilaments[i]][j];
+    for (UnsignedInteger j = 0; j < inputDimension; ++j) data[j][0] = rankedInput[selectedFilaments[i]][j];
     data[inputDimension][0] = rankedOutput[selectedFilaments[i]][0];
     Curve filament(data);
     filament.setColor(color);
@@ -429,7 +438,7 @@ Graph VisualTest::DrawCobWeb(const NumericalSample & inputSample,
   }
   // Draw the vertical lines associated with the input variables
   const Description palette(Curve::BuildDefaultPalette(inputDimension));
-  for (UnsignedLong i = 0; i < inputDimension + 1; ++i)
+  for (UnsignedInteger i = 0; i < inputDimension + 1; ++i)
   {
     NumericalSample data(2, 2);
     NumericalPoint point(2);
@@ -463,10 +472,11 @@ Graph VisualTest::DrawCobWeb(const NumericalSample & inputSample,
 
 /* Draw the Kendall plot to assess a copula for a bidimensional sample */
 Graph VisualTest::DrawKendallPlot(const NumericalSample & data,
-                                  const Copula & copula)
+                                  const Distribution & copula)
 {
   if (data.getSize() == 0) throw InvalidArgumentException(HERE) << "Error: cannot build a Kendall plot if the data sample is empty.";
   if (data.getDimension() != 2) throw InvalidArgumentException(HERE) << "Error: cannot build a Kendall plot if the data sample has a dimension not equal to 2.";
+  if (!copula.isCopula()) throw InvalidArgumentException(HERE) << "Error: the given distribution=" << copula << " is not a copula.";
   if (copula.getDimension() != 2) throw InvalidArgumentException(HERE) << "Error: cannot build a Kendall plot if the copula has a dimension not equal to 2.";
   const NumericalSample empiricalStatistics(ComputeKendallPlotEmpiricalStatistics(data));
   const NumericalSample theoreticalStatistics(ComputeKendallPlotTheoreticalStatistics(copula, data.getSize()));
@@ -511,20 +521,20 @@ Graph VisualTest::DrawKendallPlot(const NumericalSample & firstSample,
 /* Compute the Kendall plot empirical statistic associated with a bidimensional sample */
 NumericalSample VisualTest::ComputeKendallPlotEmpiricalStatistics(const NumericalSample & sample)
 {
-  const UnsignedLong size(sample.getSize());
+  const UnsignedInteger size(sample.getSize());
   NumericalSample result(size, 1);
-  for (UnsignedLong i = 0; i < size; ++i)
+  for (UnsignedInteger i = 0; i < size; ++i)
   {
     const NumericalPoint pointI(sample[i]);
     const NumericalScalar uI(pointI[0]);
     const NumericalScalar vI(pointI[1]);
-    UnsignedLong cardinal(0);
-    for (UnsignedLong j = 0; j < i; ++j)
+    UnsignedInteger cardinal(0);
+    for (UnsignedInteger j = 0; j < i; ++j)
     {
       const NumericalPoint pointJ(sample[j]);
       cardinal += (pointJ[0] <= uI) && (pointJ[1] <= vI);
     }
-    for (UnsignedLong j = i + 1; j < size; ++j)
+    for (UnsignedInteger j = i + 1; j < size; ++j)
     {
       const NumericalPoint pointJ(sample[j]);
       cardinal += (pointJ[0] <= uI) && (pointJ[1] <= vI);
@@ -535,15 +545,16 @@ NumericalSample VisualTest::ComputeKendallPlotEmpiricalStatistics(const Numerica
 }
 
 /* Compute the Kendall plot theoretical statistic associated with a bidimensional copula */
-NumericalSample VisualTest::ComputeKendallPlotTheoreticalStatistics(const Copula & copula,
-    const UnsignedLong size)
+NumericalSample VisualTest::ComputeKendallPlotTheoreticalStatistics(const Distribution & copula,
+    const UnsignedInteger size)
 {
-  const UnsignedLong maximumIteration(ResourceMap::GetAsUnsignedLong( "VisualTest-KendallPlot-MonteCarloSize" ));
+  if (!copula.isCopula()) throw InvalidArgumentException(HERE) << "Error: the given distribution=" << copula << " is not a copula.";
+  const UnsignedInteger maximumIteration(ResourceMap::GetAsUnsignedInteger( "VisualTest-KendallPlot-MonteCarloSize" ));
   NumericalSample result(size, 1);
-  for (UnsignedLong i = 0; i < maximumIteration; ++i)
+  for (UnsignedInteger i = 0; i < maximumIteration; ++i)
   {
     const NumericalSample empiricalStatistics(ComputeKendallPlotEmpiricalStatistics(copula.getSample(size)));
-    for (UnsignedLong j = 0; j < size; ++j) result[j] = (result[j] * i + empiricalStatistics[j]) / (i + 1);
+    for (UnsignedInteger j = 0; j < size; ++j) result[j] = (result[j] * i + empiricalStatistics[j]) / (i + 1);
   }
   return result;
 }
