@@ -3,7 +3,7 @@
  *  @file  openturns_library_ok.c
  *  @brief This file contains a single C function to allow m4 easy detection
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -21,13 +21,14 @@
  *  @author schueller
  *  @date   2012-02-17 19:35:43 +0100 (Fri, 17 Feb 2012)
  */
+#include "OTdebug.h"
 
 /*
  * @fn     int openturns_library_ok()
  * @brief  A function that return 1 on success
  * @return The return code
  */
-int openturns_library_ok()
+int OT_API openturns_library_ok()
 {
   return 1;
 }
