@@ -3,7 +3,7 @@
  *  @file  fonction_2.cxx
  *  @brief
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -22,7 +22,9 @@
  *  @date   2012-02-17 19:35:43 +0100 (Fri, 17 Feb 2012)
  */
 
-extern "C" double fonction2(double x, double y)
+#include <OTdebug.h>
+
+extern "C" OT_HELPER_DLL_EXPORT double fonction2(double x, double y)
 {
   return x - y;
 }
