@@ -3,7 +3,7 @@
  * @file  t_AnalyticalNumericalMathEvaluationImplementation_std.cxx
  * @brief The test file of class AnalyticalNumericalMathEvaluationImplementation for standard methods
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -51,7 +51,7 @@ int main(int argc, char *argv[])
     point[1] =  4.0;
     point[2] = -4.0;
     fullprint << "value at " << point << "=" << evaluation(point) << std::endl;
-    for (UnsignedLong i = 0; i < evaluation.getOutputDimension(); ++i)
+    for (UnsignedInteger i = 0; i < evaluation.getOutputDimension(); ++i)
       fullprint << "Marginal " << i << "=" << evaluation.getMarginal(i)->__repr__() << std::endl;
   }
   catch (TestFailed & ex)
