@@ -3,7 +3,7 @@
  *  @file  t_CalibrationStrategy_std.cxx
  *  @brief The test file of class CalibrationStrategy
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -37,7 +37,7 @@ int main(int argc, char *argv[])
   {
 
     CalibrationStrategy myAlgo(Interval(0.3, 0.5));
-    for ( UnsignedLong i = 0; i < 4; ++ i )
+    for ( UnsignedInteger i = 0; i < 4; ++ i )
     {
       NumericalScalar rho = 0.1 + i * 0.2;
       NumericalScalar updateFactor = myAlgo.computeUpdateFactor(rho);
