@@ -3,7 +3,7 @@
  *  @file  t_ConditionalDistribution_std.cxx
  *  @brief The test file of class ConditionalDistribution for standard methods
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -39,8 +39,6 @@ int main(int argc, char *argv[])
     // Test basic functionnalities
     //checkClassWithClassName<TestObject>();
 
-    // Test some extra functionnalities
-    //checkNameFeature<TestObject>();
     // Create a collection of distribution
     {
       Collection< Distribution > coll2;
@@ -54,7 +52,7 @@ int main(int argc, char *argv[])
       coll1.add(Uniform());
       ComposedDistribution d1(coll1);
       ConditionalDistribution distribution(d1, d2);
-      UnsignedLong dim(distribution.getDimension());
+      UnsignedInteger dim(distribution.getDimension());
       fullprint << "distribution=" << distribution << std::endl;
       fullprint << "Parameters " << distribution.getParametersCollection() << std::endl;
       fullprint << "Mean " << distribution.getMean() << std::endl;
@@ -73,7 +71,7 @@ int main(int argc, char *argv[])
       fullprint << "oneRealization=" << oneRealization << std::endl;
 
       // Test for sampling
-      UnsignedLong size = 10;
+      UnsignedInteger size = 10;
       NumericalSample oneSample = distribution.getSample( size );
       fullprint << "oneSample=" << oneSample << std::endl;
 
@@ -122,11 +120,11 @@ int main(int argc, char *argv[])
       atoms.add( Uniform( 1.0, 2.0) );
       conditioningDistributionCollection.add(ComposedDistribution(atoms));
     }
-    for (UnsignedLong i = 0; i < conditioningDistributionCollection.getSize(); ++i)
+    for (UnsignedInteger i = 0; i < conditioningDistributionCollection.getSize(); ++i)
     {
       fullprint << "conditioning distribution=" << conditioningDistributionCollection[i].__str__() << std::endl;
       ConditionalDistribution distribution(conditionedDistribution, conditioningDistributionCollection[i]);
-      UnsignedLong dim(distribution.getDimension());
+      UnsignedInteger dim(distribution.getDimension());
       fullprint << "Distribution " << distribution << std::endl;
       std::cout << "Distribution " << distribution << std::endl;
       fullprint << "Parameters " << distribution.getParametersCollection() << std::endl;
@@ -146,7 +144,7 @@ int main(int argc, char *argv[])
       fullprint << "oneRealization=" << oneRealization << std::endl;
 
       // Test for sampling
-      UnsignedLong size = 10;
+      UnsignedInteger size = 10;
       NumericalSample oneSample = distribution.getSample( size );
       fullprint << "oneSample=" << oneSample << std::endl;
 
@@ -171,9 +169,9 @@ int main(int argc, char *argv[])
       fullprint << "Quantile=" << quantile << std::endl;
       fullprint << "CDF(quantile)=" << distribution.computeCDF(quantile) << std::endl;
       // Extract the marginals
-      for (UnsignedLong i = 0; i < dim; i++)
+      for (UnsignedInteger j = 0; j < dim; ++j)
       {
-        Distribution margin(distribution.getMarginal(i));
+        Distribution margin(distribution.getMarginal(j));
         fullprint << "margin=" << margin << std::endl;
         fullprint << "margin PDF=" << margin.computePDF(NumericalPoint(1)) << std::endl;
         fullprint << "margin CDF=" << margin.computeCDF(NumericalPoint(1)) << std::endl;
