@@ -3,7 +3,7 @@
  *  @file  t_DickeyFullerTest_std.cxx
  *  @brief The test file of class DickeyFullerTest
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -34,7 +34,7 @@ int main(int argc, char *argv[])
   OStream fullprint(std::cout);
   setRandomGenerator();
 
-  const UnsignedLong size(100);
+  const UnsignedInteger size(100);
 
   ARMACoefficients ARCoefficients(NumericalPoint(1, 0.3));
   ARMACoefficients MACoefficients(0);
