@@ -3,7 +3,7 @@
  *  @file  t_DiracFactory_std.cxx
  *  @brief The test file of class Dirac for standard methods
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -36,7 +36,7 @@ int main(int argc, char *argv[])
   try
   {
     Dirac distribution(0.7);
-    UnsignedLong size(10000);
+    UnsignedInteger size(10000);
     NumericalSample sample(distribution.getSample(size));
     DiracFactory factory;
     CovarianceMatrix covariance;
