@@ -3,7 +3,7 @@
  *  @file  t_Dirac_std.cxx
  *  @brief The test file of class Dirac for standard methods
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -30,11 +30,7 @@ using namespace OT::Test;
 class TestObject : public Dirac
 {
 public:
-  explicit TestObject() : Dirac(0.7) {}
-  explicit TestObject(const String & name) : Dirac(0.7)
-  {
-    setName(name);
-  }
+  TestObject() : Dirac(0.7) {}
   virtual ~TestObject() {}
 };
 
@@ -50,9 +46,6 @@ int main(int argc, char *argv[])
     // Test basic functionnalities
     checkClassWithClassName<TestObject>();
 
-    // Test some extra functionnalities
-    checkNameFeature<TestObject>();
-
     // Instanciate one distribution object
     // 1D tests
     {
@@ -71,7 +64,7 @@ int main(int argc, char *argv[])
       fullprint << "oneRealization=" << oneRealization << std::endl;
 
       // Test for sampling
-      UnsignedLong size = 10000;
+      UnsignedInteger size = 10000;
       NumericalSample oneSample = distribution.getSample( size );
       fullprint << "oneSample first=" << oneSample[0] << " last=" << oneSample[size - 1] << std::endl;
       fullprint << "mean=" << oneSample.computeMean() << std::endl;
@@ -141,12 +134,12 @@ int main(int argc, char *argv[])
       fullprint << "kendall=" << kendall << std::endl;
       Dirac::NumericalPointWithDescriptionCollection parameters = distribution.getParametersCollection();
       fullprint << "parameters=" << parameters << std::endl;
-      for (UnsignedLong i = 0; i < 6; ++i) fullprint << "standard moment n=" << i << ", value=" << distribution.getStandardMoment(i) << std::endl;
+      for (UnsignedInteger i = 0; i < 6; ++i) fullprint << "standard moment n=" << i << ", value=" << distribution.getStandardMoment(i) << std::endl;
       fullprint << "Standard representative=" << distribution.getStandardRepresentative()->__str__() << std::endl;
     }
     // N-D tests
     {
-      UnsignedLong dim = 4;
+      UnsignedInteger dim = 4;
       Dirac distribution(NumericalPoint(dim, 2.3));
       fullprint << "Distribution " << distribution << std::endl;
       std::cout << "Distribution " << distribution << std::endl;
@@ -162,13 +155,13 @@ int main(int argc, char *argv[])
       fullprint << "oneRealization=" << oneRealization << std::endl;
 
       // Test for sampling
-      UnsignedLong size = 10000;
+      UnsignedInteger size = 10000;
       NumericalSample oneSample = distribution.getSample( size );
       fullprint << "oneSample first=" << oneSample[0] << " last=" << oneSample[size - 1] << std::endl;
       fullprint << "mean=" << oneSample.computeMean() << std::endl;
       CovarianceMatrix sampleCovariance(oneSample.computeCovariance());
-      for (UnsignedLong i = 0; i < dim; ++i)
-        for (UnsignedLong j = 0; j <= i; ++j)
+      for (UnsignedInteger i = 0; i < dim; ++i)
+        for (UnsignedInteger j = 0; j <= i; ++j)
           if (fabs(sampleCovariance(i, j)) < 1.0e-16) sampleCovariance(i, j) = 0.0;
       fullprint << "covariance=" << sampleCovariance << std::endl;
 
@@ -223,7 +216,7 @@ int main(int argc, char *argv[])
       fullprint << "kendall=" << kendall << std::endl;
       Dirac::NumericalPointWithDescriptionCollection parameters = distribution.getParametersCollection();
       fullprint << "parameters=" << parameters << std::endl;
-      for (UnsignedLong i = 0; i < 6; ++i) fullprint << "standard moment n=" << i << ", value=" << distribution.getStandardMoment(i) << std::endl;
+      for (UnsignedInteger i = 0; i < 6; ++i) fullprint << "standard moment n=" << i << ", value=" << distribution.getStandardMoment(i) << std::endl;
       fullprint << "Standard representative=" << distribution.getStandardRepresentative()->__str__() << std::endl;
     }
   }
