@@ -3,7 +3,7 @@
  *  @file  t_Event_domain.cxx
  *  @brief The test file of Event class
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -36,7 +36,7 @@ int main(int argc, char *argv[])
   try
   {
 
-    UnsignedLong dim(2);
+    UnsignedInteger dim(2);
     Normal distribution(dim);
 
     //
@@ -47,7 +47,7 @@ int main(int argc, char *argv[])
       RandomVector X(distribution);
       // The model: the identity function
       Description inVars(dim);
-      for (UnsignedLong i = 0; i < dim; ++i) inVars[i] = OSS() << "x" << i;
+      for (UnsignedInteger i = 0; i < dim; ++i) inVars[i] = OSS() << "x" << i;
       NumericalMathFunction model(inVars, inVars);
       // The output vector
       RandomVector Y(model, X);
