@@ -3,7 +3,7 @@
  *  @file  t_ExpertMixture_std.cxx
  *  @brief The test file of class ExpertMixture for standard methods
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -66,7 +66,7 @@ int main(int argc, char *argv[])
     fullprint << "Mixture of experts=" << moe << std::endl;
 
     // Evaluate the mixture of experts on some points
-    for (UnsignedLong i = 0; i < 5; ++i)
+    for (UnsignedInteger i = 0; i < 5; ++i)
     {
       NumericalPoint p(1, -0.3 + 0.8 * i / 4.0);
       fullprint << "moe(" << p[0] << ")=" << moe(p) << std::endl;
