@@ -3,7 +3,7 @@
  *  @file  t_FarlieGumbelMorgensternCopula_std.cxx
  *  @brief The test file of class FarlieGumbelMorgensternCopula for standard methods
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -36,13 +36,12 @@ int main(int argc, char *argv[])
   try
   {
     // Instanciate one distribution object
-    UnsignedLong dim(2);
+    UnsignedInteger dim(2);
     FarlieGumbelMorgensternCopula copula(0.7);
     copula.setName("a farlieGumbelMorgenstern copula");
     fullprint << "Copula " << copula << std::endl;
     std::cout << "Copula " << copula << std::endl;
     fullprint << "Mean " << copula.getMean() << std::endl;
-    fullprint << "Covariance " << copula.getCovariance() << std::endl;
     // Is this copula an elliptical distribution?
     fullprint << "Elliptical distribution= " << (copula.isElliptical() ? "true" : "false") << std::endl;
 
@@ -57,7 +56,7 @@ int main(int argc, char *argv[])
     fullprint << "oneRealization=" << oneRealization << std::endl;
 
     // Test for sampling
-    UnsignedLong size = 10;
+    UnsignedInteger size = 10;
     NumericalSample oneSample = copula.getSample( size );
     fullprint << "oneSample=" << oneSample << std::endl;
 
@@ -84,8 +83,17 @@ int main(int argc, char *argv[])
     NumericalPoint quantile = copula.computeQuantile( 0.5 );
     fullprint << "Quantile=" << quantile << std::endl;
     fullprint << "CDF(quantile)=" << copula.computeCDF(quantile) << std::endl;
+    // Covariance and correlation
+    CovarianceMatrix covariance = copula.getCovariance();
+    fullprint << "covariance=" << covariance << std::endl;
+    CorrelationMatrix correlation = copula.getCorrelation();
+    fullprint << "correlation=" << correlation << std::endl;
+    CorrelationMatrix spearman = copula.getSpearmanCorrelation();
+    fullprint << "spearman=" << spearman << std::endl;
+    CorrelationMatrix kendall = copula.getKendallTau();
+    fullprint << "kendall=" << kendall << std::endl;
     // Extract the marginals
-    for (UnsignedLong i = 0; i < dim; i++)
+    for (UnsignedInteger i = 0; i < dim; i++)
     {
       Copula margin(copula.getMarginal(i));
       fullprint << "margin=" << margin << std::endl;
