@@ -3,7 +3,7 @@
  *  @file  t_GeneralizedParetoFactory_std.cxx
  *  @brief The test file of class GeneralizedPareto for standard methods
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -39,11 +39,11 @@ int main(int argc, char *argv[])
     xi[0] = -0.75;
     xi[1] = 0.0;
     xi[2] = 0.75;
-    UnsignedLong size(10000);
+    UnsignedInteger size(10000);
     CovarianceMatrix covariance;
     GeneralizedParetoFactory factory;
     GeneralizedPareto distribution;
-    for (UnsignedLong i = 0; i < 3; ++i)
+    for (UnsignedInteger i = 0; i < 3; ++i)
     {
       distribution = GeneralizedPareto(2.5, xi[i]);
       NumericalSample sample(distribution.getSample(size));
