@@ -3,7 +3,7 @@
  *  @file  t_KPermutationsDistribution_std.cxx
  *  @brief The test file of class KPermutationsDistribution for standard methods
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -30,11 +30,7 @@ using namespace OT::Test;
 class TestObject : public KPermutationsDistribution
 {
 public:
-  explicit TestObject() : KPermutationsDistribution(5, 12) {}
-  explicit TestObject(const String & name) : KPermutationsDistribution(5, 12)
-  {
-    setName(name);
-  }
+  TestObject() : KPermutationsDistribution(5, 12) {}
   virtual ~TestObject() {}
 };
 
@@ -49,9 +45,6 @@ int main(int argc, char *argv[])
     // Test basic functionnalities
     checkClassWithClassName<TestObject>();
 
-    // Test some extra functionnalities
-    checkNameFeature<TestObject>();
-
     // Instanciate one distribution object
     KPermutationsDistribution distribution(5, 12);
     fullprint << "Distribution " << distribution << std::endl;
@@ -68,7 +61,7 @@ int main(int argc, char *argv[])
     fullprint << "oneRealization=" << oneRealization << std::endl;
 
     // Test for sampling
-    UnsignedLong size = 10000;
+    UnsignedInteger size = 10000;
     NumericalSample oneSample = distribution.getSample( size );
     fullprint << "oneSample first=" << oneSample[0] << " last=" << oneSample[size - 1] << std::endl;
     fullprint << "mean=" << oneSample.computeMean() << std::endl;
