@@ -3,7 +3,7 @@
  *  @file  t_KPermutations_std.cxx
  *  @brief The test file of class KPermutations for standard methods
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -34,8 +34,8 @@ int main(int argc, char *argv[])
 
   try
   {
-    UnsignedLong k(3);
-    UnsignedLong n(5);
+    UnsignedInteger k(3);
+    UnsignedInteger n(5);
     {
       // Classical permutations
       KPermutations myGenerator(k);
