@@ -3,7 +3,7 @@
  *  @file  t_NonStationaryCovarianceModelFactory_std.cxx
  *  @brief The test file of class NonStationaryCovarianceModelFactory
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -35,21 +35,23 @@ int main(int argc, char *argv[])
 {
   TESTPREAMBLE;
   OStream fullprint(std::cout);
+  setRandomGenerator();
 
   try
   {
     // Dimension of the input model
     // Size of the TimeGrid
-    UnsignedLong size(10);
-    UnsignedLong dimension(1);
+    UnsignedInteger size(10);
+    UnsignedInteger dimension(1);
+    UnsignedInteger spatialDimension(1);
     RegularGrid timeGrid(0.0, 0.1, size);
     NumericalPoint amplitude(dimension, 1.0);
     NumericalPoint scale(dimension, 1.0);
-    ExponentialModel model(amplitude, scale);
+    ExponentialModel model(spatialDimension, amplitude, scale);
     TemporalNormalProcess myProcess(model, timeGrid);
 
     // Create a Process sample of size N
-    UnsignedLong N(10000);
+    UnsignedInteger N(10000);
     ProcessSample sample(myProcess.getSample(N));
 
     // Factory initiate - No arguments
@@ -60,10 +62,10 @@ int main(int argc, char *argv[])
 
     // Get the frequency grid of the model
     RegularGrid myTimeGrid(myCovarianceModel.getTimeGrid());
-    for (UnsignedLong i = 0 ; i < size ; ++i)
+    for (UnsignedInteger i = 0 ; i < size ; ++i)
     {
       const NumericalScalar t(timeGrid.getValue(i));
-      for (UnsignedLong j = 0 ; j < size ; ++j)
+      for (UnsignedInteger j = 0 ; j < size ; ++j)
       {
         const NumericalScalar s(timeGrid.getValue(j));
         const NumericalScalar estimatedValue(myCovarianceModel(t, s)(0, 0));
