@@ -3,7 +3,7 @@
  *  @file  t_NumericalMathFunction_aggregated.cxx
  *  @brief The test file of class NumericalMathFunction for aggregation
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -61,7 +61,7 @@ int main(int argc, char *argv[])
     fullprint << "Gradient at " << inPoint << "=" << myFunction.gradient(inPoint) << std::endl;
     PlatformInfo::SetNumericalPrecision(5);
     fullprint << "Hessian at " << inPoint << "=" << myFunction.hessian(inPoint) << std::endl;
-    for (UnsignedLong i = 0; i < myFunction.getOutputDimension(); ++i)
+    for (UnsignedInteger i = 0; i < myFunction.getOutputDimension(); ++i)
     {
       fullprint << "Marginal " << i << "=" << myFunction.getMarginal(i) << std::endl;
     }
