@@ -3,7 +3,7 @@
  *  @file  t_NumericalMathFunction_draw.cxx
  *  @brief The test file of class NumericalMathFunction for drawing methods
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -31,7 +31,6 @@ int main(int argc, char *argv[])
 {
   TESTPREAMBLE;
   OStream fullprint(std::cout);
-
   try
   {
     // Simplified interfaces
@@ -42,8 +41,6 @@ int main(int argc, char *argv[])
       Graph graph(f.draw(-1.2, 1.2, 32));
       fullprint << "graph=" << graph << std::endl;
       graph.draw("NMFDraw1D");
-      fullprint << "postscript=" << graph.getPostscript() << std::endl;
-      fullprint << "bitmap=" << graph.getBitmap() << std::endl;
     }
     // Second, try 2D drawing
     {
@@ -58,8 +55,6 @@ int main(int argc, char *argv[])
       Graph graph(f.draw(NumericalPoint(2, -10.0), NumericalPoint(2, 10.0), Indices(2, 21)));
       fullprint << "graph=" << graph << std::endl;
       graph.draw("NMFDraw2D");
-      fullprint << "postscript=" << graph.getPostscript() << std::endl;
-      fullprint << "bitmap=" << graph.getBitmap() << std::endl;
     }
     // Full interfaces
     {
@@ -82,14 +77,10 @@ int main(int argc, char *argv[])
       Graph graph1D(f.draw(0, 0, centralPoint, -5.0, 5.0, 32));
       fullprint << "graph1D=" << graph1D << std::endl;
       graph1D.draw("NMFDraw1DFull");
-      fullprint << "postscript=" << graph1D.getPostscript() << std::endl;
-      fullprint << "bitmap=" << graph1D.getBitmap() << std::endl;
       // Second output as a function of second and third inputs around central point
       Graph graph2D(f.draw(1, 2, 1, centralPoint, NumericalPoint(2, -5.0), NumericalPoint(2, 5.0), Indices(2, 21)));
       fullprint << "graph1D=" << graph2D << std::endl;
       graph2D.draw("NMFDraw2DFull");
-      fullprint << "postscript=" << graph2D.getPostscript() << std::endl;
-      fullprint << "bitmap=" << graph2D.getBitmap() << std::endl;
     }
   }
   catch (TestFailed & ex)
