@@ -3,7 +3,7 @@
  * @file  t_PiecewiseHermiteEvaluationImplementation_std.cxx
  * @brief The test file of class PiecewiseHermiteEvaluationImplementation for standard methods
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -35,12 +35,12 @@ int main(int argc, char *argv[])
   try
   {
     NumericalMathFunction ref("x", "sin(x)");
-    UnsignedLong size(12);
+    UnsignedInteger size(12);
     NumericalPoint locations(size);
     NumericalPoint values(size);
     NumericalPoint derivatives(size);
     // Build locations/values/derivatives with non-increasing locations
-    for (UnsignedLong i = 0; i < size; ++i)
+    for (UnsignedInteger i = 0; i < size; ++i)
     {
       locations[i] = 10.0 * i * i / (size - 1.0) / (size - 1.0);
       values[i] = ref(NumericalPoint(1, locations[i]))[0];
@@ -49,7 +49,7 @@ int main(int argc, char *argv[])
     PiecewiseHermiteEvaluationImplementation evaluation(locations, values, derivatives);
     fullprint << "evaluation=" << evaluation << std::endl;
     // Check the values
-    for (UnsignedLong i = 0; i < 2 * size; ++i)
+    for (UnsignedInteger i = 0; i < 2 * size; ++i)
     {
       NumericalPoint x(1, -1.0 + 12.0 * i / (2.0 * size - 1.0));
       fullprint << "f(" << x[0] << ")=" << evaluation(x) << ", ref=" << ref(x) << std::endl;
