@@ -3,7 +3,7 @@
  *  @file  t_PosteriorDistribution_std.cxx
  *  @brief The test file of class PosteriorDistribution for standard methods
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -39,9 +39,7 @@ int main(int argc, char *argv[])
     // Test basic functionnalities
     //checkClassWithClassName<TestObject>();
 
-    // Test some extra functionnalities
-    //checkNameFeature<TestObject>();
-    UnsignedLong observationsSize(5);
+    UnsignedInteger observationsSize(5);
     // Create a collection of distribution
     Normal conditionedDistribution;
     Collection< Distribution > conditioningDistributionCollection;
@@ -66,14 +64,14 @@ int main(int argc, char *argv[])
       atoms.add( Uniform( 1.0, 2.0) );
       conditioningDistributionCollection.add(ComposedDistribution(atoms));
     }
-    for (UnsignedLong i = 0; i < conditioningDistributionCollection.getSize(); ++i)
+    for (UnsignedInteger i = 0; i < conditioningDistributionCollection.getSize(); ++i)
     {
       fullprint << "conditioning distribution=" << conditioningDistributionCollection[i].__str__() << std::endl;
       Distribution observationsDistribution(conditionedDistribution);
       observationsDistribution.setParametersCollection(conditioningDistributionCollection[i].getMean());
       NumericalSample observations(observationsDistribution.getSample(observationsSize));
       PosteriorDistribution distribution(ConditionalDistribution(conditionedDistribution, conditioningDistributionCollection[i]), observations);
-      UnsignedLong dim(distribution.getDimension());
+      UnsignedInteger dim(distribution.getDimension());
       fullprint << "Distribution " << distribution << std::endl;
       std::cout << "Distribution " << distribution << std::endl;
       fullprint << "range=" << distribution.getRange() << std::endl;
@@ -94,7 +92,7 @@ int main(int argc, char *argv[])
       fullprint << "oneRealization=" << oneRealization << std::endl;
 
       // Test for sampling
-      UnsignedLong size = 10;
+      UnsignedInteger size = 10;
       NumericalSample oneSample = distribution.getSample( size );
       fullprint << "oneSample=" << oneSample << std::endl;
 
@@ -119,7 +117,7 @@ int main(int argc, char *argv[])
       fullprint << "Quantile=" << quantile << std::endl;
       fullprint << "CDF(quantile)=" << distribution.computeCDF(quantile) << std::endl;
       // Extract the marginals
-      for (UnsignedLong i = 0; i < dim; i++)
+      for (UnsignedInteger i = 0; i < dim; i++)
       {
         Distribution margin(distribution.getMarginal(i));
         fullprint << "margin=" << margin << std::endl;
