@@ -3,7 +3,7 @@
  *  @file  t_RandomWalkMetropolisHastings_std.cxx
  *  @brief The test file of class RandomWalkMetropolisHastings
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -34,13 +34,14 @@ int main(int argc, char *argv[])
 {
   TESTPREAMBLE;
   OStream fullprint(std::cout);
+  setRandomGenerator();
 
   try
   {
 
     // observations
-    UnsignedLong size = 10;
-    Normal realDist(31., 1.2);
+    UnsignedInteger size = 10;
+    Normal realDist(31.0, 1.2);
 
     NumericalSample data(realDist.getSample(size));
 
@@ -83,7 +84,7 @@ int main(int argc, char *argv[])
     std::cout << "randomVector=" << randomVector << std::endl;
 
     // get the dimension
-    UnsignedLong dimension = randomVector.getDimension();
+    UnsignedInteger dimension = randomVector.getDimension();
     std::cout << "dimension=" << dimension << std::endl;
 
     // get a realization
