@@ -3,7 +3,7 @@
  *  @file  t_RandomWalkMetropolisHastings_regression.cxx
  *  @brief The test file of class RandomWalkMetropolisHastings
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -27,40 +27,24 @@
 
 using namespace OT;
 using namespace OT::Test;
-typedef ComposedDistribution::DistributionCollection DistributionCollection;
+typedef ComposedDistribution::DistributionCollection                DistributionCollection;
 typedef RandomWalkMetropolisHastings::CalibrationStrategyCollection CalibrationStrategyCollection;
 
-NumericalScalar prec = 1.0;
-
-NumericalMathFunction buildPoly(const NumericalPoint &p)
-{
-  const UnsignedLong d = p.getDimension();
-  NumericalPoint center(d);
-  NumericalPoint constant(2);
-  Matrix linear(2, d);
-  for ( UnsignedLong j = 0; j < d; ++ j )
-  {
-    linear(0, j) = p[j]; // z=p1*x1+p2*x2+p3*x3
-  }
-  constant[1] = 1.0; // sigma
-  return LinearNumericalMathFunction( center, constant, linear );
-}
-
-
 int main(int argc, char *argv[])
 {
   TESTPREAMBLE;
   OStream fullprint(std::cout);
+  setRandomGenerator();
 
   try
   {
 
     // observations
-    UnsignedLong chainDim = 3;
-    UnsignedLong obsDim = 1;
-    //UnsignedLong outputDim = 1;
+    UnsignedInteger chainDim = 3;
+    UnsignedInteger obsDim = 1;
+    //UnsignedInteger outputDim = 1;
 
-    UnsignedLong obsSize = 10;
+    UnsignedInteger obsSize = 10;
 
     NumericalSample y_obs(obsSize, obsDim);
     y_obs[0][0] = -9.50794871493506;
@@ -76,47 +60,55 @@ int main(int argc, char *argv[])
     std::cout << "y_obs=" << y_obs << std::endl;
 
     NumericalSample p(obsSize, chainDim);
-    for (UnsignedLong i = 0; i < obsSize; ++ i)
+    for (UnsignedInteger i = 0; i < obsSize; ++ i)
     {
-      for (UnsignedLong j = 0; j < chainDim; ++ j)
+      for (UnsignedInteger j = 0; j < chainDim; ++ j)
       {
-        p[i][j] = pow(-2 + 5.*i / 9., j);
+        p[i][j] = pow(-2 + 5.*i / 9., 1.0 * j);
       }
     }
     std::cout << "p=" << p << std::endl;
 
-    NumericalMathFunction::NumericalMathFunctionCollection modelCollection;
-    for (UnsignedLong i = 0; i < obsSize; ++ i)
-    {
-      modelCollection.add(buildPoly(p[i]));
-    }
-    NumericalMathFunction model(modelCollection);
+    Description fullVariables(0);
+    fullVariables.add("p1");
+    fullVariables.add("p2");
+    fullVariables.add("p3");
+    fullVariables.add("x1");
+    fullVariables.add("x2");
+    fullVariables.add("x3");
+    Description formulas(0);
+    formulas.add("p1*x1+p2*x2+p3*x3");
+    formulas.add("1.0");
+    NumericalMathFunction fullModel(fullVariables, formulas);
+    Indices parametersPosition(chainDim);
+    parametersPosition.fill();
+    NumericalMathFunction model(fullModel, parametersPosition);
 
     // calibration parameters
     CalibrationStrategyCollection calibrationColl(chainDim);
 
     // proposal distribution
     DistributionCollection proposalColl;
-    for (UnsignedLong i = 0; i < chainDim; ++ i)
+    for (UnsignedInteger i = 0; i < chainDim; ++ i)
     {
-      proposalColl.add(Uniform(-1., 1.));
+      proposalColl.add(Uniform(-1.0, 1.0));
     }
 
     // prior distribution
-    NumericalPoint sigma0(chainDim, 10.);// sigma0= (10.,10.,10.)
+    NumericalPoint sigma0(chainDim, 10.0);// sigma0= (10.,10.,10.)
     CorrelationMatrix Q0(chainDim);// precision matrix
     CorrelationMatrix Q0_inv(chainDim);// covariance matrix
-    for ( UnsignedLong i = 0; i < chainDim; ++ i )
+    for ( UnsignedInteger i = 0; i < chainDim; ++ i )
     {
       Q0_inv (i, i) = sigma0[i] * sigma0[i];
       Q0(i, i) = 1.0 / Q0_inv (i, i);
     }
     std::cout << "Q0=" << Q0 << std::endl;
-    NumericalPoint mu0(chainDim, 0.0);// mu0 = (0.,0.,0.)
+    NumericalPoint mu0(chainDim, 0.0);// mu0 = (0.0, 0.0, 0.0)
     Distribution prior(Normal( mu0, Q0_inv ) );// x0 ~ N(mu0, sigma0)
     std::cout << "x~" << prior << std::endl;
 
-    // start from te mean x0=(0.,0.,0.)
+    // start from te mean x0=(0.0, 0.0, 0.0)
     std::cout << "x0=" << mu0 << std::endl;
 
     // conditional distribution y~N(z, 1.0)
@@ -124,7 +116,13 @@ int main(int argc, char *argv[])
     std::cout << "y~" << conditional << std::endl;
 
     // create a metropolis-hastings sampler
-    RandomWalkMetropolisHastings sampler(prior, conditional, model, y_obs, mu0, proposalColl);
+    // prior=a distribution of dimension chainDim, the a priori distribution of the parameter
+    // conditional=a distribution of dimension 1, the observation error on the output
+    // model=the link between the parameter and the output
+    // y_obs=noisy observations of the output
+    // mu0=starting point of the chain
+    // proposalColl=
+    RandomWalkMetropolisHastings sampler(prior, conditional, model, p, y_obs, mu0, proposalColl);
     sampler.setVerbose(true);
     sampler.setThinning(4);
     sampler.setBurnIn(2000);
@@ -135,7 +133,7 @@ int main(int argc, char *argv[])
     std::cout << "y1=" << realization << std::endl;
 
     // try to generate a sample
-    UnsignedLong sampleSize = 1000;
+    UnsignedInteger sampleSize = 1000;
     NumericalSample sample(sampler.getSample(sampleSize));
 
     NumericalPoint x_mu(sample.computeMean());
@@ -147,32 +145,32 @@ int main(int argc, char *argv[])
     // compute covariance
     CovarianceMatrix x_cov(sample.computeCovariance());
     Matrix P(obsSize, chainDim);
-    for (UnsignedLong i = 0; i < obsSize; ++ i)
+    for (UnsignedInteger i = 0; i < obsSize; ++ i)
     {
-      for (UnsignedLong j = 0; j < chainDim; ++ j)
+      for (UnsignedInteger j = 0; j < chainDim; ++ j)
       {
         P(i, j) = p[i][j];
       }
     }
     Matrix Qn(P.transpose()*P + Q0);
     SquareMatrix Qn_inv(chainDim);
-    for ( UnsignedLong j = 0; j < chainDim; ++j )
+    for ( UnsignedInteger j = 0; j < chainDim; ++j )
     {
       NumericalPoint I_j(chainDim);
       I_j[j] = 1.0;
       NumericalPoint Qn_inv_j(Qn.solveLinearSystem(I_j));
-      for ( UnsignedLong i = 0; i < chainDim; ++i )
+      for ( UnsignedInteger i = 0; i < chainDim; ++i )
       {
         Qn_inv(i, j) = Qn_inv_j[i];
       }
     }
     NumericalPoint sigma_exp(chainDim);
-    for ( UnsignedLong i = 0; i < chainDim; ++i )
+    for ( UnsignedInteger i = 0; i < chainDim; ++i )
     {
       sigma_exp[i] = sqrt(Qn_inv(i, i));
     }
     NumericalPoint y_vec(obsSize);
-    for ( UnsignedLong i = 0; i < obsSize; ++i )
+    for ( UnsignedInteger i = 0; i < obsSize; ++i )
     {
       y_vec[i] = y_obs[i][0];
     }
