@@ -3,7 +3,7 @@
  *  @file  t_RandomWalkMetropolisHastings_std.cxx
  *  @brief The test file of class RandomWalkMetropolisHastings
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -34,10 +34,11 @@ int main(int argc, char *argv[])
 {
   TESTPREAMBLE;
   OStream fullprint(std::cout);
+  setRandomGenerator();
 
   try
   {
-    // this analitycal example is taken from "Bayesian Modeling Using WinBUGS" - Ioannis Ntzoufras
+    // this analytical example is taken from "Bayesian Modeling Using WinBUGS" - Ioannis Ntzoufras
     // 1.5.3: Inference for the mean or normal data with known variance
 
     // Variable of interest: Y=N(mu, sigma)
@@ -48,8 +49,8 @@ int main(int argc, char *argv[])
 
 
     // observations
-    UnsignedLong size = 10;
-    Normal realDist(31., 1.2);
+    UnsignedInteger size = 10;
+    Normal realDist(31.0, 1.2);
 
     NumericalSample data(realDist.getSample(size));
 
@@ -64,7 +65,7 @@ int main(int argc, char *argv[])
     proposalColl.add(std_proposal);
 
     // prior distribution
-    NumericalScalar mu0 = 25.;
+    NumericalScalar mu0 = 25.0;
 
     NumericalPoint sigma0s;
     sigma0s.add(0.1);
@@ -73,10 +74,10 @@ int main(int argc, char *argv[])
 
 
     // play with the variance of the prior:
-    // if the prior variance is low (information concernig the mu parameter is strong)
+    // if the prior variance is low (information concerning the mu parameter is strong)
     // then the posterior mean will be equal to the prior mean
     // if large, the the posterior distribution is equivalent to the distribution of the sample mean
-    for ( UnsignedLong i = 0; i < sigma0s.getDimension(); ++ i )
+    for ( UnsignedInteger i = 0; i < sigma0s.getDimension(); ++ i )
     {
 
       NumericalScalar sigma0 = sigma0s[i];
