@@ -3,7 +3,7 @@
  *  @file  t_Secant_std.cxx
  *  @brief The test file of class Secant for standard methods
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -52,9 +52,9 @@ int main(int argc, char *argv[])
     NumericalPoint initialState(2);
     initialState[0] =  1.0;
     initialState[1] = -1.0;
-    UnsignedLong nt(100);
+    UnsignedInteger nt(100);
     NumericalPoint timeGrid(nt);
-    for (UnsignedLong i = 0; i < nt; ++i)
+    for (UnsignedInteger i = 0; i < nt; ++i)
     {
       timeGrid[i] = pow(i, 2.0) / pow(nt - 1.0, 2.0);
     }
