@@ -3,7 +3,7 @@
  *  @file  t_SklarCopula_std.cxx
  *  @brief The test file of class SklarCopula for standard methods
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -36,10 +36,10 @@ int main(int argc, char *argv[])
   try
   {
     // Instanciate one distribution object
-    UnsignedLong dim(3);
+    UnsignedInteger dim(3);
 
     CorrelationMatrix R = IdentityMatrix(dim);
-    for(UnsignedLong i = 0; i < dim - 1; i++) R(i, i + 1) = 0.25;
+    for(UnsignedInteger i = 0; i < dim - 1; i++) R(i, i + 1) = 0.25;
     NumericalPoint mean(dim);
     mean[0] = 1.0;
     mean[1] = 2.0;
@@ -55,8 +55,6 @@ int main(int argc, char *argv[])
     std::cout << "Copula " << copula << std::endl;
     fullprint << "Mean      =" << copula.getMean() << std::endl;
     fullprint << "Mean (ref)=" << copulaRef.getMean() << std::endl;
-    fullprint << "Covariance      =" << copula.getCovariance() << std::endl;
-    fullprint << "Covariance (ref)=" << copulaRef.getCovariance() << std::endl;
     // Is this copula an elliptical distribution?
     fullprint << "Elliptical distribution= " << (copula.isElliptical() ? "true" : "false") << std::endl;
 
@@ -71,7 +69,7 @@ int main(int argc, char *argv[])
     fullprint << "oneRealization=" << oneRealization << std::endl;
 
     // Test for sampling
-    UnsignedLong size = 10;
+    UnsignedInteger size = 10;
     NumericalSample oneSample = copula.getSample( size );
     fullprint << "oneSample=" << oneSample << std::endl;
 
@@ -104,8 +102,18 @@ int main(int argc, char *argv[])
     fullprint << "Quantile=" << quantile << std::endl;
     fullprint << "QuantileRef=" << quantileRef << std::endl;
     fullprint << "CDF(quantile)=" << copula.computeCDF(quantile) << std::endl;
+    // Covariance and correlation
+    CovarianceMatrix covariance = copula.getCovariance();
+    fullprint << "covariance=" << covariance << std::endl;
+    CorrelationMatrix correlation = copula.getCorrelation();
+    fullprint << "correlation=" << correlation << std::endl;
+    CorrelationMatrix spearman = copula.getSpearmanCorrelation();
+    fullprint << "spearman=" << spearman << std::endl;
+    CorrelationMatrix kendall = copula.getKendallTau();
+    fullprint << "kendall=" << kendall << std::endl;
+
     // Extract the marginals
-    for (UnsignedLong i = 0; i < dim; i++)
+    for (UnsignedInteger i = 0; i < dim; i++)
     {
       Copula margin(copula.getMarginal(i));
       Copula marginRef(copulaRef.getMarginal(i));
