@@ -3,7 +3,7 @@
  *  @file  t_Study_saveload.cxx
  *  @brief The test file of class Study for standard methods
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -55,6 +55,7 @@ int main(int argc, char *argv[])
 {
   TESTPREAMBLE;
   OStream fullprint(std::cout);
+  setRandomGenerator();
 
   const char fileName[] = "myStudy.xml";
 
@@ -122,7 +123,7 @@ int main(int argc, char *argv[])
     Staircase staircase;
     {
       // Instanciate one distribution object
-      UnsignedLong dim(1);
+      UnsignedInteger dim(1);
       NumericalPoint meanPoint(dim, 1.0);
       meanPoint[0] = 0.5;
       NumericalPoint sigma(dim, 1.0);
@@ -136,8 +137,8 @@ int main(int argc, char *argv[])
       Normal distribution2(meanPoint, sigma, R);
 
       // Test for sampling
-      UnsignedLong size = 2000;
-      UnsignedLong nPoints = 20;
+      UnsignedInteger size = 2000;
+      UnsignedInteger nPoints = 20;
       NumericalSample sample1(distribution1.getSample( size ));
       NumericalSample sample2(distribution2.getSample( size ));
 
@@ -148,14 +149,14 @@ int main(int argc, char *argv[])
       NumericalScalar count1;
       NumericalScalar count2;
 
-      for(UnsignedLong i = 0; i < nPoints; i++)
+      for(UnsignedInteger i = 0; i < nPoints; i++)
       {
         cursor1[0] = 13.*i / nPoints - 6.5;
         count1 = 0;
         cursor2[0] = 24.*i / nPoints - 13.5;
         count2 = 0;
 
-        for(UnsignedLong j = 0; j < size; j++)
+        for(UnsignedInteger j = 0; j < size; j++)
         {
           if(sample1[j][0] < cursor1[0]) count1++;
           if(sample2[j][0] < cursor2[0]) count2++;
@@ -181,56 +182,85 @@ int main(int argc, char *argv[])
     simulationResult.setName("simulationResult");
     study.add("simulationResult", simulationResult);
 
-    // Create a Beta distribution
+    Arcsine arcsine(5.2, 11.6);
+    study.add("arcsine", arcsine);
+
     Beta beta(3.0, 5.0, -1.0, 4.0);
     study.add("beta", beta);
 
-    // Create an Exponential distribution
+    Chi chi(1.5);
+    study.add("chi", chi);
+
+    ChiSquare chiSquare(1.5);
+    study.add("chiSquare", chiSquare);
+
+    UnsignedInteger dim = 2;
+    NumericalPoint theta(dim + 1);
+    for (UnsignedInteger i = 0; i <= dim; i++) theta[i] = 1.0 + (i + 1.0) / 4.0;
+    Dirichlet dirichlet(theta);
+    study.add("dirichlet", dirichlet);
+
     Exponential exponential(3.0, -2.0);
     study.add("exponential", exponential);
 
-    // Create a Gamma distribution
+    FisherSnedecor fisherSnedecor(5.5, 10.5);
+    study.add("fisherSnedecor", fisherSnedecor);
+
     Gamma gamma(1.5, 3.0, -2.0);
     study.add("gamma", gamma);
 
-    // Create a Geometric distribution
+    GeneralizedPareto generalizedPareto(1.5, -0.2);
+    study.add("generalizedPareto", generalizedPareto);
+
     Geometric geometric(0.15);
     study.add("geometric", geometric);
 
-    // Create a IndependentCopula distribution
+    Gumbel gumbel(2.0, -0.5);
+    study.add("gumbel", gumbel);
+
     IndependentCopula independentCopula(5);
     study.add("independentCopula", independentCopula);
 
-    // Create a KernelSmoothing algorithm */
+    InverseNormal inverseNormal(0.5, 2.0);
+    study.add("inverseNormal", inverseNormal);
+
     KernelSmoothing kernelSmoothing;
     kernelSmoothing.build(independentCopula.getSample(20));
     study.add("kernelSmoothing", kernelSmoothing);
 
-    // Create a Logistic distribution
+    Laplace laplace(1.0 / 1.5, 0.5);
+    study.add("laplace", laplace);
+
     Logistic logistic(0.5, 1.5);
     study.add("logistic", logistic);
 
-    // Create a LogNormal distribution
     LogNormal logNormal(0.5, 1.5, -1.0);
     study.add("logNormal", logNormal);
 
-    // Create an InverseNormal
-    InverseNormal inverseNormal(0.5, 2.0);
-    study.add("inverseNormal", inverseNormal);
+    LogUniform logUniform(-0.5, 1.5);
+    study.add("logUniform", logUniform);
+
+    MeixnerDistribution meixnerDistribution(1.5, 0.5, 2.5, -0.5);
+    study.add("meixnerDistribution", meixnerDistribution);
+
+    Rayleigh rayleigh(2.5, -0.5);
+    study.add("rayleigh", rayleigh);
+
+    Rice rice(5.0, 4.0);
+    study.add("rice", rice);
 
-    // Create a Student
     Student student(5.0, -0.5, 2.0);
     study.add("student", student);
 
-    // Create a Triangular
+    Trapezoidal trapezoidal(1.0, 1.2, 3.0, 14.0);
+    study.add("trapezoidal", trapezoidal);
+
     Triangular triangular(-0.5, 1.5, 2.5);
     study.add("triangular", triangular);
 
-    // Create a TruncatedDistribution
     TruncatedDistribution truncatedDistribution(Normal(2.0, 1.5), 1.0, 4.0);
     study.add("truncatedDistribution", truncatedDistribution);
 
-    // Create a TruncatedNormal
     TruncatedNormal truncatedNormal(0.5, 3.0, -2.0, 2.0);
     study.add("truncatedNormal", truncatedNormal);
 
@@ -342,6 +372,16 @@ int main(int argc, char *argv[])
     sqp.setMaximumConstraintError(1.0e-10);
     study.add("sqp", sqp);
 
+    // Create a Cobyla algorithm
+    Cobyla cobyla;
+    study.add("cobyla", cobyla);
+    cobyla.setLevelValue(3.0);
+    cobyla.setMaximumIterationsNumber(100);
+    cobyla.setMaximumAbsoluteError(1.0e-10);
+    cobyla.setMaximumRelativeError(1.0e-10);
+    cobyla.setMaximumResidualError(1.0e-10);
+    cobyla.setMaximumConstraintError(1.0e-10);
+
     // Create a TNC algorithm
     TNC tnc;
     {
@@ -381,7 +421,8 @@ int main(int argc, char *argv[])
       formResult = FORMResult(NumericalPoint(2, 1.0), event, false);
       formResult.setName("formResult");
       formResult.getImportanceFactors();
-      formResult.getImportanceFactors(true);
+      formResult.getImportanceFactors(AnalyticalResult::CLASSICAL);
+      formResult.getImportanceFactors(AnalyticalResult::PHYSICAL);
       formResult.getEventProbabilitySensitivity();
 
       sormResult = SORMResult (NumericalPoint(2, 1.0), event, false);
@@ -399,7 +440,7 @@ int main(int argc, char *argv[])
     // Create an ARMACoefficients
     ARMACoefficients armaCoefficients;
     {
-      const UnsignedLong dim(2);
+      const UnsignedInteger dim(2);
       SquareMatrix squareMatrix1(dim);
       squareMatrix1(0, 0) = 1.;
       squareMatrix1(1, 0) = 2.;
@@ -409,7 +450,7 @@ int main(int argc, char *argv[])
       SquareMatrix squareMatrix2 = squareMatrix1.operator * (s) ;
       double t = 1.5;
       SquareMatrix squareMatrix3 = squareMatrix1.operator / (t) ;
-      const UnsignedLong size(3);
+      const UnsignedInteger size(3);
       armaCoefficients = ARMACoefficients(size, dim);
       armaCoefficients[0] = squareMatrix1 ;
       armaCoefficients[1] = squareMatrix2 ;
@@ -420,18 +461,18 @@ int main(int argc, char *argv[])
     // Create an ARMAState
     ARMAState armaState;
     {
-      const UnsignedLong dim(1);
-      const UnsignedLong p(6);
-      const UnsignedLong q(4);
+      const UnsignedInteger dim(1);
+      const UnsignedInteger p(6);
+      const UnsignedInteger q(4);
       NumericalSample valuesX(p, dim);
       NumericalSample valuesEpsilon(q, dim);
-      for(UnsignedLong j = 0 ; j < dim ; ++j)
+      for(UnsignedInteger j = 0 ; j < dim ; ++j)
       {
-        for(UnsignedLong i = 0 ; i < p ; ++i)
+        for(UnsignedInteger i = 0 ; i < p ; ++i)
         {
           valuesX[i][j] = 2.0 * i + 3.0 * j + 1.0;
         }
-        for(UnsignedLong i = 0 ; i < q ; ++i)
+        for(UnsignedInteger i = 0 ; i < q ; ++i)
         {
           valuesEpsilon[i][j] = RandomGenerator::Generate() ;
         }
@@ -443,7 +484,7 @@ int main(int argc, char *argv[])
     // Create a RegularGrid
     RegularGrid regularGrid;
     {
-      const UnsignedLong points(8);
+      const UnsignedInteger points(8);
       const NumericalScalar tMin(0.0);
       const NumericalScalar tStep(1.0 / (points - 1));
       regularGrid = RegularGrid(tMin, tStep, points);
@@ -467,8 +508,8 @@ int main(int argc, char *argv[])
     // Create an WhittleFactory
     WhittleFactory whittleFactory;
     {
-      const UnsignedLong p(1);
-      const UnsignedLong q(2);
+      const UnsignedInteger p(1);
+      const UnsignedInteger q(2);
       whittleFactory = WhittleFactory( p, q );
     }
     study.add("whittleFactory", whittleFactory);
@@ -476,7 +517,7 @@ int main(int argc, char *argv[])
     // Create an ARMA
     ARMA arma;
     {
-      const UnsignedLong dim(2);
+      const UnsignedInteger dim(2);
       SquareMatrix squareMatrix1(dim);
       squareMatrix1(0, 0) = 0.2 ;
       squareMatrix1(1, 0) = 0.3 ;
@@ -487,8 +528,8 @@ int main(int argc, char *argv[])
       squareMatrix2(1, 0) = 0.0;
       squareMatrix2(0, 1) = 0.0;
       squareMatrix2(1, 1) = 0.5;
-      const UnsignedLong p(1);
-      const UnsignedLong q(1);
+      const UnsignedInteger p(1);
+      const UnsignedInteger q(1);
       ARMACoefficients coefficientsP(p, dim);
       coefficientsP[0] = squareMatrix1 ;
       ARMACoefficients coefficientsQ(q, dim);
@@ -501,10 +542,10 @@ int main(int argc, char *argv[])
     Basis basis;
     BasisSequence basisSequence;
     {
-      const UnsignedLong dimension = 3;
+      const UnsignedInteger dimension = 3;
       Description input;
       Description output[dimension];
-      for ( UnsignedLong j = 0; j < dimension; ++ j )
+      for ( UnsignedInteger j = 0; j < dimension; ++ j )
       {
         OSS oss;
         oss << "x" << j;
@@ -515,7 +556,7 @@ int main(int argc, char *argv[])
       Collection<NumericalMathFunction> coll;
       Indices cumulBasis;
       Indices partialBasis[dimension];
-      for ( UnsignedLong j = 0; j < dimension; ++ j )
+      for ( UnsignedInteger j = 0; j < dimension; ++ j )
       {
         NumericalMathFunction ei(input, output[j], output[j]);
         coll.add(ei);
@@ -525,7 +566,7 @@ int main(int argc, char *argv[])
 
       basis = Basis(coll);
       basisSequence = BasisSequence(basis);
-      for ( UnsignedLong j = 0; j < dimension; ++ j )
+      for ( UnsignedInteger j = 0; j < dimension; ++ j )
       {
         basisSequence.add(partialBasis[j]);
       }
@@ -547,11 +588,11 @@ int main(int argc, char *argv[])
     // Create a BoundConstrainedAlgorithmImplementationResult
     BoundConstrainedAlgorithmImplementationResult boundConstrainedAlgorithmImplementationResult;
     {
-      UnsignedLong dim(4);
+      UnsignedInteger dim(4);
       NumericalPoint optimizer(dim, 1.0);
       NumericalScalar optimalValue(5.0);
       BoundConstrainedAlgorithmImplementationResult::OptimizationProblem optimization(BoundConstrainedAlgorithmImplementationResult::MINIMIZATION);
-      UnsignedLong evaluationsNumber(10);
+      UnsignedInteger evaluationsNumber(10);
       NumericalScalar absoluteError(1e-6);
       NumericalScalar relativeError(1e-7);
       NumericalScalar objectiveError(1e-8);
@@ -573,12 +614,13 @@ int main(int argc, char *argv[])
     // Create an ExponentialModel
     ExponentialModel exponentialModel;
     {
-      const UnsignedLong defaultDimension(1);
-      const UnsignedLong highDimension(3);
+      const UnsignedInteger defaultDimension(1);
+      const UnsignedInteger highDimension(3);
+      const UnsignedInteger spatialDimension(1);
       NumericalPoint amplitude(highDimension, 1.0);
       NumericalPoint scale(highDimension, 1.0);
       CorrelationMatrix spatialCorrelation(highDimension);
-      for (UnsignedLong index = 0 ; index < highDimension; ++index)
+      for (UnsignedInteger index = 0 ; index < highDimension; ++index)
       {
         amplitude[index] = 1.0 ;
         scale[index] = (index + 1.0) / defaultDimension ;
@@ -586,7 +628,7 @@ int main(int argc, char *argv[])
       }
       cauchyModel = CauchyModel (amplitude, scale, spatialCorrelation);
       exponentialCauchy = ExponentialCauchy (amplitude, scale, spatialCorrelation);
-      exponentialModel = ExponentialModel (amplitude, scale, spatialCorrelation);
+      exponentialModel = ExponentialModel (spatialDimension, amplitude, scale, spatialCorrelation);
     }
     study.add("cauchyModel", cauchyModel);
     study.add("exponentialCauchy", exponentialCauchy);
@@ -603,10 +645,10 @@ int main(int argc, char *argv[])
     // Create an  UserDefinedSpectralModel
     UserDefinedSpectralModel userDefinedSpectralModel;
     {
-      UnsignedLong size(5);
+      UnsignedInteger size(5);
       UserDefinedSpectralModel::HermitianMatrixCollection dspCollection(size);
       RegularGrid frequencyGrid(0.0, 2.0 / size, size);
-      for (UnsignedLong i = 0; i < size; ++i)
+      for (UnsignedInteger i = 0; i < size; ++i)
         dspCollection[i] = cauchyModel(frequencyGrid.getValue(i));
       userDefinedSpectralModel = UserDefinedSpectralModel(frequencyGrid, dspCollection);
     }
@@ -621,7 +663,7 @@ int main(int argc, char *argv[])
     {
       NumericalScalar Tmin(0.0);
       NumericalScalar deltaT(0.1);
-      UnsignedLong steps(11);
+      UnsignedInteger steps(11);
       RegularGrid timeGrid(Tmin, deltaT, steps);
       ARMA myARMAProcess;
       myARMAProcess.setTimeGrid(timeGrid);
@@ -636,7 +678,7 @@ int main(int argc, char *argv[])
     // Create a Domain Object
     Domain domain;
     {
-      UnsignedLong dim(2);
+      UnsignedInteger dim(2);
       NumericalPoint a(dim, -1.0);
       NumericalPoint b(dim, 2.0);
       domain  = Interval(a, b);
@@ -646,11 +688,11 @@ int main(int argc, char *argv[])
     // Create an EventDomainImplementation
     EventDomainImplementation eventDomainImplementation;
     {
-      UnsignedLong dim(2);
+      UnsignedInteger dim(2);
       Normal distribution(dim);
       RandomVector X(distribution);
       Description inVars(dim);
-      for (UnsignedLong i = 0; i < dim; ++i) inVars[i] = OSS() << "x" << i;
+      for (UnsignedInteger i = 0; i < dim; ++i) inVars[i] = OSS() << "x" << i;
       NumericalMathFunction model(inVars, inVars);
       CompositeRandomVector Y(model, X);
       Interval domain(dim);
@@ -661,7 +703,7 @@ int main(int argc, char *argv[])
     // Create an EventProcess
     EventProcess eventProcess;
     {
-      UnsignedLong dim(2);
+      UnsignedInteger dim(2);
       Normal distribution(dim);
 
       WhiteNoise X(distribution);
@@ -675,7 +717,7 @@ int main(int argc, char *argv[])
     // Create a BlendedStep
     BlendedStep blendedStep;
     {
-      UnsignedLong dimension = 2;
+      UnsignedInteger dimension = 2;
       NumericalPoint epsilon( dimension, 1e-5 );
       constantStep = ConstantStep(epsilon);
       NumericalPoint eta( dimension, 1.0 );
@@ -684,17 +726,13 @@ int main(int argc, char *argv[])
     study.add("constantStep", constantStep);
     study.add("blendedStep", blendedStep);
 
-    // Create a FisherSnedecor
-    FisherSnedecor fisherSnedecor(5.5, 10.5);
-    study.add("fisherSnedecor", fisherSnedecor);
-
     // Create a FunctionalBasisProcess
     FunctionalBasisProcess functionalBasisProcess;
     {
-      UnsignedLong basisDimension(10);
+      UnsignedInteger basisDimension(10);
       Basis basis(basisDimension);
       Collection<Distribution> coefficients(basisDimension);
-      for (UnsignedLong i = 0; i < basisDimension; ++i)
+      for (UnsignedInteger i = 0; i < basisDimension; ++i)
       {
         basis[i] = NumericalMathFunction("x", String(OSS() << "sin(" << i << "*x)"));
         coefficients[i] = Normal(0.0, (1.0 + i));
@@ -776,14 +814,10 @@ int main(int argc, char *argv[])
     lhs.setMaximumCoefficientOfVariation(0.1);
     study.add("lhs", lhs);
 
-    // Create a LogUniform
-    LogUniform logUniform(-0.5, 1.5);
-    study.add("logUniform", logUniform);
-
     // Create a Mixture
     Mixture mixture;
     {
-      UnsignedLong dimension(3);
+      UnsignedInteger dimension(3);
       NumericalPoint meanPoint(dimension, 1.0);
       meanPoint[0] = 0.5;
       meanPoint[1] = -0.5;
@@ -791,7 +825,7 @@ int main(int argc, char *argv[])
       sigma[0] = 2.0;
       sigma[1] = 3.0;
       CorrelationMatrix R(dimension);
-      for (UnsignedLong i = 1; i < dimension; i++)
+      for (UnsignedInteger i = 1; i < dimension; i++)
       {
         R(i, i - 1) = 0.5;
       }
@@ -854,7 +888,7 @@ int main(int argc, char *argv[])
     // Create a StrongMaximumTest
     StrongMaximumTest strongMaximumTest;
     {
-      UnsignedLong dim(analytical.getInputDimension());
+      UnsignedInteger dim(analytical.getInputDimension());
       double seuil(10);
       NumericalPoint designPoint(dim, 0.0);
       double C(0.3);
@@ -894,27 +928,28 @@ int main(int argc, char *argv[])
     UserDefinedCovarianceModel userDefinedCovarianceModel;
     UserDefinedStationaryCovarianceModel userDefinedStationaryCovarianceModel;
     {
-      const UnsignedLong dimension(1);
+      const UnsignedInteger dimension(1);
+      const UnsignedInteger spatialDimension(1);
       NumericalPoint amplitude(dimension);
       NumericalPoint scale(dimension);
       CorrelationMatrix spatialCorrelation(dimension);
-      for (UnsignedLong index = 0 ; index < dimension; ++index)
+      for (UnsignedInteger index = 0 ; index < dimension; ++index)
       {
         amplitude[index] = 1.0 ;
         scale[index] = (index + 1.0) / dimension ;
         if (index > 0) spatialCorrelation(index, index - 1) = 1.0 / index;
       }
-      ExponentialModel referenceModel(amplitude, scale, spatialCorrelation);
-      UnsignedLong size(20);
+      ExponentialModel referenceModel(spatialDimension, amplitude, scale, spatialCorrelation);
+      UnsignedInteger size(20);
       RegularGrid timeGrid(0.0, 0.1, size);
       {
-        const UnsignedLong collectionSize(size * (size + 1) / 2);
+        const UnsignedInteger collectionSize(size * (size + 1) / 2);
         UserDefinedCovarianceModel::CovarianceMatrixCollection covarianceCollection(collectionSize);
-        UnsignedLong k(0);
-        for (UnsignedLong i = 0; i < timeGrid.getN(); ++i)
+        UnsignedInteger k(0);
+        for (UnsignedInteger i = 0; i < timeGrid.getN(); ++i)
         {
           const NumericalScalar t(timeGrid.getValue(i));
-          for (UnsignedLong j = i; j < timeGrid.getN(); ++j)
+          for (UnsignedInteger j = i; j < timeGrid.getN(); ++j)
           {
             const NumericalScalar s(timeGrid.getValue(j));
             covarianceCollection[k] = referenceModel(t, s);
@@ -925,7 +960,7 @@ int main(int argc, char *argv[])
       }
       {
         UserDefinedStationaryCovarianceModel::CovarianceMatrixCollection covarianceCollection(size);
-        for (UnsignedLong i = 0; i < size; ++i)
+        for (UnsignedInteger i = 0; i < size; ++i)
         {
           const NumericalScalar t(timeGrid.getValue(i));
           covarianceCollection[i] = referenceModel(0, t);
@@ -984,6 +1019,7 @@ int main(int argc, char *argv[])
     compare<NearestPointAlgorithm::Result >( nearestPointAlgorithmResult, study2, "nearestPointAlgorithmResult");
     compare<AbdoRackwitz >( abdoRackwitz, study2 );
     compare<SQP >( sqp, study2, "sqp" );
+    compare<Cobyla >( cobyla, study2, "cobyla" );
     compare<TNC >( tnc, study2, "tnc" );
     compare<BoundConstrainedAlgorithmImplementationResult >( boundConstrainedAlgorithmImplementationResult, study2 );
 
@@ -992,26 +1028,37 @@ int main(int argc, char *argv[])
     compare<StandardEvent >( standardEvent, study2 );
 
     // Distribution
+    compare<Arcsine >( arcsine, study2 );
     compare<Beta >( beta, study2 );
+    compare<Burr >( burr, study2 );
+    compare<Chi >( chi, study2 );
+    compare<ChiSquare >( chiSquare, study2 );
+    compare<Dirichlet >( dirichlet, study2 );
+    compare<ComposedDistribution >( composedDistribution, study2 );
     compare<Exponential >( exponential, study2 );
+    compare<FisherSnedecor >( fisherSnedecor, study2 );
     compare<Gamma >( gamma, study2 );
+    compare<GeneralizedPareto >( generalizedPareto, study2 );
     compare<Geometric >( geometric, study2 );
+    compare<Gumbel >( gumbel, study2 );
     compare<IndependentCopula >( independentCopula, study2 );
+    compare<InverseNormal>(inverseNormal, study2 );
     compare<KernelSmoothing >( kernelSmoothing, study2 );
+    compare<Laplace >( laplace, study2 );
     compare<Logistic >( logistic, study2 );
     compare<LogNormal >( logNormal, study2 );
-    compare<NormalCopula >( normalCopula, study2 );
-    compare<Uniform >( uniform, study2 );
-    compare<ComposedDistribution >( composedDistribution, study2 );
-    compare<Burr >( burr, study2 );
-    compare<FisherSnedecor >( fisherSnedecor, study2 );
-    compare<InverseNormal>(inverseNormal, study2 );
     compare<LogUniform>(logUniform, study2 );
+    compare<MeixnerDistribution>(meixnerDistribution, study2 );
     compare<Mixture>(mixture, study2 );
+    compare<NormalCopula >( normalCopula, study2 );
+    compare<Rayleigh>(rayleigh, study2 );
+    compare<Rice>(rice, study2 );
     compare<Student>(student, study2 );
+    compare<Trapezoidal>(trapezoidal, study2 );
     compare<Triangular>(triangular, study2 );
     compare<TruncatedDistribution>(truncatedDistribution, study2 );
     compare<TruncatedNormal>(truncatedNormal, study2 );
+    compare<Uniform >( uniform, study2 );
     compare<UserDefined>(userDefined, study2 );
     compare<Weibull>(weibull, study2 );
 
