@@ -3,7 +3,7 @@
  *  @file  t_UserDefinedCovarianceModel_std.cxx
  *  @brief The test file of class UserDefinedCovarianceModel
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -43,8 +43,10 @@ int main(int argc, char *argv[])
     fullprint << "myDefautModel = " << myDefautModel << std::endl;
 
     // Default dimension parameter to evaluate the model
-    const UnsignedLong dimension(1);
+    const UnsignedInteger dimension(1);
 
+    // Spatial dimension of the model
+    UnsignedInteger spatialDimension(1);
     /* Amplitude values */
     NumericalPoint amplitude(dimension);
 
@@ -52,7 +54,7 @@ int main(int argc, char *argv[])
     NumericalPoint scale(dimension);
     /* Spatial correclation */
     CorrelationMatrix spatialCorrelation(dimension);
-    for (UnsignedLong index = 0 ; index < dimension; ++index)
+    for (UnsignedInteger index = 0 ; index < dimension; ++index)
     {
       // constant amplitude
       amplitude[index] = 1.0 ;
@@ -61,21 +63,21 @@ int main(int argc, char *argv[])
     }
 
     /* Sample a CauchyModel */
-    ExponentialModel referenceModel(amplitude, scale, spatialCorrelation);
+    ExponentialModel referenceModel(spatialDimension, amplitude, scale, spatialCorrelation);
 
-    UnsignedLong size(20);
+    UnsignedInteger size(20);
     RegularGrid timeGrid(0.0, 0.1, size);
-    const UnsignedLong collectionSize(size * (size + 1) / 2);
+    const UnsignedInteger collectionSize(size * (size + 1) / 2);
     UserDefinedCovarianceModel::CovarianceMatrixCollection covarianceCollection(collectionSize);
-    UnsignedLong k(0);
-    for (UnsignedLong i = 0; i < timeGrid.getN(); ++i)
+    UnsignedInteger k(0);
+    for (UnsignedInteger i = 0; i < timeGrid.getN(); ++i)
     {
       const NumericalScalar t(timeGrid.getValue(i));
-      for (UnsignedLong j = i; j < timeGrid.getN(); ++j)
+      for (UnsignedInteger j = 0; j <= i; ++j)
       {
         const NumericalScalar s(timeGrid.getValue(j));
         covarianceCollection[k] = referenceModel(t, s);
-        k++;
+        ++k;
       }
     }
 
@@ -84,10 +86,10 @@ int main(int argc, char *argv[])
     fullprint << "myModel= " << myModel << std::endl;
 
     /* Sample the UserDefinedCovarianceModel */
-    for (UnsignedLong i = 0; i < timeGrid.getN(); ++i)
+    for (UnsignedInteger i = 0; i < timeGrid.getN(); ++i)
     {
       const NumericalScalar t(timeGrid.getValue(i));
-      for (UnsignedLong j = i; j < timeGrid.getN(); ++j)
+      for (UnsignedInteger j = i; j < timeGrid.getN(); ++j)
       {
         const NumericalScalar s(timeGrid.getValue(j));
         // We look for cov(s,t) ==> when adding to the collection, we compute cov(t,s)
@@ -95,7 +97,7 @@ int main(int argc, char *argv[])
         fullprint << "myModel = " << myModel(s, t)(0, 0) << ", referenceModel = " << referenceModel(s, t)(0 , 0) << std::endl;
       }
     }
-
+    fullprint << "myModel.discretize()=" << myModel.discretize(timeGrid) << std::endl;
   }
   catch (TestFailed & ex)
   {
