@@ -3,7 +3,7 @@
  *  @file  t_UserDefinedStationaryCovarianceModel_std.cxx
  *  @brief The test file of class UserDefinedStationaryCovarianceModel
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -43,7 +43,10 @@ int main(int argc, char *argv[])
     fullprint << "myDefautModel = " << myDefautModel << std::endl;
 
     // Default dimension parameter to evaluate the model
-    const UnsignedLong dimension(1);
+    const UnsignedInteger dimension(1);
+
+    // Spatial dimension of the model
+    const UnsignedInteger spatialDimension(1);
 
     /* Amplitude values */
     NumericalPoint amplitude(dimension);
@@ -52,7 +55,7 @@ int main(int argc, char *argv[])
     NumericalPoint scale(dimension);
     /* Spatial correclation */
     CorrelationMatrix spatialCorrelation(dimension);
-    for (UnsignedLong index = 0 ; index < dimension; ++index)
+    for (UnsignedInteger index = 0 ; index < dimension; ++index)
     {
       // constant amplitude
       amplitude[index] = 1.0 ;
@@ -61,12 +64,12 @@ int main(int argc, char *argv[])
     }
 
     /* Sample a CauchyModel */
-    ExponentialModel referenceModel(amplitude, scale, spatialCorrelation);
+    ExponentialModel referenceModel(spatialDimension, amplitude, scale, spatialCorrelation);
 
-    UnsignedLong size(20);
+    UnsignedInteger size(20);
     RegularGrid timeGrid(0.0, 0.1, size);
     UserDefinedStationaryCovarianceModel::CovarianceMatrixCollection covarianceCollection(size);
-    for (UnsignedLong i = 0; i < size; ++i)
+    for (UnsignedInteger i = 0; i < size; ++i)
     {
       const NumericalScalar t(timeGrid.getValue(i));
       covarianceCollection[i] = referenceModel(0, t);
@@ -77,7 +80,7 @@ int main(int argc, char *argv[])
     fullprint << "myModel= " << myModel << std::endl;
 
     /* Sample the UserDefinedStationaryCovarianceModel */
-    for (UnsignedLong i = 0; i < timeGrid.getN(); ++i)
+    for (UnsignedInteger i = 0; i < timeGrid.getN(); ++i)
     {
       const NumericalScalar t(timeGrid.getValue(i));
       // We look for cov(t) ==> when adding to the collection, we compute cov(t)
