@@ -3,7 +3,7 @@
  *  @file  t_Waarts_saddle.cxx
  *  @brief The test file for Waarts saddle surface
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -53,7 +53,7 @@ int main(int argc, char *argv[])
 
     NumericalMathFunction EtatLimite(inputFunction, outputFunction, formulas);
 
-    UnsignedLong dim = EtatLimite.getInputDimension();
+    UnsignedInteger dim = EtatLimite.getInputDimension();
     fullprint << dim << std::endl;
 
     //   #########################################################################################################;
@@ -230,23 +230,23 @@ int main(int argc, char *argv[])
     fullprint <<  "event probability =" << PfC << std::endl;
     fullprint <<  "generalized reliability index =" << Beta_generalizedC << std::endl;
     fullprint <<  "************************************************************************************************" << std::endl;
-    for (UnsignedLong i = 0; i < u_starC.getDimension(); i++)
+    for (UnsignedInteger i = 0; i < u_starC.getDimension(); i++)
       fullprint << "standard space design point =" << u_starC[i] << std::endl;
     fullprint <<  "************************************************************************************************" << std::endl;
-    for (UnsignedLong i = 0; i < x_starC.getDimension(); i++)
+    for (UnsignedInteger i = 0; i < x_starC.getDimension(); i++)
       fullprint << "physical space design point =" << x_starC[i] << std::endl;
     fullprint <<  "************************************************************************************************" << std::endl;
     fullprint << "is standard point origin in failure space? " << PtC << std::endl;
     fullprint <<  "************************************************************************************************" << std::endl;
-    for (UnsignedLong i = 0; i < gammaC.getDimension(); i++)
+    for (UnsignedInteger i = 0; i < gammaC.getDimension(); i++)
       fullprint << "importance factors =" << gammaC[i] << std::endl;
-    for (UnsignedLong i = 0; i < gammaCC.getDimension(); i++)
+    for (UnsignedInteger i = 0; i < gammaCC.getDimension(); i++)
       fullprint << "importance factors (classical)=" << gammaCC[i] << std::endl;
     fullprint <<  "************************************************************************************************" << std::endl;
     fullprint <<  "Hasofer reliability index =" << beta_hasoferC << std::endl;
     fullprint <<  "************************************************************************************************" << std::endl;
-    for (UnsignedLong i = 0; i < SensitivityAR.getSize(); ++i)
-      for (UnsignedLong j = 0; j < SensitivityAR[i].getDimension(); ++j)
+    for (UnsignedInteger i = 0; i < SensitivityAR.getSize(); ++i)
+      for (UnsignedInteger j = 0; j < SensitivityAR[i].getDimension(); ++j)
         fullprint <<  "Pf sensitivity =" << i << j << SensitivityC[i][j] << std::endl;
     fullprint <<  "************************************************************************************************" << std::endl;
     fullprint <<  "" << std::endl;
@@ -256,23 +256,23 @@ int main(int argc, char *argv[])
     fullprint <<  "event probability =" << PfAR << std::endl;
     fullprint <<  "generalized reliability index =" << Beta_generalizedAR << std::endl;
     fullprint <<  "************************************************************************************************" << std::endl;
-    for (UnsignedLong i = 0; i < u_starAR.getDimension(); i++)
+    for (UnsignedInteger i = 0; i < u_starAR.getDimension(); i++)
       fullprint << "standard space design point =" << u_starAR[i] << std::endl;
     fullprint <<  "************************************************************************************************" << std::endl;
-    for (UnsignedLong i = 0; i < x_starAR.getDimension(); i++)
+    for (UnsignedInteger i = 0; i < x_starAR.getDimension(); i++)
       fullprint << "physical space design point =" << x_starAR[i] << std::endl;
     fullprint <<  "************************************************************************************************" << std::endl;
     fullprint << "is standard point origin in failure space? " << PtAR << std::endl;
     fullprint <<  "************************************************************************************************" << std::endl;
-    for (UnsignedLong i = 0; i < gammaAR.getDimension(); i++)
+    for (UnsignedInteger i = 0; i < gammaAR.getDimension(); i++)
       fullprint << "importance factors =" << gammaAR[i] << std::endl;
-    for (UnsignedLong i = 0; i < gammaCAR.getDimension(); i++)
+    for (UnsignedInteger i = 0; i < gammaCAR.getDimension(); i++)
       fullprint << "importance factors (classical)=" << gammaCAR[i] << std::endl;
     fullprint <<  "************************************************************************************************" << std::endl;
     fullprint <<  "Hasofer reliability index =" << beta_hasoferAR << std::endl;
     fullprint <<  "************************************************************************************************" << std::endl;
-    for (UnsignedLong i = 0; i < SensitivityAR.getSize(); ++i)
-      for (UnsignedLong j = 0; j < SensitivityAR[i].getDimension(); ++j)
+    for (UnsignedInteger i = 0; i < SensitivityAR.getSize(); ++i)
+      for (UnsignedInteger j = 0; j < SensitivityAR[i].getDimension(); ++j)
         fullprint <<  "Pf sensitivity =" << i << j << SensitivityAR[i][j] << std::endl;
     fullprint <<  "************************************************************************************************" << std::endl;
     fullprint <<  "" << std::endl;
@@ -286,21 +286,21 @@ int main(int argc, char *argv[])
     fullprint <<  "Tvedt event probability =" << PFTvedtC2 << std::endl;
     fullprint <<  "Tvedt generalized reliability index =" << BetaTvedtC2 << std::endl;
     fullprint <<  "************************************************************************************************" << std::endl;
-    for (UnsignedLong i = 0; i < CurvC2.getDimension(); i++)
+    for (UnsignedInteger i = 0; i < CurvC2.getDimension(); i++)
       fullprint << "sorted curvatures =" << clean(CurvC2[i]) << std::endl;
     fullprint <<  "************************************************************************************************" << std::endl;
-    for (UnsignedLong i = 0; i < u_starC2.getDimension(); i++)
+    for (UnsignedInteger i = 0; i < u_starC2.getDimension(); i++)
       fullprint << "standard space design point =" << u_starC2[i] << std::endl;
     fullprint <<  "************************************************************************************************" << std::endl;
-    for (UnsignedLong i = 0; i < x_starC2.getDimension(); i++)
+    for (UnsignedInteger i = 0; i < x_starC2.getDimension(); i++)
       fullprint << "physical space design point =" << x_starC2[i] << std::endl;
     fullprint <<  "************************************************************************************************" << std::endl;
     fullprint <<  "************************************************************************************************" << std::endl;
     fullprint << "is standard point origin in failure space? " << PtC2 << std::endl;
     fullprint <<  "************************************************************************************************" << std::endl;
-    for (UnsignedLong i = 0; i < gammaC2.getDimension(); i++)
+    for (UnsignedInteger i = 0; i < gammaC2.getDimension(); i++)
       fullprint << "importance factors =" << gammaC2[i] << std::endl;
-    for (UnsignedLong i = 0; i < gammaCC2.getDimension(); i++)
+    for (UnsignedInteger i = 0; i < gammaCC2.getDimension(); i++)
       fullprint << "importance factors (classical)=" << gammaCC2[i] << std::endl;
     fullprint <<  "************************************************************************************************" << std::endl;
     fullprint <<  "Hasofer reliability index =" << beta_hasoferC2 << std::endl;
@@ -316,21 +316,21 @@ int main(int argc, char *argv[])
     fullprint <<  "Tvedt event probability =" << PFTvedtAR2 << std::endl;
     fullprint <<  "Tvedt generalized reliability index =" << BetaTvedtAR2 << std::endl;
     fullprint <<  "************************************************************************************************" << std::endl;
-    for (UnsignedLong i = 0; i < CurvAR2.getDimension(); i++)
+    for (UnsignedInteger i = 0; i < CurvAR2.getDimension(); i++)
       fullprint << "sorted curvatures =" << clean(CurvAR2[i]) << std::endl;
     fullprint <<  "************************************************************************************************" << std::endl;
-    for (UnsignedLong i = 0; i < u_starAR2.getDimension(); i++)
+    for (UnsignedInteger i = 0; i < u_starAR2.getDimension(); i++)
       fullprint << "standard space design point =" << u_starAR2[i] << std::endl;
     fullprint <<  "************************************************************************************************" << std::endl;
-    for (UnsignedLong i = 0; i < x_starAR2.getDimension(); i++)
+    for (UnsignedInteger i = 0; i < x_starAR2.getDimension(); i++)
       fullprint << "physical space design point =" << x_starAR2[i] << std::endl;
     fullprint <<  "************************************************************************************************" << std::endl;
     fullprint <<  "************************************************************************************************" << std::endl;
     fullprint << "is standard point origin in failure space? " << PtAR2 << std::endl;
     fullprint <<  "************************************************************************************************" << std::endl;
-    for (UnsignedLong i = 0; i < gammaAR2.getDimension(); i++)
+    for (UnsignedInteger i = 0; i < gammaAR2.getDimension(); i++)
       fullprint << "importance factors =" << gammaAR2[i] << std::endl;
-    for (UnsignedLong i = 0; i < gammaCAR2.getDimension(); i++)
+    for (UnsignedInteger i = 0; i < gammaCAR2.getDimension(); i++)
       fullprint << "importance factors (classical)=" << gammaCAR2[i] << std::endl;
     fullprint <<  "************************************************************************************************" << std::endl;
     fullprint <<  "Hasofer reliability index =" << beta_hasoferAR2 << std::endl;
