@@ -3,7 +3,7 @@
  * @file  PythonRandomVectorImplementation.cxx
  * @brief This class binds a Python object to an Open TURNS' RandomVector
  *
- *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+ *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -64,18 +64,18 @@ PythonRandomVectorImplementation::PythonRandomVectorImplementation(PyObject * py
 
   setName( checkAndConvert< _PyString_, String >(name.get()) );
 
-  const UnsignedLong dimension  = getDimension();
+  const UnsignedInteger dimension  = getDimension();
   Description description(dimension);
   ScopedPyObjectPointer desc(PyObject_CallMethod ( pyObj_,
                              const_cast<char *>( "getDescription" ),
                              const_cast<char *>( "()" ) ));
   if ( ( desc.get() != NULL )
        && PySequence_Check( desc.get() )
-       && ( PySequence_Size( desc.get() ) == dimension ) )
+       && ( PySequence_Size( desc.get() ) == static_cast<SignedInteger>(dimension) ) )
   {
     description = convert< _PySequence_, Description >( desc.get() );
   }
-  else for (UnsignedLong i = 0; i < dimension; ++i) description[i] = (OSS() << "x" << i);
+  else for (UnsignedInteger i = 0; i < dimension; ++i) description[i] = (OSS() << "x" << i);
   setDescription(description);
 }
 
@@ -129,7 +129,7 @@ String PythonRandomVectorImplementation::__str__(const String & offset) const
 
 
 /* Accessor for input point dimension */
-UnsignedLong PythonRandomVectorImplementation::getDimension() const
+UnsignedInteger PythonRandomVectorImplementation::getDimension() const
 {
   ScopedPyObjectPointer result(PyObject_CallMethod ( pyObj_,
                                const_cast<char *>( "getDimension" ),
@@ -139,7 +139,7 @@ UnsignedLong PythonRandomVectorImplementation::getDimension() const
     handleException();
   }
 
-  UnsignedLong dim = convert< _PyInt_, UnsignedLong >( result.get() );
+  UnsignedInteger dim = convert< _PyInt_, UnsignedInteger >( result.get() );
   return dim;
 }
 
@@ -158,14 +158,14 @@ NumericalPoint PythonRandomVectorImplementation::getRealization() const
 
 
 /* Numerical sample accessor */
-NumericalSample PythonRandomVectorImplementation::getSample(const UnsignedLong size) const
+NumericalSample PythonRandomVectorImplementation::getSample(const UnsignedInteger size) const
 {
   NumericalSample sample;
 
   if ( PyObject_HasAttrString( pyObj_, const_cast<char *>("getSample") ) )
   {
     ScopedPyObjectPointer methodName(convert< String, _PyString_>( "getSample" ));
-    ScopedPyObjectPointer sizeArg(convert< UnsignedLong, _PyInt_ >(size));
+    ScopedPyObjectPointer sizeArg(convert< UnsignedInteger, _PyInt_ >(size));
     ScopedPyObjectPointer result(PyObject_CallMethodObjArgs( pyObj_,
                                  methodName.get(),
                                  sizeArg.get(), NULL ));
