@@ -5,7 +5,7 @@
 # @brief Gives functions that help coupling against external code,
 #   .i.e: manipulate template file.
 #
-# Copyright (C) 2005-2014 Airbus-EDF-Phimeca
+# Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
 #
 # This library is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -24,6 +24,15 @@
 # @date   2012-08-28
 #
 
+"""
+External code helpers.
+
+Provides several functions to ease wrapping of an external code:
+- replace: allows to replace a value in template file
+- execute: run an external code
+- get: parse values from a result file
+"""
+
 import re
 import shutil
 import os
@@ -38,11 +47,7 @@ default_encoding = sys.getdefaultencoding()
 
 
 def check_param(obj, obj_type):
-    """
-    private func
-    assert obj as type obj_type
-    """
-
+    """Assert obj as type obj_type."""
     # int casts into long ; long is deprecated
     if (obj_type == int) and (sys.version_info[0] < 3):
         obj_type = long
@@ -57,51 +62,59 @@ def check_param(obj, obj_type):
 
 def replace(infile, outfile, tokens, values, formats=None, encoding=default_encoding):
     """
-    replace tokens on a file
+    Replace tokens in a file.
 
-    parameters:
-    infile:  template file that will be parsed
-    outfile: file that will received the template parsed. If equal to "None" or
-             to "infile", the result file will be moved to infile.
-    tokens:  a list of regex that will be replaced
-    values:  list of values (can be string, float, ...) that will replace
-             the tokens. The list must have the same size as tokens.
-    formats: (optional) a list of formats for printing the values in the
-             parsed files at tokens locations.
-    encoding: (optional) file encoding, see http://docs.python.org/2/library/codecs.html#codec-base-classes
+    Parameters
+    ----------
+    infile : str, template file that will be parsed
+    outfile : str, file that will received the template parsed.
+        If equal to "None" or to "infile", the result file will be moved to infile.
+    tokens : list, regexes that will be replaced
+    values : list, values (can be string, float, ...) that will replace
+        the tokens. The list must have the same size as tokens.
+    formats : list, optional, a list of formats for printing the values in the
+        parsed files at tokens locations.
+    encoding : str, optional, file encoding
+        see http://docs.python.org/2/library/codecs.html#codec-base-classes
 
-    exception:
-        AssertionError: parameters badly set
-        EOFError: a token has not been found
+    Raises
+    ------
+    AssertionError
+        parameters badly set
+    EOFError
+        a token has not been found
 
-    example:
-        # template.in = 'E=@E_VAR F=-PF-')
-        replace(infile="template.in",
-                outfile="prgm_data.in",
-                tokens=["@E_VAR", ".PF."],
-                values=[1.4, "5"])
-        # => prgm_data.in = 'E=1.4 F=5')
+    Examples
+    --------
+    template.in = 'E=@E_VAR F=-PF-')
 
-        # be careful with overlapping tokens !!
-        # template.in = 'E=@E EE=@EE')
-        replace(infile="template.in",
-                outfile="prgm_data.in",
-                tokens=["@E", "@EE"],
-                values=[1, 2])
-        # => raise exception!! -> @EE token not found!
-        # (this is due to the first pass with token "@E" that modify
-        # prgm_data.in like this : 'E=1 EE=1E')
+    >>> # replace(infile="template.in",
+    >>> #    outfile="prgm_data.in",
+    >>> #    tokens=["@E_VAR", ".PF."],
+    >>> #    values=[1.4, "5"])
+    >>> # prgm_data.in = 'E=1.4 F=5'
 
-        # deals with overlapping tokens : put longest tokens first
-        # template.in = 'E=@E EE=@EE')
-        replace(infile="template.in",
-                outfile="prgm_data.in",
-                tokens=["@EE", "@E"],
-                values=[2, 1])
-        # => prgm_data.in = 'E=1 EE=2')
+    be careful with overlapping tokens !!
+    template.in = 'E=@E EE=@EE')
 
+    >>> # replace(infile="template.in",
+    >>> #    outfile="prgm_data.in",
+    >>> #    tokens=["@E", "@EE"],
+    >>> #    values=[1, 2])
+
+    It raises exception!! -> @EE token not found!
+    (this is due to the first pass with token "@E" that modify
+    prgm_data.in like this : 'E=1 EE=1E')
+
+    deals with overlapping tokens : put longest tokens first
+    template.in = 'E=@E EE=@EE')
+
+    >>> # replace(infile="template.in",
+    >>> #    outfile="prgm_data.in",
+    >>> #    tokens=["@EE", "@E"],
+    >>> #    values=[2, 1])
+    >>> # prgm_data.in = 'E=1 EE=2')
     """
-
     if len(tokens) != len(values):
         raise AssertionError("Error: tokens size is != values size!")
     check_param(tokens, list)
@@ -157,31 +170,40 @@ def execute(cmd, workdir=None, is_shell=False, shell_exe=None, hide_win=True,
     """
     Launch an external processus in a clean way.
 
-    cmd: a string representing the command.
+    Parameters
+    ----------
+    cmd : str, representing the command.
         e.g.: "ls -l /home"
-    workdir: set the current directory of the executed command
-    is_shell: if set to True, the command is started in a shell (bash).
+    workdir : str, current directory of the executed command
+    is_shell : bool, if set to True, the command is started in a shell (bash).
         default: False.
-    shell_exe: path to the shell. e.g. /bin/zsh.
+    shell_exe : str, path to the shell. e.g. /bin/zsh.
         default: None -> /bin/bash.
-    hide_win: hide cmd.exe popup on windows
-    check_exit_code: if set to True: raise a RuntimeError exception if return
+    hide_win : str, hide cmd.exe popup on windows
+    check_exit_code : bool, if set to True: raise a RuntimeError exception if return
         code of process != 0
-    get_stdout: whether standard output of the command is returned
-    get_stderr: whether standard error of the command is returned
+    get_stdout : bool, whether standard output of the command is returned
+    get_stderr : bool, whether standard error of the command is returned
 
-    return:
+    Returns
+    -------
+    ret :  int
         the exit code of the command
+    stdout_data : str
         the stdout data if get_stdout parameter is set
+    stderr_data : str
         the stderr data if get_stderr parameter is set
 
-    example:
-        ret, stdout = execute('/bin/ls /bin/kill', get_stdout=True).
-        # => ret = 0, stdout = '/bin/kill'
+    Raises
+    ------
+    RuntimeError
+        could not run
 
-    exception: RuntimeError
+    Examples
+    --------
+    >>> # ret, stdout = execute('/bin/ls /bin/kill', get_stdout=True).
+    >>> ## => ret = 0, stdout = '/bin/kill'
     """
-
     # split cmd if not in a shell before passing it to os.execvp()
     if not is_shell:
         process_args = shlex.split(cmd)
@@ -192,7 +214,10 @@ def execute(cmd, workdir=None, is_shell=False, shell_exe=None, hide_win=True,
     startupinfo = None
     if hide_win and sys.platform.startswith('win'):
         startupinfo = subprocess.STARTUPINFO()
-        startupinfo.dwFlags |= subprocess.STARTF_USESHOWWINDOW
+        if hasattr(subprocess, 'STARTF_USESHOWWINDOW'):
+            startupinfo.dwFlags |= subprocess.STARTF_USESHOWWINDOW
+        else:
+            startupinfo.dwFlags |= 1
 
     stdout = None
     stderr = None
@@ -223,29 +248,35 @@ def execute(cmd, workdir=None, is_shell=False, shell_exe=None, hide_win=True,
 
 def get_regex(filename, patterns, encoding=default_encoding):
     """
-    get results from a file using regex
+    Get results from a file using regex.
 
-    filename: the file to parse
-    patterns: a list of patterns that will permit to get the values.
-        \R and \I can be used to match float and integer.
-        \s can be used to match any whitespace character (= [ \t\n\r\f\v])
-        ! \S can be used to match any non-whitespace character !
-        The value to be searched must be surrounded by '(' and ')' (see example).
-    encoding: file encoding, see http://docs.python.org/2/library/codecs.html#codec-base-classes
+    Parameters
+    ----------
+    filename : str, the file to parse
+    patterns : list, patterns that will permit to get the values
+        see https://docs.python.org/2/library/re.html for available patterns
+        The value to be searched must be surrounded by parenthesis.
+    encoding : str, file encoding
+        see http://docs.python.org/2/library/codecs.html#codec-base-classes
 
-    return: a list of values corresponding to each pattern.
+    Returns
+    -------
+    results : list, values corresponding to each pattern
         If nothing has been found, the corresponding value is set to None.
-    exception:
-        AssertionError: parameters badly set
-        EOFError: no value found
 
-    example:
-        # simple (results.out = '@E=-9.5E8')
-        Y = get_regex(filename='results.out',
-                      patterns=['@E=(\R)'])
-        # Y = [-9.5E8]
+    Raises
+    ------
+    AssertionError
+        parameters badly set
+    EOFError
+        no value found
+
+    Examples
+    --------
+    >>> ## simple (results.out = '@E=-9.5E8')
+    >>> #Y = get_regex(filename='results.out',patterns=['@E=(\R)'])
+    >>> ## Y = [-9.5E8]
     """
-
     if not isinstance(patterns, list) or len(patterns) == 0:
         raise AssertionError("error: patterns parameter badly set!")
 
@@ -283,12 +314,12 @@ def get_regex(filename, patterns, encoding=default_encoding):
 
 def get_real_from_line(line):
     """
-    private func
-
     Try to get a real value from the beginning of a text line.
 
-    return: The float value if a real (or an integer) is found. Raise an
-      exception if nothing found.
+    Returns
+    -------
+    value : float or int
+        Found value. Raise an exception if nothing found.
     """
     result = None
     # print "token=" + str(token) + ', skip_token=' + str(skip_token) + ','\
@@ -313,11 +344,14 @@ def get_real_from_line(line):
 
 def read_line(handle, seek=0, encoding=default_encoding):
     """
-    private func
+    Get next line.
 
-    get next line.
-    seek: if seek < 0: stop reading seek before the end of the file
-    encoding: file encoding, see http://docs.python.org/2/library/codecs.html#codec-base-classes
+    Parameters
+    ----------
+    seek : int
+        if seek < 0: stop reading seek before the end of the file
+    encoding : str
+        file encoding, see http://docs.python.org/2/library/codecs.html#codec-base-classes
     """
     line = handle.readline().decode(encoding)
 
@@ -346,17 +380,26 @@ def read_line(handle, seek=0, encoding=default_encoding):
 
 def get_line_col(filename, skip_line=0, skip_col=0, seek=0, encoding=default_encoding):
     """
-    skip_line: number of lines skipped
+    Get a token at specific coordinates.
+
+    Parameters
+    ----------
+    skip_line : int, number of lines skipped
         If skip_line < 0: count lines backward from the end of the file.
         Be careful: a last empty line is taken into account too!
         Default: 0: no line skipped
-    skip_col: number of columns skipped from the beginning or end of the line.
+    skip_col : int, number of columns skipped from the beginning or end of the line.
         If skip_col < 0: count col backward from the end of the line.
         Default: 0: no column skipped
-    seek: if > 0, consider the file starts at pos seek.
+    seek : int, if > 0, consider the file starts at pos seek.
         if < 0, consider the file ends at pos -seek (and NOT (end-(-seek))!).
         Default: 0: consider the whole file.
-    encoding: file encoding, see http://docs.python.org/2/library/codecs.html#codec-base-classes
+    encoding : str, file encoding
+        see http://docs.python.org/2/library/codecs.html#codec-base-classes
+
+    Returns
+    -------
+    result : float, value to retrieve
     """
     check_param(filename, str)
     check_param(skip_line, int)
@@ -433,75 +476,87 @@ def get_line_col(filename, skip_line=0, skip_col=0, seek=0, encoding=default_enc
 
 def get_value(filename, token=None, skip_token=0, skip_line=0, skip_col=0, encoding=default_encoding):
     """
-    get one result from a file using token and/or various offsets
+    Get one result from a file using token and/or various offsets.
 
     This function is optimized to be rather fast and takes low memory on human
     readable file.
 
-    filename: a file that will be parsed
-    token: a regex that will be searched. The value right after the token is
-        returned.
+    Parameters
+    ----------
+    filename : str, the file that will be parsed
+    token : str, a regex that will be searched.
+        The value right after the token is returned.
         Default: None (no token searched)
-    skip_token: the number of tokens that will be skipped before getting the
-        value. If set to != 0, the corresponding token parameter must not be
-        equal to None.
+    skip_token : int, the number of tokens that will be skipped before getting
+        the value. If set to != 0, the corresponding token parameter must
+        not be equal to None.
         If skip_tokens < 0: count tokens backward from the end of the file.
         Default: 0: no token skipped
-    skip_line: number of lines skipped from the token found.
+    skip_line : int, number of lines skipped from the token found.
         If corresponding token equal None, skip from the beginning of the file.
         If corresponding token != None, skip from the token.
         If skip_line < 0: count lines backward from the token or from the end
         of the file. Be careful: a last empty line is taken into account too.
         Default: 0: no line skipped
-    skip_col: number of columns skipped from the token found.
-        If corresponding token = None, skip words from the beginning of the line.
+    skip_col : int, number of columns skipped from the token found.
+        If corresponding token = None, skip words from the beginning
+        of the line.
         If corresponding token != None, skip words from the token.
         If skip_col < 0: count col backward from the end of the line or from
         the token.
         Default: 0: no column skipped
-    encoding: file encoding, see http://docs.python.org/2/library/codecs.html#codec-base-classes
+    encoding : str, file encoding
+        see http://docs.python.org/2/library/codecs.html#codec-base-classes
 
-    return: a real value.
+    Returns
+    -------
+    value : float
 
-    exception:
-        AssertionError: parameters badly set
-        EOFError: no value found
+    Raises
+    ------
+    AssertionError
+        parameters badly set
+    EOFError
+        no value found
 
-    examples:
-        # simple token (results.out = ' @Y1=2.6, Y2=  -6.6E56')
-        Y = coupling_tools.get_value(filename='results.out',
-                                    token='@Y1=',
-                                    )
-        # Y = 2.6
+    Examples
+    --------
+    simple token (results.out = ' @Y1=2.6, Y2=  -6.6E56')
 
-        # using token ans skip_tokens (results.out =
-                                       '@Y1=5.9 @Y1=2.6 # temperature 2')
-        Y = coupling_tools.get_value(filename='results.out',
-                                    token='@Y1=',
-                                    skip_token=1,
-                                    )
-        # Y = 2.6
+    >>> # Y = coupling_tools.get_value(filename='results.out',
+    >>> #                        token='@Y1=',
+    >>> #                        )
+    >>> # Y = 2.6
 
-        # using column & line (results.out = ' 2.6 3.5 6.8  9.0
-                                               3.6 7.5 6.9  9.8  ')
-        Y = coupling_tools.get_value(filename='results.out',
-                                    skip_line=1,
-                                    skip_col=-2,
-                                    )
-        # Y = 6.9
+    using token ans skip_tokens (results.out =
+    '@Y1=5.9 @Y1=2.6 # temperature 2')
 
-        # mix it (results.out = ' 2.6  Y1=3.5 Y1=6.8 9.0
-                                 temperatures:
-                                 88.8 99.9 # ')
-        Y = coupling_tools.get_value(filename='results.out',
-                                    token='Y1=',
-                                    skip_token=1,
-                                    skip_line=0,
-                                    skip_col=1,
-                                    )
-        # Y = 9.0
+    >>> # Y = coupling_tools.get_value(filename='results.out',
+    >>> #                        token='@Y1=',
+    >>> #                        skip_token=1,
+    >>> #                        )
+    >>> # Y = 2.6
+
+    using column & line (results.out = ' 2.6 3.5 6.8  9.0
+    3.6 7.5 6.9  9.8  ')
+    >>> # Y = coupling_tools.get_value(filename='results.out',
+    >>> #                        skip_line=1,
+    >>> #                        skip_col=-2,
+    >>> #                        )
+    >>> # Y = 6.9
+
+    mix it (results.out = ' 2.6  Y1=3.5 Y1=6.8 9.0
+    temperatures:
+    88.8 99.9 # ')
+
+    >>> # Y = coupling_tools.get_value(filename='results.out',
+    >>> #                        token='Y1=',
+    >>> #                        skip_token=1,
+    >>> #                        skip_line=0,
+    >>> #                        skip_col=1,
+    >>> #                        )
+    >>> # Y = 9.0
     """
-
     if debug:
         sys.stderr.write("get_value(token=" + str(token) +
                          ', skip_token=' + str(skip_token) +
@@ -597,9 +652,11 @@ def get_value(filename, token=None, skip_token=0, skip_line=0, skip_col=0, encod
 
 def get(filename, tokens=None, skip_tokens=None, skip_lines=None, skip_cols=None, encoding=default_encoding):
     """
-    get results from a file using token and/or various offsets
+    Get results from a file using token and/or various offsets.
 
-    filename: a file that will be parsed
+    Parameters
+    ----------
+    filename : str, the file that will be parsed
 
     Each following parameters must be a list. The first element of each list
     will be used to get the first value, the 2nd ...
@@ -610,35 +667,42 @@ def get(filename, tokens=None, skip_tokens=None, skip_lines=None, skip_cols=None
     skip_tokens:
     skip_lines:
     skip_cols:
-        see get_value() function
+    see get_value() function
 
     encoding: file encoding, see http://docs.python.org/2/library/codecs.html#codec-base-classes
 
-    return: a list of real values.
+    Returns
+    -------
+    result : list, of real values.
 
-    exception:
-        AssertionError: parameters badly set
-        EOFError: no value found
+    Raises
+    ------
+    AssertionError
+        parameters badly set
+    EOFError
+        no value found
 
-    examples:
-        # simple token (results.out = ' @Y1=2.6, Y2=  -6.6E56')
-        Y = coupling_tools.get(filename='results.out',
-                              tokens=['@Y1=', 'Y2='],
-                              )
-        # Y = [2.6, -6.6E56]
+    Examples
+    --------
+    simple token (results.out = ' @Y1=2.6, Y2=  -6.6E56')
 
-        # mix (results.out = ' 2.6  Y1=3.5 Y1=6.8 9.0
-                                 temperatures:
-                                 88.8 99.9 # ')
-        Y = coupling_tools.get(filename='results.out',
-                              tokens=['Y1=', None],
-                              skip_tokens=[1, 0],
-                              skip_lines=[0, 2],
-                              skip_cols=[1, 1],
-                              )
-        # Y = [9.0, 99.9]
+    >>> # Y = coupling_tools.get(filename='results.out',
+    >>> #                  tokens=['@Y1=', 'Y2='],
+    >>> #                  )
+    >>> # Y = [2.6, -6.6E56]
+
+    mix (results.out = ' 2.6  Y1=3.5 Y1=6.8 9.0
+    temperatures:
+    88.8 99.9 # ')
+
+    >>> # Y = coupling_tools.get(filename='results.out',
+    >>> #                  tokens=['Y1=', None],
+    >>> #                  skip_tokens=[1, 0],
+    >>> #                  skip_lines=[0, 2],
+    >>> #                  skip_cols=[1, 1],
+    >>> #                  )
+    >>> # Y = [9.0, 99.9]
     """
-
     # test parameters and determine the number of value to return
     nb_values = None
     if tokens != None:
