@@ -1,110 +1,94 @@
-#                                               -*- Python -*-
-#
-#  @file  viewer.py
-#  @brief Script to plot OpenTURNS graphs
-#
-#  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
-#
-#  This program is free software; you can redistribute it and/or
-#  it under the terms of the GNU Lesser General Public License as published by
-#  the Free Software Foundation, either version 3 of the License, or
-#  (at your option) any later version.
-#
-#  This program is distributed in the hope that it will be useful
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#  GNU Lesser General Public License for more details.
-#
-#  You should have received a copy of the GNU Lesser General Public
-#  along with this library.  If not, see <http://www.gnu.org/licenses/>.
-#
-
 """
-    OpenTURNS viewer
-    =============================
-    graph viewer using matplotlib
+Graph viewer.
 
-    Example
-    --------
-    >>> import openturns as ot
-    >>> from openturns.viewer import View
-    >>> graph = ot.Normal().drawPDF()
-    >>> view = View(graph, plot_kwargs={'color':'blue'})
-    >>> view.save('curve.png', dpi=100)
-    >>> view.show(block=False)
+Graph or Drawable viewer using matplotlib
 
+Examples
+--------
+>>> import openturns as ot
+>>> from openturns.viewer import View
+>>> graph = ot.Normal().drawPDF()
+>>> view = View(graph, plot_kwargs={'color':'blue'})
+>>> view.save('curve.png', dpi=100)
+>>> view.show(block=False)
 """
-
 import openturns as ot
 import numpy as np
 import matplotlib
-import matplotlib.pyplot as pyplot
+import matplotlib.pyplot as plt
 from distutils.version import LooseVersion
 import os
 import re
 import warnings
+import io
+import sys
 
 
 class View(object):
 
     """
-    View(graph, **kwargs)
-
-    Create the matplotlib figure.
+    Create the figure.
 
     Parameters
     ----------
-    graph:
-        An OpenTURNS Graph object, or else a Drawable object.
+    graph : :class:`~openturns.Graph, :class:`~openturns.Drawable`
+        A Graph or Drawable object.
 
-    figure:
-        The figure to draw on, as matplotlib.figure.Figure
+    figure : :class:`matplotlib.figure.Figure`
+        The figure to draw on.
 
-    axes:
-        The axes to draw on, as matplotlib.axes.Axes
+    axes : :class:`matplotlib.axes.Axes`
+        The axes to draw on.
 
-    plot_kwargs:
+    plot_kwargs : dict, optional
         Used when drawing Cloud, Curve drawables
         Passed on as matplotlib.axes.Axes.plot kwargs
 
-    axes_kwargs:
+    axes_kwargs : dict, optional
         Passed on to matplotlib.figure.Figure.add_subplot kwargs
 
-    bar_kwargs:
+    bar_kwargs : dict, optional
         Used when drawing BarPlot drawables
         Passed on to matplotlib.pyplot.bar kwargs
 
-    pie_kwargs:
+    pie_kwargs : dict, optional
         Used when drawing Pie drawables
         Passed on to matplotlib.pyplot.pie kwargs
 
-    polygon_kwargs:
+    polygon_kwargs : dict, optional
         Used when drawing Polygon drawables
         Passed on to matplotlib.patches.Polygon kwargs
 
-    contour_kwargs:
+    polygoncollection_kwargs : dict, optional
+        Used when drawing PolygonArray drawables
+        Passed on to matplotlib.collection.PolygonCollection kwargs
+
+    contour_kwargs : dict, optional
         Used when drawing Contour drawables
         Passed on to matplotlib.pyplot.contour kwargs
 
-    clabel_kwargs:
+    clabel_kwargs : dict, optional
         Used when drawing Contour drawables
         Passed on to matplotlib.pyplot.clabel kwargs
 
-    step_kwargs:
+    step_kwargs : dict, optional
         Used when drawing Staircase drawables
         Passed on to matplotlib.pyplot.step kwargs
 
-    text_kwargs:
+    text_kwargs : dict, optional
         Used when drawing Pairs drawables
         Passed on to matplotlib.axes.Axes.text kwargs
 
-    legend_kwargs:
+    legend_kwargs : dict, optional
         Passed on to matplotlib.axes.Axes.legend kwargs
+
+    add_legend : bool, optional
+        Adds a legend if True. Default is True.
     """
 
-    # check that the argument is a dictionnary
     @staticmethod
     def CheckDict(arg):
+        """Check that the argument is a python dictionary."""
         result = arg
         if arg is None:
             result = dict()
@@ -112,7 +96,13 @@ class View(object):
             raise TypeError('Argument is not a dict')
         return result
 
-    # constructor
+    @staticmethod
+    def ToUnicode(s):
+        """Convert to unicode if necessary."""
+        if isinstance(s, bytes):
+            s = s.decode('utf8')
+        return s
+
     def __init__(self,
                  graph,
                  figure=None,
@@ -122,17 +112,19 @@ class View(object):
                  bar_kwargs=None,
                  pie_kwargs=None,
                  polygon_kwargs=None,
+                 polygoncollection_kwargs=None,
                  contour_kwargs=None,
                  step_kwargs=None,
                  clabel_kwargs=None,
                  text_kwargs=None,
                  legend_kwargs=None,
+                 add_legend=True,
                  **kwargs):
 
         # prevent Qt from stopping the interpreter, see matplotlib PR #1905
         if LooseVersion(matplotlib.__version__) < LooseVersion('1.3'):
             # check for DISPLAY env variable on X11 build of Qt
-            if pyplot.get_backend().startswith('Qt4'):
+            if plt.get_backend().startswith('Qt4'):
                 from matplotlib.backends.qt4_compat import QtGui
                 if hasattr(QtGui, 'QX11Info'):
                     display = os.environ.get('DISPLAY')
@@ -156,19 +148,24 @@ class View(object):
             return
 
         # check that arguments are dictionnaries
-        axes_kwargs = View.CheckDict(axes_kwargs)
-        plot_kwargs_default = View.CheckDict(plot_kwargs)
-        bar_kwargs_default = View.CheckDict(bar_kwargs)
-        pie_kwargs_default = View.CheckDict(pie_kwargs)
-        polygon_kwargs_default = View.CheckDict(polygon_kwargs)
-        contour_kwargs_default = View.CheckDict(contour_kwargs)
-        step_kwargs_default = View.CheckDict(step_kwargs)
-        clabel_kwargs_default = View.CheckDict(clabel_kwargs)
-        text_kwargs_default = View.CheckDict(text_kwargs)
-        legend_kwargs = View.CheckDict(legend_kwargs)
+        axes_kwargs = self.CheckDict(axes_kwargs)
+        plot_kwargs_default = self.CheckDict(plot_kwargs)
+        bar_kwargs_default = self.CheckDict(bar_kwargs)
+        pie_kwargs_default = self.CheckDict(pie_kwargs)
+        polygon_kwargs_default = self.CheckDict(polygon_kwargs)
+        polygoncollection_kwargs_default = self.CheckDict(
+            polygoncollection_kwargs)
+        contour_kwargs_default = self.CheckDict(contour_kwargs)
+        step_kwargs_default = self.CheckDict(step_kwargs)
+        clabel_kwargs_default = self.CheckDict(clabel_kwargs)
+        text_kwargs_default = self.CheckDict(text_kwargs)
+        legend_kwargs = self.CheckDict(legend_kwargs)
+
+        # set step drawstyle
+        step_kwargs_default.setdefault('where', 'post')
 
         # set title
-        axes_kwargs.setdefault('title', graph.getTitle())
+        axes_kwargs.setdefault('title', self.ToUnicode(graph.getTitle()))
 
         # set scale
         if (graph.getLogScale() == ot.GraphImplementation.LOGX) or (graph.getLogScale() == ot.GraphImplementation.LOGXY):
@@ -184,7 +181,10 @@ class View(object):
 
         # set figure
         if figure is None:
-            self._fig = pyplot.figure()
+            if len(axes) == 0:
+                self._fig = plt.figure()
+            else:
+                self._fig = axes[0].get_figure()
         else:
             self._fig = figure
             if len(axes) == 0:
@@ -196,13 +196,16 @@ class View(object):
         else:
             self._ax = axes
 
-        self._ax[0].grid()
+        has_labels = False
+        if graph.getGrid():
+            self._ax[0].grid()
         for drawable in drawables:
             # reset working dictionaries by excplicitely creating copies
             plot_kwargs = dict(plot_kwargs_default)
             bar_kwargs = dict(bar_kwargs_default)
             pie_kwargs = dict(pie_kwargs_default)
             polygon_kwargs = dict(polygon_kwargs_default)
+            polygoncollection_kwargs = dict(polygoncollection_kwargs_default)
             contour_kwargs = dict(contour_kwargs_default)
             step_kwargs = dict(step_kwargs_default)
             clabel_kwargs = dict(clabel_kwargs_default)
@@ -255,19 +258,18 @@ class View(object):
             if data.getDimension() > 1:
                 y = data.getMarginal(1)
 
-            # add legend, title
+            # add label, title
             drawableKind = drawable.getImplementation().getClassName()
             if drawableKind != 'Pie':
-                self._ax[0].set_xlabel(graph.getXTitle())
-                self._ax[0].set_ylabel(graph.getYTitle())
+                self._ax[0].set_xlabel(self.ToUnicode(graph.getXTitle()))
+                self._ax[0].set_ylabel(self.ToUnicode(graph.getYTitle()))
 
-                legend = '_nolegend_'
-                if len(drawable.getLegend()) > 0:
-                    legend = drawable.getLegend()
-
-                plot_kwargs.setdefault('label', legend)
-                bar_kwargs.setdefault('label', legend)
-                step_kwargs.setdefault('label', legend)
+                if (len(drawable.getLegend()) > 0) and ((drawableKind != 'Cloud') or (drawable.getPointStyle() != 'none')):
+                    label = self.ToUnicode(drawable.getLegend())
+                    has_labels = True
+                    plot_kwargs.setdefault('label', label)
+                    bar_kwargs.setdefault('label', label)
+                    step_kwargs.setdefault('label', label)
 
             if drawableKind == 'BarPlot':
                 # linestyle for bar() is different than the one for plot()
@@ -289,7 +291,7 @@ class View(object):
                     # items
                     if (i == 1) and ('label' in bar_kwargs):
                         bar_kwargs.pop('label')
-                    pyplot.bar(
+                    self._ax[0].bar(
                         xi, height=y[i][0], width=x[i][0], **bar_kwargs)
                     xi += x[i][0]
 
@@ -311,11 +313,30 @@ class View(object):
                 self._ax[0].add_patch(
                     matplotlib.patches.Polygon(data, **polygon_kwargs))
 
+            elif drawableKind == 'PolygonArray':
+
+                polygonsNumber = drawable.getPalette().getSize()
+                verticesNumber = drawable.getData().getSize() // polygonsNumber
+                colors = drawable.getPalette()
+                colorsRGBA = []
+                for i in range(polygonsNumber):
+                    rgba = drawable.ConvertToRGBA(colors[i])
+                    colorsRGBA.append(
+                        (rgba[0] / 255.0, rgba[1] / 255.0, rgba[2] / 255.0, rgba[3] / 255.0))
+                if (not 'facecolors' in polygoncollection_kwargs_default):
+                    polygoncollection_kwargs['facecolors'] = colorsRGBA
+
+                if (not 'edgecolors' in polygon_kwargs_default):
+                    polygoncollection_kwargs['edgecolors'] = colorsRGBA
+                self._ax[0].add_collection(
+                    matplotlib.collections.PolyCollection(np.array(data).reshape((polygonsNumber, verticesNumber, 2)), **polygoncollection_kwargs))
+
             elif drawableKind == 'Pie':
-                pie_kwargs.setdefault('labels', drawable.getLabels())
+                pie_kwargs.setdefault(
+                    'labels', list(map(self.ToUnicode, drawable.getLabels())))
                 pie_kwargs.setdefault('colors', drawable.getPalette())
                 self._ax[0].set_aspect('equal')
-                pyplot.pie(x, **pie_kwargs)
+                self._ax[0].pie(x, **pie_kwargs)
 
             elif drawableKind == 'Contour':
                 X, Y = np.meshgrid(drawable.getX(), drawable.getY())
@@ -329,14 +350,14 @@ class View(object):
                             drawable.getLineStyle()]
                     except:
                         warnings.warn('-- Unknown line style')
-                contourset = pyplot.contour(X, Y, Z, **contour_kwargs)
+                contourset = self._ax[0].contour(X, Y, Z, **contour_kwargs)
 
                 clabel_kwargs.setdefault('fontsize', 8)
                 clabel_kwargs.setdefault('fmt', '%g')
-                pyplot.clabel(contourset, **clabel_kwargs)
+                plt.clabel(contourset, **clabel_kwargs)
 
             elif drawableKind == 'Staircase':
-                pyplot.step(x, y, **step_kwargs)
+                self._ax[0].step(x, y, **step_kwargs)
 
             elif drawableKind == 'Pairs':
                 # disable axis : grid, ticks, axis
@@ -386,12 +407,18 @@ class View(object):
                     'Drawable type not implemented: ' + drawableKind)
 
         # Add legend
-        if (drawableKind != 'Pie') and (graph.getLegendPosition() != ''):
+        if add_legend and has_labels and (graph.getLegendPosition() != ''):
             # set legend position
             if not 'loc' in legend_kwargs:
                 try:
-                    legendPositionDict = {'bottomright': 'lower right', 'bottom': 'lower center', 'bottomleft': 'lower left', 'left':
-                                          'center left', 'topleft': 'upper left', 'topright': 'upper right', 'right': 'center right', 'center': 'center'}
+                    legendPositionDict = {'bottomright': 'lower right',
+                                          'bottom': 'lower center',
+                                          'bottomleft': 'lower left',
+                                          'left': 'center left',
+                                          'topleft': 'upper left',
+                                          'topright': 'upper right',
+                                          'right': 'center right',
+                                          'center': 'center'}
                     legend_kwargs['loc'] = legendPositionDict[
                         graph.getLegendPosition()]
                 except:
@@ -411,8 +438,6 @@ class View(object):
 
     def show(self, **kwargs):
         """
-        show(**kwargs)
-
         Display the graph on screen.
 
         Parameters
@@ -423,14 +448,11 @@ class View(object):
 
             These parameters are passed to matplotlib.pyplot.show()
         """
-
-        pyplot.show(**kwargs)
+        plt.show(**kwargs)
 
     def save(self, fname, **kwargs):
         """
-        save(fname, **kwargs)
-
-        Display the graph on screen.
+        Save the graph as file.
 
         Parameters
         ----------
@@ -440,13 +462,10 @@ class View(object):
         kwargs:
             Refer to matplotlib.figure.Figure.savefig documentation for valid keyword arguments.
         """
-
         self._fig.savefig(fname, **kwargs)
 
     def getFigure(self):
         """
-        getFigure()
-
         Accessor to the underlying figure object.
 
         Refer to matplotlib.figure.Figure for further information.
@@ -455,10 +474,43 @@ class View(object):
 
     def getAxes(self):
         """
-        getAxes()
-
-        Accessor to the list of Axes objects.
+        Get the list of Axes objects.
 
         Refer to matplotlib.axes.Axes for further information.
         """
         return self._ax
+
+    def close(self):
+        """Close the figure."""
+        plt.close(self._fig)
+
+
+def ToSVGString(graph):
+    """
+    Convert as SVG file.
+
+    Parameters
+    ----------
+    graph : object
+        A Graph or Drawable object.
+
+    Returns a SVG representation as string
+    """
+    if sys.version_info[0] >= 3:
+        output = io.StringIO()
+    else:
+        output = io.BytesIO()
+
+    # save interactive mode state
+    ision = plt.isinteractive()
+    plt.ioff()
+
+    view = View(graph)
+    view.save(output, format='svg')
+    view.close()
+
+    # restore interactive mode state
+    if ision:
+        plt.ion()
+
+    return output.getvalue()
