@@ -23,7 +23,8 @@ def printNumericalPoint(point, digits):
 TESTPREAMBLE()
 
 try:
-    levelFunction = NumericalMathFunction("TestOptimLinear")
+    levelFunction = NumericalMathFunction(
+        ["x1", "x2", "x3", "x4"], ["y1"], ["x1+2*x2-3*x3+4*x4"])
     # Add a finite difference gradient to the function, as Abdo Rackwitz algorithm
     # needs it
     myGradient = NonCenteredFiniteDifferenceGradient(
