@@ -8,7 +8,8 @@ try:
 
     try:
         # Test function operator ()
-        levelFunction = NumericalMathFunction("TestOptimLinear")
+        levelFunction = NumericalMathFunction(
+            ["x1", "x2", "x3", "x4"], ["y1"], ["x1+2*x2-3*x3+4*x4"])
         specific = AbdoRackwitzSpecificParameters()
         startingPoint = NumericalPoint(4, 1.0)
         myAlgorithm = AbdoRackwitz(specific, levelFunction)
