@@ -58,6 +58,8 @@ try:
     print "physical space design point=", printNumericalPoint(result.getPhysicalSpaceDesignPoint(), digits)
     print "is standard point origin in failure space? ", result.getIsStandardPointOriginInFailureSpace()
     print "importance factors=", printNumericalPoint(result.getImportanceFactors(), digits)
+    print "importance factors(classical)=", printNumericalPoint(result.getImportanceFactors(AnalyticalResult.CLASSICAL), digits)
+    print "importance factors(physical) =", printNumericalPoint(result.getImportanceFactors(AnalyticalResult.PHYSICAL), digits)
     print "Hasofer reliability index=%.5f" % result.getHasoferReliabilityIndex()
     print "graph importance factors=", result.drawImportanceFactors()
     print "graph sensitivity=", result.drawHasoferReliabilityIndexSensitivity()
