@@ -26,6 +26,11 @@ try:
     estimatedBurr = factory.buildAsBurr(distribution.getParametersCollection())
     print "Burr from parameters=", estimatedBurr
 
+    try:
+        estimatedBurr = BurrFactory().build(Normal(1e-3, 1e-5).getSample(100))
+        print 'Estimated burr=', estimatedBurr
+    except:
+        pass
 except:
     import sys
     print "t_BurrFactory_std.py", sys.exc_type, sys.exc_value
