@@ -24,7 +24,8 @@ def printNumericalPoint(point, digits):
 TESTPREAMBLE()
 
 try:
-    levelFunction = NumericalMathFunction("TestOptimLinear")
+    levelFunction = NumericalMathFunction(
+        ["x1", "x2", "x3", "x4"], ["y1"], ["x1+2*x2-3*x3+4*x4"])
     specific = CobylaSpecificParameters()
     startingPoint = NumericalPoint(4, 0.0)
     myAlgorithm = Cobyla(specific, levelFunction)
