@@ -1,9 +1,9 @@
 #! /usr/bin/env python
 
 from openturns import *
-from math import *
 
 TESTPREAMBLE()
+RandomGenerator.SetSeed(0)
 
 try:
     size = 100
@@ -11,16 +11,17 @@ try:
     x = xuniform.getSample(size)
     yuniform = Uniform(1.9, 2.1)
     y = yuniform.getSample(size)
-    f = NumericalMathFunction(
-        Description("x"), Description("y"), Description("2.0*x"))
-    basis = Basis()
-    basis.add(f)
+    f = NumericalMathFunction(['x'], ['y'], ['2.0*x'])
+    coll = []
+    coll.append(f)
+    basis = Basis(coll)
+    indices = range(len(coll))
 
     fittingAlgo = CorrectedLeaveOneOut()
 
     print "algo =", fittingAlgo
 
-    result = fittingAlgo.run(x, y, basis)
+    result = fittingAlgo.run(x, y, basis, indices)
 
     print "result = %g" % result
 
