@@ -67,3 +67,8 @@ print 'desc6[1:3] = ', desc6[1:3]
 print 'desc6[:] = ', desc6[:]
 desc6[1:3] = ('88', '99')
 print 'desc6 = ', desc6
+
+# unicode support
+desc7 = Description([u'forunicode', 'n2', u'n3'])
+desc7[1] = u'r2'
+print 'desc7 = ', desc7
