@@ -3,7 +3,7 @@
 from openturns import *
 
 TESTPREAMBLE()
-RandomGenerator().SetSeed(0)
+RandomGenerator.SetSeed(0)
 
 try:
 
@@ -33,7 +33,7 @@ try:
     output = RandomVector(myFunction, vect)
 
     # We create an Event from this RandomVector */
-    myEvent = Event(output, ComparisonOperator(Less()), -3)
+    myEvent = Event(output, Less(), -3)
 
 # TEST ONE : directional sampling from an event (slow and safe strategy by default)
     # We create a Directional Sampling algorithm */
