@@ -3,7 +3,7 @@
 from openturns import *
 
 TESTPREAMBLE()
-RandomGenerator().SetSeed(0)
+RandomGenerator.SetSeed(0)
 
 try:
     distribution = Dirichlet(NumericalPoint([0.2, 0.3, 0.4, 0.5]))
