@@ -3,7 +3,7 @@
 from openturns import *
 
 TESTPREAMBLE()
-RandomGenerator().SetSeed(0)
+RandomGenerator.SetSeed(0)
 
 try:
     # Instanciate one distribution object
@@ -12,9 +12,9 @@ try:
         for i in range(dim + 1):
             theta[i] = (i + 1.0) / 4.0
         distribution = Dirichlet(theta)
-        description = Description(dim)
+        description = [''] * dim
         for j in range(1, dim + 1):
-            oss = "Marginal " + str(j)
+            oss = 'Marginal ' + str(j)
             description[j - 1] = oss
         distribution.setDescription(description)
         print "Distribution ", repr(distribution)
@@ -39,7 +39,7 @@ try:
 
         if (dim == 1):
             size = 100
-            for i in range(5):
+            for i in range(2):
                 RandomGenerator.SetSeed(0)
                 msg = ''
                 if FittingTest.Kolmogorov(distribution.getSample(size), distribution).getBinaryQualityMeasure():
