@@ -4,6 +4,7 @@ from openturns import *
 from math import *
 
 TESTPREAMBLE()
+RandomGenerator.SetSeed(0)
 
 
 class UniformNdPy(PythonDistribution):
@@ -14,7 +15,7 @@ class UniformNdPy(PythonDistribution):
         self.b = b
 
     def getRange(self):
-        return [self.a, self.b, [True] * len(self.a), [True] * len(self.a)]
+        return Interval(self.a, self.b, [True] * len(self.a), [True] * len(self.a))
 
     def getRealization(self):
         X = []
