@@ -3,7 +3,7 @@
 from openturns import *
 
 TESTPREAMBLE()
-RandomGenerator().SetSeed(0)
+RandomGenerator.SetSeed(0)
 
 try:
     print "Named colors=", Drawable.GetValidColors()
