@@ -3,7 +3,7 @@
 from openturns import *
 
 TESTPREAMBLE()
-RandomGenerator().SetSeed(0)
+RandomGenerator.SetSeed(0)
 
 try:
 
@@ -28,14 +28,15 @@ try:
     print "vect sample =", repr(vect.getSample(5))
 
     # We create a numerical math function
-    myFunction = NumericalMathFunction("poutre")
+    myFunction = NumericalMathFunction(
+        ["E", "F", "L", "I"], ["d"], ["-F*L^3/(3*E*I)"])
 
     # We create a composite random vector
     output = RandomVector(myFunction, vect)
 
     # We create an Event from this RandomVector
 
-    myEvent = Event(output, ComparisonOperator(Less()), 50)
+    myEvent = Event(output, Less(), 50)
     print "myEvent=", repr(myEvent)
 
     # We compute one realization of the event
