@@ -3,7 +3,7 @@
 from openturns import *
 
 TESTPREAMBLE()
-RandomGenerator().SetSeed(0)
+RandomGenerator.SetSeed(0)
 
 
 aCollection = DistributionCollection(0)
@@ -31,7 +31,7 @@ moeNMF = NumericalMathFunction(moe)
 print "Mixture of experts=", moe
 
 # Evaluate the mixture of experts on some points
-for i in range(5):
+for i in range(2):
     p = NumericalPoint(1, -0.3 + 0.8 * i / 4.0)
     print "moe   ( %.6g )=" % p[0], moe(p)
     print "moeNMF( %.6g )=" % p[0], moeNMF(p)
