@@ -74,12 +74,12 @@ try:
 
         # We create a composite random vector
         output = RandomVector(myFunction, vect)
-        outputDescription = Description(dim)
+        outputDescription = Description(1)
         outputDescription[0] = "Interest Variable 1"
         output.setDescription(outputDescription)
 
         # We create an Event from this RandomVector
-        myEvent = Event(output, Greater(), 0.0, "Event 1")
+        myEvent = Event(output, Greater(), 0.0)
 
         # We create a NearestPoint algorithm
         myCobyla = Cobyla()
@@ -116,7 +116,6 @@ try:
 
         # Event Probability Sensitivity
         eventProbabilitySensitivity = result.getEventProbabilitySensitivity()
-        #    UnsignedLong digits(5)
         print "eventProbabilitySensitivity = ", repr(eventProbabilitySensitivity)
 
 except:
