@@ -52,8 +52,7 @@ try:
     listAdaptiveStrategy = list()
     degree = 6
     indexMax = enumerateFunction.getStrataCumulatedCardinal(degree)
-    basisDimension = enumerateFunction.getStrataCumulatedCardinal(
-        divmod(degree, 2)[0])
+    basisDimension = enumerateFunction.getStrataCumulatedCardinal(degree // 2)
     threshold = 1.0e-6
     listAdaptiveStrategy.append(
         CleaningStrategy(productBasis, indexMax, basisDimension, threshold, False))
@@ -62,7 +61,7 @@ try:
         FixedStrategy(productBasis, enumerateFunction.getStrataCumulatedCardinal(degree)))
     # Third, a slight enhancement with respect to the basic strategy
     listAdaptiveStrategy.append(
-        SequentialStrategy(productBasis, enumerateFunction.getStrataCumulatedCardinal(divmod(degree, 2)[0]), False))
+        SequentialStrategy(productBasis, enumerateFunction.getStrataCumulatedCardinal(degree // 2), False))
 
     for adaptiveStrategyIndex in range(len(listAdaptiveStrategy)):
         adaptiveStrategy = listAdaptiveStrategy[adaptiveStrategyIndex]
