@@ -11,8 +11,7 @@ try:
     myPlane = GaussProductExperiment(
         Distribution(distribution), marginalDegrees)
     print "myPlane = ", myPlane
-    weights = NumericalPoint(0)
-    sample = NumericalSample(myPlane.generate(weights))
+    sample, weights = myPlane.generateWithWeights()
     print "sample = ", repr(sample)
     print "weights = ", repr(weights)
 except:
