@@ -5,7 +5,7 @@ from math import *
 
 TESTPREAMBLE()
 
-try :
+try:
     def clean(inPoint):
         dim = inPoint.getDimension()
         for i in range(dim):
@@ -19,10 +19,10 @@ try :
     print "algo=", repr(algo)
     for i in range(iMax):
         print distribution.getClassName() + " polynomial(", i, ")=", clean(algo.getRecurrenceCoefficients(i))
-    algo.setReferenceFamily(OrthogonalUniVariatePolynomialFamily(LegendreFactory()))
+    algo.setReferenceFamily(
+        OrthogonalUniVariatePolynomialFamily(LegendreFactory()))
     print "Reference family=", algo.getReferenceFamily()
 
-except :
+except:
     import sys
     print "t_GramSchmidtAlgorithm_std.py", sys.exc_type, sys.exc_value
-
