@@ -3,6 +3,7 @@
 from openturns import *
 
 TESTPREAMBLE()
+RandomGenerator.SetSeed(0)
 
 try:
     distribution = Normal(4)
@@ -12,8 +13,7 @@ try:
     myPlane = ImportanceSamplingExperiment(
         distribution, weightingDistribution, size)
     print "myPlane = ", myPlane
-    weights = NumericalPoint(0)
-    sample = NumericalSample(myPlane.generate(weights))
+    sample, weights = myPlane.generateWithWeights()
     print "sample = ", repr(sample)
     print "weights = ", repr(weights)
 except:
