@@ -11,7 +11,7 @@ try:
         indices[i] = i
     print "indices=", repr(indices)
     print "are indices valid with bound=", size, "? ", indices.check(size)
-    print "are indices valid with bound=", divmod(size, 2)[0], "? ", indices.check(divmod(size, 2)[0])
+    print "are indices valid with bound=", size // 2, "? ", indices.check(size // 2)
     indices[0] = indices[size - 1]
     print "indices after transformation=", repr(indices)
     print "are indices valid with bound=", size, "? ", indices.check(size)
