@@ -1,9 +1,9 @@
 #! /usr/bin/env python
 
 from openturns import *
-from math import *
 
 TESTPREAMBLE()
+RandomGenerator.SetSeed(0)
 
 try:
     size = 100
@@ -14,12 +14,13 @@ try:
     f = NumericalMathFunction(['x'], ['y'], ['2.0*x'])
     basis = Basis()
     basis.add(f)
+    indices = range(basis.getSize())
 
     fittingAlgo = KFold()
 
     print "algo =", fittingAlgo
 
-    result = fittingAlgo.run(x, y, basis)
+    result = fittingAlgo.run(x, y, basis, indices)
 
     print "result = %g" % result
 
