@@ -9,7 +9,7 @@ def test_model(myModel):
 
     print "myModel = ",  myModel
 
-    dimension = myModel.getDimension()
+    dimension = myModel.getSpatialDimension()
 
     x1 = NumericalPoint(dimension)
     x2 = NumericalPoint(dimension)
@@ -19,13 +19,13 @@ def test_model(myModel):
 
     print "myModel(", x1, ", ", x2, ")=",  myModel(x1, x2)
 
-    grad = SymmetricTensor(myModel.partialGradient(x1, x2))
+    grad = myModel.partialGradient(x1, x2)
     print "dCov =", grad
 
     eps = 1e-5
     gradfd = NumericalPoint(dimension)
     for j in range(dimension):
-        x1_d = x1
+        x1_d = NumericalPoint(x1)
         x1_d[j] = x1_d[j] + eps
         gradfd[j] = (myModel(x1_d, x2)[0, 0] - myModel(x1, x2)[0, 0]) / eps
 
@@ -46,7 +46,7 @@ test_model(myModel)
 myDefautModel = GeneralizedExponential()
 print "myDefautModel = ",  myDefautModel
 
-myModel = GeneralizedExponential(dimension, 0.1, 1.5)
+myModel = GeneralizedExponential(dimension, 10.0, 1.5)
 test_model(myModel)
 
 myDefautModel = AbsoluteExponential()
