@@ -8,7 +8,7 @@ TESTPREAMBLE()
 sampleSize = 6
 dimension = 1
 
-f = NumericalMathFunction(['x0'], ['f0'], ['x0 * sin(x0)'])
+f = NumericalMathFunction(['x0'], ['y'], ['x0 * sin(x0)'])
 
 X = NumericalSample(sampleSize, dimension)
 X2 = NumericalSample(sampleSize, dimension)
@@ -19,12 +19,12 @@ X[0, 0] = 1.0
 X[1, 0] = 3.0
 X2[0, 0] = 2.0
 X2[1, 0] = 4.0
-Y = NumericalSample(f(X))
-Y2 = NumericalSample(f(X2))
+Y = f(X)
+Y2 = f(X2)
 
 # create algorithm
 basis = ConstantBasisFactory(dimension).build()
-covarianceModel = SquaredExponential(dimension)
+covarianceModel = SquaredExponential(dimension, 2.23606797749979)
 
 algo = KrigingAlgorithm(X, Y, basis, covarianceModel)
 
