@@ -3,12 +3,13 @@
 from openturns import *
 
 TESTPREAMBLE()
-RandomGenerator().SetSeed(0)
+RandomGenerator.SetSeed(0)
 
 try:
 
     # We create a numerical math function
-    myFunction = NumericalMathFunction("poutre")
+    myFunction = NumericalMathFunction(
+        ["E", "F", "L", "I"], ["d"], ["-F*L^3/(3*E*I)"])
 
     dim = myFunction.getInputDimension()
 
@@ -33,7 +34,7 @@ try:
     output = RandomVector(myFunction, vect)
 
     # We create an Event from this RandomVector
-    myEvent = Event(output, ComparisonOperator(Less()), -3)
+    myEvent = Event(output, Less(), -3)
 
     # We create a Monte Carlo algorithm
     myAlgo = LHS(myEvent)
