@@ -10,8 +10,7 @@ try:
     size = 10
     myPlane = LowDiscrepancyExperiment(HaltonSequence(), distribution, size)
     print "myPlane = ", myPlane
-    weights = NumericalPoint(0)
-    sample = NumericalSample(myPlane.generate(weights))
+    sample, weights = myPlane.generateWithWeights()
     print "sample = ", repr(sample)
     print "weights = ", repr(weights)
 except:
