@@ -10,8 +10,7 @@ try:
         print "meixner(", i, ")=", meixner.build(i)
     roots = meixner.getRoots(10)
     print "meixner(10) roots=", repr(roots)
-    weights = NumericalPoint()
-    nodes = meixner.getNodesAndWeights(10, weights)
+    nodes, weights = meixner.getNodesAndWeights(10)
     print "meixner(10) nodes=", nodes, "and weights=", weights
 except:
     import sys
