@@ -3,7 +3,7 @@
 from openturns import *
 
 TESTPREAMBLE()
-RandomGenerator().SetSeed(0)
+RandomGenerator.SetSeed(0)
 
 try:
     # Instanciate one distribution object
@@ -50,7 +50,7 @@ try:
     print "oneRealization=", repr(oneRealization)
 
     # Test for sampling
-    size = 10000
+    size = 1000
     oneSample = distribution.getSample(size)
     print "oneSample first=", repr(oneSample[0]), " last=", repr(oneSample[size - 1])
     print "mean=", repr(oneSample.computeMean())
