@@ -3,14 +3,14 @@
 from openturns import *
 
 TESTPREAMBLE()
+RandomGenerator.SetSeed(0)
 
 try:
     distribution = Normal(4)
     size = 10
     myPlane = MonteCarloExperiment(distribution, size)
     print "myPlane = ", myPlane
-    weights = NumericalPoint(0)
-    sample = NumericalSample(myPlane.generate(weights))
+    sample, weights = myPlane.generateWithWeights()
     print "sample = ", repr(sample)
     print "weights = ", repr(weights)
 except:
