@@ -53,8 +53,6 @@ try:
     # Draw the convergence graph
     convergenceGraph = myAlgo.drawProbabilityConvergence()
     convergenceGraph.draw("convergenceMonteCarlo", 640, 480)
-    print "bitmap=", convergenceGraph.getBitmap()
-    print "postscript=", convergenceGraph.getPostscript()
 
 except:
     import sys
