@@ -10,7 +10,8 @@ try:
     try:
         # Function
         sampleSize = 20
-        levelFunction = NumericalMathFunction("TestOptimLinear")
+        levelFunction = NumericalMathFunction(
+            ["x1", "x2", "x3", "x4"], ["y1"], ["x1+2*x2-3*x3+4*x4"])
         myOperator = LessOrEqual()
         threshold = 2.0
         mySample = NumericalSample(0, levelFunction.getInputDimension())
