@@ -12,8 +12,6 @@ try:
     graph = f.draw(-1.2, 1.2, 32)
     print "graph=", graph
     graph.draw("NMFDraw1D")
-    print "postscript=", graph.getPostscript()
-    print "bitmap=", graph.getBitmap()
 
     # Second, try 2D drawing
     f = NumericalMathFunction(
@@ -23,8 +21,6 @@ try:
                    NumericalPoint(2, 10.0), Indices(2, 21))
     print "graph=", graph
     graph.draw("NMFDraw2D")
-    print "postscript=", graph.getPostscript()
-    print "bitmap=", graph.getBitmap()
 
     # Full interfaces
     f = NumericalMathFunction(["x0", "x1", "x2"], ["y0", "y1"], [
@@ -34,16 +30,12 @@ try:
     graph1D = f.draw(0, 0, centralPoint, -5.0, 5.0, 32)
     print "graph1D=", graph1D
     graph1D.draw("NMFDraw1DFull")
-    print "postscript=", graph1D.getPostscript()
-    print "bitmap=", graph1D.getBitmap()
     # Second output as a function of second and third inputs around central
     # point
     graph2D = f.draw(1, 2, 1, centralPoint, NumericalPoint(
         2, -5.0), NumericalPoint(2, 5.0), Indices(2, 21))
     print "graph1D=", graph2D
     graph2D.draw("NMFDraw2DFull")
-    print "postscript=", graph2D.getPostscript()
-    print "bitmap=", graph2D.getBitmap()
 
 except:
     import sys
