@@ -12,22 +12,22 @@ try:
         inputSample[i, 0] = i
     outputSample = f(inputSample)
     print "Is history enabled for f? ", f.isHistoryEnabled()
-    print "input history=", f.getInputHistory()
-    print "output history=", f.getOutputHistory()
+    print "input history=", f.getHistoryInput()
+    print "output history=", f.getHistoryOutput()
     f.enableHistory()
     outputSample = f(inputSample)
     print "Is history enabled for f? ", f.isHistoryEnabled()
-    print "input history=", f.getInputHistory()
-    print "output history=", f.getOutputHistory()
+    print "input history=", f.getHistoryInput()
+    print "output history=", f.getHistoryOutput()
     f.clearHistory()
     print "Is history enabled for f? ", f.isHistoryEnabled()
-    print "input history=", f.getInputHistory()
-    print "output history=", f.getOutputHistory()
+    print "input history=", f.getHistoryInput()
+    print "output history=", f.getHistoryOutput()
     # Perform the computation twice
     outputSample = f(inputSample)
     outputSample = f(inputSample)
-    print "input history=", f.getInputHistory()
-    print "output history=", f.getOutputHistory()
+    print "input history=", f.getHistoryInput()
+    print "output history=", f.getHistoryOutput()
 
 except:
     import sys
