@@ -20,7 +20,7 @@ try:
 
     # Create indicator function
     indicator = NumericalMathFunction(
-        analytical, ComparisonOperator(Less()), 0.0)
+        analytical, Less(), 0.0)
     # Does it work?
     x = NumericalPoint(NumericalPoint(2, 1.0))
     value = analytical(x)[0]
