@@ -123,6 +123,28 @@ myFunc = PythonFunction(2, 1, func_sample=a_exec_sample)
 outSample = myFunc(a_sample)
 print(outSample)
 
+
+def a_grad(X):
+    # wrong but allows to verify
+    dY = [[1.], [-1.]]
+    return dY
+
+print('gradient')
+myFunc = PythonFunction(2, 1, a_exec, gradient=a_grad)
+grad = myFunc.gradient([100., 100.])
+print(grad)
+
+
+def a_hess(X):
+    # wrong but allows to verify
+    d2Y = [[[0.1], [0.3]], [[0.3], [0.1]]]
+    return d2Y
+
+print('hessian')
+myFunc = PythonFunction(2, 1, a_exec, hessian=a_hess)
+hess = myFunc.hessian([100., 100.])
+print(hess)
+
 print('no func')
 try:
     myFunc = PythonFunction(2, 1)
