@@ -7,7 +7,8 @@ TESTPREAMBLE()
 try:
 
     # Instance creation
-    myFunc = NumericalMathFunction("TestCompositionLeft")
+    myFunc = NumericalMathFunction(
+        ['x1', 'x2'], ['y1', 'y2', 'y3'], ['x1*sin(x2)', 'cos(x1+x2)', '(x2+1)*exp(x1-2*x2)'])
 
     # Copy constructor
     newFunc = NumericalMathFunction(myFunc)
