@@ -114,6 +114,20 @@ try:
     point8[1:3] = (88, 99)
     print 'point8 = ', point8
 
+    # equality
+    pt1 = NumericalPoint([1.1, 2.2, 3.3])
+    pt2 = NumericalPoint((1.1, 2.2, 3.3))
+    print "Equality ? ", (pt1 == pt2)
+
+    # non-regression for #754
+    pt = NumericalPoint([-3, -5, 6])
+    print 'pt = ', pt
+
+    # last
+    print 'pt[-1]=', pt[-1]
+    pt[-1] = 8.
+    print 'pt[-1]=', pt[-1]
+
 except:
     import traceback
     traceback.print_exc()
