@@ -3,7 +3,7 @@
 from openturns import *
 
 TESTPREAMBLE()
-RandomGenerator().SetSeed(0)
+RandomGenerator.SetSeed(0)
 
 try:
     # We create a distribution
@@ -30,7 +30,7 @@ try:
     print "vect realization=", repr(r)
     print "parameters value=", repr(p)
     distribution.setParametersCollection(p)
-    RandomGenerator().SetSeed(0)
+    RandomGenerator.SetSeed(0)
     # Generate a parameter set to put the random generator into the proper
     # state
     randomParameters.getRealization()
