@@ -4,7 +4,7 @@ from openturns import *
 
 TESTPREAMBLE()
 
-try :
+try:
 
     # We create a numerical point of dimension 4
     point = NumericalPoint(4)
@@ -15,22 +15,20 @@ try :
     point[2] = 103.
     point[3] = 104.
 
-    print  "point = " , repr(ref_point)
-
+    print "point = ", repr(ref_point)
 
     # We create a 'constant' RandomVector from the NumericalPoint
     vect = RandomVector(ConstantRandomVector(point))
-    print  "vect=" , vect
+    print "vect=", vect
 
     # Check standard methods of class RandomVector
-    print  "vect dimension=" , vect.getDimension()
-    print  "vect realization (first )=" , repr(vect.getRealization())
-    print  "vect realization (second)=" , repr(vect.getRealization())
-    print  "vect realization (third )=" , repr(vect.getRealization())
-    print  "vect sample =" , repr(vect.getNumericalSample(5))
+    print "vect dimension=", vect.getDimension()
+    print "vect realization (first )=", repr(vect.getRealization())
+    print "vect realization (second)=", repr(vect.getRealization())
+    print "vect realization (third )=", repr(vect.getRealization())
+    print "vect sample =", repr(vect.getSample(5))
 
-#except TestFailed, ex :
-except :
+# except TestFailed, ex :
+except:
     import sys
     print "t_RandomVector_constant.py", sys.exc_type, sys.exc_value
-
