@@ -27,7 +27,8 @@ TESTPREAMBLE()
 try:
 
     # We create a numerical math function
-    myFunction = NumericalMathFunction("poutre")
+    myFunction = NumericalMathFunction(
+        ["E", "F", "L", "I"], ["d"], ["-F*L^3/(3*E*I)"])
 
     dim = myFunction.getInputDimension()
 
@@ -52,7 +53,7 @@ try:
     output = RandomVector(myFunction, vect)
 
     # We create an Event from this RandomVector
-    myEvent = Event(output, ComparisonOperator(Less()), -1.5)
+    myEvent = Event(output, Less(), -1.5)
 
     # We create a NearestPoint algorithm
     myAbdoRackwitz = AbdoRackwitz()
