@@ -25,7 +25,8 @@ TESTPREAMBLE()
 try:
     try:
         # Test function operator ()
-        levelFunction = NumericalMathFunction("TestOptimLinear")
+        levelFunction = NumericalMathFunction(
+            ["x1", "x2", "x3", "x4"], ["y1"], ["x1+2*x2-3*x3+4*x4"])
         # Add a finite difference gradient to the function
         myGradient = NonCenteredFiniteDifferenceGradient(
             1e-7, levelFunction.getEvaluationImplementation())
