@@ -27,7 +27,8 @@ def printNumericalPoint(point, digits):
 try:
     try:
         # Test function operator ()
-        levelFunction = NumericalMathFunction("TestOptimNonLinear")
+        levelFunction = NumericalMathFunction(
+            ["x1", "x2", "x3", "x4"], ["y1"], ["x1*cos(x1)+2*x2*x3-3*x3+4*x3*x4"])
         # Add a finite difference gradient to the function,
         # needs it
         myGradient = NonCenteredFiniteDifferenceGradient(
