@@ -9,6 +9,7 @@ try:
 
     # Default dimension parameter to evaluate the model
     dimension = 1
+    spatialDimension = 1
 
     # Amplitude values
     amplitude = NumericalPoint(dimension, 1.0)
@@ -17,7 +18,7 @@ try:
     scale = NumericalPoint(dimension, 1.0)
 
     # Covariance model
-    myCovarianceModel = ExponentialModel(amplitude, scale)
+    myCovarianceModel = ExponentialModel(spatialDimension, amplitude, scale)
     print "myCovarianceModel = ", myCovarianceModel
 
     # Spectral model
@@ -40,7 +41,7 @@ try:
     # Discretize the process on a small time grid
     timeGrid = RegularGrid(0.0, 1.0, 11)
     print "discretized covariance over the time grid = ", timeGrid, " is "
-    print myModel.discretizeCovariance(timeGrid)
+    print myModel.discretize(timeGrid)
 
 except:
     import sys
