@@ -3,7 +3,7 @@
 from openturns import *
 
 TESTPREAMBLE()
-RandomGenerator().SetSeed(0)
+RandomGenerator.SetSeed(0)
 
 try:
     # Instanciate one distribution object
@@ -29,7 +29,7 @@ try:
     print "covariance=", repr(oneSample.computeCovariance())
 
     size = 100
-    for i in range(5):
+    for i in range(2):
         msg = ''
         if FittingTest.Kolmogorov(distribution.getSample(size), distribution).getBinaryQualityMeasure():
             msg = "accepted"
@@ -110,7 +110,7 @@ try:
     print "Standard representative=", distribution.getStandardRepresentative()
 
     # Specific to this distribution
-    beta = point.norm2()
+    beta = point.normSquare()
     densityGenerator = distribution.computeDensityGenerator(beta)
     print "density generator=%.6f" % densityGenerator
     print "pdf via density generator=%.6f" % EllipticalDistribution.computePDF(distribution, point)
