@@ -24,7 +24,8 @@ def printNumericalPoint(point, digits):
     return oss
 
 try:
-    levelFunction = NumericalMathFunction("TestOptimLinear")
+    levelFunction = NumericalMathFunction(
+        ["x1", "x2", "x3", "x4"], ["y1"], ["x1+2*x2-3*x3+4*x4"])
     specific = TNCSpecificParameters()
     startingPoint = NumericalPoint(4, 0.0)
     bounds = Interval(NumericalPoint(4, -3.0), NumericalPoint(4, 5.0))
