@@ -5,7 +5,8 @@ from openturns import *
 TESTPREAMBLE()
 
 try:
-    levelFunction = NumericalMathFunction("TestOptimLinear")
+    levelFunction = NumericalMathFunction(
+        ["x1", "x2", "x3", "x4"], ["y1"], ["x1+2*x2-3*x3+4*x4"])
     specific = TNCSpecificParameters()
     startingPoint = NumericalPoint(4, 1.0)
     bounds = Interval(NumericalPoint(4, -3.0), NumericalPoint(4, 5.0))
