@@ -5,7 +5,7 @@ from math import *
 
 TESTPREAMBLE()
 
-try :
+try:
     # Create an intance
     inputVars = Description(["t"])
     formula = Description(["sin(t)", "cos(t)"])
@@ -26,11 +26,13 @@ try :
         for j in range(data.getDimension()):
             data[i, j] = i * data.getDimension() + j
     ts = TimeSeries(tg, data)
-    print "input time series =  \n", ts
-    print "output time series = \n", myTrendFunc(ts)
+    print "input time series =  "
+    print ts
+    print "output time series = "
+    print myTrendFunc(ts)
     # Get the number of calls
     print "called ", myTrendFunc.getCallsNumber(), " times"
 
-except :
+except:
     import sys
     print "t_TrendTransform_std.py", sys.exc_type, sys.exc_value
