@@ -3,7 +3,7 @@
 from openturns import *
 
 TESTPREAMBLE()
-RandomGenerator().SetSeed(0)
+RandomGenerator.SetSeed(0)
 
 try:
 
@@ -29,7 +29,7 @@ try:
     print "covariance=", repr(oneSample.computeCovariance())
 
     size = 100
-    for i in range(5):
+    for i in range(2):
         msg = ''
         if FittingTest.Kolmogorov(distribution.getSample(size), distribution).getBinaryQualityMeasure():
             msg = "accepted"
