@@ -13,6 +13,7 @@ try:
 
     # Default dimension parameter to evaluate the model
     dimension = 1
+    spatialDimension = 1
 
     # Amplitude values
     amplitude = NumericalPoint(dimension)
@@ -26,7 +27,8 @@ try:
         scale[index] = (index + 1.0) / dimension
 
     # Sample a ExponentialModel
-    referenceModel = ExponentialModel(amplitude, scale, spatialCorrelation)
+    referenceModel = ExponentialModel(
+        spatialDimension, amplitude, scale, spatialCorrelation)
 
     size = 20
     timeGrid = RegularGrid(0.0, 0.1, size)
@@ -36,9 +38,9 @@ try:
     k = 0
     for i in range(timeGrid.getN()):
         t = timeGrid.getValue(i)
-        for j in range(i, timeGrid.getN()):
+        for j in range(i + 1):
             s = timeGrid.getValue(j)
-            covarianceCollection[k] = referenceModel.computeCovariance(t, s)
+            covarianceCollection[k] = referenceModel(t, s)
             k = k + 1
     # Create a UserDefinedCovarianceModel
     myModel = UserDefinedCovarianceModel(timeGrid, covarianceCollection)
@@ -50,7 +52,8 @@ try:
             s = timeGrid.getValue(j)
             # We look for cov(s,t) ==> when adding to the collection, we compute cov(t,s)
             # Because of symmetry, we check the right index computation
-            print "myModel =  %.12g" % myModel.computeCovariance(s, t)[0, 0], ", referenceModel=  %.12g" % referenceModel.computeCovariance(s, t)[0, 0]
+            print "myModel =  %.6g" % myModel(s, t)[0, 0], ", referenceModel=  %.6g" % referenceModel(s, t)[0, 0]
+    print "myModel.discretize()=", myModel.discretize(timeGrid)
 
 except:
     import sys
