@@ -13,6 +13,7 @@ try:
 
     # Default dimension parameter to evaluate the model
     dimension = 1
+    spatialDimension = 1
 
     # Amplitude values
     amplitude = NumericalPoint(dimension)
@@ -26,8 +27,10 @@ try:
         scale[index] = (index + 1.0) / dimension
 
     # Sample a ExponentialModel
-    referenceModel = ExponentialModel(amplitude, scale, spatialCorrelation)
+    referenceModel = ExponentialModel(
+        spatialDimension, amplitude, scale, spatialCorrelation)
 
+    print "reference model=", referenceModel
     size = 100
     timeGrid = RegularGrid(0.0, 0.1, size)
     covarianceCollection = CovarianceMatrixCollection(size)
@@ -44,7 +47,7 @@ try:
         t = timeGrid.getValue(i)
         # We look for cov(s,t) ==> when adding to the collection, we compute cov(t,s)
         # Because of symmetry, we check the right index computation
-        print "myModel =  %.12g" % myModel(t)[0, 0], ", referenceModel=  %.12g" % referenceModel(t)[0, 0]
+        print "t= %.6g" % t, "myModel =  %.6g" % myModel(t)[0, 0], ", referenceModel=  %.6g" % referenceModel(t)[0, 0]
 
 except:
     import sys
