@@ -9,18 +9,16 @@ import openturns as ot
 
 # Curve
 graph = ot.Normal().drawCDF()
-width = 640
-height = 480
-#graph.draw('curve1', width, height, ot.GraphImplementation.PNG)
+# graph.draw('curve1.png')
 view = View(graph, plot_kwargs={'color': 'blue'})
-#view.save('curve1.png', dpi=fdpi)
+# view.save('curve1.png')
 view.show(block=False)
 
 # Contour
 graph = ot.Normal([1, 2], [3, 5], ot.CorrelationMatrix(2)).drawPDF()
-#graph.draw('curve2', width, height, ot.GraphImplementation.PNG)
+# graph.draw('curve2.png')
 view = View(graph)
-#view.save('curve2.png', dpi=fdpi)
+# view.save('curve2.png')
 view.show(block=False)
 
 # Histogram tests
@@ -28,9 +26,9 @@ normal = ot.Normal(1)
 size = 100
 sample = normal.getSample(size)
 graph = ot.VisualTest.DrawHistogram(sample, 10)
-#graph.draw('curve3', width, height, ot.GraphImplementation.PNG)
+# graph.draw('curve3.png')
 view = View(graph)
-#view.save('curve3.png', dpi=fdpi)
+# view.save('curve3.png')
 view.show(block=False)
 
 # QQPlot tests
@@ -39,9 +37,9 @@ normal = ot.Normal(1)
 sample = normal.getSample(size)
 sample2 = ot.Gamma(3.0, 4.0, 0.0).getSample(size)
 graph = ot.VisualTest.DrawQQplot(sample, sample2, 100)
-#graph.draw('curve4', width, height, ot.GraphImplementation.PNG)
+# graph.draw('curve4.png.png')
 view = View(graph)
-#view.save('curve4.png', dpi=fdpi)
+# view.save('curve4.png')
 view.show()
 
 # Clouds tests
@@ -58,10 +56,10 @@ for i in range(size):
     firstSample[i] = ot.NumericalPoint(1, sample2D[i, 0])
     secondSample[i] = ot.NumericalPoint(1, sample2D[i, 1])
 graph = ot.VisualTest.DrawClouds(
-    sample2D, ot.Normal(ot.NumericalPoint(dimension, 2.0), ot.NumericalPoint(dimension, 3.0), R).getSample(divmod(size, 2)[0]))
-#graph.draw('curve5', width, height, ot.GraphImplementation.PNG)
+    sample2D, ot.Normal(ot.NumericalPoint(dimension, 2.0), ot.NumericalPoint(dimension, 3.0), R).getSample(size // 2))
+# graph.draw('curve5.png')
 view = View(graph)
-#view.save('curve5.png', dpi=fdpi)
+# view.save('curve5.png')
 view.show(block=False)
 
 # CobWeb tests
@@ -78,25 +76,25 @@ model = ot.NumericalMathFunction(inputVar, ['y'], [expression])
 outputSample = model(inputSample)
 graph = ot.VisualTest.DrawCobWeb(
     inputSample, outputSample, 2.5, 3.0, "red", False)
-#graph.draw('curve6', width, height, ot.GraphImplementation.PNG)
+# graph.draw('curve6.png')
 view = View(graph, legend_kwargs={'loc': 'lower center'})
-#view.save('curve6.png', dpi=fdpi)
+# view.save('curve6.png')
 view.show(block=False)
 
 # Staircase
 distribution = ot.Poisson(10.0)
 graph = distribution.drawCDF()
-#graph.draw('curve7', width, height, ot.GraphImplementation.PNG)
+# graph.draw('curve7.png')
 view = View(graph)
-#view.save('curve7.png', dpi=fdpi)
+# view.save('curve7.png')
 view.show(block=False)
 
 # Pie
 graph = ot.SensitivityAnalysis.DrawImportanceFactors(
     [.4, .3, .2, .1], ['a0', 'a1', 'a2', 'a3'], 'Zou')
-#graph.draw('curve8', width, height, ot.GraphImplementation.PNG)
+# graph.draw('curve8.png')
 view = View(graph)
-#view.save('curve8.png', dpi=fdpi)
+# view.save('curve8.png')
 view.show()
 
 # Pairs
@@ -114,9 +112,9 @@ labels = list(map(lambda i: 'x' + str(i), range(dim)))
 myPairs = ot.Pairs(sample, 'Pairs example',
                    labels, 'green', 'bullet')
 graph.add(myPairs)
-#graph.draw('curve9', width, height, ot.GraphImplementation.PNG)
+# graph.draw('curve9.png')
 view = View(graph)
-#view.save('curve9.png', dpi=fdpi)
+# view.save('curve9.png')
 view.show(block=False)
 
 # Convergence graph curve
@@ -133,6 +131,33 @@ myAlgo.setMaximumCoefficientOfVariation(0.05)
 myAlgo.setMaximumOuterSampling(int(1e5))
 myAlgo.run()
 graph = myAlgo.drawProbabilityConvergence()
+# graph.draw('curve10.png')
 view = View(graph)
-#view.save('curve10.png', dpi=fdpi)
+# view.save('curve10.png')
+view.show(block=False)
+
+
+# Polygon
+size = 50
+cursor = [0.] * 2
+data1 = ot.NumericalSample(size, 2)  # polygon y = 2x for x in [-25]
+data2 = ot.NumericalSample(size, 2)  # polygon y = x*x for x in [-11]
+for i in range(size):
+    tmp = 7. * i / size + 2
+    cursor[0] = tmp
+    cursor[1] = 2 * tmp
+    data1[i] = cursor
+    tmp = 9. * i / size + 1
+    cursor[0] = tmp
+    cursor[1] = tmp * tmp
+    data2[i] = cursor
+graph = ot.Graph('Some polygons', 'x1', 'x2', True, 'topright', 1.0)
+myPolygon1 = ot.Polygon(data1)
+myPolygon1.setColor('blue')
+graph.add(myPolygon1)
+myPolygon2 = ot.Polygon(data2)
+myPolygon2.setColor('red')
+# graph.draw('curve11.png')
+view = View(graph)
+# view.save('curve11.png')
 view.show()
