@@ -4,7 +4,7 @@ from openturns import *
 from math import *
 
 TESTPREAMBLE()
-RandomGenerator().SetSeed(0)
+RandomGenerator.SetSeed(0)
 
 
 def cleanScalar(inScalar):
@@ -59,13 +59,13 @@ try:
 
     output = RandomVector(EtatLimite, vect)
 
-    myEvent = Event(output, ComparisonOperator(Less()), 0.0)
+    myEvent = Event(output, Less(), 0.0)
 
     #
     # Autres parametres
     #
 
-    RandomGenerator().SetSeed(0)
+    RandomGenerator.SetSeed(0)
 
     #
     # Calculs
