@@ -15,7 +15,7 @@ def cleanScalar(inScalar):
 # initialize the random generator
 #
 
-RandomGenerator().SetSeed(0)
+RandomGenerator.SetSeed(0)
 
 try:
 
@@ -62,7 +62,7 @@ try:
 
     output = RandomVector(limitState, vect)
 
-    myEvent = Event(output, ComparisonOperator(Less()), 0.0)
+    myEvent = Event(output, Less(), 0.0)
 
     #
     # Computation
