@@ -47,13 +47,7 @@ try:
         "userPrefix_": "GenericWrapperTest",
     }
 
-    # Framework
-    framework = {"studyid_": 1,
-                 "studycase_": "Case1",
-                 "componentname_": "Component1"
-                 }
-
-    wrp = makeWrapper(vars, files, params, framework)
+    wrp = makeWrapper(vars, files, params)
 
     # print wrp
 
