@@ -20,7 +20,7 @@ try:
 
     # Show the content
     # replace dll suffix on windows
-    libraryPath = data.getLibraryPath().replace("-0.dll", ".so")
+    libraryPath = data.getLibraryPath().replace(".dll", ".so")
     print "library path =", libraryPath
     print "function =", repr(data.getFunctionDescription())
     print "gradient =", repr(data.getGradientDescription())
@@ -65,7 +65,7 @@ try:
     # write it out to disk
     if (data.isValid()):
         wrapper.setWrapperData(data)
-        print "data =", data.__repr__().replace("-0.dll", ".so")
+        print "data =", data.__repr__().replace(".dll", ".so")
         wrapper.writeFile("wrp.xml")
 
     deviation = NumericalMathFunction(wrapper)
