@@ -3,7 +3,7 @@
 from openturns import *
 
 TESTPREAMBLE()
-RandomGenerator().SetSeed(0)
+RandomGenerator.SetSeed(0)
 
 try:
     # Instanciate one distribution object
@@ -32,7 +32,7 @@ try:
     print "covariance=", repr(oneSample.computeCovariance())
 
     ## size = 100;
-    # for i in range(5):
+    # for i in range(2):
     ##     msg = ''
     # if FittingTest::ChiSquared(distribution.getSample(size), distribution).getBinaryQualityMeasure():
     ##         msg = "accepted"
