@@ -13,7 +13,7 @@ parsed = '# ooo\nE=1.6\nE1=1.6\nFE1=5#oo\nZ=66\n# ooo\n'
 # how many Mo for perf file
 #howbig = 3024
 howbig = 256
-max_time = divmod(howbig, 5)[0]
+max_time = howbig // 5
 # enable it manually, see #600
 max_time = sys.maxint
 
